<?php
namespace Topalis\ActiveSyncFilter\Cache;

use Topalis\ConfigGroup\Entity\ConfigGroup;
use Topalis\ActiveSyncFilter\Entity\AsfCacheEntityManager;

/**
 * This class class gives basic access to the cache of the Filter Server.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class AsfCacheManager
{
    /**
     *
     * @var \Topalis\ActiveSyncFilter\Entity\AsfCacheEntityManager
     */
    private $entityManager;

    public function __construct(AsfCacheEntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    /**
     * @return \Topalis\ActiveSyncFilter\Entity\AsfCacheEntityManager
     */
    private function getEntityManager()
    {
        return $this->entityManager;
    }

    /**
     * Clears the cache for the specified group. If no group is given the cache
     * is completely cleard.
     *
     * @param ConfigGroup $group
     */
    public function clear(ConfigGroup $group = null)
    {
        $qb = $this->getEntityManager()->createQueryBuilder("c")->delete();
        if ($group) {
            $qb->where("c.configId = :configId")
                ->setParameter("configId", $group->getId());
        }
        $qb->getQuery()->execute();
    }

    /**
     * @param ConfigGroup $group
     * @return int The number of entries in the cache for the specified group,
     *    or the complete numer of entries if no group is specified.
     */
    public function count(ConfigGroup $group = null)
    {
        if ($group) {
            return $this->getEntityManager()->count("entity.configId = :configId",
                array("configId" => $group->getId()));
        }

        return $this->getEntityManager()->count();
    }

    /**
     *
     * @param ConfigGroup $group
     * @return int The number of bytes of the cached files for the specified
     *     group, or the complete number of bytes if no group is specified.
     */
    public function size(ConfigGroup $group = null)
    {
        $qb = $this->getEntityManager()->createQueryBuilder("c")->select("SUM(c.outSize)");
        if ($group) {
            $qb->where("c.configId = :configId")
                ->setParameter("configId", $group->getId());
        }

        return $qb->getQuery()->getSingleScalarResult() + 0;
    }
}
