<?php
namespace Topalis\ActiveSyncFilter\Config\Form;

use Topalis\ActiveSyncFilter\Plugin\Plugin;
use Topalis\ActiveSyncFilter\Plugin\PluginManager;
use Topalis\ConfigGroup\Entity\ConfigGroup;

/**
 * Class for storing plugin config filled by forms
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class FormPluginConfig
{
    /**
     * @var integer
     */
    protected $configId;

    /**
     * @var PluginManager
     */
    protected $pluginManager;

    /**
     * @var Plugin
     */
    protected $plugin;

    /**
     * @var boolean
     */
    protected $enabled;

    /**
     * @var array[FormConfigEntry]
     */
    protected $configEntries = array();

    /**
     *
     * @param Plugin $plugin
     * @param ConfigGroup $config The configuration to access.
     */
    public function __construct(Plugin $plugin, ConfigGroup $config)
    {
        $this->pluginManager = $plugin->getPluginManager();
        $this->plugin = $plugin;
        $this->config = $config;
        $this->init();
    }

    protected function init()
    {
        $this->setEnabled($this->pluginManager->isEnabled($this->config, $this->plugin->getKey()));
        $entries = $this->plugin->getConfig($this->config)->getEntries();

        $entryList = array();
        foreach ($entries as $entry) {
            $entry = new FormConfigEntry($entry);
            $entryList[$entry->getId()] = $entry;
        }

        $this->setConfigEntries($entryList);
    }

    public function save()
    {
        foreach ($this->getConfigEntries() as $entry) {
            $entry->save();
        }
    }

    public function getLabel()
    {
        return $this->plugin->getName();
    }

    public function getKey()
    {
        return $this->plugin->getKey();
    }

    /**
     * @param boolean $enabled
     *
     * @return $this
     */
    public function setEnabled($enabled)
    {
        $this->enabled = $enabled == 1;

        return $this;
    }

    /**
     * @return boolean
     */
    public function isEnabled()
    {
        return $this->enabled;
    }

    /**
     * @param array $configEntries
     *
     * @return $this
     */
    public function setConfigEntries(array $configEntries)
    {
        $this->configEntries = $configEntries;

        return $this;
    }

    /**
     * @return array
     */
    public function getConfigEntries()
    {
        return $this->configEntries;
    }
}
