<?php
namespace Topalis\ActiveSyncFilter\Config;

use Topalis\Util\StringUtil;
use Topalis\Configuration\Configuration;

/**
 * This class provides information about the roaming status of an user.
 * Note: if there's no system to fill the database with this information you
 * won't get useful information.
 *
 * @author Dominic Tubach
 */
class UserRoamingConfig
{
    private $config;

    /**
     * Constructor.
     *
     * @param Configuration $config The configuration that allows to access the
     *         roaming status.
     */
    public function __construct(Configuration $config)
    {
        $this->config = $config;
    }

    /**
     * @param string $user The user to get the roaming status for.
     * @return boolean true if the specified user is in roaming, false otherwise.
     */
    public function isUserRoaming($user)
    {
        return StringUtil::strtobool($this->config->getProperty($user, "false"));
    }

    /**
     * Sets the roaming status of the specified user.
     *
     * @param string $user The user to set the roaming status for.
     * @param boolean $enabled true to set the roaming status to true, false
     *         otherwise.
     */
    public function setUserRoaming($user, $enabled)
    {
        $this->config->setProperty($user, StringUtil::booltostr($enabled));
    }
}
