<?php
namespace Topalis\ActiveSyncFilter\Controller;

use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Topalis\ActiveSyncFilter\Config\Form\FormConfig;
use Topalis\ActiveSyncFilter\Form\ASFConfigForm;
use Topalis\ConfigGroup\Entity\ConfigGroup;
use Topalis\Kernel\Controller;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @Route("/admin/group/{group}/section/traffic-control", service="asf.config_group.controller")
 */
class ConfigGroupController extends Controller
{
    /**
     * @Route("", name="admin_group_section_asf")
     * @Template()
     * @param ConfigGroup $group
     *
     * @return array|\Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function indexAction(ConfigGroup $group)
    {
        $asfAllowed = $this->getLicense()->isASFAllowed();
        $request = $this->getRequest();
        $formBuilder = $this->getFormFactory()->createBuilder(new ASFConfigForm());

        if (!$asfAllowed) {
            $formBuilder->setDisabled(true);
        }

        $form = $formBuilder->getForm();

        $filterServer = $this->getFilterServer();
        $config = new FormConfig(
            $filterServer,
            $group
        );

        $form->setData($config);

        if ($request->isMethod("POST") && $asfAllowed) {
            $form->submit($request);
            if ($form->isValid()) {
                $config->save();
                $this->addSuccess($this->tr("admin.group.saveSuccess"));

                return $this->redirect(
                    $this->generateUrl("admin_group_section_asf",  array("group" => $group->getId()))
                );
            }
        }

        return array(
            "group"      => $group,
            "form"       => $form->createView(),
            "asfAllowed" => $asfAllowed
        );
    }

    /**
     * @Route("/revert", name="admin_asf_revert")
     * @param ConfigGroup $group
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function revertAction(ConfigGroup $group)
    {
        if (!$this->getLicense()->isASFAllowed()) {
            return $this->redirect();
        }
        try {
            $filterServer = $this->getFilterServer();
            $plugins = $filterServer->getPluginManager()->getPlugins();
            foreach ($plugins as $plugin) {
                /** @var $plugin Plugin */
                $plugin->getConfig($group)->revert();
            }
        } catch (\Exception $e) {
            $this->getLogger()->error("Error reverting config of TrafficControl plugins", array("exception" => $e));
            $msg = $this->tr("admin.asf.error.revertPluginConfig", array("%errmsg%" => $e->getMessage()));
            $this->addError($msg);
        }

        return $this->redirect(
            $this->generateUrl("admin_group_section_asf",
                array("group" => $group->getId(), "section" => "traffic_control"))
        );
    }

    /**
     * @return \Topalis\ActiveSyncFilter\FilterServer
     */
    private function getFilterServer()
    {
        return $this->container->get("asf.filter_server");
    }
}
