<?php
namespace Topalis\ActiveSyncFilter\DependencyInjection;

use Symfony\Component\Config\FileLocator;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Extension\Extension;
use Symfony\Component\DependencyInjection\Loader\YamlFileLoader;
use Topalis\ActiveSyncFilter\Util\JdbcUrlConverter;

/**
 *
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class TopalisAsfExtension extends Extension
{
    public function load(array $configs, ContainerBuilder $container)
    {
        $configuration = $this->getConfiguration($configs, $container);
        $config = $this->processConfiguration($configuration, $configs);

        if (!$container->hasParameter("asf.config_file")) {
            $container->setParameter("asf.config_file", $config['config_file']);
        }
        $container->setParameter("asf.service_command", $config['service_command']);
        $container->setParameter("asf.libwbxml_file", $config['libwbxml_file']);

        $loader = new YamlFileLoader($container, new FileLocator(__DIR__."/../Resources/config"));
        $loader->load("services.yml");

        if (!$container->hasParameter("asf.database_configured")
            || !$container->getParameter("asf.database_configured")) {
            $config = $container->get("asf.server_config");
            $dbConfig = JdbcUrlConverter::toArray($config->getJdbcUrl());
            $dbConfig['user'] = $config->getJdbcUser();
            $dbConfig['password'] = $config->getJdbcPassword();
            $container->setParameter("asf.database_driver", "pdo_mysql");
            $container->setParameter("asf.database_host", $dbConfig['host']);
            $container->setParameter("asf.database_port", $dbConfig['port']);
            $container->setParameter("asf.database_name", $dbConfig['database']);
            $container->setParameter("asf.database_user", $dbConfig['user']);
            $container->setParameter("asf.database_password", $dbConfig['password']);
        }

        $loader->load("form.yml");
    }
}
