<?php
namespace Topalis\ActiveSyncFilter\Form\Extension\EventListener;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\Form\FormFactoryInterface;
use Topalis\ActiveSyncFilter\Form\Extension\Type\ConfigEntryType;

/**
 * Dynamically add plugin fields
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class PluginEventListener implements EventSubscriberInterface
{
    /**
     * @var FormFactoryInterface
     */
    protected $factory;

    public function __construct(FormFactoryInterface $factory)
    {
        $this->factory = $factory;
    }

    public static function getSubscribedEvents()
    {
        return array(
            FormEvents::PRE_SET_DATA => "setData"
        );
    }

    public function setData(FormEvent $event)
    {
        $form = $event->getForm();
        /** @var $data FormPluginConfig */
        $data = $event->getData();

        $form->add($this->factory->createNamed("enabled", "checkbox", null, array(
            "label" => $data->getLabel(),
            "required" => false,
            "auto_initialize" => false
        )));

        $builder = $this->factory->createNamedBuilder("configEntries", "collection", null, array(
            "type" => new ConfigEntryType(),
            "auto_initialize" => false
        ));
        $builder
            ->addEventSubscriber(new ConfigKeyFixListener())
        ;

        $form->add($builder->getForm());

    }
}
