<?php
namespace Topalis\ActiveSyncFilter\Form\Extension\Transformer;

use Symfony\Component\Form\DataTransformerInterface;
use Symfony\Component\Form\Exception\UnexpectedTypeException;

/**
 * Transform mime type array to textarea list
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class MimeTypeTransformer implements DataTransformerInterface
{
    public function transform($value)
    {
        if (null === $value) {
            return null;
        }

        if (!is_array($value)) {
            throw new UnexpectedTypeException($value, "array");
        }

        $removeMimeTypes = array();
        $excludeMimeTypes = array();

        foreach ($value as $mimeType => $remove) {
            if ($remove) {
                $removeMimeTypes[] = $mimeType;
            } else {
                $excludeMimeTypes[] = $mimeType;
            }
        }

        return array(
            "remove" => implode("\n", $removeMimeTypes),
            "exclude" => implode("\n", $excludeMimeTypes)
        );

    }

    public function reverseTransform($value)
    {
        if (null == $value) {
            return null;
        }

        if (!is_array($value)) {
            throw new UnexpectedTypeException($value, "array");
        }

        $removeMimeTypes = isset($value['remove']) ?
            array_unique(preg_split("/\s+/", $value['remove'])) : array();
        $excludeMimeTypes = isset($value['exclude']) ?
            array_unique(preg_split("/\s+/", $value['exclude'])) : array();

        $mimeTypes = array();

        foreach ($removeMimeTypes as $mimeType) {
            $mimeTypes[$mimeType] = true;
        }
        foreach ($excludeMimeTypes as $mimeType) {
            $mimeTypes[$mimeType] = false;
        }

        return $mimeTypes;
    }
}
