<?php
namespace Topalis\ActiveSyncFilter\Plugin;

/**
 * Implemantation of {@link PluginConfigMetaInterface}.
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class PluginConfigMeta implements PluginConfigMetaInterface
{

    /**
     *
     * @var PluginConfigEntryMetaInterface[]
     */
    private $entries = array();

    /**
     * @var Plugin
     */
    private $plugin;

    /**
     * Constructor.
     *
     * @param \SimpleXmlElement $configXml the {@link \SimpleXMLElement}
     *   containing the description of the configuration entries.
     * @param Plugin $plugin The plugin this configuration belongs to.
     */
    public function __construct(\SimpleXMLElement $configXml, Plugin $plugin)
    {
        $this->plugin = $plugin;
        foreach ($configXml->entry as $entry) {
            $configEntry = new PluginConfigEntryMeta($entry, $plugin);
            $this->entries[$configEntry->getKey()] = $configEntry;
        }
    }

    public function containsEntry($key)
    {
        return array_key_exists($key, $this->entries);
    }

    public function getEntries()
    {
        return $this->entries;
    }

    public function getEntry($key)
    {
        return $this->containsEntry($key) ? $this->entries[$key] : null;
    }

    public function getPlugin()
    {
        return $this->plugin;
    }
}
