<?php
namespace Topalis\ActiveSyncFilter\Util;

/**
 * This class represents a mime type (<code>media type/sub type</code>).
 *
 * @author Dominic Tubach
 */
class MimeType
{
    public $mediaType;
    public $subType;

    /**
     * Creates an object of this class for the specified mime type.
     * @param string $mimeTypeStr the mime type to be converted.
     * @return boolean|MimeType The created object or false if the specified
     *         string is not a mime type (e.g. it does not have the form
     *         <code>media type/sub type</code>).
     */
    public static function fromString($mimeTypeStr)
    {
        $split = explode("/", $mimeTypeStr);
        if (count($split) != 2) {
            return false;
        }
        $mediaType = $split[0];
        $subType = $split[1];
        if (empty($mediaType) || empty($subType)) {
            return false;
        }
        return new MimeType($mediaType, $subType);
    }

    /**
     * Constructor.
     * @param string $mediaType the media type.
     * @param string $subType the sub type.
     */
    public function __construct($mediaType, $subType)
    {
        $this->mediaType = $mediaType;
        $this->subType = $subType;
    }

    /**
     * @return string Returns a string in the form
     * <code>media type/sub type</code>
     */
    public function __toString()
    {
        return $this->mediaType . "/" . $this->subType;
    }

    /**
     * @param MimeType $other the mime type to compare.
     * @return boolean true if the specified mime type equals this mime type,array
     *         false otherwise.
     */
    public function equals(MimeType $other)
    {
        return $this->mediaType == $other->mediaType && $this->subType == $other->subType;
    }

    /**
     * @param MimeType $other the mime type to be matched.
     * @return boolean true if this mime type matches the specified mime type.
     *         This method considers possible wildcards ("*") for sub type and
     *         media type.
     */
    public function match(MimeType $other)
    {
        if ($this->equals($other)) {
            return true;
        }

        if ($this->subType == "*" && $this->mediaType == $other->mediaType) {
            return true;
        }

        return $this->mediaType == "*";
    }
}
