<?php
namespace Topalis\ActiveSyncFilter\Validator;

use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;
use Symfony\Component\Validator\Exception\UnexpectedTypeException;
use Topalis\ActiveSyncFilter\Util\MimeType as MimeTypeUtil;

/**
 * Validates mime types
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class MimeTypeValidator extends ConstraintValidator
{
    public function validate($value, Constraint $constraint)
    {
        /** @var $constraint MimeType */
        if (null === $value || '' === $value) {
            return;
        }

        if (!is_array($value)) {
            throw new UnexpectedTypeException($value, 'array');
        }

        foreach ($value as $mimeTypeString => $remove) {
            $mimeType = MimeTypeUtil::fromString($mimeTypeString);
            if ($mimeType) {
                continue;
            }
            $path = "remove";
            if (!$remove) {
                $path = "exclude";
            }
            $this->context->addViolationAt(
                $path,
                $constraint->message,
                array("%mimeType%" => $mimeTypeString),
                $mimeTypeString
            );
        }
    }

}
