<?php
namespace Topalis\Admin\Controller;

use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Form\FormError;
use Topalis\Kernel\Controller;
use Topalis\Admin\Entity\Admin;
use Topalis\Admin\Form\AdminForm;

use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;

/**
 *
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 *
 * @Route("/admin/admin", service="admin.controller")
 */
class AdminController extends Controller
{
    /**
     * @return \Topalis\Admin\Entity\AdminEntityManager
     */
    private function getAdminEntityManager()
    {
        return $this->container->get("admin.entity.manager.admin");
    }

    /**
     * @return \Topalis\Admin\AdminManager
     */
    private function getAdminManager()
    {
        return $this->container->get("admin.manager");
    }

    /**
     * @Route("", name="admin_admin")
     * @Template()
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function indexAction()
    {
        return array(
            "admins" => $this->getAdminManager()->getAdmins("login")
        );
    }

    /**
     * @Route("/add", name="admin_admin_add", options={"expose" = true})
     * @Template()
     * @return string|\Symfony\Component\HttpFoundation\Response
     */
    public function addAction()
    {
        $admin = new Admin();

        return $this->forward("admin.controller:editAction", array("admin" => $admin));
    }

    /**
     * @Route("/{id}/delete", name="admin_admin_delete")
     *
     * @param integer $id
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function deleteAction($id)
    {
        try {
            if ($id == 0) {
                $msg = "Deleting the system admin is not possible";
                throw new \Exception($msg);
            }
            if ($id == 1) {
                $msg = $this->tr("admin.admins.error.deleteInitialAdmin");
                throw new \Exception($msg);
            }
            $this->getAdminManager()->deleteAdminUser($id);
            $this->addFlash("success", $this->tr("admin.admins.deleteSuccess"));
        } catch (\Exception $e) {
            $msg = $this->tr("admin.admins.error.delete", array("%id%" => $id, "%errmsg%" => $e->getMessage()));
            $this->addError($msg);
        }

        return $this->redirect($this->generateUrl("admin_admin"));
    }

    /**
     * @Route("/{id}/edit", name="admin_admin_edit", options={"expose" = true})
     * @Template()
     *
     * @param Admin $admin
     *
     * @throws \Symfony\Component\HttpKernel\Exception\NotFoundHttpException
     * @return string|\Symfony\Component\HttpFoundation\Response
     */
    public function editAction(Admin $admin)
    {
        $formBuilder = $this->getFormFactory()->createBuilder(new AdminForm($admin->getId() === null));
        try {
            if (null !== $admin->getId()) {
                $formBuilder->get("plainPassword")->setRequired(false);
                if ($admin->getId() == 0) {
                    throw new \Exception("Editing system admin not allowed");
                }
                if ($admin->getId() == 1) {
                    $formBuilder->get("level")->setDisabled(true);
                    $formBuilder->get("login")->setDisabled(true);
                }
            }

            $form = $formBuilder->getForm();
            $form->setData($admin);

            $request = $this->getRequest();
            if ($request->isMethod("POST")) {
                $form->submit($request);
                if ($admin->getId() == 1) {
                    if ($admin->getLevel() != Admin::LEVEL_ADMIN) {
                        $form->addError(new FormError("admin.changeInitialAdminUserLevel"));
                    }
                    if ($admin->getLogin() != "admin") {
                        $form->addError(new FormError("admin.changeInitialAdminUserName"));
                    }
                }

                if ($form->isValid()) {
                    $this->getAdminEntityManager()->save($admin);
                    $this->addFlash("success", $this->tr("admin.admins.saveSuccess"));
                    return new Response("OK");
                }
            }
        } catch (\Exception $e) {
            if ($admin->getId() === null) {
                $this->getLogger()->error("Error inserting admin user", array("exception" => $e));
                $msg = $this->tr(
                    "admin.admins.error.cantAdd",
                    array("%errmsg%" => $e->getMessage())
                );
            } else {
                $this->getLogger()->error("Error updating admin user", array("exception" => $e));
                $msg = $this->tr(
                    "admin.admins.error.cantChange",
                    array("%id%" => $admin->getId(), "%errmsg%" => $e->getMessage())
                );
            }
            $form->addError(new FormError($msg));
        }

        return array(
            "form" => $form->createView(),
            "admin" => $admin
        );
    }
}
