<?php
namespace Topalis\App\Android;

use ApkParser\Archive;
use ApkParser\Manifest;
use ApkParser\XmlParser;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class ApkFile
{
    /**
     * @var array
     * @see https://developer.android.com/guide/topics/manifest/uses-sdk-element.html#ApiLevels
     */
    private static $apiLevel2OSVersion = array(
        1  => "1.0",
        2  => "1.1",
        3  => "1.5",
        4  => "1.6",
        5  => "2.0",
        6  => "2.0.1",
        7  => "2.1",
        8  => "2.2",
        9  => "2.3",
        10 => "2.3.3",
        11 => "3.0",
        12 => "3.1",
        13 => "3.2",
        14 => "4.0",
        15 => "4.0.3",
        16 => "4.1",
        17 => "4.2",
        18 => "4.3",
        19 => "4.4",
        20 => "4.4W",
        21 => "5.0",
    );

    /**
     * @var string
     */
    private $pathname;

    /**
     * @var Manifest
     */
    protected $manifest;

    public function __construct($pathname)
    {
        $this->pathname = $pathname;
    }

    public function getIdentifier()
    {
        return $this->getManifest()->getPackageName();
    }

    /**
     * @return Manifest
     */
    public function getManifest()
    {
        if (null !== $this->manifest) {
            return $this->manifest;
        }
        $apk = new Archive($this->pathname);

        return $this->manifest = new Manifest(new XmlParser($apk->getManifestStream()));
    }

    /**
     * @return string The minimum required OS version.
     */
    public function getMinOSVersion()
    {
        $minSdk = $this->getManifest()->getMinSdkLevel();

        return isset(self::$apiLevel2OSVersion[$minSdk]) ? self::$apiLevel2OSVersion[$minSdk] : null;
    }
}
