<?php
namespace Topalis\App\Command;

use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;
use Topalis\App\Entity\AppState;
use Topalis\App\Entity\AppStateEntityManager;
use Doctrine\ORM\Query\Expr;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class GetManagedApplicationListCommand extends ContainerAwareCommand
{
    protected function configure()
    {
        $this
            ->setName("app:managed")
            ->setDescription("refresh managed application lists")
            ->setDefinition(array(
                new InputOption("all", null, InputOption::VALUE_NONE,
                    "get managed application list for all devices with managed apps")
            ))
        ;
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $output; // unused

        foreach ($this->getDeviceTypeFactory()->getTypes() as $type) {
            if (!$type->hasSupport("apps", null)) {
                continue;
            }
            /** @var AppStateEntityManager $entityManager */
            $entityManager = $this->getContainer()->get($type->getAppStateEntityManagerId());
            $query = $entityManager->createQueryBuilder("s")
                ->select("s, d")
                ->join("s.device", "d", Expr\Join::WITH, "d.disabled = 0")
                ->groupBy("s.device")
            ;
            if ($input->getOption("all")) {
                // either the state is managed or the device is in a group which
                // has a managed app
                $query
                    ->leftJoin("s.app", "a", Expr\Join::WITH, "a.managed = 1")
                    ->leftJoin("a.configGroups", "c", Expr\Join::WITH, "c = d.configGroup")
                    ->where("s.managed = 1 OR c.id IS NOT NULL")
                ;
            } else {
                $query
                ->where("s.state = :installationRequested OR s.state = :updateRequested")
                ->setParameter("installationRequested", AppState::INSTALLATION_REQUESTED)
                ->setParameter("updateRequested", AppState::UPDATE_REQUESTED)
                ;
            }
            /** @var AppState[] $states */
            $states = $query
                ->getQuery()
                ->getResult()
            ;
            foreach ($states as $state) {
                $this->getMdmAdmin()->requestManagedApplicationList($state->getDevice());
            }
        }
    }

    /**
     * @return \Topalis\Device\Type\DeviceTypeFactory
     */
    protected function getDeviceTypeFactory()
    {
        return $this->getContainer()->get("device.type.factory");
    }

    /**
     * @return \Topalis\MDM\MdmAdmin
     */
    protected function getMdmAdmin()
    {
        return $this->getContainer()->get("mdm.admin");
    }
}
