<?php
namespace Topalis\App\Command;

use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand;
use Symfony\Component\Console\Helper\ProgressHelper;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Topalis\App\AppStore;
use Topalis\App\Entity\AppEntityManager;
use Topalis\App\Entity\IosApp;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
abstract class RefreshAppsCommand extends ContainerAwareCommand
{

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $input; // unused

        $showProgress = $output->getVerbosity() >= OutputInterface::VERBOSITY_VERBOSE;
        if ($showProgress) {
            /** @var ProgressHelper $progress */
            $progress = $this->getHelperSet()->get('progress');
        }

        $batchSize = 30;
        $count = $this->getAppEntityManager()->count();

        $query = $this->getAppEntityManager()->createQueryBuilder("a")
            ->select("a");
        if ($showProgress) {
            $progress->start($output, $count);
        }

        $batchCount = ceil($count / $batchSize);
        for ($i = 0; $i < $batchCount; $i++) {
            $query->setFirstResult($i * $batchSize)->setMaxResults($batchSize);
            /** @var IosApp[] $apps */
            $apps = $query->getQuery()->getResult();
            $this->getAppStore()->refreshApps($apps);
            foreach ($apps as $app) {
                $this->getAppEntityManager()->save($app, false);
            }
            if ($showProgress) {
                $progress->advance(count($apps));
            }
            $this->getAppEntityManager()->flush();
        }
        if ($showProgress) {
            $progress->finish();
        }
    }

    /**
     * @return AppEntityManager
     */
    abstract protected function getAppEntityManager();

    /**
     * @return AppStore
     */
    abstract protected function getAppStore();
}
