<?php
namespace Topalis\App\Command;

use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;
use Topalis\App\Ios\VppToken;

/**
 * This command sends an email to the admin if the VPP token will expire in one
 * of the configured warn days.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class VppTokenExpireWarnCommand extends ContainerAwareCommand
{
    protected function configure()
    {
        $this
            ->setName("app:ios:vpp:token:expire-warn")
            ->setDescription("Sends an email to the admin if the VPP token will"
                . " expire in one of the configured warn days.")
        ;
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $input; // unused
        $output; // unused

        $container = $this->getContainer();
        $mailer = $container->get("mailer");
        if (!$mailer->isConfigured()) {
            return;
        }

        $config = $container->get("config.auralis");
        $token = new VppToken($config->getVppToken());
        if (!$token->isValid()) {
            return;
        }

        $remainingDays = $token->getRemainingDays();
        $warnDays = $container->getParameter("app.vpp.token.expire_warn_days");
        if (!in_array($remainingDays, $warnDays)) {
            return;
        }

        $translator = $container->get("translator");
        $subject = $translator->trans("admin.app.ios.vppToken.expire.warnMail.subject");
        $text = $translator->trans("admin.app.ios.vppToken.expire.warnMail.text",
            array("%remainingDays%" => $remainingDays));
        $mailer->sendAdminMessage($subject, $text);
    }
}
