<?php
namespace Topalis\App\Controller\Section;

use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\HttpFoundation\Request;
use Topalis\App\Entity\AndroidApp;
use Topalis\App\Entity\AndroidAppState;
use Topalis\ConfigGroup\Entity\ConfigGroup;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @Route("/admin/app/android")
 */
class AndroidAppSectionController extends GenericAppSectionController
{
    /**
     * @Route("/managed", name="admin_app_android_managed")
     * @Template("TopalisAppBundle:Section/GenericAppSection:managed.html.twig")
     *
     * @param ConfigGroup $group
     * @param boolean $embed
     * @return array
     */
    public function managedAction(ConfigGroup $group = null, $embed = false)
    {
        return $this->doManagedAction($group, $embed);
    }

    /**
     * @param string $identifier App identifier.
     *
     * @return RedirectResponse|Response A RedirectResponse with the URL to the
     *    icon, or Response without content and status 404 if no icon has been
     *    found.
     *
     * @Route("/icon/{identifier}", name="admin_app_android_icon", options={"expose" = true})
     */
    public function iconAction($identifier)
    {
        return $this->doIconAction($identifier);
    }

    /**
     * @Route("/inventory", name="admin_app_android_inventory")
     * @Template("TopalisAppBundle:Section/GenericAppSection:inventory.html.twig")
     */
    public function inventoryAction()
    {
        return $this->doInventoryAction();
    }

    /**
     * @param Request $request
     *
     * @return \Symfony\Component\HttpFoundation\JsonResponse
     *
     * @Route("/inventory/json", name="admin_app_android_inventory_json", defaults={"_format": "json"})
     */
    public function inventoryJsonAction(Request $request)
    {
        return $this->doInventoryJsonAction($request);
    }

    protected function getInventoryQuery($system = false)
    {
        $query = parent::getInventoryQuery();
        $query
            ->andWhere("a.system = :system")
            ->setParameter("system", $system)
        ;

        return $query;
    }
    /**
     * @Route("/system", name="admin_app_android_system")
     * @Template()
     */
    public function systemInventoryAction()
    {
        $apps = $this
            ->getInventoryQuery(true)
            ->getQuery()
            ->getResult()
        ;

        return array(
            "apps"           => $apps,
            "device_count"   => $this->getDeciveCount(),
            "sections"       => $this->container->getParameter("app.sections"),
            "active_section" => $this->getOsName(),
            "sub_section"    => "system",
        );
    }

    /**
     * @Route("/{storeId}/add", name="admin_app_android_add")
     * @param int $storeId
     *
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function addAction($storeId)
    {
        try {
            $app = $this->getAppStore()->lookupByIdentifier($storeId);
        } catch (\Exception $e) {
            $this->get("session")->getFlashBag()->add("error",
                $this->getTranslator()->trans("admin.app.error.appStoreConnection", array(
                    "%errmsg%" => $e->getMessage(),
                ))
            );
        }
        if (null === $app) {
            return $this->createNotFoundException();
        }
        $app->setManaged(true);

        return $this->forward("TopalisAppBundle:Section/AndroidAppSection:edit", array("app" => $app));
    }

    /**
     * @Route("/{app}/edit", name="admin_app_android_edit")
     * @Template("TopalisAppBundle:Section/GenericAppSection:edit.html.twig")
     *
     * @param Request $request
     * @param AndroidApp $app
     * @return array
     */
    public function editAction(Request $request, AndroidApp $app)
    {
        return $this->doEditAction($request, $app);
    }

    /**
     * @Route("/upload", name="admin_app_android_upload")
     *
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function uploadAction()
    {
        $app = new AndroidApp();
        $app
            ->setManaged(true)
            ->setType(AndroidApp::TYPE_UPLOADED)
            ->setForceInstall(true)
        ;

        return $this->forward("TopalisAppBundle:Section/AndroidAppSection:edit",
            array("app" => $app, "standalone" => true));
    }

    /**
     * @Route("/search", name="admin_app_android_search")
     * @Template("TopalisAppBundle:Section/GenericAppSection:search.html.twig")
     *
     * @param Request $request
     * @return array
     */
    public function searchAction(Request $request)
    {
        return $this->doSearchAction($request);
    }

    /**
     * @param Request $request
     *
     * @return \Symfony\Component\HttpFoundation\JsonResponse
     *
     * @Route("/search/json", name="admin_app_android_search_json", defaults={"_format": "json"})
     */
    public function searchJsonAction(Request $request)
    {
        return $this->doSearchJsonAction($request);
    }

    /**
     * @Route("/{app}/delete", name="admin_app_android_delete")
     * @param AndroidApp $app
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function deleteAction(AndroidApp $app)
    {
        $this->getAppEntityManager()->delete($app);
        return $this->redirect($this->generateUrl("admin_app_android_managed"));
    }

    /**
     * @Route("/{app}/enable/{group}", name="admin_app_android_enable")
     *
     * @param ConfigGroup $group
     * @param IosApp $app
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function enableAction(ConfigGroup $group, AndroidApp $app)
    {
        return $this->doEnableAction($group, $app);
    }

    /**
     * @Route("/{app}/disable/{group}", name="admin_app_android_disable")
     *
     * @param ConfigGroup $group
     * @param IosApp $app
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function disableAction(ConfigGroup $group, AndroidApp $app)
    {
        return $this->doDisableAction($group, $app);
    }

    /**
     * @Route("/state/{state}/retryinstall", name="admin_app_android_state_retry_install")
     * @Template("TopalisAppBundle:Section/GenericAppSection:retryInstall.html.twig")
     *
     * @param AndroidAppState $state
     * @return array
     */
    public function retryInstallAction(AndroidAppState $state)
    {
        return $this->doRetryInstallAction($state);
    }

    /**
     * @Route("/state/{state}/remove", name="admin_app_android_state_remove")
     * @Template("TopalisAppBundle:Section/GenericAppSection:remove.html.twig")
     *
     * @param AndroidAppState $state
     * @return array
     */
    public function removeAction(AndroidAppState $state)
    {
        return $this->doRemoveAction($state);
    }

    protected function getAppEntityManager()
    {
        return $this->get("app.entity.manager.android_app");
    }

    protected function getAppStateEntityManager()
    {
        return $this->get("app.entity.manager.android_app_state");
    }

    /**
     * @return \Topalis\App\Android\GooglePlayStore
     */
    protected function getAppStore()
    {
        return $this->get("app.android.play_store");
    }

    protected function getEditFormHandler()
    {
        return $this->get("app.form.handler.edit.android");
    }

    protected function getOsName()
    {
        return "android";
    }
}
