<?php
namespace Topalis\App\Controller;

use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * This controller contains actions used for the app policy.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 * @Route("/admin/app/winphone")
 */
class WinPhoneAppController extends Controller
{
    /**
     * @param string $identifier App identifier.
     *
     * @Route("/icon/{identifier}", name="admin_app_winphone_icon", options={"expose" = true})
     */
    public function iconAction($identifier)
    {
        // search in the store
        $app = $this->getAppStore()->lookupByIdentifier($identifier);
        if (null !== $app && $app->getIcon()) {
            return new RedirectResponse($app->getIcon());
        }

        // no icon available
        return new Response(null, 404);
    }

    /**
     * @param Request $request
     *
     * @return \Symfony\Component\HttpFoundation\JsonResponse
     *
     * @Route("/search/json", name="admin_app_winphone_search_json", defaults={"_format": "json"})
     */
    public function searchJsonAction(Request $request)
    {
        $name = $request->get("name");
        $storeApps = array();

        try {
            $storeApps = $this->getAppStore()->search($name);
        } catch (\Exception $e) {
            $this->getLogger()->error("Error searching in store: " . $e->getMessage(), array("exception" => $e));
            $msg = $this->getTranslator()->trans("admin.app.error.appStoreConnection", array(
                "%errmsg%" => $e->getMessage()
            ));
            return new JsonResponse(array("error" => array("code" => $e->getCode(), "message" => $msg)), 500);
        }

        $apps = array();
        foreach ($storeApps as $storeApp) {
            $apps[] = array(
                "identifier" => $storeApp->getIdentifier(),
                "name" => $storeApp->getName(),
                "vendor" => $storeApp->getVendor(),
                "icon" => $storeApp->getIcon(),
            );
        }

        return new JsonResponse($apps);
    }

    /**
     * @return \Topalis\App\WinPhone\WinPhoneStore
     */
    protected function getAppStore()
    {
        return $this->container->get("app.winphone.store");
    }
}
