<?php
namespace Topalis\App\Device\Info;

use Symfony\Component\Templating\EngineInterface;
use Symfony\Component\DependencyInjection\ContainerAware;
use Topalis\App\Entity\AppState;
use Topalis\Device\Entity\Device;
use Topalis\Device\Info\DeviceInfoSectionInterface;

/**
 * AppDeviceInfoSection
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class AppDeviceInfoSection extends ContainerAware implements DeviceInfoSectionInterface
{
    /**
     * @var \Symfony\Bundle\FrameworkBundle\Templating\EngineInterface
     */
    private $templating;

    public function __construct(EngineInterface $templating)
    {
        $this->templating = $templating;
    }

    public function getKey()
    {
        return "app";
    }

    public function getTabAttributes()
    {
        return array("class" => "app-tab");
    }

    public function getTitle()
    {
        return "admin.app.title";
    }

    public function isVisible(Device $device)
    {
        return $device->getType()->hasSupport("mdm", $device);
    }

    public function renderContent(Device $device)
    {
        $appStates = array();
        if ($device->getType()->hasSupport("apps", $device)) {
            /** @var \Topalis\App\Entity\AppStateEntityManager $appStateEntityManager */
            $appStateEntityManager = $this->container->get($device->getType()->getAppStateEntityManagerId());
            $appStates = $appStateEntityManager->createQueryBuilder("s")
                ->select("s, a")
                ->join("s.app", "a")
                ->where("s.device = :device")
                ->andWhere("s.state in (:installedStates)")
                ->setParameter("device", $device)
                ->setParameter("installedStates", AppState::getInstalledStates())
                ->orderBy("a.name")
                ->getQuery()
                ->getResult();
        }

        return $this->templating->render("TopalisAppBundle:Device:info.html.twig", array(
            "device" => $device,
            "appStates" => $appStates,
        ));
    }
}
