<?php
namespace Topalis\App\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * NOTE: Check AndroidAppEditFormHandler when adding new attributes that aren't
 * copied in merge().
 *
 * @ORM\Entity
 * @ORM\Table(name="androidapps")
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class AndroidApp extends App
{
    /**
     * @var \Doctrine\Common\Collections\ArrayCollection
     * @ORM\OneToMany(targetEntity="Topalis\App\Entity\AndroidAppState", mappedBy="app", cascade={"persist"})
     */
    protected $states;

    /**
     * @var string
     * @ORM\Column(type="string", nullable=true)
     */
    protected $apkPath;

    /**
     * indicates that this app needs to be updated by RefreshUploadedAndroidAppsCommand
     * @var boolean
     * @ORM\Column(type="boolean")
     */
    protected $needsUpdate = false;

    /**
     * app is a system app
     * @var boolean
     * @ORM\Column(type="boolean")
     */
    protected $system = false;

    public function merge(App $app, $force = false)
    {
        parent::merge($app, $force);
        $this->setSystem($app->isSystem());
    }

    /**
     * @return string
     */
    public function getApkPath()
    {
        return $this->apkPath;
    }

    /**
     * @param string $apkPath
     *
     * @return self
     */
    public function setApkPath($apkPath)
    {
        // Objects of type File are converted to their path on comparison. So
        // we have to check for non-identity.
        if ($this->apkPath !== $apkPath) {
            $this->apkPath = $apkPath;
            $this->setUploadedPackageChanged(true);
        }

        return $this;
    }

    /**
     * @return boolean
     */
    public function isNeedsUpdate()
    {
        return $this->needsUpdate;
    }

    /**
     * @param boolean $needsUpdate
     *
     * @return self
     */
    public function setNeedsUpdate($needsUpdate)
    {
        $this->needsUpdate = $needsUpdate;

        return $this;
    }

    /**
     * @return boolean
     */
    public function isSystem()
    {
        return $this->system;
    }

    /**
     * @param boolean $system
     *
     * @return self
     */
    public function setSystem($system)
    {
        $this->system = $system;

        return $this;
    }
}
