<?php
namespace Topalis\App\Entity;

use Topalis\Database\EntityManager;
use Topalis\Device\Entity\Device;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class AppStateEntityManager extends EntityManager
{
    /**
     * Returns all app states for the specified device that are not assigned to
     * the group the device belongs to.
     *
     * @param Device $device
     * @return AppState[]
     */
    public function findUnassignedForDevice(Device $device)
    {
        $qb = $this->createQueryBuilder("s")
            ->select("s")
            ->join("s.app", "a")
            ->leftJoin("a.configGroups", "g")
            ->where("s.device = :device")
            ->setParameter("device", $device);
        $states = $qb->getQuery()->getResult();
        foreach ($states as $key => $state) {
            if ($state->getApp()->getConfigGroups()->contains($device->getConfigGroup())) {
                unset($states[$key]);
            }
        }

        return $states;
    }

    /**
     * Returns all app states for the specified app whose devices are not
     * assigned to a group that is assigned to the app.
     *
     * @param App $app
     *
     * @return AppState[]
     */
    public function findUnassigned(App $app)
    {
        $qb = $this->createQueryBuilder("s")
            ->select("s")
            ->join("s.device", "d")
            ->where("s.app = :app")
            ->setParameter("app", $app)
        ;
        if (!$app->getConfigGroups()->isEmpty()) {
             $qb->andWhere("d.configGroup NOT IN (:groups)")
                ->setParameter("groups", $app->getConfigGroups()->toArray())
            ;
        }

        return $qb->getQuery()->getResult();
    }
}
