<?php
namespace Topalis\App\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity
 * @ORM\Table(name="iosappstates", indexes={
 *    @ORM\Index(name="idx_state", columns={"state"}),
 * })
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class IosAppState extends MdmAppState
{
    /**
     * @var App
     * @ORM\ManyToOne(targetEntity="Topalis\App\Entity\IosApp", inversedBy="states", cascade={"persist"})
     */
    protected $app;

    /**
     *
     * @var \Topalis\MDM\Entity\MdmCommand
     * @ORM\OneToOne(targetEntity="Topalis\MDM\Entity\MdmCommand", cascade={"persist"})
     */
    protected $applyRedemptionCodeCommand;

    /**
     * @var VppLicense
     * @ORM\ManyToOne(targetEntity="Topalis\App\Entity\VppLicense", inversedBy="states", cascade={"persist"})
     */
    protected $vppLicense;

    /**
     * @return string[] Array of states which indicate that an associated VPP
     *    license is required, i.e. all installed states, but REMOVAL_REQUESTED.
     */
    public static function getLicenseRequiredStates()
    {
        static $licenseRequiredStates = null;
        if (null === $licenseRequiredStates) {
            $licenseRequiredStates = array_filter(self::getInstalledStates(), function ($value) {
                return $value !== IosAppState::REMOVAL_REQUESTED;
            });
        }

        return $licenseRequiredStates;
    }

    /**
     * @return \Topalis\MDM\Entity\MdmCommand
     */
    public function getApplyRedemptionCodeCommand()
    {
        return $this->applyRedemptionCodeCommand;
    }

    /**
     * @param \Topalis\MDM\Entity\MdmCommand $applyRedemptionCodeCommand
     *
     * @return $this
     */
    public function setApplyRedemptionCodeCommand(\Topalis\MDM\Entity\MdmCommand $applyRedemptionCodeCommand)
    {
        $this->applyRedemptionCodeCommand = $applyRedemptionCodeCommand;

        return $this;
    }

    /**
     * @return VppLicense
     */
    public function getVppLicense()
    {
        return $this->vppLicense;
    }

    /**
     * @param VppLicense $vppLicense
     *
     * @return $this
     */
    public function setVppLicense(VppLicense $vppLicense = null)
    {
        $this->vppLicense = $vppLicense;

        return $this;
    }
}
