<?php
namespace Topalis\App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Topalis\User\Entity\User;
use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity
 * @ORM\Table(name="vpp_licenses")
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class VppLicense
{
    const STATUS_ASSOCIATED = "associated";

    const STATUS_AVAILABLE = "available";

    /**
     * @var integer
     * @ORM\Column(type="integer", nullable=false, options={"unsigned"=true})
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    protected $id;

    /**
     * @var int licenseId from apple
     * @ORM\Column(type="bigint", options={"unsigned"=true})
     */
    protected $licenseId;

    /**
     * @var IosApp
     * @ORM\ManyToOne(targetEntity="Topalis\App\Entity\IosApp", inversedBy="vppLicenses", cascade={"persist"})
     */
    protected $app;

    /**
     * @var string
     * @ORM\Column(type="string")
     */
    protected $status;

    /**
     * @var User
     * @ORM\ManyToOne(targetEntity="Topalis\User\Entity\User", inversedBy="vppLicenses")
     * @ORM\JoinColumn(onDelete="SET NULL")
     */
    protected $user;

    /**
     * @var ArrayCollection
     * @ORM\OneToMany(targetEntity="Topalis\App\Entity\IosAppState", mappedBy="vppLicense")
     */
    protected $states;

    public function __construct()
    {
        $this->states = new ArrayCollection();
    }

    /**
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * @return int
     */
    public function getLicenseId()
    {
        return $this->licenseId;
    }

    /**
     * @param int $licenseId
     *
     * @return $this
     */
    public function setLicenseId($licenseId)
    {
        $this->licenseId = $licenseId;

        return $this;
    }

    /**
     * @param IosApp $app
     *
     * @return $this
     */
    public function setApp(IosApp $app)
    {
        if ($this->app !== $app) {
            $this->app = $app;
            $app->addVppLicense($this);
        }

        return $this;
    }

    /**
     * @return IosApp
     */
    public function getApp()
    {
        return $this->app;
    }

    /**
     * @return string
     */
    public function getStatus()
    {
        return $this->status;
    }

    /**
     * @param string $status
     *
     * @return $this
     */
    public function setStatus($status)
    {
        $this->status = $status;

        return $this;
    }

    /**
     * @param User $user
     *
     * @return $this
     */
    public function setUser(User $user = null)
    {
        if ($this->user !== $user) {
            $this->user = $user;
            if (null !== $user) {
                $user->addVppLicense($this);
            }
        }

        return $this;
    }

    /**
     * @return User
     */
    public function getUser()
    {
        return $this->user;
    }

    /**
     * @param IosAppState[] $states
     *
     * @return $this
     */
    public function setStates(array $states)
    {
        $this->states->clear();
        foreach ($states as $state) {
            $this->addAppState($state);
        }

        return $this;
    }

    /**
     * @param IosAppState $state
     *
     * @return $this
     */
    public function addAppState(IosAppState $state)
    {
        if (!$this->states->contains($state)) {
            $this->states->add($state);
            $state->setVppLicense($this);
        }

        return $this;
    }

    /**
     * @param IosAppState $state
     *
     * @return $this
     */
    public function removeAppState(IosAppState $state)
    {
        if ($this->states->removeElement($state)) {
            $state->setVppLicense(null);
        }

        return $this;
    }

    /**
     * @return IosAppState[]
     */
    public function getStates()
    {
        return $this->states;
    }
}
