<?php
namespace Topalis\App\EventListener;

use Topalis\Configuration\AuralisConfig;
use Symfony\Component\Security\Http\Event\InteractiveLoginEvent;
use Symfony\Component\DependencyInjection\ContainerAware;

/**
 * This listener is called after admin login to ensure that a region for the
 * iTunes App Store is configured. The locale must be set before this listener
 * is called.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class LoginListener extends ContainerAware
{
    private $config;

    public function __construct(AuralisConfig $config)
    {
        $this->config = $config;
    }

    public function onSecurityInteractiveLogin(InteractiveLoginEvent $event)
    {
        $event; // unused

        $playStoreLang = $this->config->getGooglePlayStoreLang();
        if (!$playStoreLang) {
            $playStoreLang = \Locale::getPrimaryLanguage(\Locale::getDefault());
            $this->config->setGooglePlayStoreLang($playStoreLang);
        }

        $storeRegion = $this->config->getItunesAppStore();
        if (!$storeRegion) {
            $storeRegion = strtolower(\Locale::getRegion(\Locale::getDefault()));
            $this->config->setItunesAppStore($storeRegion);
        }

        $winPhoneStoreLocale = $this->config->getWinPhoneStoreLocale();
        if (!$winPhoneStoreLocale) {
            $winPhoneStoreLocale = str_replace("_", "-", strtolower(\Locale::getDefault()));
            $this->config->setWinPhoneStoreLocale($winPhoneStoreLocale);
        }
    }
}
