<?php
namespace Topalis\App\EventListener\MDM;

use Topalis\App\Entity\AppState;
use Topalis\Device\Entity\Device;
use Topalis\Device\Type\AndroidDeviceType;

/**
 * AndroidAppMdmListener
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class AndroidAppMdmListener extends AppMdmListener
{
    public function supports(Device $device)
    {
        return $device->getType() instanceof AndroidDeviceType;
    }

    protected function handleRemoveAcknowledged(AppState $state)
    {
        if (!$state->isManaged() && $state->isInstalled() && $state->getRejected() != AppState::REJECTED_NONE) {
            /*
             * App is installed, but has been rejected. Through the remove
             * command the device knows that the app shouldn't be managed,
             * anymore.
             */
            $state->setRejected(AppState::REJECTED_NONE);
        } else {
            parent::handleRemoveAcknowledged($state);
        }
    }

    protected function isSendRemoveCommand(AppState $state)
    {
        if (parent::isSendRemoveCommand($state)) {
            return true;
        }

        $app = $state->getApp();
        $device = $state->getDevice();
        switch ($state->getRejected()) {
            case AppState::REJECTED_DEVICE:
                /* fall through */
            case AppState::REJECTED_USER:
                // send remove command if app has been rejected so the device
                // gets to know that it shouldn't be managed, anymore.
                return !$app->getConfigGroups()->contains($device->getConfigGroup());
        }

        return false;
    }
}
