<?php
namespace Topalis\App\EventListener\ORM;

use Doctrine\ORM\Event\OnFlushEventArgs;
use Symfony\Component\DependencyInjection\ContainerAware;
use Topalis\ConfigGroup\Entity\ConfigGroup;

/**
 * Assigns a cloned group to the apps of the original group.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class GroupCloneListener extends ContainerAware
{
    public function onFlush(OnFlushEventArgs $eventArgs)
    {
        $em = $eventArgs->getEntityManager();
        $eventManager = $em->getEventManager();

        // remove event to avoid infinite recursion loop if we call $em->flush()
        $eventManager->removeEventListener("onFlush", $this);

        $uow = $em->getUnitOfWork();
        $appEms = $this->getAppEntityManagers();

        foreach ($uow->getScheduledEntityInsertions() as $entity) {
            if (!$entity instanceof ConfigGroup) {
                continue;
            }

            if (!$entity->isCloned()) {
                continue;
            }

            $originGroupId = $entity->getOriginId();
            foreach ($appEms as $appEm) {
                $apps = $appEm->getAppsForConfigGroup($originGroupId);
                foreach ($apps as $app) {
                    $app->addConfigGroup($entity);
                    $em->persist($app);
                    $md = $em->getClassMetadata(get_class($app));
                    $uow->computeChangeSet($md, $app);
                }
            }
        }

        // re-attach since we're done
        $eventManager->addEventListener("onFlush", $this);
    }

    /**
     * @return \Topalis\App\Entity\AppEntityManager[]
     */
    private function getAppEntityManagers()
    {
        return array(
            $this->container->get("app.entity.manager.android_app"),
            $this->container->get("app.entity.manager.ios_app"),
        );
    }
}
