<?php
namespace Topalis\App\EventListener\ORM;

use Doctrine\ORM\Event\LifecycleEventArgs;
use Doctrine\ORM\Event\PostFlushEventArgs;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Topalis\App\Entity\IosApp;

/**
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class IosAppStoreEventListener
{
    /**
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    protected $container;

    protected $flushing = false;

    /**
     * @var IosApp[]
     */
    protected $apps;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    public function prePersist(LifecycleEventArgs $event)
    {
        $app = $event->getEntity();
        if (!$app instanceof IosApp) {
            return;
        }
        $this->apps[] = $app;
    }

    public function postFlush(PostFlushEventArgs $eventArgs)
    {
        if (empty($this->apps)) {
            return;
        }
        $this->flushing = true;
        $batchSize = 30;
        $count = ceil(count($this->apps) / $batchSize);
        for ($i = 0; $i < $count; $i++) {
            $apps = array_slice($this->apps, $i * $batchSize, $batchSize);
            $this->getAppStore()->refreshApps($apps);
        }
        foreach ($this->apps as $app) {
            $eventArgs->getEntityManager()->persist($app);
        }
        $this->apps = array();
        $eventArgs->getEntityManager()->flush();
    }

    /**
     *
     * @return \Topalis\App\Ios\IosAppStore
     */
    private function getAppStore()
    {
        return $this->container->get("app.ios.store");
    }
}
