<?php
namespace Topalis\App\Exception;

use Topalis\Kernel\Http\Response;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class VppApiException extends VppException
{
    private $response;

    private $reason;

    public function __construct(Response $response, array $content = null)
    {
        if (null === $content) {
            $content = json_decode($response->getContent(), true);
        }
        if (0 === $content['status']) {
            throw new \InvalidArgumentException(
                "Expected a failed api request, but the given response was successfull");
        }

        $code = isset($content['errorNumber']) ? $content['errorNumber'] : 0;
        $this->reason = isset($content['errorMessage']) ? $content['errorMessage'] : "unkown";

        parent::__construct(
            sprintf(
                "The VPP API requests to %s failed: (%d: %s)",
                $response->getRequest()->getUrl(),
                $code,
                $this->reason
            ),
            $code
        );
    }

    public function getReason()
    {
        return $this->reason;
    }

    public function getResponse()
    {
        return $this->response;
    }
}
