<?php
namespace Topalis\App\Form\Handler;

use Symfony\Component\Form\FormError;
use Symfony\Component\Form\FormFactoryInterface;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Validator\ConstraintViolation;
use Symfony\Component\Validator\ValidatorInterface;
use Topalis\App\Entity\App;
use Topalis\App\Entity\AppEntityManager;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
abstract class AppEditFormHandler
{
    /**
     * @var AppEntityManager
     */
    protected $appEntityManager;

    /**
     * @var ValidatorInterface
     */
    protected $validator;

    /**
     * @var FormFactoryInterface
     */
    protected $formFactory;

    public function __construct(AppEntityManager $appEntityManager, ValidatorInterface $validator,
        FormFactoryInterface $formFactory)
    {
        $this->appEntityManager = $appEntityManager;
        $this->validator = $validator;
        $this->formFactory = $formFactory;
    }

    public function process(Request $request, FormInterface $form, App &$app)
    {
        $this->beforeHandleRequest($app);
        /*
         * unset identifier before call of handleRequest() to avoid a form error
         * because of duplicate identifiers. This allows us to replace uploaeded
         * apps with apps from store. A duplicate identifier check is performed
         * below.
         */
        $identifier = $app->getIdentifier();
        $app->setIdentifier(null);
        $form->handleRequest($request);
        $app->setIdentifier($identifier);
        if ($form->isValid()) {
            $app->setManaged(true);
            $this->handleUpload($form, $app);

            // identifier already in use validation
            /** @var ConstraintViolation[] $errors */
            $errors = $this->validator->validate($app);
            foreach ($errors as $error) {
                $form->addError(new FormError($error->getMessage(), $error->getMessageTemplate(),
                    $error->getMessageParameters()));
            }
            if ($form->isValid()) {
                $this->appEntityManager->save($app);

                return true;
            }
        }
        $this->handleRequestFailed($app);

        return false;
    }

    /**
     * @param App $app
     *
     * @return FormInterface
     */
    abstract public function createForm(App $app);

    abstract protected function handleUpload(FormInterface $form, App &$app);

    protected function beforeHandleRequest(App $app)
    {
    }

    protected function handleRequestFailed(App $app)
    {
    }
}
