<?php
namespace Topalis\App\Form\Type;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Topalis\App\Validator\Ipa;
use Topalis\Configuration\AuralisConfig;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class IosAppForm extends AbstractType
{

    /**
     * @var AuralisConfig
     */
    private $config;

    /**
     * @param AuralisConfig $config
     */
    public function __construct(AuralisConfig $config)
    {
        $this->config = $config;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused
        $builder
            ->add("ipaPath", "jquery_file_upload", array(
                "label"       => "admin.app.ios.ipaFile",
                "endpoint"    => "ios_app",
                "required"    => true,
                "constraints" => array(new Ipa())
            ))
            ->add("configGroups", "genemu_jqueryselect2_entity", array(
                "label"            => "admin.app.groups",
                "descriptionBlock" => true,
                "description"      => "admin.app.groupsDescription",
                "class"            => 'Topalis\ConfigGroup\Entity\ConfigGroup',
                "property"         => "name",
                "multiple"         => true,
                "by_reference"     => false,
                "required"         => false,
                "placeholder"      => "admin.app.selectGroup",
            ))
            ->add("removeWheneMdmIsRemoved", "checkbox", array(
                "label"    => "admin.app.ios.removeWhenMdmIsRemoved",
                "required" => false,
            ))
            ->add("preventBackup", "checkbox", array(
                "label"    => "admin.app.ios.preventBackup",
                "required" => false,
            ))
            ->add("forceInstall", "checkbox", array(
                "label"             => "admin.app.force",
                "description"       => "admin.app.ios.forceDescription",
                "descriptionBlock"  => true,
                "descriptionParams" => array(
                    "%attempts%" => $this->config->getAppInstallAttempts(),
                ),
                "required"          => false,
            ));
    }

    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        $resolver->setDefaults(array(
            "data_class" => "Topalis\App\Entity\IosApp"
        ));
    }

    public function getName()
    {
        return "app";
    }
}
