<?php
namespace Topalis\App\Ios;

use CFPropertyList\CFPropertyList;

/**
 * This class repesents an iOS app manifest. It can parse a manifest and extract
 * the essential values.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 * @see http://www.informit.com/articles/article.aspx?p=1829415&seqNum=16
 */
class IosAppManifest
{
    /**
     *
     * @var string
     */
    private $softwarePackageURL;

    /**
     *
     * @var string
     */
    private $displayImageURL;

    /**
     *
     * @var string
     */
    private $fullSizeImageURL;

    /**
     *
     * @var string
     */
    private $identifier;

    /**
     *
     * @var string
     */
    private $version;

    /**
     *
     * @var string
     */
    private $kind;

    /**
     *
     * @var string
     */
    private $title;

    /**
     *
     * @var string
     */
    private $subtitle;

    public function parse($str)
    {
        $dict = new CFPropertyList();
        $dict->parse($str);
        $manifest = $dict->toArray();

        if (isset($manifest['items'][0]['assets'])) {
            $assets = $manifest['items'][0]['assets'];
        }

        foreach ($assets as $asset) {
            if (!isset($asset['kind']) || !isset($asset['url'])) {
                continue;
            }
            $url = $asset['url'];
            switch ($asset['kind']) {
                case "software-package":
                    $this->softwarePackageURL = $url;
                    break;
                case "display-image":
                    $this->displayImageURL = $url;
                    break;
                case "full-size-image":
                    $this->fullSizeImageURL = $url;
                    break;
            }
        }

        if (isset($manifest['items'][0]['metadata'])) {
            $metadata = $manifest['items'][0]['metadata'];
        }
        if (isset($metadata['bundle-identifier'])) {
            $this->identifier = $metadata['bundle-identifier'];
        }
        if (isset($metadata['bundle-version'])) {
            $this->version = $metadata['bundle-version'];
        }
        if (isset($metadata['kind'])) {
            $this->kind = $metadata['kind'];
        }
        if (isset($metadata['title'])) {
            $this->title = $metadata['title'];
        }
        if (isset($metadata['subtitle'])) {
            $this->subtitle = $metadata['subtitle'];
        }
    }

    /**
     *
     * @return string
     */
    public function getSoftwarePackageURL()
    {
        return $this->softwarePackageURL;
    }

    /**
     *
     * @param string $softwarePackageURL
     */
    public function setSoftwarePackageURL($softwarePackageURL)
    {
        $this->softwarePackageURL = $softwarePackageURL;
    }

    /**
     *
     * @return string
     */
    public function getDisplayImageURL()
    {
        return $this->displayImageURL;
    }

    /**
     *
     * @param string $displayImageURL
     */
    public function setDisplayImageURL($displayImageURL)
    {
        $this->displayImageURL = $displayImageURL;
    }

    /**
     *
     * @return string
     */
    public function getFulleSizeImageURL()
    {
        return $this->fullSizeImageURL;
    }

    /**
     *
     * @param string $fullSizeImageURL
     */
    public function setFullSizeImageURL($fullSizeImageURL)
    {
        $this->fullSizeImageURL = $fullSizeImageURL;
    }

    /**
     *
     * @return string
     */
    public function getIdentifier()
    {
        return $this->identifier;
    }

    /**
     *
     * @param string $identifier
     */
    public function setIdentifier($identifier)
    {
        $this->identifier = $identifier;
    }

    /**
     *
     * @return string
     */
    public function getVersion()
    {
        return $this->version;
    }

    /**
     *
     * @param string $version
     */
    public function setVersion($version)
    {
        $this->version = $version;
    }

    /**
     *
     * @return string
     */
    public function getKind()
    {
        return $this->kind;
    }

    /**
     *
     * @param string $kind
     */
    public function setKind($kind)
    {
        $this->kind = $kind;
    }

    /**
     *
     * @return string
     */
    public function getTitle()
    {
        return $this->title;
    }

    /**
     *
     * @param string $title
     */
    public function setTitle($title)
    {
        $this->title = $title;
    }

    public function getSubtitle()
    {
        return $this->subtitle;
    }

    public function setSubtile($subtitle)
    {
        $this->subtitle = $subtitle;
    }
}
