<?php
namespace Topalis\App\Ios;

/**
 * This interface defines method to access the VPP service API.
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
interface VppApiInterface
{
    /**
     * Get url for a VPP-API Service.
     * Urls can change and shouldn't be hardcoded
     *
     * @param string $name Service name
     *
     * @return string Service URL
     */
    public function getServiceUrl($name);

    /**
     * @return string The token.
     */
    public function getToken();

    /**
     * @return bool true if a token is set, false otherwise.
     */
    public function hasToken();

    /**
     * @return bool true if a valid token is configured, false otherwise.
     *
     * @throws VppClientException If an exception occurs when trying to connect.
     * @throws VppResponseException If the status code of the HTTP response is
     *     not between 200 and 299.
     * @throws VppApiException If the VPP server rejects executing the request
     *     for a specific reason (status != 0).
     */
    public function hasValidToken();

    /**
     * @param string $message Contains the reason if the VPP service is not
     *    available.
     *
     * @return bool true if the VPP service is available, false otherwise.
     */
    public function isAvailable(&$message = null);

    /**
     *
     * @param string $token The token to verify.
     *
     * @return bool true if the specified token is valid, false otherwise.
     *
     * @throws VppClientException If an exception occurs when trying to connect.
     * @throws VppResponseException If the status code of the HTTP response is
     *     not between 200 and 299.
     * @throws VppApiException If the VPP server rejects executing the request
     *     for a specific reason (status != 0).
     */
    public function isTokenValid($token);

    /**
     * @param string $service Service Name
     * @param array  $params  GET Params
     *
     * @return array
     * @throws VppClientException If an exception occurs when trying to connect.
     * @throws VppResponseException If the status code of the HTTP response is
     *     not between 200 and 299.
     * @throws VppApiException If the VPP server rejects executing the request
     *     for a specific reason (status != 0).
     */
    public function sendRequest($service, array $params = array());

    /**
     * Get batch data from VPP API
     *
     * @param string $service Service Name
     * @param string $key     Key for response payload
     * @param array  $params  GET Params
     *
     * @return array
     * @throws VppClientException If an exception occurs when trying to connect.
     * @throws VppResponseException If the status code of the HTTP response is
     *     not between 200 and 299.
     * @throws VppApiException If the VPP server rejects executing the request
     *     for a specific reason (status != 0).
     */
    public function sendBatchRequest($service, $key, array $params = array());
}
