<?php
namespace Topalis\App\Ios;

/**
 * A VppTokenManager allows to get, set, and remove a VPP token.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
interface VppTokenManagerInterface
{
    /**
     * @return VppToken|null The current token, or null if none is set.
     */
    public function getToken();

    /**
     * Removes the current token. The following steps are performed before
     * actually removing the token:
     * <ul>
     *   <li>Cancel pending VPP invitations.</li>
     *   <li>Retire all VPP users.</li>
     *   <li>Remove all VPP apps.</li>
     *   <li>Set VPP apps to not-VPP and unmanaged.</li>
     * </ul>
     *
     * @throws VppException If the VPP service is not reachable, or a VPP action
     *    fails.
     */
    public function removeToken();

    /**
     * Sets the current token. If the actual token is different from the current
     * one, the current token is removed before.
     *
     * @param VppToken $token The token to set.
     *
     * @see removeToken()
     *
     * @throws VppException If the VPP service is not reachable, the token is
     *    invalid, or the removal of the previous token fails.
     */
    public function setToken(VppToken $token);
}
