<?php
namespace Topalis\App\Ios;

use Topalis\User\Entity\User;

/**
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
interface VppUserServiceInterface
{
    /**
     * @param string $message Contains the reason if the VPP service is not
     *    available.
     *
     * @return bool true if the VPP service is available, false otherwise.
     */
    public function isAvailable(&$message = null);

    /**
     * bool true if a VPP token is configured, false otherwise.
     */
    public function isTokenConfigured();

    /**
     * Register user with VPP
     *
     * @param User $user
     *
     * @throws \Topalis\App\Exception\VppException
     */
    public function registerUser(User $user);

    /**
     * Remove all users from VPP.
     *
     * @param bool $ignoreInvalidToken If true the users' VPP status will be set
     *    to  {@link User::VPP_STATUS_UNREGISTERED} if the configured token is
     *    invalid.
     *
     * @throws \Topalis\App\Exception\VppException
     */
    public function retireAllUsers($ignoreInvalidToken = false);

    /**
     * Remove user from VPP
     *
     * @param User $user
     *
     * @throws \Topalis\App\Exception\VppException
     */
    public function retireUser(User $user);

    /**
     *
     * @param boolean $incremental
     *
     * @throws \Topalis\App\Exception\VppException
     */
    public function syncUsers($incremental = true);
}
