<?php
namespace Topalis\App\Mdm;

use Topalis\App\Entity\AndroidApp;
use Topalis\App\Entity\App;
use Topalis\App\Entity\AppState;
use Topalis\Device\Entity\Device;
use Topalis\MDM\Request\AndroidInstallApplicationRequest;

/**
 * AndroidAppMdmAdmin
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class AndroidAppMdmAdmin extends GenericAppMdmAdmin
{
    public function deviceSupportsApp(Device $device, App $app)
    {
        if (!$this->supportsApp($app) || !$this->supportsDevice($device)) {
            return false;
        }

        $appSupports = $app->getSupports();
        if (!isset($appSupports['minOSVersion'])) {
            return null;
        }

        return version_compare($device->getVersion(), $appSupports['minOSVersion'], ">=");
    }

    public function supportsDevice(Device $device)
    {
        return $device->getType()->getName() == "android";
    }

    public function supportsApp(App $app)
    {
        return $app instanceof AndroidApp;
    }

    protected function getAppEntityManager()
    {
        return $this->container->get("app.entity.manager.android_app");
    }

    protected function getAppStateEntityManager()
    {
        return $this->container->get("app.entity.manager.android_app_state");
    }

    protected function getInstallationRequest(App $app)
    {
        /** @var AndroidApp $app */
        $request = new AndroidInstallApplicationRequest();
        $request->setIdentifier($app->getIdentifier());
        $request->setName($app->getName());
        if (AndroidApp::TYPE_UPLOADED === $app->getType()) {
            $port = $this->getConfig()->getSecondaryPort();
            $request->setManifestURL(
                "https://" . $this->getConfig()->getHostname() . ":" . $port
                . "/uploads/android_app/" . basename($app->getApkPath())
            );
        }
        $request->setForce($app->isForceInstall());

        return $request;
    }

    protected function isRemoveCommandSafe(AppState $state)
    {
        switch ($state->getRejected()) {
            case AppState::REJECTED_DEVICE:
                /* fall through */
            case AppState::REJECTED_USER:
                // remove command can be send to signal the device that the app
                // shouldn't be managed, anymore
                return true;
        }

        return parent::isRemoveCommandSafe($state);
    }
}
