<?php
namespace Topalis\App\Mdm;

use Topalis\App\Entity\App;
use Topalis\App\Entity\AppState;
use Topalis\App\Entity\IosApp;
use Topalis\App\Entity\IosAppState;
use Topalis\App\Entity\MdmAppState;
use Topalis\Device\Entity\Device;
use Topalis\MDM\Request\InstallApplicationRequest;
use Topalis\Profile\ConfigurationProfile;
use Topalis\User\Entity\User;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class IosAppMdmAdmin extends GenericAppMdmAdmin
{
    protected $configGroupStoreDisabled;

    public function deviceSupportsApp(Device $device, App $app)
    {
        static $models = array(
            "iPhone1,1" => "iPhone",
            "iPhone1,2" => "iPhone3-G",
            "iPhone2,1" => "iPhone3-GS",
            "iPhone3,1" => "iPhone4",
            "iPhone3,3" => "iPhone4",
            "iPhone4,1" => "iPhone4S",
            "iPhone5,1" => "iPhone5",
            "iPhone5,2" => "iPhone5",
            "iPhone5,3" => "iPhone5c",
            "iPhone5,4" => "iPhone5c",
            "iPhone6,1" => "iPhone5s",
            "iPhone6,2" => "iPhone5s",

            // no mapping in store, yet
            // "iPhone7,1" => "iPhone6Plus",
            // "iPhone7,2" => "iPhone6",

            "iPod1,1"   => "iPodTouch",
            "iPod2,1"   => "iPodTouchSecondGen",
            "iPod3,1"   => "iPodTouchThirdGen",
            "iPod4,1"   => "iPodTouchourthGen", // this is not a typo
            "iPod5,1"   => "iPodTouchFifthGen",

            // iPad1,1 could also be iPadWifi... we would need to now if gps is supported to distinguish them
            "iPad1,1"   => "iPad3G",
            "iPad2,1"   => "iPad2Wifi",
            "iPad2,2"   => "iPad23G",
            "iPad2,3"   => "iPad23G",
            "iPad2,4"   => "iPad2Wifi",
            "iPad2,5"   => "iPadMini",
            "iPad2,6"   => "iPadMini4G",
            "iPad2,7"   => "iPadMini4G",
            "iPad3,1"   => "iPadThirdGen",
            "iPad3,2"   => "iPadThirdGen4G",
            "iPad3,3"   => "iPadThirdGen4G",
            "iPad3,4"   => "iPadFourthGen",
            "iPad3,5"   => "iPadFourthGen4G",
            "iPad3,6"   => "iPadFourthGen4G",

            // no mapping in store, yet...
            // "iPad4,1"   => "iPad Air (WiFi)",
            // "iPad4,2"   => "iPad Air (LTE)",
            // "iPad4,3"   => "iPad Air (TD-LTE)",
            // "iPad4,4"   => "iPad mini 2 (WiFi)",
            // "iPad4,5"   => "iPad mini 2 (LTE)",
            // "iPad4,6"   => "iPad mini 2 (TD-LTE)",
            // "iPad4,8"   => "iPad mini 3 (LTE)",
            // "iPad4,9"   => "iPad mini 3 (TD-LTE)",
            // "iPad5,3"   => "iPad Air 2",
            // "iPad5,4"   => "iPad Air 2 (LTE)",
        );

        if (!$this->supportsApp($app) || !$this->supportsDevice($device)) {
            return false;
        }

        $appSupports = $app->getSupports();
        $supported = null;

        $productName = $device->getType()->getDeviceInfo($device)->get("ProductName");
        if (isset($models[$productName]) && isset($appSupports['devices'])) {
            $model = $models[$productName];
            if (!in_array($model, $appSupports['devices'])) {
                return false;
            }

            $supported = true;
        }

        if (isset($appSupports['minOSVersion'])) {
            $supported = version_compare($device->getVersion(), $appSupports['minOSVersion'], ">=");
        }

        return $supported;
    }

    public function supportsDevice(Device $device)
    {
        return $device->getType()->getName() == "ios";
    }

    public function supportsApp(App $app)
    {
        return $app instanceof IosApp;
    }

    protected function getAppEntityManager()
    {
        return $this->container->get("app.entity.manager.ios_app");
    }

    protected function getAppStateEntityManager()
    {
        return $this->container->get("app.entity.manager.ios_app_state");
    }

    /**
     * @return \Topalis\App\Job\VppAssociateQueue
     */
    protected function getVppAssociateQueue()
    {
        return $this->container->get("app.job.queue.vpp_associate");
    }

    protected function getInstallationRequest(App $app)
    {
        /** @var IosApp $app */
        $request = new InstallApplicationRequest();
        if (null !== $app->getITunesStoreID()) {
            $request->setITunesStoreID($app->getITunesStoreID());
        } else {
            if (IosApp::TYPE_UPLOADED === $app->getType()) {
                $port = $this->getConfig()->getSecondaryPort();
                $request->setManifestURL(
                    "https://" . $this->getConfig()->getHostname() . ":" . $port
                    . "/app/manifest/ios/" . $app->getId() . "/manifest.plist"
                );
            } else {
                $request->setIdentifier($app->getIdentifier());
            }
        }
        $request->setManagementFlags($app->getManagementFlags());

        $options = array("NotManaged" => false);
        if ($app->isUseVpp()) {
            $options['PurchaseMethod'] = 0;
        }
        $request->setOptions($options);

        return $request;
    }

    protected function beforeInstallCommand(MdmAppState $state)
    {
        $device = $state->getDevice();
        if ($state->getApp()->getType() != App::TYPE_STORE || !$this->isStoreDisabled($device)) {
            return;
        }

        // enable app store
        $device->setFlag(Device::FLAG_APP_STORE_TEMPORARY_ENABLED, true);
        $this->container->get("device.entity.manager.device")->save($device, false);
        $this->getMdmAdmin()->installDeviceProfile($device);
    }

    protected function cancelMdmCommands(MdmAppState $state)
    {
        parent::cancelMdmCommands($state);

        /** @var IosAppState $state */
        if ($state->getApplyRedemptionCodeCommand()) {
            $this->getMdmQueue()->cancelCommand($state->getApplyRedemptionCodeCommand());
        }
    }

    public function removeApp(AppState $state)
    {
        $result = parent::removeApp($state);
        if (!$result) {
            return false;
        }
        /** @var IosAppState $state */
        if (null !== $state->getVppLicense()) {
            $this->getVppAssociateQueue()->disassociate($state);
        }

        return true;
    }

    private function isStoreDisabled(Device $device)
    {
        if ($device->isFlag(Device::FLAG_APP_STORE_TEMPORARY_ENABLED)) {
            return false;
        }

        $group = $device->getConfigGroup();
        if (!isset($this->configGroupStoreDisabled[$group->getId()])) {
            $profile = $device->getType()->getDeviceProfile($device);
            $restrictions = $profile->getRestrictions();
            $this->configGroupStoreDisabled[$group->getId()] = $restrictions
                ? !$restrictions[0]->isAllowAppInstallation() : false;
        }

        return $this->configGroupStoreDisabled[$group->getId()];
    }

    protected function isNeedsLicense(AppState $state)
    {
        /** @var IosAppState $state */
        /** @var IosApp $app */
        $app = $state->getApp();

        return $app->isUseVpp() && null === $state->getVppLicense();
    }

    protected function associateLicense(AppState $state)
    {
        if ($state->getDevice()->getUser()->getVppStatus() != User::VPP_STATUS_ASSOCIATED) {
            return;
        }

        /** @var IosAppState $state */

        // must be saved to get an id
        if (null === $state->getId()) {
            $this->getAppStateEntityManager()->save($state);
        }

        $this->getVppAssociateQueue()->associate($state);
    }
}
