<?php
namespace Topalis\Certificate\Controller;

use Symfony\Component\Form\Form;
use Symfony\Component\HttpFoundation\Response;
use Topalis\Certificate\Certificate;
use Topalis\Certificate\Form\CertForm;
use Topalis\Certificate\Form\CertUploadForm;
use Topalis\Kernel\Controller;

/**
 *
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
abstract class AbstractCertController extends Controller
{
    /**
     * The type of object returned here is used when calling handleEdit().
     *
     * @return \Topalis\Certificate\Certificate The certificate.
     */
    abstract protected function getCertificate();

    /**
     * @return \Topalis\Certificate\CertificateManager
     */
    protected function getCertificateManager()
    {
        return $this->container->get("certificate.manager");
    }

    /**
     * @return string The name of the index route.
     */
    abstract protected function getPathBaseName();

    /**
     * @return string name of the active subsection
     */
    abstract protected function getSubSection();

    public function indexAction()
    {
        $formBuilder = $this->getFormFactory()->createBuilder(new CertForm());
        foreach ($formBuilder->all() as $child) {
            /** @var $child \Symfony\Component\Form\FormBuilderInterface */
            $child->setDisabled(true);
        }

        $form = $formBuilder->getForm();
        $form->setData($this->getCertificate());

        return array(
            "form" => $form->createView(),
            "formEnabled" => false,
            "routeBaseName" => $this->getPathBaseName(),
            "sections"       => $this->container->getParameter("config.sections"),
            "sub_section"    => $this->getSubSection(),
            "active_section" => "certificate",
        );
    }

    protected function createCertForm()
    {
        return $this->createForm(new CertForm());
    }

    public function editAction()
    {
        $request = $this->getRequest();

        $form = $this->createCertForm();
        $certificate = $this->getCertificate();
        $form->setData($certificate);

        if ($request->isMethod("POST") && !$request->request->has("upload")) {
            try {
                $form->submit($request);

                if ($form->isValid()) {
                    return $this->handleEdit($form->getData());
                }
            } catch (\Exception $e) {
                $this->getLogger()->error("Error saving certificate", array("exception" => $e));
                $msg = $this->tr("admin.cert.error.save", array("%errmsg%" => $e->getMessage()));
                $this->addError($msg);
            }
        }

        $uploadForm = $this->getUploadForm();
        if ($uploadForm instanceof Response) {
            return $uploadForm;
        }

        return array(
            "form" => $form->createView(),
            "uploadForm" => $uploadForm,
            "formLegend" => $this->getFormLegend(),
            "uploadFormLegend" => $this->getUploadFormLegend(),
            "formEnabled" => true,
            "routeBaseName" => $this->getPathBaseName(),
            "sections"       => $this->container->getParameter("config.sections"),
            "sub_section"    => $this->getSubSection(),
            "active_section" => "certificate",
        );
    }

    /**
     * @param Certificate $certificate
     * @return \Symfony\Component\HttpFoundation\Response
     */
    abstract protected function handleEdit(Certificate $certificate);

    protected function createUploadForm()
    {
        return $this->createForm(new CertUploadForm());
    }

    protected function getUploadForm()
    {
        $request = $this->getRequest();

        $form = $this->createUploadForm();
        $form->setData(array(
                "file" => null
        ));

        if ($request->isMethod("POST") && $request->request->has("upload")) {
            try {
                $form->bind($request);
                if ($form->isValid()) {
                    return $this->handleUpload($form->getData());
                }
            } catch (\Exception $e) {
                $this->getLogger()->error("Error saving uploaded certificate", array("exception" => $e));
                $msg = $this->tr("admin.cert.error.upload", array("%errmsg%" => $e->getMessage()));
                $this->addError($msg);
                return $this->redirect($this->generateUrl($this->getPathBaseName()));
            }
        }

        return $form->createView();
    }

    abstract protected function getFormLegend();

    abstract protected function getUploadFormLegend();

    /**
     * @param array $data
     * @return \Symfony\Component\HttpFoundation\Response
     */
    abstract protected function handleUpload(array $data);
}
