<?php
namespace Topalis\Certificate\Controller;

use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Symfony\Component\HttpFoundation\Response;
use Topalis\Certificate\Certificate;
use Topalis\Certificate\Exception\CertificateException;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;

/**
 *
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 *
 * @Route("/admin/config/cert/ca", service="cacert.controller")
 */
class CACertController extends AbstractCertController
{
    /**
     * @Route("", name="admin_cacert")
     * @Template("TopalisCertificateBundle:Cert:ca_cert.html.twig")
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse|\Symfony\Component\HttpFoundation\Response
     */
    // avoid useless method override warning
    // @codingStandardsIgnoreStart
    public function indexAction()
    {
        return parent::indexAction();
    }
    // @codingStandardsIgnoreEnd

    /**
     * @Route("/edit", name="admin_cacert_edit")
     * @Template("TopalisCertificateBundle:Cert:ca_cert.html.twig")
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse|\Symfony\Component\HttpFoundation\Response
     */
    // avoid useless method override warning
    // @codingStandardsIgnoreStart
    public function editAction()
    {
        return parent::editAction();
    }
    // @codingStandardsIgnoreEnd

    /**
     * @return \Topalis\Certificate\Certificate
     */
    protected function getCertificate()
    {
        $certMgr = $this->getCertificateManager();
        $cert = $certMgr->getCACertificate();
        return ($cert !== null) ? $cert : new Certificate(null, null,
            array("config" => $certMgr->getSslConfigFilename()));
    }

    protected function getPathBaseName()
    {
        return "admin_cacert";
    }

    protected function getTemplate()
    {
        return "admin/caCert.html.twig";
    }

    protected function getUploadFormLegend()
    {
        return $this->tr("admin.cert.ca.upload");
    }

    protected function getFormLegend()
    {
        return $this->tr("admin.cert.ca.create");
    }

    protected function handleEdit(Certificate $certificate)
    {
        $config = $this->getConfig();
        $serial = $config->getAndDecrementCertNextSerial();
        $certPem = $certificate->export($serial);
        $privateKey = $certificate->exportPrivateKey();

        $config = $this->getConfig();
        $config->setCACert($certPem);
        $config->setCAPrivateKey($privateKey);
        $config->setCAChain(serialize(array()));

        $serverCert = $this->getCertificateManager()->getServerCert();
        if (null !== $serverCert && $serverCert->getSignerKeyId() == $certificate->getKeyId()) {
            // server cert is signed by CA so we need to update its chain
            $config->setServerChain(serialize(array($certPem)));
            $this->getCertificateManager()->exportServerCert();
        }

        $this->getCertificateManager()->exportCACert();

        $this->addFlash("success", $this->tr("admin.cert.saveSuccess"));
        return $this->redirect($this->generateUrl("admin_cacert"));
    }

    protected function handleUpload(array $data)
    {
        $content = file_get_contents($data["file"]->getPathname());
        $certs = array();
        openssl_pkcs12_read($content, $certs, $data['password']);

        $caCertPem = null;
        $privateKey = null;
        try {
            openssl_x509_export($certs['cert'], $caCertPem);
            openssl_pkey_export($certs['pkey'], $privateKey);
        } catch (\Exception $e) {
            $msg = "[openssl]: " . $e->getMessage();
            throw new CertificateException($msg, $e->getCode(), $e);
        }

        $chain = array();
        if (isset($certs['extracerts']) && is_array($certs['extracerts'])) {
            $chain = $certs['extracerts'];
        }

        $caCert = new Certificate($caCertPem, $privateKey);

        $this->getDB()->beginTransaction();
        try {
            $config = $this->getConfig();
            $config->setCAChain(serialize($chain));
            $config->setCACert($caCertPem);
            $config->setCAPrivateKey($privateKey);

            $serverCert = $this->getCertificateManager()->getServerCert();
            if (null !== $serverCert && $serverCert->getSignerKeyId() == $caCert->getKeyId()) {
                // server cert is signed by CA so we need to update its chain
                $serverChain = $chain;
                array_unshift($serverChain, $caCertPem);
                $config->setServerChain(serialize($serverChain));
                $this->getCertificateManager()->exportServerCert();
            }

            $this->getCertificateManager()->exportCACert();
            $this->getDB()->commitTransaction();
            return $this->redirect($this->generateUrl("admin_cacert"));
        } catch (\Exception $e) {
            $this->getDB()->rollbackTransaction();
            throw $e;
        }
    }

    /**
     * @return string name of the active subsection
     */
    protected function getSubSection()
    {
        return "ca";
    }
}
