<?php
namespace Topalis\Certificate\Controller;

use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Topalis\Certificate\Certificate;
use Topalis\Certificate\Exception\CertificateException;
use Topalis\Certificate\Form\CertForm;
use Topalis\Certificate\Form\CertUploadForm;
use Topalis\Certificate\ServerCertificate;

/**
 * Server Certificate Controller
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 *
 * @Route("/admin/config/cert/server", service="servercert.controller")
 */
class ServerCertController extends AbstractCertController
{
    /**
     * @Route("", name="admin_servercert")
     * @Template("TopalisCertificateBundle:Cert:server_cert.html.twig")
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse|\Symfony\Component\HttpFoundation\Response
     */
    // avoid useless method override warning
    // @codingStandardsIgnoreStart
    public function indexAction()
    {
        return parent::indexAction();
    }
    // @codingStandardsIgnoreEnd

    /**
     * @Route("/edit", name="admin_servercert_edit")
     * @Template("TopalisCertificateBundle:Cert:server_cert.html.twig")
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse|\Symfony\Component\HttpFoundation\Response
     */
    // avoid useless method override warning
    // @codingStandardsIgnoreStart
    public function editAction()
    {
        return parent::editAction();
    }
    // @codingStandardsIgnoreEnd

    protected function getCertificate()
    {
        $cert = $this->getCertificateManager()->getServerCert();
        if ($cert !== null) {
            return $cert;
        }

        $caCert = $this->getCertificateManager()->getCACertificate();
        $cert = new ServerCertificate($this->getCertificateManager(), $caCert->getPem());
        $cert->setCommonName($this->getConfig()->getHostname());
        return $cert;
    }

    protected function getPathBaseName()
    {
        return "admin_servercert";
    }

    protected function getTemplate()
    {
        return "admin/serverCert.html.twig";
    }

    protected function getUploadFormLegend()
    {
        return $this->tr("admin.cert.server.upload");
    }


    protected function getFormLegend()
    {
        return $this->tr("admin.cert.server.create");
    }

    protected function createCertForm()
    {
        return $this->createForm(new CertForm(true));
    }

    protected function handleEdit(Certificate $certificate)
    {
        $config = $this->getConfig();

        $serial = $config->getAndDecrementCertNextSerial();
        $cert = $certificate->export($serial);
        $privateKey = $certificate->exportPrivateKey();

        $config->setServerCert($cert);
        $config->setServerPrivateKey($privateKey);
        $config->setServerChain(serialize($this->getCertificateManager()->getChainedCACert()));
        $this->getCertificateManager()->exportServerCert();

        $this->addFlash("success", $this->tr("admin.cert.saveSuccess"));

        return $this->redirect($this->generateUrl("admin_servercert"));
    }

    protected function createUploadForm()
    {
        return $this->createForm(new CertUploadForm(), array(), array(
            "constraints" => new \Topalis\Certificate\Validator\ServerCertificate()
        ));
    }

    protected function handleUpload(array $data)
    {
        $content = file_get_contents($data['file']->getPathname());
        $certs = array();
        openssl_pkcs12_read($content, $certs, $data['password']);

        $cert = null;
        $pkey = null;
        try {
            openssl_x509_export($certs['cert'], $cert);
            openssl_pkey_export($certs['pkey'], $pkey);
        } catch (\Exception $e) {
            $msg = "[openssl]: " . $e->getMessage();
            throw new CertificateException($msg, $e->getCode(), $e);
        }

        $chain = (isset($certs['extracerts']) && is_array($certs['extracerts']))
                ?  $certs['extracerts'] : array();

        $this->getDB()->beginTransaction();
        try {
            $config = $this->getConfig();
            $config->setServerCert($cert);
            $config->setServerPrivateKey($pkey);
            $config->setServerChain(serialize($chain));

            $this->getCertificateManager()->exportServerCert();
            $this->getDB()->commitTransaction();
            return $this->redirect($this->generateUrl("admin_servercert"));
        } catch (\Exception $e) {
            $this->getDB()->rollbackTransaction();
            throw $e;
        }
    }

    /**
     * @return string name of the active subsection
     */
    protected function getSubSection()
    {
        return "server";
    }
}
