<?php
namespace Topalis\Certificate;

use Symfony\Component\Validator\Constraints;
use Symfony\Component\Validator\Constraints\NotBlank;
use Symfony\Component\Validator\Mapping\ClassMetadata;

/**
 * Push certificate class. Aditional Fields are inserted as name.
 *
 * @author Florian Pfitzer <florian.pfitzer@to.com>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class PushCertificate extends Certificate
{
    /**
     * @var string
     */
    protected $firstname;

    /**
     * @var string
     */
    protected $lastname;

    /**
     * @var string
     */
    protected $street;

    /**
     * @var string
     */
    protected $houseNo;

    /**
     * @var string
     */
    protected $phone;

    /**
     * @var string
     */
    protected $zipCode;

    public function __construct($auralisId = null, $certificate = null, $privateKey = null, $configArgs = array())
    {
        // 2048 bit key length is required by Apple
        parent::__construct($certificate, $privateKey, $configArgs + array("private_key_bits" => 2048));
        $this->setCommonName("com.auralis.push-" . $auralisId);

    }

    public static function loadValidatorMetadata(ClassMetadata $metadata)
    {
        $regexConstraint = new Constraints\Regex(array(
            'pattern' => '/=/',
            'match'   => false,
            'message' => 'pushCert.equalSign',
        ));
        $metadata
            ->addPropertyConstraint("firstname", new NotBlank())
            ->addPropertyConstraint("firstname", $regexConstraint)
            ->addPropertyConstraint("lastname", new NotBlank())
            ->addPropertyConstraint("lastname", $regexConstraint)
            ->addPropertyConstraint("street", new NotBlank())
            ->addPropertyConstraint("lastname", $regexConstraint)
            ->addPropertyConstraint("houseNo", new NotBlank())
            ->addPropertyConstraint("houseNo", $regexConstraint)
            ->addPropertyConstraint("phone", new NotBlank())
            ->addPropertyConstraint("phone", $regexConstraint)
            ->addPropertyConstraint("zipCode", new NotBlank())
            ->addPropertyConstraint("zipCode", $regexConstraint)
        ;
    }

    protected function getCertData()
    {
        $data = parent::getCertData();

        // evil certificate hax
        $data['name'] =
            "/firstname=" . $this->getFirstname() . "/lastname=" . $this->getLastname() .
            "/street=" . $this->getStreet() . "/houseNo=" . $this->getHouseNo() .
            "/zipCode=" . $this->getZipCode() . "/phone=" . $this->getPhone()
        ;

        return $data;
    }

    /**
     * @return string
     */
    public function getFirstname()
    {
        return $this->firstname;
    }

    /**
     * @param string $firstname
     *
     * @return $this
     */
    public function setFirstname($firstname)
    {
        if ($this->firstname != $firstname) {
            $this->internalClear();
            $this->firstname = $firstname;
        }

        return $this;
    }

    /**
     * @return string
     */
    public function getHouseNo()
    {
        return $this->houseNo;
    }

    /**
     * @param string $houseNo
     *
     * @return $this
     */
    public function setHouseNo($houseNo)
    {
        if ($this->houseNo != $houseNo) {
            $this->internalClear();
            $this->houseNo = $houseNo;
        }

        return $this;
    }

    /**
     * @return string
     */
    public function getLastname()
    {
        return $this->lastname;
    }

    /**
     * @param string $lastname
     *
     * @return $this
     */
    public function setLastname($lastname)
    {
        if ($this->lastname != $lastname) {
            $this->internalClear();
            $this->lastname = $lastname;
        }

        return $this;
    }

    /**
     * @return string
     */
    public function getPhone()
    {
        return $this->phone;
    }

    /**
     * @param string $phone
     *
     * @return $this
     */
    public function setPhone($phone)
    {
        if ($this->phone != $phone) {
            $this->internalClear();
            $this->phone = $phone;
        }

        return $this;
    }

    /**
     * @return string
     */
    public function getStreet()
    {
        return $this->street;
    }

    /**
     * @param string $street
     *
     * @return $this
     */
    public function setStreet($street)
    {
        if ($this->street != $street) {
            $this->internalClear();
            $this->street = $street;
        }

        return $this;
    }

    /**
     * @return string
     */
    public function getZipCode()
    {
        return $this->zipCode;
    }

    /**
     * @param string $zipCode
     * @return \Topalis\Certificate\PushCertificate $this
     */
    public function setZipCode($zipCode)
    {
        if ($this->zipCode != $zipCode) {
            $this->internalClear();
            $this->zipCode = $zipCode;
        }

        return $this;
    }
}
