<?php
namespace Topalis\Certificate;

use Symfony\Component\Validator\Mapping\ClassMetadata;

/**
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class ServerCertificate extends Certificate
{
    /**
     * @var \Topalis\Certificate\CertificateManager
     */
    private $certificateManager;

    public function __construct(\Topalis\Certificate\CertificateManager $certificateManager,
        $certificate = null, $privateKey = null, $configArgs = array())
    {
        $this->certificateManager = $certificateManager;

        $configArgs += array(
            "config" => $this->getCertificateManager()->getSslConfigFilename(),
            "x509_extensions" => "server_cert"
        );
        parent::__construct($certificate, $privateKey, $configArgs);
    }

    public function exportPrivateKey()
    {
        $tmp = null;
        try {
            openssl_pkey_export($this->getPrivateKey(), $tmp, '', array("encrypt_key" => false));
        } catch (\Exception $e) {
            $msg = sprintf("[openssl]: %s", $e->getMessage());
            throw new Exception\CreateCertificateException($msg, $e->getCode(), $e);
        }

        return $tmp;
    }

    /**
     * @return \Topalis\Certificate\CertificateManager
     */
    protected function getCertificateManager()
    {
        return $this->certificateManager;
    }

    /**
     * Validation Vodoo
     * @param \Symfony\Component\Validator\Mapping\ClassMetadata $metadata
     */
    public static function loadValidatorMetadata(ClassMetadata $metadata)
    {
        $metadata->addPropertyConstraint("commonName", new \Topalis\Certificate\Validator\Hostname());
    }

    /**
     * @param integer     $serial The serial for server certificates MUST NOT be null.
     * @param Certificate $caCert The CA certificate to sign the certificate.
     *                            If null the CA certificate will be loaded from the CertificateManager.
     * @param integer $days specifies the length of time for which the
     *     generated certificate will be valid, in days.
     * @throws Exception\CreateCertificateException
     * @throws \InvalidArgumentException If $serial is null.
     * @return resource
     */
    public function sign($serial = null, Certificate $caCert = null, $days = 3650)
    {
        if ($serial === null) {
            throw new \InvalidArgumentException("The serial for server certificates must not be null");
        }

        if ($caCert === null) {
            $caCert = $this->getCertificateManager()->getCACertificate();
        }

        return parent::sign($serial, $caCert, $days);
    }

}
