<?php
namespace Topalis\Compliance\Action;

use Symfony\Component\DependencyInjection\ContainerAware;
use Topalis\Compliance\Exception\InvalidArgumentException;
use Topalis\Compliance\Exception\NoSuchComplianceActionException;
use Symfony\Component\DependencyInjection\Exception\ServiceNotFoundException;

/**
 * ComplianceActionContainer
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class ComplianceActionContainer extends ContainerAware implements ComplianceActionContainerInterface
{
    private $actions = array();

    /**
     * Constructor.
     *
     * @param array $actions Array of key-value pairs with key the key of the
     *     action and value the action or a service id.
     */
    public function __construct(array $actions = array())
    {
        $this->actions = $actions;
    }

    public function get($key)
    {
        if (!isset($this->actions[$key])) {
            throw new NoSuchComplianceActionException(sprintf("No compliance action with key \"%s\" found", $key));
        }

        $action = $this->actions[$key];
        if (is_string($action)) {
            try {
                $this->actions[$key] = $action = $this->container->get($action);
            } catch (ServiceNotFoundException $e) {
                throw new NoSuchComplianceActionException(
                    sprintf("No compliance action with key \"%s\" found", $key), $e->getCode(), $e);
            }
        }

        return $action;
    }

    public function add($key, ComplianceActionInterface $action)
    {
        $this->actions[$key] = $action;

        return $this;
    }

    public function addService($key, $serviceId)
    {
        $this->actions[$key] = $serviceId;

        return $this;
    }
}
