<?php
namespace Topalis\Compliance\Action;

/**
 * Container for actions that may be performed after a compliance check.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
interface ComplianceActionContainerInterface
{
    /**
     * @param string $key The key of the compliance action to get.
     *
     * @return ComplianceActionInterface The compliance action with the
     *     specified key.
     *
     * @throws \Topalis\Compliance\Exception\NoSuchComplianceActionException
     *     If no compliance action exists for the key.
     */
    public function get($key);

    /**
     * @param string $key The key of the compliance action to add.
     * @param ComplianceActionInterface $action The compliance action to add.
     *
     * @return ComplianceActionContainerInterface
     */
    public function add($key, ComplianceActionInterface $action);

    /**
     * @param string $key The key of the compliance action service to add.
     * @param string $serviceId The service id of the compliance action to add.
     *
     * @return ComplianceActionContainerInterface
     */
    public function addService($key, $serviceId);
}
