<?php
namespace Topalis\Compliance\Action;

use Topalis\Device\Entity\Device;
use Topalis\Compliance\ComplianceVerificationResultInterface;
use Topalis\Compliance\PreviousComplianceVerificationResultInterface;

/**
 * A compliance action may be performed after a compliance check.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
interface ComplianceActionInterface
{
    /**
     * Performs the compliance action.
     *
     * @param array $options An array that may contain configuration options.
     * @param Device $device The device that was checked.
     * @param ComplianceVerificationResultInterface $verificationResult The
     *     result of the check.
     * @param PreviousComplianceVerificationResultInterface $previousVerificationResult
     *     The result of the previous check. Contains no rule validation results
     *     if there was no previous check.
     * @param array $actions The configured actions.
     *
     * @return ComplianceActionResult
     */
    public function perform(array $options, Device $device, ComplianceVerificationResultInterface $verificationResult,
        PreviousComplianceVerificationResultInterface $previousVerificationResult, array $actions);

    /**
     * Hook that will be called if the action is removed from the compliance,
     * or the action is not enabled after a compliance change, anymore.
     *
     * @param Device $device The affected device.
     */
    public function onRemove(Device $device);
}
