<?php
namespace Topalis\Compliance\Action;

use Psr\Log\LoggerInterface;
use Topalis\Device\DeviceManager;
use Topalis\Device\Entity\Device;
use Topalis\Compliance\Entity\RuleValidation;

/**
 * This compliance action disables ActiveSync if a rule is violated. If no rule
 * is violated ActiveSync is enabled again.
 */
class DisableActiveSyncComplianceAction extends AbstractDelayedComplianceAction
{
    /**
     * @var \Topalis\Device\DeviceManager
     */
    private $deviceManager;

    /**
     * @var \Psr\Log\LoggerInterface
     */
    private $logger;

    /**
     * Constructor.
     *
     * @param DeviceManager $deviceManager
     * @param LoggerInterface $logger
     */
    public function __construct(DeviceManager $deviceManager, LoggerInterface $logger)
    {
        $this->deviceManager = $deviceManager;
        $this->logger = $logger;
    }

    public function onRemove(Device $device)
    {
        $this->deviceManager->setActiveSyncDisabled($device, false);
    }

    protected function onNoViolation(array $options, Device $device, array $actions)
    {
        $options; // unused
        $actions; // unused
        $this->deviceManager->setActiveSyncDisabled($device, false);
    }

    protected function onViolation(array $options, Device $device, RuleValidation $ruleValidation, array $actions)
    {
        $actions; // unused

        $delay = $options['delay'];
        $this->logger->info(
            "Rule \"" . $ruleValidation->getRule()->getType() . "\" is violated for more than "
            . $delay . " seconds. ActiveSync is going to be disabled on Device \""
            . $device->getCombinedName() . "\".",
            array("device" => $device->getCombinedId()));
        $this->deviceManager->setActiveSyncDisabled($device, true);
    }
}
