<?php
namespace Topalis\Compliance\Action;

use Psr\Log\LoggerInterface;
use Topalis\Device\DeviceManager;
use Topalis\Device\Entity\Device;
use Topalis\Compliance\Entity\RuleValidation;

/**
 * This compliance action disables/wipes the device if a rule is validated for
 * more than a specified delay.
 */
class DisableDeviceComplianceAction extends AbstractDelayedComplianceAction
{
    /**
     * @var \Topalis\Device\DeviceManager
     */
    private $deviceManager;

    /**
     * @var \Psr\Log\LoggerInterface
     */
    private $logger;

    /**
     * Constructor.
     *
     * @param DeviceManager $deviceManager
     * @param LoggerInterface $logger
     */
    public function __construct(DeviceManager $deviceManager, LoggerInterface $logger)
    {
        $this->deviceManager = $deviceManager;
        $this->logger = $logger;
    }

    public function onRemove(Device $device)
    {
    }

    protected function onViolation(array $options, Device $device, RuleValidation $ruleValidation, array $actions)
    {
        $actions; // unused

        $delay = $options['delay'];
        $this->getLogger()->info(sprintf(
            "Rule \"%s\" is violated for more than %d seconds. The device \"%s\" is going to be wiped.",
            $ruleValidation->getRule()->getType(), $delay, $device->getCombinedName()
        ), array("device" => $device->getCombinedId()));
        $this->deviceManager->disableDevice($device);
    }

    private function getLogger()
    {
        return $this->logger;
    }
}
