<?php
namespace Topalis\Compliance\Command;

use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Ensures that a compliance control job is running for all compliances.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class ComplianceControlJobEnsureCommand extends ContainerAwareCommand
{
    protected function configure()
    {
        $this
            ->setName("compliance:control:job:ensure")
            ->addOption("interval", "i", InputOption::VALUE_OPTIONAL,
                "The interval in seconds in wich it is ensured the control jobs exist."
                . " If not specified the check will be executed once."
            )
            ->setDescription("Ensure compliance control jobs exist.")
            ->setHelp("The command ensures that a control job for every compliance exists in the queue.");
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $output; // unused

        $interval = $input->getOption("interval");
        if ($interval !== null) {
            if (!is_numeric($interval)) {
                throw new \InvalidArgumentException("The interval must be an integer");
            }
            if ($interval <= 0) {
                throw new \InvalidArgumentException("The interval must be at least 1 second");
            }
        }

        $jobEnsurer = $this->getContainer()->get("compliance.job.control_job_ensurer");
        if (null === $interval) {
            $jobEnsurer->ensureJobsExist();
        } else {
            do {
                $jobEnsurer->ensureJobsExist();
                sleep($interval);
            } while (true);
        }
    }
}
