<?php
namespace Topalis\Compliance;

use Topalis\Compliance\Entity\Compliance;
use Topalis\Device\Entity\Device;

/**
 * A compliance manager manages compliances and the verification results.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
interface ComplianceManagerInterface
{
    /**
     * @param Device $device The device to get the compliance for.
     *
     * @return \Topalis\Compliance\Entity\Compliance|null The compliance for
     *     the device, or null if no compliance is configured for the device.
     */
    public function getComplianceForDevice(Device $device);

    /**
     * @param Device $device The device to check if it has a compliance.
     *
     * @return bool true if there exists a compliance for the device, false
     *     otherwise.
     */
    public function hasComplianceForDevice(Device $device);

    /**
     * @param Device $device The device to get the last result for.
     *
     * @return PreviousComplianceVerificationResultInterface The result of the
     *     last compliance verification.
     */
    public function getLastResult(Device $device);

    /**
     * @param Device $device The device to get the performed actions for.
     *
     * @return array Array with pairs of action name and the UNIX timestamp the
     *    action has been performed.
     */
    public function getPerformedActions(Device $device);

    /**
     * @param Device $device The device to get the planned actions for.
     *
     * @return array Array with pairs of action name and the UNIX timestamp the
     *    action has been planned to be performed.
     */
    public function getPlannedActions(Device $device);

    /**
     * Verifies the compliance of the device and persists the result.
     *
     * @param Device $device The device to verify.
     */
    public function verify(Device $device);
}
