<?php
namespace Topalis\Compliance;

use Topalis\Compliance\Rule\RuleValidationResultInterface;
use Topalis\Compliance\Entity\Rule;

/**
 * ComplianceVerificationResult
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class ComplianceVerificationResult implements ComplianceVerificationResultInterface
{
    private $passed = array();

    private $results = array();

    private $violated = array();

    public function addValidationResult(Rule $rule, RuleValidationResultInterface $validationResult)
    {
        $resultArray = array(
            "rule" => $rule,
            "result" => $validationResult
        );
        $key = $rule->getId() ?: $this->composeKey($rule);
        if ($validationResult->isViolated()) {
            $this->violated[$key] = $resultArray;
        } else {
            $this->passed[$key] = $resultArray;
        }

        $this->results[$key] = $resultArray;
    }

    public function getPassed()
    {
        return $this->passed;
    }

    public function getViolated()
    {
        return $this->violated;
    }

    public function getValidationResult(Rule $rule)
    {
        if ($rule->getId() !== null && isset($this->results[$rule->getId()])) {
            return $this->results[$rule->getId()]['result'];
        }

        $key = $this->composeKey($rule);
        return isset($this->results[$key]) ? $this->results[$key]['result'] : null;
    }

    public function getValidationResults()
    {
        return $this->results;
    }

    public function hasNewViolations(ComplianceVerificationResultInterface $previousResult)
    {
        foreach ($this->violated as $violation) {
            $previousValidationResult = $previousResult->getValidationResult($violation['rule']);
            if (null === $previousValidationResult || !$previousValidationResult->isViolated()) {
                return true;
            }
        }

        return false;
    }

    /**
     * Composes a key that can be used for rules that do not have a id, yet.
     *
     * @param Rule $rule The rule to compose the key for.
     * @return string The composed key.
     */
    protected function composeKey(Rule $rule)
    {
        return $rule->getCompliance() ? $rule->getCompliance()->getName() : null
            . "|" . $rule->getOs() . "|" . $rule->getType();
    }
}
