<?php
namespace Topalis\Compliance;

use Topalis\Compliance\Entity\Rule;

/**
 * A compliance verification result holds the result of a compliance
 * verification check.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
interface ComplianceVerificationResultInterface
{
    /**
     * Returns the rules and validation results of passed rules.
     *
     * @return array Array of arrays with the keys "rule" and "result". The
     *     entry "rule" has an object of type \Topalis\Compliance\Entity\Rule
     *     as value. The entry "result" has the corresponding object of type
     *     \Topalis\Compliance\Rule\RuleValidationResultInterface as value.
     */
    public function getPassed();

    /**
     * Returns the rules and validation results of violated rules.
     *
     * @return array Array of arrays with the keys "rule" and "result". The
     *     entry "rule" has an object of type \Topalis\Compliance\Entity\Rule
     *     as value. The entry "result" has the corresponding object of type
     *     \Topalis\Compliance\Rule\RuleValidationResultInterface as value.
     */
    public function getViolated();

    /**
     * @param Rule $rule The rule to get the validation result for.
     *
     * @return \Topalis\Compliance\Rule\RuleValidationResultInterface|NULL The
     *     validation result for the specified rule, or null if no result for
     *     the rule exists.
     */
    public function getValidationResult(Rule $rule);

    /**
     * Returns all validation results.
     *
     * @return array Array of arrays with the keys "rule" and "result". The
     *     entry "rule" has an object of type \Topalis\Compliance\Entity\Rule
     *     as value. The entry "result" has the corresponding object of type
     *     \Topalis\Compliance\Rule\RuleValidationResultInterface as value.
     */
    public function getValidationResults();

    /**
     * @param ComplianceVerificationResultInterface $previousResult The result
     *     to compare with.
     *
     * @return boolean true If the result has rule violations that aren't in the
     *     specified previous result.
     */
    public function hasNewViolations(ComplianceVerificationResultInterface $previousResult);
}
