<?php
namespace Topalis\Compliance\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Topalis\ConfigGroup\Entity\ConfigGroup;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Topalis\Compliance\Entity\Compliance;

/**
 * ConfigGroupController for Compliances.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 *
 * @Route("/admin/group/{group}/section/compliance")
 */
class ConfigGroupController extends Controller
{
    /**
     * @param ConfigGroup                   $group
     *
     * @return array
     *
     * @Route("", name="admin_group_section_compliance")
     * @Template()
     */
    public function indexAction(ConfigGroup $group)
    {
        $em = $this->get("compliance.entity.manager.compliance");
        $compliances = $em->findAll();
        $deviceCount = array();
        $violatingDeviceCount = array();
        foreach ($compliances as $compliance) {
            $deviceCount[$compliance->getId()] = $em->getDeviceCount($compliance);
            $violatingDeviceCount[$compliance->getId()] = $em->getViolatingDeviceCount($compliance);
        }

        return array(
            "compliances"      => $compliances,
            "deviceCount"          => $deviceCount,
            "violatingDeviceCount" => $violatingDeviceCount,
            "group"            => $group,
        );
    }

    /**
     * @Route("/{compliance}/enable", name="admin_compliance_group_enable")
     *
     * @param ConfigGroup $group
     * @param Compliance $compliance
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function enable(ConfigGroup $group, Compliance $compliance)
    {
        $em = $this->container->get("compliance.entity.manager.compliance");
        $currentCompliance = $em->getComplianceForGroup($group);
        if (null !== $currentCompliance && $currentCompliance !== $compliance) {
            $msg = $this->container->get("translator")->trans("compliance.group.alreadyHasCompliance", array(
                "%group%" => $group->getName(),
                "%compliance%" => $currentCompliance->getName(),
            ), "validators");
            $this->container->get("session")->getFlashBag()->add("error", $msg);
        } else {
            $compliance->addGroup($group);
            $em->save($compliance);
        }

        return $this->redirect(
            $this->generateUrl("admin_group_section_compliance", array("group" => $group->getId()))
        );
    }

    /**
     * @Route("/{compliance}/disable", name="admin_compliance_group_disable")
     *
     * @param ConfigGroup $group
     * @param Compliance $compliance
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function disable(ConfigGroup $group, Compliance $compliance)
    {
        $compliance->removeGroup($group);
        $this->get("compliance.entity.manager.compliance")->save($compliance);

        return $this->redirect(
            $this->generateUrl("admin_group_section_compliance", array("group" => $group->getId()))
        );
    }
}
