<?php
namespace Topalis\Compliance\DependencyInjection\Compiler;

use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Exception\InvalidArgumentException;

/**
 * This pass adds services tagged with topalis.compliance.action to the
 * compliance action container.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class ActionPass implements CompilerPassInterface
{
    public function process(ContainerBuilder $container)
    {
        $actions = array();
        foreach ($container->findTaggedServiceIds("topalis.compliance.action") as $serviceId => $tag) {
            $key = $tag[0]['key'];
            if (isset($actions[$key])) {
                throw new InvalidArgumentException(sprintf("Duplicate compliance action key \"%s\"", $key));
            }

            $actions[$key] = $serviceId;
        }

        $container->getDefinition("compliance.action.container")->addArgument($actions);
    }
}
