<?php
namespace Topalis\Compliance\Device\Info;

use Symfony\Component\Templating\EngineInterface;
use Symfony\Component\Translation\TranslatorInterface;
use Topalis\Compliance\ComplianceManager;
use Topalis\Compliance\Util\ComplianceVerificationUtils;
use Topalis\Device\Entity\Device;
use Topalis\Device\Info\DeviceInfoSectionInterface;

/**
 * The compliance section in the device information.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class ComplianceDeviceInfoSection implements DeviceInfoSectionInterface
{
    /**
     * @var \Topalis\Compliance\ComplianceManager
     */
    private $complianceManager;

    /**
     * @var \Symfony\Bundle\FrameworkBundle\Templating\EngineInterface
     */
    private $templating;

    /**
     * @var \Symfony\Component\Translation\TranslatorInterface
     */
    private $translator;

    public function __construct(ComplianceManager $complianceManager,
        TranslatorInterface $translator, EngineInterface $templating)
    {
        $this->complianceManager = $complianceManager;
        $this->translator = $translator;
        $this->templating = $templating;
    }

    public function getKey()
    {
        return "compliance";
    }

    public function getTabAttributes()
    {
        return array();
    }

    public function getTitle()
    {
        return "admin.compliance.title";
    }

    public function isVisible(Device $device)
    {
        return $this->complianceManager->getComplianceForDevice($device) !== null;
    }

    public function renderContent(Device $device)
    {
        $verificationResult = $this->complianceManager->getLastResult($device);
        $violationMessages = ComplianceVerificationUtils::getViolationMessages($verificationResult, $this->translator);
        $performedActions = $this->complianceManager->getPerformedActions($device);
        $plannedActions = $this->complianceManager->getPlannedActions($device);
        return $this->templating->render("TopalisComplianceBundle:Device:info.html.twig", array(
            "device" => $device,
            "violationMessages" => $violationMessages,
            "performedActions" => $performedActions,
            "plannedActions" => $plannedActions
        ));
    }
}
