<?php
namespace Topalis\Compliance\Entity;

use Doctrine\ORM\Mapping as ORM;
use Topalis\Device\Entity\Device;

/**
 * Represents a compliance action for a device. It is either performed or going
 * to be performed.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 *
 * @ORM\Entity
 * @ORM\Table(name="compliance_device_actions", indexes={
 *    @ORM\Index(columns={"time"})
 * }, uniqueConstraints={
 *    @ORM\UniqueConstraint(columns={"device_id", "action"})
 * })
 */
class DeviceAction
{
    /**
     * @var int
     *
     * @ORM\Column(type="integer", options={"unsigned"=true})
     * @ORM\Id @ORM\GeneratedValue(strategy="IDENTITY")
     */
    protected $id;

    /**
     * @var Device
     *
     * @ORM\ManyToOne(targetEntity="Topalis\Device\Entity\Device")
     * @ORM\JoinColumn(nullable=false, onDelete="CASCADE")
     */
    protected $device;

    /**
     * @var string
     *
     * @ORM\Column(type="string")
     */
    protected $action;

    /**
     * @var int
     *
     * @ORM\Column(type="integer", nullable=true, options={"unsigned"=true})
     */
    protected $time;

    /**
     * @var bool
     *
     * @ORM\Column(type="boolean")
     */
    protected $performed = false;

    /**
     *
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     *
     * @return Device
     */
    public function getDevice()
    {
        return $this->device;
    }

    /**
     *
     * @param Device $device
     *
     * @return DeviceAction
     */
    public function setDevice(Device $device)
    {
        $this->device = $device;
        return $this;
    }

    /**
     *
     * @return string
     */
    public function getAction()
    {
        return $this->action;
    }

    /**
     *
     * @param string $action
     *
     * @return DeviceAction
     */
    public function setAction($action)
    {
        $this->action = $action;
        return $this;
    }

    /**
     *
     * @return int
     */
    public function getTime()
    {
        return $this->time;
    }

    /**
     *
     * @param int $time
     *
     * @return DeviceAction
     */
    public function setTime($time)
    {
        $this->time = $time;
        return $this;
    }

    /**
     *
     * @return bool
     */
    public function isPerformed()
    {
        return $this->performed;
    }

    /**
     *
     * @param bool $performed
     *
     * @return DeviceAction
     */
    public function setPerformed($performed)
    {
        $this->performed = $performed;
        return $this;
    }
}
