<?php
namespace Topalis\Compliance\Entity;

use Topalis\Database\EntityManager;
use Topalis\Device\Entity\Device;

/**
 * DeviceActionEntityManager
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class DeviceActionEntityManager extends EntityManager
{
    public function __construct(\Doctrine\ORM\EntityManager $em)
    {
        parent::__construct($em, "Topalis\Compliance\Entity\DeviceAction");
    }

    /**
     * Returns the persisted DeviceAction with the specified device and the
     * specified action. If it does not exist a new one will be created (but not
     * persisted).
     *
     * @param Device $device
     * @param string $action
     *
     * @return \Topalis\Compliance\Entity\DeviceAction
     */
    public function findOrCreate(Device $device, $action)
    {
        $deviceAction = $this->findOneBy(array("device" => $device, "action" => $action));
        if (null !== $deviceAction) {
            return $deviceAction;
        }

        $deviceAction = new DeviceAction();
        $deviceAction->setDevice($device);
        $deviceAction->setAction($action);
        return $deviceAction;
    }
}
