<?php
namespace Topalis\Compliance\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * Represents a compliance rule.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 *
 * @ORM\Entity
 * @ORM\Table(name="compliance_rules")
 */
class Rule
{
    /**
     * @var integer
     * @ORM\Column(type="integer", options={"unsigned"=true})
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    protected $id;

    /**
     * @var Compliance
     * @ORM\ManyToOne(targetEntity="Compliance", inversedBy="rules", cascade={"persist"})
     * @ORM\JoinColumn(nullable=false, onDelete="CASCADE")
     */
    protected $compliance;

    /**
     * @var string
     * @ORM\Column(type="string", nullable=true)
     */
    protected $os;

    /**
     * @var string
     * @ORM\Column(type="string")
     */
    protected $type;

    /**
     * "condition" is a reserved keyword so we use "rule_condition"
     * @var string
     * @ORM\Column(name="rule_condition", type="string", length=1023)
     */
    protected $condition;

    /**
     * UNIX timestamp of the last condition change.
     * @var integer
     * @ORM\Column(type="integer", options={"unsigned"=true})
     */
    protected $lastConditionChange;

    /**
     * Get id
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set os
     *
     * @param string|null $os The OS the rule is intended for, or null if this
     *     rule is intended for all devices.
     * @return Rule
     */
    public function setOs($os)
    {
        $this->os = $os;

        return $this;
    }

    /**
     * Get os
     *
     * @return string|null The OS the rule is intended for, or null if this rule
     *     is intended for all devices.
     */
    public function getOs()
    {
        return $this->os;
    }

    /**
     * Set type
     *
     * @param string $type
     * @return Rule
     */
    public function setType($type)
    {
        $this->type = $type;

        return $this;
    }

    /**
     * Get type
     *
     * @return string
     */
    public function getType()
    {
        return $this->type;
    }

    /**
     * Set condition
     *
     * @param string $condition
     * @return Rule
     */
    public function setCondition($condition)
    {
        $condition = (string) $condition;
        if ($this->condition !== $condition) {
            $this->condition = $condition;
            $this->lastConditionChange = time();
        }

        return $this;
    }

    /**
     * Get condition
     *
     * @return string
     */
    public function getCondition()
    {
        return $this->condition;
    }

    /**
     * Get lastConditionChange
     *
     * @return integer UNIX timestamp of the last condition change.
     */
    public function getLastConditionChange()
    {
        return $this->lastConditionChange;
    }

    /**
     * Set compliance
     *
     * @param \Topalis\Compliance\Entity\Compliance $compliance
     * @return Rule
     */
    public function setCompliance(Compliance $compliance)
    {
        if ($this->compliance === $compliance) {
            return $this;
        }

        if (null !== $this->compliance) {
            $this->compliance->removeRule($this);
        }

        $this->compliance = $compliance;
        $this->compliance->addRule($this);

        return $this;
    }

    /**
     * Get compliance
     *
     * @return \Topalis\Compliance\Entity\Compliance
     */
    public function getCompliance()
    {
        return $this->compliance;
    }
}
