<?php
namespace Topalis\Compliance\Entity;

use Doctrine\ORM\Mapping as ORM;
use Topalis\Device\Entity\Device;

/**
 * Represents the result of a compliance rule validation.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 *
 * @ORM\Entity
 * @ORM\Table(name="compliance_rule_validations",
 *     uniqueConstraints={@ORM\UniqueConstraint(name="validation_result_unique", columns={"device_id", "rule_id"})})
 */
class RuleValidation
{
    /**
     * @var integer
     * @ORM\Column(type="bigint", options={"unsigned"=true})
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    protected $id;

    /**
     * @var \Topalis\Device\Entity\Device
     *
     * @ORM\ManyToOne(targetEntity="Topalis\Device\Entity\Device")
     * @ORM\JoinColumn(nullable=false, onDelete="CASCADE")
     */
    protected $device;

    /**
     * @var Rule
     *
     * @ORM\ManyToOne(targetEntity="Rule")
     * @ORM\JoinColumn(nullable=false, onDelete="CASCADE")
     */
    protected $rule;

    /**
     * @var integer
     *
     * @ORM\Column(type="integer", nullable=false, options={"unsigned"=true})
     */
    protected $lastCheckTime;

    /**
     * @var integer
     *
     * @ORM\Column(type="integer", nullable=true, options={"unsigned"=true})
     */
    protected $violationTime;

    /**
     * @var boolean
     *
     * @ORM\Column(type="boolean")
     */
    protected $violated;

    /**
     * @var array
     *
     * @ORM\Column(type="json_array", length=65532)
     */
    protected $parameters;

    /**
     * Get id
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set lastCheckTime
     *
     * @param integer $lastCheckTime
     * @return RuleValidation
     */
    public function setLastCheckTime($lastCheckTime)
    {
        $this->lastCheckTime = $lastCheckTime;

        return $this;
    }

    /**
     * Get lastCheckTime
     *
     * @return integer
     */
    public function getLastCheckTime()
    {
        return $this->lastCheckTime;
    }

    /**
     * Set violationTime
     *
     * @param integer $violationTime
     * @return RuleValidation
     */
    public function setViolationTime($violationTime)
    {
        $this->violationTime = $violationTime;

        return $this;
    }

    /**
     * Get violationTime
     *
     * @return integer
     */
    public function getViolationTime()
    {
        return $this->violationTime;
    }

    /**
     * Set violated
     *
     * @param boolean $violated
     * @return RuleValidation
     */
    public function setViolated($violated)
    {
        $this->violated = $violated;

        return $this;
    }

    /**
     * Get violated
     *
     * @return boolean
     */
    public function isViolated()
    {
        return $this->violated;
    }

    /**
     * Set device
     *
     * @param \Topalis\Device\Entity\Device $device
     * @return RuleValidation
     */
    public function setDevice(Device $device)
    {
        $this->device = $device;

        return $this;
    }

    /**
     * Get device
     *
     * @return \Topalis\Device\Entity\Device
     */
    public function getDevice()
    {
        return $this->device;
    }

    /**
     * Set rule
     *
     * @param \Topalis\Compliance\Entity\Rule $rule
     * @return RuleValidation
     */
    public function setRule(Rule $rule)
    {
        $this->rule = $rule;

        return $this;
    }

    /**
     * Get rule
     *
     * @return \Topalis\Compliance\Entity\Rule
     */
    public function getRule()
    {
        return $this->rule;
    }

    /**
     * Get violated
     *
     * @return boolean
     */
    public function getViolated()
    {
        return $this->violated;
    }

    /**
     * Set parameters
     *
     * @param array $parameters
     * @return RuleValidation
     */
    public function setParameters(array $parameters)
    {
        $this->parameters = $parameters;

        return $this;
    }

    /**
     * Get parameters
     *
     * @return array
     */
    public function getParameters()
    {
        return $this->parameters;
    }
}
