<?php
namespace Topalis\Compliance\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Doctrine\Common\Collections\ArrayCollection;
use Topalis\WinPhone\MS\MSAppPolicy;

/**
 * This entity represents an app policy for Windows Phones.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 *
 * @ORM\Entity
 */
class WinPhoneAppPolicy
{
    const TYPE_BLACKLIST = 0;
    const TYPE_WHITELIST = 1;

    /**
     * @var integer
     * @ORM\Column(type="integer", options={"unsigned"=true})
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    protected $id;

    /**
     * @var integer
     * @ORM\Column(type="smallint")
     */
    protected $type;

    /**
     * @var string
     * @ORM\Column(type="text", length=16777215)
     */
    protected $policy;

    /**
     * @var Compliance
     * @ORM\OneToOne(targetEntity="Compliance", mappedBy="winPhoneAppPolicy")
     */
    protected $compliance;

    /**
     * Get id
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set type
     *
     * @param integer $type
     * @return WinPhoneAppPolicy
     */
    public function setType($type)
    {
        $this->type = $type;

        return $this;
    }

    /**
     * Get type
     *
     * @return integer
     */
    public function getType()
    {
        return $this->type;
    }

    /**
     * @return string
     */
    public function getPolicy()
    {
        return $this->policy;
    }

    /**
     * @param string|MSAppPolicy $policy
     * @return WinPhoneAppPolicy self
     */
    public function setPolicy($policy)
    {
        if ($policy instanceof MSAppPolicy) {
            $this->policy = $policy->toXml();
            $this->type = $policy->isBlacklist() ? self::TYPE_BLACKLIST : self::TYPE_WHITELIST;
        } else {
            $this->policy = $policy;
        }

        return $this;
    }

    /**
     * Set compliance
     *
     * @param Compliance $compliance
     * @return WinPhoneAppPolicy self
     */
    public function setCompliance(Compliance $compliance)
    {
        if ($this->compliance != $compliance) {
            $this->compliance = $compliance;
            $compliance->setWinPhoneAppPolicy($this);
        }

        return $this;
    }

    /**
     * Get compliance
     *
     * @return Compliance
     */
    public function getCompliance()
    {
        return $this->compliance;
    }

    /**
     * @see \Serializable::serialize()
     */
    public function serialize()
    {
        return serialize(array(
            $this->id,
        ));
    }

    /**
     * @param string $serialized The value returned by serialize().
     * @see \Serializable::unserialize()
     */
    public function unserialize($serialized)
    {
        list ($this->id) = unserialize($serialized);
    }
}
