<?php
namespace Topalis\Compliance\Event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Topalis\Compliance\ComplianceManagerInterface;
use Topalis\Compliance\Job\ComplianceVerifyQueueInterface;
use Topalis\WinPhone\Event\OMA\SyncML\SyncMLEvent;
use Topalis\WinPhone\Event\OMA\SyncML\SyncMLEvents;

/**
 * Initiates a compliance verify job after the device information of a device
 * were received through SyncML.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class SyncMLSubscriber implements EventSubscriberInterface
{
    /**
     * @var \Topalis\Compliance\ComplianceManagerInterface
     */
    private $complianceManager;

    /**
     * @var \Topalis\Compliance\Job\ComplianceVerifyQueueInterface
     */
    private $verifyQueue;

    /**
     * @param ComplianceVerifyQueueInterface $verifyQueue
     * @param ComplianceManagerInterface $complianceManager
     */
    public function __construct(ComplianceVerifyQueueInterface $verifyQueue,
        ComplianceManagerInterface $complianceManager)
    {
        $this->verifyQueue = $verifyQueue;
        $this->complianceManager = $complianceManager;
    }

    public static function getSubscribedEvents()
    {
        return array(
            SyncMLEvents::DEVICE_INFORMATION => "onDeviceInformation",
        );
    }

    /**
     * @param MdmEvent $event
     */
    public function onDeviceInformation(SyncMLEvent $event)
    {
        $device = $event->getDevice();
        if (!$this->complianceManager->hasComplianceForDevice($device)) {
            return;
        }

        $this->verifyQueue->putDevice($device);
    }
}
