<?php
namespace Topalis\Compliance\Form\Event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\Form\FormError;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;

/**
 * This form subscriber validates that an app identifier is not used both as
 * required and forbidden. (Doing the same with a constraint would be more
 * complex.)
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class AppIdentifierSubscriber implements EventSubscriberInterface
{
    public static function getSubscribedEvents()
    {
        return array(FormEvents::POST_SUBMIT => "postSubmit");
    }

    public function postSubmit(FormEvent $event)
    {
        $form = $event->getForm();
        $identifiers = array();
        $appRequiredForm = $form->get("appRequired");
        foreach ($appRequiredForm as $app) {
            $identifierForm = $app->get("identifier");
            $identifier = $identifierForm->getData();
            if (!isset($identifiers[$identifier])) {
                // show error only on first identifier
                $identifiers[$identifier] = $identifierForm;
            }
        }

        $appForbidden = $form->get("appForbidden");
        foreach ($appForbidden as $app) {
            $identifierForm = $app->get("identifier");
            $identifier = $identifierForm->getData();
            if (isset($identifiers[$identifier])) {
                $identifiers[$identifier]->addError(new FormError("compliance.appIdentifier.requiredAndForbidden"));
                $identifierForm->addError(new FormError("compliance.appIdentifier.requiredAndForbidden"));
            }
        }
    }
}
