<?php
namespace Topalis\Compliance\Form\Handler;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\Form\FormError;
use Topalis\Compliance\Entity\ComplianceEntityManager;
use Topalis\Compliance\Entity\WinPhoneAppPolicy;

/**
 * ComplianceFormHandler
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class ComplianceFormHandler
{
    /**
     *
     * @var \Symfony\Component\HttpFoundation\Request
     */
    private $request;

    /**
     * @var \Topalis\Compliance\Entity\Compliance
     */
    private $complianceEntity;

    /**
     * @var \Topalis\Compliance\Entity\ComplianceEntityManager
     */
    private $complianceEm;

    public function __construct(ComplianceEntityManager $complianceEm, Request $request)
    {
        $this->complianceEm = $complianceEm;
        $this->request = $request;
    }

    /**
     *
     * @return \Topalis\Compliance\Entity\Compliance
     */
    public function getComplianceEntity()
    {
        return $this->complianceEntity;
    }

    public function process(FormInterface $form)
    {
        $form->handleRequest($this->request);

        $compliance = $form->get("compliance")->getData();
        $timeout = $form->get("compliance")->get("rules")->get("global")->get("timeout");
        if ($timeout->getData() !== null && intval($timeout->getData()) < $compliance->getCheckInterval()) {
            $timeout->addError(new FormError("compliance.timeout.lessThanCheckInterval", null, array(
                "%checkInterval%" => $compliance->getCheckInterval()
            )));
        }

        $groups = $form->get("compliance")->get("groups");
        foreach ($compliance->getGroups() as $group) {
            $groupCompliance = $this->complianceEm->getComplianceForGroup($group);
            if (null !== $groupCompliance && $groupCompliance->getId() !==  $compliance->getId()) {
                $groups->addError(new FormError("compliance.group.alreadyHasCompliance", null, array(
                    "%group%" => $group->getName(),
                    "%compliance%" => $groupCompliance->getName(),
                )));
            }
        }

        if ($form->isSubmitted()) {
            if ($compliance->getRules()->isEmpty() && null === $compliance->getWinPhoneAppPolicy()) {
                $form->get("compliance")->get("rules")->addError(new FormError("compliance.noRuleConfigured"));
            }
        }

        $policyForm = $form->get("compliance")->get("winPhoneAppPolicy")->get("policy");
        if ($policyForm->isSubmitted() && $policyForm->has("0")) {
            $policyForm = $policyForm->get("0");
            $type = $policyForm->get("type")->getData();
            if ($type == WinPhoneAppPolicy::TYPE_BLACKLIST) {
                if ($policyForm->getData()->isDeniedAll()) {
                    // the choosen type is blacklist, but no app/publisher is defined
                    $policyForm->get("type")->addError(new FormError("compliance.winphone.appPolicy.blacklistEmpty"));
                }
            }
        }

        if (!$form->isValid()) {
            return false;
        }

        $this->onSuccess($form);
        return true;
    }

    private function onSuccess(FormInterface $form)
    {
        $this->complianceEntity = $form->get("compliance")->getData();
    }
}
