<?php
namespace Topalis\Compliance\Form\Transformer;

use Symfony\Component\Form\DataTransformerInterface;
use Topalis\Util\StringUtil;

/**
 * Transforms the actions in a Compliance object. Options of actions may be
 * seperated by a collon in the field name.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class ActionsTransformer implements DataTransformerInterface
{
    public function transform($actions)
    {
        if (!$actions) {
            return array();
        }

        $rv = array();
        foreach ($actions as $key => $options) {
            $rv[$key] = true;
            foreach ($options as $optionKey => $optionValue) {
                $rv[$key . ":" . $optionKey] = $optionValue;
            }
        }

        return $rv;
    }

    public function reverseTransform($actions)
    {
        $rv = array();
        foreach ($actions as $key => $value) {
            if ($value === null) {
                continue;
            }

            $keys = explode(":", $key);
            if (isset($actions[$keys[0]]) && $actions[$keys[0]] === false) {
                continue;
            }

            $count = count($keys);
            if ($count === 1) {
                if (!isset($rv[$key])) {
                    $rv[$key] = array();
                }
            } else {
                $array = &$rv;
                for ($i = 0; $i < $count - 1; $i++) {
                    if (!isset($array[$keys[$i]]) || !is_array($array[$keys[$i]])) {
                        $array[$keys[$i]] = array();
                    }
                    $array = &$array[$keys[$i]];
                }

                $array[$keys[$count - 1]] = $value;
            }
        }

        if (!isset($rv['disableActiveSync']['delay'])) {
            // if no delay is set disableActiveSync is disabled
            unset($rv['disableActiveSync']);
        }

        if (!isset($rv['disableDevice']['delay'])) {
            // if no delay is set disableDevice is disabled
            unset($rv['disableDevice']);
        }

        return $rv;
    }
}
