<?php
namespace Topalis\Compliance\Form\Transformer;

use Symfony\Component\Form\DataTransformerInterface;

/**
 * Transforms a number by calcualting its multiple.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class NumberMultipleTransformer implements DataTransformerInterface
{
    const DIV = "/";
    const MUL = "*";

    private $transformValue;

    private $operation;

    /**
     * Constructor.
     *
     * @param number $transformValue The value used to calculate the multiple.
     * @param string $operation The operation to use, either "/" or "*". If "/"
     *     then a division is performed on transformation and a multiplication
     *     on reverse transformation. If "*" then it's the other way around.
     */
    public function __construct($transformValue, $operation = self::DIV)
    {
        $this->transformValue = $transformValue;
        $this->operation = $operation;
    }

    public function transform($value)
    {
        if (empty($value)) {
            return $value;
        }

        return $this->operation == self::DIV ? $value / $this->transformValue
            : $value * $this->transformValue;
    }

    public function reverseTransform($value)
    {
        if (empty($value)) {
            return $value;
        }

        return (string) ($this->operation == self::DIV ? $value * $this->transformValue
            : $value / $this->transformValue);
    }
}
