<?php
namespace Topalis\Compliance\Form\Transformer;

use Symfony\Component\Form\DataTransformerInterface;
use Doctrine\Common\Collections\ArrayCollection;
use Topalis\Compliance\Entity\Compliance;

/**
 * Transforms the collection of rules in an Compliance object.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class RulesCollectionTransformer implements DataTransformerInterface
{
    /**
     * @var \Topalis\Compliance\Entity\Compliance
     */
    private $compliance;

    /**
     * @var \Doctrine\ORM\PersistentCollection
     */
    private $rules;

    /**
     * @var array
     */
    private $rulesByOS;

    /**
     * Constructor.
     *
     * @param Compliance $compliance
     */
    public function __construct(Compliance $compliance)
    {
        $this->compliance = $compliance;
    }

    public function transform($rules)
    {
        $this->rules = $rules;
        $this->rulesByOS = array();

        foreach ($rules as $rule) {
            if ($rule->getOs() === null) {
                $this->rulesByOS["global"][$rule->getType()][] = $rule;
            } else {
                $this->rulesByOS[$rule->getOs()][$rule->getType()][] = $rule;
            }
        }

        return $this->rulesByOS;
    }

    public function reverseTransform($rulesByOS)
    {
        $newRules = array();
        foreach ($rulesByOS as $os => $rulesByType) {
            foreach ($rulesByType as $rules) {
                foreach ($rules as $rule) {
                    $newRules[] = $rule;
                    $rule->setOs($os === "global" ? null : $os);
                    $this->compliance->addRule($rule);
                }
            }
        }

        foreach ($this->compliance->getRules() as $rule) {
            if (!in_array($rule, $newRules)) {
                $this->compliance->removeRule($rule);
            }
        }

        return $this->rules;
    }
}
