<?php
namespace Topalis\Compliance\Form\Transformer;

use Symfony\Component\Form\DataTransformerInterface;
use Topalis\Compliance\Entity\Rule;

/**
 * Transforms rules to form field values.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class RulesTransformer implements DataTransformerInterface
{
    private $rulesByType;

    public function transform($rulesByType)
    {
        if (null === $rulesByType) {
            $rulesByType = array();
        }
        $this->rulesByType = $rulesByType;
        $rv = array();
        foreach ($rulesByType as $rules) {
            foreach ($rules as $rule) {
                if ($this->isCollectionType($rule->getType())) {
                    $rv[$rule->getType()][] = $rule->getCondition() == "" ? true : $rule->getCondition();
                } else {
                    $rv[$rule->getType()] = $rule->getCondition() == "" ? true : $rule->getCondition();
                }
            }
        }

        return $rv;
    }

    public function reverseTransform($value)
    {
        $rulesByType = array();
        foreach ($value as $type => $condition) {
            if ($condition === false || null === $condition) {
                continue;
            }

            $rulesByType[$type] = array();
            if (!is_array($condition)) {
                $condition = array($condition);
            }

            foreach ($condition as $i => $value) {
                if (isset($this->rulesByType[$type][$i])) {
                    $rule = $this->rulesByType[$type][$i];
                } else {
                    $rule = new Rule();
                    $rule->setType($type);
                }
                $rule->setCondition($value === true ? "" : $value);
                $rulesByType[$type][] = $rule;
            }
        }

        return $rulesByType;
    }

    private function isCollectionType($type)
    {
        switch ($type) {
            case "appForbidden":
                /* fall through */
            case "appRequired":
                return true;
            default:
                return false;
        }
    }
}
