<?php
namespace Topalis\Compliance\Form\Transformer\WinPhone;

use Symfony\Component\Form\DataTransformerInterface;
use Topalis\WinPhone\MS\MSAppPolicy;
use Topalis\Compliance\Entity\WinPhoneAppPolicy;

/**
 * Transformer for Windows Phone App Policy configuration.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class WinPhoneAppPolicyTransformer implements DataTransformerInterface
{
    public function transform($value)
    {
        if (is_string($value)) {
            $value = MSAppPolicy::fromXml($value);
        } else if (!$value instanceof MSAppPolicy) {
            return null;
        }

        $appPolicy = $value;
        $value = array();

        if ($appPolicy->isBlacklist()) {
            $value['type'] = WinPhoneAppPolicy::TYPE_BLACKLIST;
            foreach ($appPolicy->getDeniedApps() as $productId) {
                $value['productIds'][]['productId'] = $productId;
            }
            foreach ($appPolicy->getDeniedPublishers() as $publisher => $productIds) {
                $publisherValue = array("name" => $publisher);
                foreach ($productIds as $productId) {
                    $publisherValue['productIds'][]['productId'] = $productId;
                }
                $value['publishers'][] = $publisherValue;
            }
        } else {
            $value['type'] = WinPhoneAppPolicy::TYPE_WHITELIST;
            foreach ($appPolicy->getAllowedApps() as $productId => $publisher) {
                $value['productIds'][]['productId'] = $productId;
            }
            foreach ($appPolicy->getAllowedPublishers() as $publisher => $productIds) {
                $publisherValue = array("name" => $publisher);
                foreach ($productIds as $productId) {
                    $publisherValue['productIds'][]['productId'] = $productId;
                }
                $value['publishers'][] = $publisherValue;
            }
        }

        return $value;
    }

    public function reverseTransform($value)
    {
        if (!$value) {
            return null;
        }

        $appPolicy = new MSAppPolicy();
        if ($value['type'] == WinPhoneAppPolicy::TYPE_WHITELIST) {
            foreach ($value['productIds'] as $productId) {
                $appPolicy->addAllowedApp($productId['productId']);
            }
            foreach ($value['publishers'] as $publisher) {
                $deniedApps = array();
                foreach ($publisher['productIds'] as $productId) {
                    $deniedApps[] = $productId['productId'];
                }
                $appPolicy->addAllowedPublisher($publisher['name'], $deniedApps);
            }
        } else {
            foreach ($value['productIds'] as $productId) {
                $appPolicy->addDeniedApp($productId['productId']);
            }
            foreach ($value['publishers'] as $publisher) {
                $allowedApps = array();
                foreach ($publisher['productIds'] as $productId) {
                    $allowedApps[] = $productId['productId'];
                }
                $appPolicy->addDeniedPublisher($publisher['name'], $allowedApps);
            }
        }

        return $appPolicy;
    }
}
