<?php
namespace Topalis\Compliance\Form\Type;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Topalis\Compliance\Form\Transformer\ActionsTransformer;
use Topalis\Compliance\Form\Transformer\NumberMultipleTransformer;
use Topalis\Compliance\Validator\Constraints\RangeMultiple;

/**
 * ActionsType contains the compliance actions. Options of actions may be
 * seperated by a collon in the field name.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class ActionsType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused

        $hoursTransformer = new NumberMultipleTransformer(3600);

        $prefix = "admin.compliance.action.";
        $builder
            ->add("sendAdminMail", "checkbox", array(
                "label"    => $prefix . "sendAdminMail.label",
                "required" => false,
            ))
            ->add("sendUserMail", "checkbox", array(
                "label"    => $prefix . "sendUserMail.label",
                "required" => false,
            ))
            ->add($builder->create("disableActiveSync:delay", "integer", array(
                "label"    =>    $prefix . "disableActiveSync.label",
                "description" =>    $prefix . "disableActiveSync.description",
                "required" => false,
                "constraints" => new RangeMultiple(array("min" => 0, "transformer" => $hoursTransformer)),
            ))->addViewTransformer($hoursTransformer))
            ->add($builder->create("disableDevice:delay", "integer", array(
                "label"    =>    $prefix . "disableDevice.label",
                "description" =>    $prefix . "disableDevice.description",
                "required" => false,
                "constraints" => new RangeMultiple(array("min" => 3600, "transformer" => $hoursTransformer)),
            ))->addViewTransformer($hoursTransformer))
            ->addViewTransformer(new ActionsTransformer())

        ;
    }

    public function getName()
    {
        return "actions";
    }
}
