<?php
namespace Topalis\Compliance\Form\Type;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Symfony\Component\Validator\Constraints as Assert;
use Topalis\App\WinPhone\WinPhoneStore;
use Topalis\Compliance\Entity\Compliance;
use Topalis\Compliance\Form\Transformer\NumberMultipleTransformer;
use Topalis\Compliance\Form\Type\WinPhone\WinPhoneAppPolicyForm;
use Topalis\Compliance\Validator\Constraints\RangeMultiple;
use Topalis\Form\Validator\Constraint\NotEmpty;

/**
 * ComplianceType
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class ComplianceType extends AbstractType
{
    /**
     * @var \Topalis\Compliance\Entity\Compliance
     */
    private $compliance;

    /**
     * @var \Topalis\App\WinPhone\WinPhoneStore
     */
    private $winPhoneStore;

    /**
     * Constructor.
     *
     * @param Compliance $compliance
     * @param WinPhoneStore $winPhoneStore
     */
    public function __construct(Compliance $compliance, WinPhoneStore $winPhoneStore)
    {
        $this->compliance = $compliance;
        $this->winPhoneStore = $winPhoneStore;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused

        $minutesTransformer = new NumberMultipleTransformer(60);

        $prefix = "admin.compliance.";
        $builder
            ->add("name", "text", array(
                "label"       => $prefix . "name",
                "max_length"  => 255,
                "constraints" => array(
                    new Assert\NotBlank(),
                    new Assert\Length(array("max" => 255)),
                )
            ))
            ->add("description", "text", array(
                "label"       => $prefix . "description",
                "max_length"  => 255,
                "constraints" => array(
                    new Assert\NotBlank(),
                    new Assert\Length(array("max" => 255)),
                )
            ))
            ->add($builder->create("checkInterval", "integer", array(
                "label"       => $prefix . "checkInterval",
                "constraints" => array(
                    new Assert\NotBlank(),
                    new RangeMultiple(array("min" => 3600, "max" => 4294967295, "transformer" => $minutesTransformer)),
                ),
            ))->addViewTransformer($minutesTransformer))
            ->add("groups", "configgroup_select", array(
                "label" => $prefix . "groups",
                "descriptionBlock" => true,
                "description" => $prefix . "groupsDescription",
                "required" => false,
            ))
            ->add("rules", new RulesType($this->compliance), array(
                "label" => $prefix . "rules.title",
            ))
            ->add("winPhoneAppPolicy", new WinPhoneAppPolicyForm($this->winPhoneStore))
            ->add("actions", new ActionsType(), array(
                "label" => $prefix . "actions.title",
                "constraints" => new NotEmpty(array("message" => "compliance.noActionConfigured"))
            ))
            ;

    }

    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        $resolver->setDefaults(array(
            "data_class" => 'Topalis\Compliance\Entity\Compliance'
        ));
    }

    public function getName()
    {
        return "compliance";
    }
}
