<?php
namespace Topalis\Compliance\Form\Type;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Topalis\Compliance\Form\Transformer\RulesTransformer;
use Topalis\Compliance\Form\Transformer\NumberMultipleTransformer;
use Topalis\Compliance\Validator\Constraints\RangeMultiple;

/**
 * RulesGlobalType to modify rules for all OS.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class RulesGlobalType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused

        $minutesTransformer = new NumberMultipleTransformer(60);

        $prefix = "admin.compliance.rule.";
        $builder
            ->add($builder->create("timeout", "integer", array(
                "label"       => $prefix . "timeout.label",
                "description" => $prefix . "timeout.description",
                "constraints" => array(
                    new RangeMultiple(array("min" => 3600, "max" => 4294967295, "transformer" => $minutesTransformer)),
                ),
                "required" => false,
            ))->addViewTransformer($minutesTransformer))
            ->add("encrypted", "checkbox", array(
                "label"       => $prefix . "encrypted.label",
                "description" => $prefix . "encrypted.description",
                "required"    => false,
            ))
            ->add("dataRoaming", "checkbox", array(
                "label"       => $prefix . "dataRoaming.label",
                "description" => $prefix . "dataRoaming.description",
                "required"    => false,
            ))->addViewTransformer(new RulesTransformer())
        ;
    }

    public function getName()
    {
        return "global";
    }
}
