<?php
namespace Topalis\Compliance\Form\Type;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Symfony\Component\Validator\Constraints as Assert;
use Topalis\Compliance\Form\Event\AppIdentifierSubscriber;
use Topalis\Compliance\Form\Transformer\RulesTransformer;
use Topalis\Form\Validator\Constraint\VersionNumber;

/**
 * RulesIosType
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class RulesIosType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused
        $prefix = "admin.compliance.rule.";
        $builder
            ->add("minOS", "text", array(
                "label" => $prefix . "minOS.label",
                "description" => $prefix . "minOS.description",
                "constraints" => new VersionNumber(),
                "required" => false,
            ))
            ->add("maxOS", "text", array(
                "label" => $prefix . "maxOS.label",
                "description" => $prefix . "maxOS.description",
                "constraints" => new VersionNumber(),
                "required" => false,
            ))
            ->add("appRequired", new AppRuleCollectionType(), array(
                "label"            => $prefix . "appsRequired.label",
                "description"      => $prefix . "appsRequired.description",
                "operating_system" => "ios",
                "store"            => false,
                "custom"           => false,
                "managed"          => true,
            ))
            ->add("appForbidden", new AppRuleCollectionType(), array(
                "label" => $prefix . "appsForbidden.label",
                "description" => $prefix . "appsForbidden.description",
                "operating_system" => "ios",
            ))
            ->addEventSubscriber(new AppIdentifierSubscriber())
            ->addViewTransformer(new RulesTransformer())
        ;
    }

    public function getName()
    {
        return "ios";
    }
}
