<?php
namespace Topalis\Compliance\Form\Type;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Validator\Constraints as Assert;
use Topalis\Compliance\Form\Transformer\RulesCollectionTransformer;
use Topalis\Compliance\Entity\Compliance;

/**
 * RulesType contains the OS specific rule types.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class RulesType extends AbstractType
{
    /**
     * @var \Topalis\Compliance\Entity\Compliance
     */
    private $compliance;

    /**
     * Constructor.
     *
     * @param Compliance $compliance
     */
    public function __construct(Compliance $compliance)
    {
        $this->compliance = $compliance;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused
        $prefix = "admin.compliance.rule.";
        $builder
            ->add("global", new RulesGlobalType(), array(
                "label" => $prefix . "global.title",
            ))
            ->add("android", new RulesAndroidType(), array(
                "label" => $prefix . "android.title",
            ))
            ->add("ios", new RulesIosType(), array(
                "label" => $prefix . "ios.title",
            ))
            ->add("winphone", new RulesWinphoneType(), array(
                "label" => $prefix . "winphone.title",
            ))
            ->addViewTransformer(new RulesCollectionTransformer($this->compliance))

        ;
    }

    public function getName()
    {
        return "rules";
    }
}
