<?php
namespace Topalis\Compliance\Form\Type\WinPhone;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Topalis\App\WinPhone\WinPhoneStore;
use Topalis\Compliance\Entity\WinPhoneAppPolicy;
use Topalis\Compliance\Form\Transformer\WinPhone\WinPhoneAppPolicyTransformer;

/**
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class WinPhoneAppPolicyType extends AbstractType
{
    /**
     * @var \Topalis\App\WinPhone\WinPhoneStore
     */
    private $store;

    public function __construct(WinPhoneStore $store)
    {
        $this->store = $store;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused
        $prefix = "admin.compliance.winphone.appPolicy.";
        $builder
            ->add("type", "choice", array(
                "label" => $prefix . "type",
                "choices" => array(
                    WinPhoneAppPolicy::TYPE_BLACKLIST => $prefix . "blacklist",
                    WinPhoneAppPolicy::TYPE_WHITELIST => $prefix . "whitelist",
                )
            ))
            ->add("productIds", new WinPhoneAppProductIdCollectionType($this->store), array(
                "label" => $prefix . "appGuids",
            ))
            ->add("publishers", "jquery_collection", array(
                "type" => new WinPhoneAppPublisherType($this->store),
                "label" => $prefix . "publishers",
                "allow_add" => true,
                "allow_delete" => true,
                "options" => array(
                    "required" => true,
                )
            ))
            ->addViewTransformer(new WinPhoneAppPolicyTransformer())
            ;

    }

    public function getName()
    {
        return "policy";
    }
}
