<?php
namespace Topalis\Compliance\Form\Type\WinPhone;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Topalis\Form\Validator\Constraint\UniqueInCollection;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Component\Form\FormView;
use Symfony\Component\Form\FormInterface;
use Topalis\App\WinPhone\WinPhoneStore;

/**
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class WinPhoneAppProductIdType extends AbstractType
{
    /**
     * @var \Topalis\App\WinPhone\WinPhoneStore
     */
    private $store;

    public function __construct(WinPhoneStore $store)
    {
        $this->store = $store;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused
        $builder
            ->add("productId", "text", array(
                "label" => "admin.compliance.winphone.appPolicy.guid",
                "descriptionBlock" => true,
                "constraints" => array(
                    new Assert\NotBlank(),
                    new Assert\Regex(array(
                        "message" => "compliance.winphone.guidInvalid",
                        "pattern" => WinPhoneStore::GUID_PATTERN,
                    )),
                    new UniqueInCollection(),
                )
            ))
            ;
    }

    public function finishView(FormView $view, FormInterface $form, array $options)
    {
        $options; // unused

        $productId = $form->get("productId")->getData();
        $productIdView = $view['productId'];

        if ($productIdView->vars['errors']) {
            return;
        }

        if (!$productId) {
            // ensure we have a help block
            $productIdView->vars['description'] = " ";
            return;
        }

        // empty description to have a description block
        $productIdView->vars['description'] = " ";
    }

    public function getName()
    {
        return "appProductId";
    }
}
