<?php
namespace Topalis\Compliance\Form\Type\WinPhone;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Topalis\Form\Validator\Constraint\UniqueInCollection;
use Symfony\Component\Validator\Constraints as Assert;
use Topalis\App\WinPhone\WinPhoneStore;

/**
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class WinPhoneAppPublisherType extends AbstractType
{
    /**
     * @var \Topalis\App\WinPhone\WinPhoneStore
     */
    private $store;

    public function __construct(WinPhoneStore $store)
    {
        $this->store = $store;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused
        $prefix = "admin.compliance.winphone.appPolicy.";
        $builder
            ->add("name", "text", array(
                "label" => $prefix . "publisherName",
                "max_length" => 255,
                "constraints" => array(
                    new Assert\NotBlank(),
                    new Assert\Length(array("min" => 1, "max" => "255")),
                    new UniqueInCollection(),
                )
            ))
            ->add("productIds", new WinPhoneAppProductIdCollectionType($this->store), array(
                "label" => $prefix . "excludedAppGuids",
            ))
            ;
    }

    public function getName()
    {
        return "appPublisher";
    }
}
