<?php
namespace Topalis\Compliance\Job;

use Topalis\Compliance\Entity\Compliance;
use Topalis\Kernel\Job\QueueInterface;

/**
 * Manages the queue of compliance control jobs.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
interface ComplianceControlQueueInterface extends QueueInterface
{
    /**
     * @param Compliance $compliance The compliance to check.
     *
     * @return boolean True if a job for the specified compliance exists, false
     *     otherwise.
     */
    public function containsCompliance(Compliance $compliance);

    /**
     * @param Compliance $compliance The compliance of the job to get.
     *
     * @return \Pheanstalk_Job|null The job that belongs to the specified
     *     compliance, or null if no such job exists.
     */
    public function peekForCompliance(Compliance $compliance);

    /**
     * Puts a job for the specified compliance in the queue. If there is already
     * a job for the compliance in the queue it will be deleted. Sets the job
     * id in the compliance.
     *
     * @param Compliance $compliance The compliance to put a job for.
     * @param boolean $complianceChanged true if the compliance has been
     *     changed, false otherwise. Will be sent to the job.
     * @param int $delay Seconds to wait before job becomes ready.
     * @param boolean $replace true to replace an existing job, false otherwise.
     *     If false an existing job will be kicked, if the compliance changed
     *     flag is set.
     *
     * @return int The id of the job.
     */
    public function putCompliance(Compliance $compliance, $complianceChanged = false, $delay = 0, $replace = true);
}
