<?php
namespace Topalis\Compliance\Job;

use Psr\Log\LoggerAwareInterface;
use Psr\Log\LoggerInterface;
use Topalis\Compliance\ComplianceManagerInterface;
use Topalis\Compliance\Exception\NoSuchDeviceException;
use Topalis\Database\Util\DatabaseUtils;
use Topalis\Device\Entity\DeviceEntityManager;
use Topalis\Kernel\Job\WorkerInterface;

/**
 * Worker for jobs in a ComplianceVerifyQueue.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class ComplianceVerifyWorker implements WorkerInterface, LoggerAwareInterface
{
    /**
     * @var \Topalis\Compliance\ComplianceManagerInterface
     */
    private $complianceManager;

    /**
     * @var \Topalis\Device\Entity\DeviceEntityManager
     */
    private $deviceEntityManager;

    /**
     * @var \Psr\Log\LoggerInterface
     */
    private $logger;

    /**
     * Constructor.
     *
     * @param ComplianceManagerInterface $complianceManager
     * @param DeviceEntityManager $deviceEntityManager
     */
    public function __construct(ComplianceManagerInterface $complianceManager,
        DeviceEntityManager $deviceEntityManager)
    {
        $this->complianceManager = $complianceManager;
        $this->deviceEntityManager = $deviceEntityManager;
    }

    public function handle(array $data)
    {
        $device = $this->deviceEntityManager->find($data['device']);
        if (null === $device) {
            throw new NoSuchDeviceException(sprintf("A device with id '%s' doesn't exist", $data['device']));
        }
        $this->logger->debug("Verify compliance of device " . $device->getCombinedId());
        $this->complianceManager->verify($device);
    }

    public function cleanup()
    {
    }

    public function setLogger(LoggerInterface $logger)
    {
        $this->logger = $logger;
    }
}
