<?php
namespace Topalis\Compliance;

use Topalis\Compliance\ComplianceVerificationResult;
use Topalis\Compliance\Rule\PreviousRuleValidationResultInterface;
use Topalis\Compliance\Entity\Rule;
use Topalis\Compliance\Rule\RuleValidationResultInterface;
use Topalis\Compliance\Entity\RuleValidation;
use Topalis\Compliance\Rule\PreviousRuleValidationResult;
use Topalis\Compliance\Rule\RuleTypeContainer;
use Topalis\Compliance\Rule\RuleTypeContainerInterface;
use Topalis\Compliance\Exception\InvalidArgumentException;

/**
 * PreviousComplianceVerificationResult
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class PreviousComplianceVerificationResult extends ComplianceVerificationResult implements PreviousComplianceVerificationResultInterface
{
    /**
     * @var RuleTypeContainerInterface
     */
    private $ruleTypeContainer;

    /**
     * Constructor.
     *
     * @param RuleTypeContainerInterface $ruleTypeContainer
     */
    public function __construct(RuleTypeContainerInterface $ruleTypeContainer)
    {
        $this->ruleTypeContainer = $ruleTypeContainer;
    }

    public function addRuleValidation(RuleValidation $ruleValidation)
    {
        $ruleType = $this->ruleTypeContainer->get($ruleValidation->getRule()->getType());
        $deviceOs = $ruleValidation->getDevice()->getType()->getName();
        $this->addValidationResult($ruleValidation->getRule(),
            new PreviousRuleValidationResult(
                $ruleValidation,
                $ruleType->getViolationMessage($deviceOs),
                $ruleType->getShortViolationMessage($deviceOs)
            )
        );
    }

    public function addValidationResult(Rule $rule, RuleValidationResultInterface $validationResult)
    {
        if (!$validationResult instanceof PreviousRuleValidationResultInterface) {
            throw new InvalidArgumentException(
                sprintf("Expected validation result of type \"%s\", but got \"%s\"",
                    "Topalis\Compliance\Rule\PreviousRuleValidationResultInterface",
                    get_class($validationResult)
                ));
        }

        parent::addValidationResult($rule, $validationResult);
    }

    public function getRuleValidation(Rule $rule)
    {
        $result = $this->getValidationResult($rule);
        return null !== $result ? $result->getRuleValidation() : null;
    }
}
