<?php
namespace Topalis\Compliance\Rule;

use Topalis\Compliance\Rule\RuleValidatorInterface;
use Topalis\Device\Entity\Device;
use Topalis\App\Mdm\AppMdmAdminRegistry;
use Topalis\Compliance\Exception\InvalidConditionException;

/**
 * Validator for the AppForbiddenRule.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class AppForbiddenRuleValidator extends AbstractRuleValidator
{
    private $appMdmAdminRegistry;

    public function __construct(AppMdmAdminRegistry $appMdmAdminRegistry)
    {
        $this->appMdmAdminRegistry = $appMdmAdminRegistry;
    }

    public function validate(Device $device, $condition)
    {
        $app = json_decode($condition, true);
        if (!isset($app['identifier'])) {
            throw new InvalidConditionException(sprintf(
                "No app identifier given for rule validator %s", __CLASS__
            ));
        }

        if (!isset($app['name'])) {
            $app['name'] = $app['identifier'];
        }
        $violated = false;
        if ($this->appMdmAdminRegistry->containsForDevice($device)) {
            $appMdmAdmin = $this->appMdmAdminRegistry->getForDevice($device);
            $violated = $appMdmAdmin->isAppInstalled($device, $app['identifier']);
        }

        return new AppForbiddenRuleValidationResult($violated, $app['identifier'], $app['name']);
    }
}
