<?php
namespace Topalis\Compliance\Rule;

/**
 * The result of the AppRequired.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class AppRequiredRuleValidationResult implements RuleValidationResultInterface
{
    const MESSAGE = "admin.compliance.rule.appRequired.violation";
    const SHORT_MESSAGE = "admin.compliance.rule.appRequired.violationShort";

    private $parameters;

    private $violated;

    /**
     * Constructor.
     *
     * @param boolean $violated
     * @param string $identifier The identifier of the required app.
     * @param string $name The name of the required app.
     */
    public function __construct($violated, $identifier, $name)
    {
        $this->violated = $violated;
        $this->parameters = array(
            "%appIdentifier%" => $identifier,
            "%appName%" => $name,
        );
    }

    public function getMessage()
    {
        return self::MESSAGE;
    }

    /**
     * @return array Array with keys "%appIdentifier% and the identifier of the
     *     required app, and "%appName%" with the name of the required app.
     *
     * @see \Topalis\Compliance\Rule\RuleValidationResultInterface::getParameters()
     */
    public function getParameters()
    {
        return $this->parameters;
    }

    public function getShortMessage()
    {
        return self::SHORT_MESSAGE;
    }

    public function isViolated()
    {
        return $this->violated;
    }
}
