<?php
namespace Topalis\Compliance\Rule;

/**
 * The result of the MaxOSRule.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class MaxOSRuleValidationResult implements RuleValidationResultInterface
{
    const MESSAGE = "admin.compliance.rule.maxOS.violation";
    const SHORT_MESSAGE = "admin.compliance.rule.maxOS.violationShort";

    private $parameters = array();

    private $violated;

    /**
     * Constructor.
     *
     * @param boolean $violated
     * @param string $expected The maximum expected version.
     * @param string $actual The actual version.
     */
    public function __construct($violated, $expected, $actual)
    {
        $this->violated = $violated;
        $this->parameters['%expected%'] = $expected;
        $this->parameters['%actual%'] = $actual;
    }

    public function getMessage()
    {
        return self::MESSAGE;
    }

    /**
     * @return array Array with the keys '%expected%' and '%actual%' with their
     *     corresponding values.
     *
     * @see \Topalis\Compliance\Rule\RuleValidationResultInterface::getParameters()
     */
    public function getParameters()
    {
        return $this->parameters;
    }

    public function getShortMessage()
    {
        return self::SHORT_MESSAGE;
    }

    public function isViolated()
    {
        return $this->violated;
    }
}
