<?php
namespace Topalis\Compliance\Rule;

use Topalis\Compliance\Rule\RuleValidatorInterface;
use Topalis\Device\Entity\Device;
use Topalis\Compliance\Exception\InvalidConditionException;

/**
 * The MinOS rule checks if the installed OS version deceeds a configured
 * version number.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class MinOSRuleValidator extends AbstractRuleValidator
{
    public function validate(Device $device, $condition)
    {
        $expected = trim($condition);
        if (!$expected) {
            throw new InvalidConditionException(sprintf(
                "No version given for rule validator %s", __CLASS__
            ));
        }

        $version = $device->getVersion();
        $violated = version_compare($version, $expected, "<");

        return new MinOSRuleValidationResult($violated, $expected, $version);
    }
}
