<?php
namespace Topalis\Compliance\Rule;

use Topalis\Compliance\Exception\NoSuchRuleTypeException;
use Symfony\Component\DependencyInjection\ContainerAware;
use Symfony\Component\DependencyInjection\Exception\ServiceNotFoundException;
use Topalis\Util\TypeCheck;

/**
 * RuleTypeContainer
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class RuleTypeContainer extends ContainerAware implements RuleTypeContainerInterface
{
    private $types;

    /**
     * Constructor.
     *
     * @param array $ruleTypes Array of key-value pairs with key the key of the
     *     rule type and value the rule type or a service id. Or an non
     *     associative array of rule types.
     */
    public function __construct(array $ruleTypes = array())
    {
        if (TypeCheck::isAssocArray($ruleTypes)) {
            $this->types = $ruleTypes;
        } else {
            foreach ($ruleTypes as $type) {
                $this->add($type);
            }
        }
    }

    public function get($key)
    {
        if (!isset($this->types[$key])) {
            throw new NoSuchRuleTypeException(sprintf("No rule type with key \"%s\" found", $key));
        }

        $type = $this->types[$key];
        if (is_string($type)) {
            try {
                $this->types[$key] = $type = $this->container->get($type);
            } catch (ServiceNotFoundException $e) {
                throw new NoSuchRuleTypeException(
                    sprintf("No rule type with key \"%s\" found", $key), $e->getCode(), $e);
            }
        }

        return $type;
    }

    public function add(RuleTypeInterface $ruleType)
    {
        $this->types[$ruleType->getKey()] = $ruleType;
    }

    public function addService($key, $serviceId)
    {
        $this->types[$key] = $serviceId;
    }
}
