<?php
namespace Topalis\Compliance\Rule;

/**
 * A RuleType is required for every rule and has to be added to a
 * RuleTypeContainer.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
interface RuleTypeInterface
{
    /**
     * @return string The name of the rule type. May be a translation id.
     */
    public function getName();

    /**
     * @param string $os The OS to get the short violation message for.
     *
     * @return string The short violation message of the rule type for the
     *     specified OS. May be a translation id. A short violation message is
     *     independent of the values used for the validation, so placeholders
     *     must not be used.
     */
    public function getShortViolationMessage($os);

    /**
     * @return string The key of the rule type.
     */
    public function getKey();

    /**
     * @param string $os The OS to get the validator class for.
     *
     * @return RuleValidatorInterface The RuleValidator of the rule type for the
     *     specified OS.
     */
    public function getValidator($os);

    /**
     * @param string $os The OS to get the violation message for.
     *
     * @return string The violation message of the rule type for the specified
     *     OS. May be a translation id. Placeholders may be used and will be
     *     replaced by the values returned by
     *     RuleValidationResultInterface::getParameters().
     */
    public function getViolationMessage($os);
}
