<?php
namespace Topalis\Compliance\Rule;

use Topalis\Compliance\Entity\Rule;
use Topalis\Compliance\Exception\NoSuchValidatorException;
use Topalis\Compliance\Exception\NoSuchRuleTypeException;

/**
 * RuleValidatorFactory
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class RuleValidatorFactory implements RuleValidatorFactoryInterface
{
    /**
     * @var RuleTypeContainerInterface
     */
    private $ruleTypeContainer;

    /**
     * Constructor.
     *
     * @param RuleTypeContainerInterface $ruleTypeContainer
     */
    public function __construct(RuleTypeContainerInterface $ruleTypeContainer)
    {
        $this->ruleTypeContainer = $ruleTypeContainer;
    }

    public function create(Rule $rule)
    {
        $os = $rule->getOs();
        $typeKey = $rule->getType();

        try {
            $type = $this->ruleTypeContainer->get($typeKey);
            $validator = $type->getValidator($os);
            if (!$validator) {
                throw new NoSuchValidatorException(sprintf(
                    "No rule validator for OS \"%s\" and type \"%s\" found", $os, $typeKey),
                    $os, $typeKey
                );
            }
        } catch (NoSuchRuleTypeException $e) {
            throw new NoSuchValidatorException(sprintf(
                "No rule validator for OS \"%s\" and type \"%s\" found", $os, $typeKey),
                $os, $typeKey, $e->getCode(), $e
            );
        }

        return $validator;
    }
}
