<?php
namespace Topalis\Compliance\Rule;

use Topalis\Device\DeviceManager;
use Topalis\Device\MDM\MdmFacadeInterface;

/**
 * The Timeout rule checks if a device connected at least once during a
 * specified timeout. For managed devices the response time of the last
 * executed MDM command is checked. Since a command to get the device
 * information required for the check is regularly it is a valid approach.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class TimeoutRuleType implements RuleTypeInterface
{
    private $deviceManager;
    private $mdmFacade;

    public function __construct(DeviceManager $deviceManager, MdmFacadeInterface $mdmFacade)
    {
        $this->deviceManager = $deviceManager;
        $this->mdmFacade = $mdmFacade;
    }

    public function getKey()
    {
        return "timeout";
    }

    public function getName()
    {
        return "compliance.rule.timeout.name";
    }

    public function getShortViolationMessage($os)
    {
        $os; // unused

        return TimeoutRuleValidationResult::SHORT_MESSAGE;
    }

    public function getValidator($os)
    {
        $os; // unused

        return new TimeoutRuleValidator($this->deviceManager, $this->mdmFacade);
    }

    public function getViolationMessage($os)
    {
        $os; // unused

        return TimeoutRuleValidationResult::MESSAGE;
    }
}
