<?php
namespace Topalis\Compliance\Rule;

/**
 * The result of the TimeoutRule.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class TimeoutRuleValidationResult implements RuleValidationResultInterface
{
    const MESSAGE = "admin.compliance.rule.timeout.violation";
    const SHORT_MESSAGE = "admin.compliance.rule.timeout.violationShort";

    private $parameters = array();

    private $violated;

    /**
     * Constructor.
     *
     * @param boolean $violated
     * @param int $lastAccess The last access of the device as UNIX timestamp.
     * @param int $timeout The timeout in seconds.
     */
    public function __construct($violated, $lastAccess, $timeout)
    {
        $this->violated = $violated;
        $this->parameters = array(
            "%lastAccess%" => $lastAccess,
            "%timeout%" => $timeout,
            "%timeoutMinutes%" => $timeout / 60,
        );
    }

    public function getMessage()
    {
        return self::MESSAGE;
    }

    /**
     * @return array Array containing the keys "%lastAccess%" with the time of
     *     the last access as UNIX timestamp, and "%timeout%" with the timeout
     *     in seconds.
     *
     * @see \Topalis\Compliance\Rule\RuleValidationResultInterface::getParameters()
     */
    public function getParameters()
    {
        return $this->parameters;
    }

    public function getShortMessage()
    {
        return self::SHORT_MESSAGE;
    }

    public function isViolated()
    {
        return $this->violated;
    }
}
