<?php
namespace Topalis\Compliance\Util;

use Symfony\Component\Translation\TranslatorInterface;
use Topalis\Compliance\ComplianceVerificationResultInterface;

/**
 * ComplianceVerificationUtils
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class ComplianceVerificationUtils
{
    /**
     *
     * @param ComplianceVerificationResultInterface $verificationResult
     * @param TranslatorInterface $translator
     *
     * @return string[]
     */
    public static function getShortViolationMessages(ComplianceVerificationResultInterface $verificationResult,
        TranslatorInterface $translator)
    {
        $violationMessages = array();
        foreach ($verificationResult->getViolated() as $violated) {
            $validationResult = $violated['result'];
            $rule = $violated['rule'];
            $type = $rule->getType();
            if (!isset($violationMessages[$type])) {
                $violationMessages[$type] = $translator->trans($validationResult->getShortMessage());
            }
        }

        return $violationMessages;
    }

    /**
     *
     * @param ComplianceVerificationResultInterface $verificationResult
     * @param TranslatorInterface $translator
     * @param string $locale
     *
     * @return string[]
     */
    public static function getViolationMessages(ComplianceVerificationResultInterface $verificationResult,
        TranslatorInterface $translator, $locale = null)
    {
        $violationMessages = array();
        foreach ($verificationResult->getViolated() as $violated) {
            $validationResult = $violated['result'];
            $violationMessages[] = $translator->trans($validationResult->getMessage(),
                $validationResult->getParameters(), null, $locale);
        }

        return $violationMessages;
    }
}
