<?php
namespace Topalis\Compliance\Validator\Constraints;

use Symfony\Component\Validator\Constraints\Range;
use Symfony\Component\Validator\Exception\InvalidOptionsException;
use Symfony\Component\Validator\Exception\MissingOptionsException;
use Topalis\Compliance\Form\Transformer\NumberMultipleTransformer;

/**
 * The RangeMultiple constraint is similar to the Range constraint of Symfony.
 * The difference is that a NumberMultipleTransformer has to be specified which
 * is used to display the correct value in the error message.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class RangeMultiple extends Range
{
    public $transformer;

    public function __construct($options = null)
    {
        parent::__construct($options);

        if (null === $this->transformer) {
            throw new MissingOptionsException(sprintf('"transformer" must be given for constraint %s', __CLASS__),
                array("transformer"));
        }

        if (!$this->transformer instanceof NumberMultipleTransformer) {
            throw new InvalidOptionsException(sprintf('"transformer" must be an instance of %s for constraint %s',
                "Topalis\Compliance\Form\Transformer\NumberMultipleTransformer", __CLASS__), array("transformer"));
        }
    }
}
