<?php
namespace Topalis\Compliance\WinPhone;

use Topalis\WinPhone\MS\MSAppPolicyManagerInterface;
use Topalis\Device\Entity\Device;
use Topalis\WinPhone\MS\MSAppPolicy;
use Topalis\Compliance\Entity\WinPhoneAppPolicyEntityManager;

/**
 * Implementation of MSAppPolicyManagerInterface that uses a
 * WinPhoneAppPolicyEntityManager to get the app policy for a device.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class MSAppPolicyManager implements MSAppPolicyManagerInterface
{
    /**
     * @var \Topalis\Compliance\Entity\WinPhoneAppPolicyEntityManager
     */
    private $winPhoneAppPolicyEm;

    public function __construct(WinPhoneAppPolicyEntityManager $winPhoneAppPolicyEm)
    {
        $this->winPhoneAppPolicyEm = $winPhoneAppPolicyEm;
    }

    public function getPolicy(Device $device)
    {
        $policyXml = $this->getPolicyXml($device);
        if (!$policyXml) {
            return null;
        }

        return MSAppPolicy::fromXml($policyXml);
    }

    public function getPolicyXml(Device $device)
    {
        $policy = $this->winPhoneAppPolicyEm->findForDevice($device);
        if (null === $policy) {
            return null;
        }

        return $policy->getPolicy();
    }
}
