<?php
namespace Topalis\ConfigGroup;

/**
 *
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class ConfigSectionManager
{
    /**
     * @var ConfigGroupSectionInterface[]
     */
    private $sections;

    /**
     * @param ConfigGroupSectionInterface[] $sections
     */
    public function __construct(array $sections)
    {
        foreach ($sections as $section) {
            $this->sections[$section->getName()] = $section;
        }
    }

    /**
     * @param string $name
     *
     * @return bool
     */
    public function hasSection($name)
    {
        return isset($this->sections[$name]);
    }

    /**
     * @param string $name
     *
     * @return ConfigGroupSectionInterface
     * @throws \InvalidArgumentException
     */
    public function getSection($name)
    {
        if (!$this->hasSection($name)) {
            throw new \InvalidArgumentException(sprintf("undefined section %s", $name));
        }

        return $this->sections[$name];
    }

    /**
     * @return ConfigGroupSectionInterface[]
     */
    public function getAllSections()
    {
        return $this->sections;
    }
}
