<?php
namespace Topalis\ConfigGroup\DependencyInjection\Compiler;

use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Definition;
use Symfony\Component\DependencyInjection\Reference;

/**
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class SectionPass implements CompilerPassInterface
{
    public function process(ContainerBuilder $container)
    {
        if (!$container->has("config_group.section.manager")) {
            return;
        }

        $definition = $container->getDefinition('config_group.section.manager');

        $sections = new \SplPriorityQueue();

        foreach ($container->findTaggedServiceIds('config_group.section') as $serviceId => $tag) {
            $priority = isset($tag[0]['priority'])
                ? $tag[0]['priority']
                : 0;

            $sections->insert($serviceId, $priority);
        }

        // convert queue to array
        $sectionList = array();
        foreach ($sections as $section) {
            $sectionList[] = new Reference($section);
        }

        $definition->replaceArgument(0, $sectionList);
    }
}
