<?php
namespace Topalis\ConfigGroup\EventListener;

use Doctrine\ORM\Event\LifecycleEventArgs;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Topalis\ConfigGroup\Entity\ConfigGroup;

/**
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class InstallProfileEventListener
{
    /**
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    private $container;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    /**
     * @return \Topalis\Device\MDM\MdmFacadeInterface
     */
    private function getMdmFacade()
    {
        return $this->container->get("device.mdm.facade");
    }

    public function postUpdate(LifecycleEventArgs $eventArgs)
    {
        $configGroup = $eventArgs->getEntity();
        if (!$configGroup instanceof ConfigGroup) {
            return;
        }

        $em = $eventArgs->getEntityManager();
        $em->beginTransaction();
        try {
            $uow = $em->getUnitOfWork();
            $this->getMdmFacade()->updateConfigGroup($configGroup, $uow);
            $em->commit();
        } catch (\Exception $e) {
            $em->rollback();
            throw $e;
        }
    }
}
