<?php
namespace Topalis\ConfigGroup\EventListener;

use Topalis\ConfigGroup\Entity\ConfigGroup;
use Doctrine\ORM\Event\LifecycleEventArgs;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 *
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class RemoveConfigGroupEventListener
{
    /**
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    private $container;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    /**
     * @return \Topalis\Device\Entity\DeviceEntityManager
     */
    protected function getDeviceEntityManager()
    {
        return $this->container->get("device.entity.manager.device");
    }

    /**
     * @return \Topalis\ActiveSyncFilter\FilterServer
     */
    protected function getFilterServer()
    {
        return $this->container->get("asf.filter_server");
    }

    public function preRemove(LifecycleEventArgs $eventArgs)
    {
        $entity = $eventArgs->getEntity();
        if (!$entity instanceof ConfigGroup) {
            return;
        }

        $this->getFilterServer()->clearConfig($entity);

        $deviceEntityManager = $this->getDeviceEntityManager();
        $deviceEntityManager->disableDeleteFilter();
        $deviceEntityManager->createQueryBuilder("d")
            ->update()
            ->set("d.configGroup", "NULL")
            ->where("d.configGroup = :cg")
            ->setParameter("cg", $entity)
            ->getQuery()->execute();
        $deviceEntityManager->enableDeleteFilter();
    }
}
