<?php
namespace Topalis\ConfigGroup\Form\Handler;

use Symfony\Component\Form\FormInterface;
use Symfony\Component\HttpFoundation\Request;
use Topalis\Certificate\CertificateManager;
use Topalis\ConfigGroup\Entity\ConfigGroup;
use Topalis\ConfigGroup\Entity\ConfigGroupEntityManager;
use Topalis\Profile\ConfigurationProfile;
use Topalis\Profile\Payload\WifiPayload;
use Topalis\Profile\ProfileFactory;
use Symfony\Component\Form\FormError;
use Symfony\Component\Validator\Constraints\NotBlank;

/**
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class ProfileFormHandler
{
    /**
     * @var \Symfony\Component\HttpFoundation\Request
     */
    protected $request;

    /**
     * @var \Topalis\ConfigGroup\Entity\ConfigGroupEntityManager
     */
    protected $manager;
    /**
     * @var \Topalis\Profile\ProfileFactory
     */
    private $profileFactory;
    /**
     * @var \Topalis\Certificate\CertificateManager
     */
    private $certificateManager;

    public function __construct(Request $request, ConfigGroupEntityManager $manager,
        ProfileFactory $profileFactory, CertificateManager $certificateManager)
    {
        $this->request = $request;
        $this->manager = $manager;
        $this->profileFactory = $profileFactory;
        $this->certificateManager = $certificateManager;
    }

    public function process(FormInterface $form, ConfigGroup $group)
    {
        if (null !== $profile = $group->getProfile()) {
            $profile = $this->profileFactory->fromXML($group->getProfile());
        } else {
            $profile = new ConfigurationProfile();
            $profile->setIdentifier($this->profileFactory->getDeviceProfileIdentifier());
            $profile->setOrganization($this->certificateManager->getCAOrg());
        }
        $form->setData($profile);

        // exchange config
        $form->get("exchange")->setData(array(
            "sync_days"    => $group->getSyncDays(),
            "allow_move"   => $group->isAllowMove(),
            "from_any_app" => $group->isFromAnyApp()
        ));

        $params = $this->request->request->get($form->getName());
        if (!empty($params) && isset($params['save'])) {
            $form->handleRequest($this->request);
            if ($form->has("wifi")) {
                foreach ($form->get("wifi")->all() as $child) {
                    /** @var WifiPayload $payload */
                    $payload = $child->getData();
                    if (null === $child->get("encryption_type")->getData()) {
                        $payload->setPassword(null);
                    } else {
                        if (strlen($payload->getPassword()) == 0) {
                            $notBlank = new NotBlank();
                            $child->get("password")->addError(new FormError($notBlank->message));
                        }
                    }
                }
            }
        }

        if ($form->get("save")->isClicked() && $form->isValid()) {
            /** @var $profile ConfigurationProfile */
            $profile = $form->getData();

            $group->setProfile($profile->toXML());
            // exchange config
            $exchange = $form->get("exchange")->getData();
            $group->setSyncDays($exchange['sync_days']);
            $group->setAllowMove($exchange['allow_move']);
            $group->setFromAnyApp($exchange['from_any_app']);

            if ($form->isValid()) {
                $this->onSuccess($group);
                return true;
            } else {
                $this->manager->refresh($group);
            }
        }

        return false;
    }

    protected function onSuccess(ConfigGroup $group)
    {
        $this->manager->save($group);
    }
}
