<?php
namespace Topalis\ConfigGroup\Form\Type\Android;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Symfony\Component\Validator\Constraints\Range;
use Topalis\ConfigGroup\Form\Transformer\Android\AndroidPassCodeTransformer;

/**
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class PassCodeType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused

        $prefix = "admin.group.android_profile.passcode.";
        $prefixGeneral = "admin.group.profile.passcode.";
        $prefixWin = "admin.group.winphone.passcode.";

        $builder
            ->add("minLength", "choice", array(
                "label"       => $prefixGeneral . "minLength",
                "description" => $prefixGeneral . "minLengthDescr",
                "choices" => array(
                    1 => 1,
                    2 => 2,
                    3 => 3,
                    4 => 4,
                    5 => 5,
                    6 => 6,
                    7 => 7,
                    8 => 8,
                    9 => 9,
                    10 => 10,
                    11 => 11,
                    12 => 12,
                    13 => 13,
                    14 => 14,
                    15 => 15,
                    16 => 16,
                    17 => 17,
                    18 => 18,
                ),
                "required" => true,
            ))
            ->add("minLetters", "choice", array(
                "label" => $prefix . "minLetters",
                "choices" => array(
                    1 => 1,
                    2 => 2,
                    3 => 3,
                    4 => 4,
                    5 => 5,
                    6 => 6,
                    7 => 7,
                    8 => 8,
                    9 => 9,
                ),
                "empty_value" => "--",
            ))
            ->add("minLowercase", "choice", array(
                "label" => $prefix . "minLowercase",
                "choices" => array(
                    1 => 1,
                    2 => 2,
                    3 => 3,
                    4 => 4,
                    5 => 5,
                    6 => 6,
                    7 => 7,
                    8 => 8,
                    9 => 9,
                ),
                "empty_value" => "--",
            ))
            ->add("minUppercase", "choice", array(
                "label" => $prefix . "minUppercase",
                "choices" => array(
                    1 => 1,
                    2 => 2,
                    3 => 3,
                    4 => 4,
                    5 => 5,
                    6 => 6,
                    7 => 7,
                    8 => 8,
                    9 => 9,
                ),
                "empty_value" => "--",
            ))
            ->add("minNumeric", "choice", array(
                "label" => $prefix . "minNumeric",
                "choices" => array(
                    1 => 1,
                    2 => 2,
                    3 => 3,
                    4 => 4,
                    5 => 5,
                    6 => 6,
                    7 => 7,
                    8 => 8,
                    9 => 9,
                ),
                "empty_value" => "--",
            ))
            ->add("minSymbols", "choice", array(
                "label" => $prefix . "minSymbols",
                "choices" => array(
                    1 => 1,
                    2 => 2,
                    3 => 3,
                    4 => 4,
                    5 => 5,
                    6 => 6,
                    7 => 7,
                    8 => 8,
                    9 => 9,
                ),
                "empty_value" => "--",
            ))
            ->add("history", "integer", array(
                "label" => $prefixGeneral."pinHistory",
                "description" => $prefixGeneral . "pinHistoryDescr",
                "constraints" => new Range(array(
                    "min" => 0,
                    "max" => 50
                )),
            ))
            ->add("maxFailedAttempts", "integer", array(
                "label" => $prefixWin."maxFailedAttempts",
                "description" => $prefixGeneral."maxFailedAttemptsDescr",
                "constraints" => new Range(array(
                    "min" => 0,
                    "max" => 999
                )),
            ))
            ->add("expirationTimeout", "integer", array(
                "label" => $prefixGeneral."maxPINAgeInDays",
                "description" => $prefixGeneral."maxPINAgeInDaysDescr",
                "constraints" => new Range(array(
                    "min" => 0,
                    "max" => 730
                )),
            ))
            ->addViewTransformer(new AndroidPassCodeTransformer())
        ;
    }

    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        $resolver->setDefaults(array(
            "data_class" => 'Topalis\Profile\Payload\Android\PasscodePayload',
            "required"    => false,
        ));
    }

    public function getName()
    {
        return "android_passcode";
    }
}
