<?php
namespace Topalis\ConfigGroup\Form\Type\Ios;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Symfony\Component\Validator\Constraints\Range;
use Topalis\ConfigGroup\Form\Transformer\Ios\IosPassCodeTransformer;

/**
 *
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class PassCodeType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused
        $prefix = "admin.group.profile.passcode.";
        $builder
            ->add("allowSimple", "checkbox", array(
                "label" => $prefix."allowSimple",
                "description" => $prefix."allowSimpleDescr"
            ))
            ->add("requireAlphanumeric", "checkbox", array(
                "label" => $prefix."requireAlphanumeric",
                "description" => $prefix."requireAlphanumericDescr"
            ))
            ->add("minLength", "choice", array(
                "label" => $prefix."minLength",
                "description" => $prefix."minLengthDescr",
                "choices" => array(
                    1 => 1,
                    2 => 2,
                    3 => 3,
                    4 => 4,
                    5 => 5,
                    6 => 6,
                    7 => 7,
                    8 => 8,
                    9 => 9,
                    10 => 10,
                    11 => 11,
                    12 => 12,
                    13 => 13,
                    14 => 14,
                    15 => 15,
                    16 => 16
                ),
                "required" => true,
            ))
            ->add("minComplexChars", "choice", array(
                "label" => $prefix."minComplexChars",
                "description" => $prefix."minComplexCharsDescr",
                "choices" => array(
                    1 => 1,
                    2 => 2,
                    3 => 3,
                    4 => 4,
                ),
                "empty_value" => 0,
            ))
            ->add("maxPINAgeInDays", "number", array(
                "label" => $prefix."maxPINAgeInDays",
                "description" => $prefix."maxPINAgeInDaysDescr",
                "constraints" => new Range(array(
                    "min" => 0,
                    "max" => 730
                ))
            ))
            ->add("maxInactivity", "choice", array(
                "label" => $prefix."maxInactivity",
                "description" => $prefix."maxInactivityDescr",
                "choices" => array(
                    1 => 1,
                    2 => 2,
                    3 => 3,
                    4 => 4,
                    5 => 5,
                    10 => 10,
                    15 => 15
                ),
                "empty_value" => "Never",
            ))
            ->add("pinHistory", "number", array(
                "label" => $prefix."pinHistory",
                "description" => $prefix."pinHistoryDescr",
                "constraints" => new Range(array(
                    "min" => 0,
                    "max" => 50
                ))
            ))
            ->add("maxGracePeriod", "choice", array(
                "label" => $prefix."maxGracePeriod",
                "description" => $prefix."maxGracePeriodDescr",
                "choices" => array(
                    1 => "1 minute",
                    5 => "5 minutes",
                    15 => "15 minutes",
                    60 => "1 hour",
                    240 => "4 hours"
                ),
                "empty_value" => $prefix."maxGracePeriod.immediately"
            ))
            ->add("maxFailedAttempts", "choice", array(
                "label" => $prefix."maxFailedAttempts",
                "description" => $prefix."maxFailedAttemptsDescr",
                "choices" => array(
                    4 => 4,
                    5 => 5,
                    6 => 6,
                    7 => 7,
                    8 => 8,
                    9 => 9,
                    10 => 10
                ),
                "required" => true,
            ))
            ->addViewTransformer(new IosPassCodeTransformer())
        ;
    }

    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        $resolver->setDefaults(array(
            "data_class" => 'Topalis\Profile\Payload\PasscodePayload',
            "required" => false,
        ));
    }

    public function getName()
    {
        return "code";
    }
}
