<?php
namespace Topalis\ConfigGroup\Form\Type;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Topalis\ConfigGroup\Form\Type\Ios\AirPlayType;
use Topalis\ConfigGroup\Form\Type\Ios\AirPrintType;
use Topalis\ConfigGroup\Form\Type\Ios\ApnType;
use Topalis\ConfigGroup\Form\Type\Ios\ExchangeType;
use Topalis\ConfigGroup\Form\Type\Ios\PassCodeType;
use Topalis\ConfigGroup\Form\Type\Ios\RestrictionsType;
use Topalis\ConfigGroup\Form\Type\Ios\WifiType;
use Symfony\Component\DependencyInjection\ContainerInterface;

// @codingStandardsIgnoreStart
/**
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@to.com>
 * https://developer.apple.com/library/ios/featuredarticles/iPhoneConfigurationProfileRef/Introduction/Introduction.html#//apple_ref/doc/uid/TP40010206-CH1-SW4
 */
// @codingStandardsIgnoreEnd
class ProfileForm extends AbstractType
{
    /**
     *
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    protected $container;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unsued
        $builder
            ->add("pass_code", "jquery_collection", array(
                "type"  => new PassCodeType(),
                "limit" => 1,
                "add_text" => "admin.group.configure",
            ))
            ->add("restrictions", "jquery_collection", array(
                "type"  => new RestrictionsType(),
                "limit" => 1,
                "add_text" => "admin.group.configure",
            ))
            ->add("exchange", new ExchangeType(), array(
                "mapped" => false
            ))
            ->add("wifi", "jquery_collection", array(
                "type" => new WifiType(),
                "allow_add" => false,
            ))
            ->add("apn", "jquery_collection", array(
                "type"  => new ApnType(),
                "limit" => 1,
                "add_text" => "admin.group.configure",
            ))
            ->add("air_play", "jquery_collection", array(
                "type"  => new AirPlayType(),
                "limit" => 1,
                "add_text" => "admin.group.configure",
            ))
            ->add("air_print", "jquery_collection", array(
                "type"  => new AirPrintType(),
                "limit" => 1,
                "add_text" => "admin.group.configure",
            ))
            ->add("save", "submit", array(
                "label" => "Save",
                "attr" => array("class" => "btn btn-primary")
            ))
        ;

    }

    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        $resolver->setDefaults(
            array(
                "data_class" => 'Topalis\Profile\ConfigurationProfile'
            )
        );
    }

    public function getName()
    {
        return "config_group_profile";
    }
}
