<?php
namespace Topalis\ConfigGroup\Form\Type\WinPhone;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Topalis\ConfigGroup\Form\Transformer\WinPhone\WinPhoneRestrictionsTransformer;

/**
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class WinPhoneRestrictionsType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused
        $prefix = "admin.group.winphone.restrictions.";
        $prefixProfile = "admin.group.profile.restrictions.";
        $prefixGeneral = "admin.group.general.restrictions.";
        $builder
            ->add("requireDeviceEncryption", "checkbox", array(
                "label" => $prefix . "encryption",
                "description" => $prefix . "encryptionDescr",
                "required" => false,
            ))
            ->add("allowStore", "checkbox", array(
                "label" => $prefix . "allowStore",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowCamera", "checkbox", array(
                "label" => $prefixProfile . "allowCamera",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowScreenCapture", "checkbox", array(
                "label" => $prefixProfile . "allowScreenShot",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowVoiceRecording", "checkbox", array(
                "label" => $prefix . "allowVoiceRecording",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowSaveAsOfOfficeFiles", "checkbox", array(
                "label" => $prefix . "allowSaveAsOfOfficeFiles",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowCortana", "checkbox", array(
                "label" => $prefix . "allowCortana",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowCopyPaste", "checkbox", array(
                "label" => $prefix . "allowCopyPaste",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowSyncMySettings", "checkbox", array(
                "label" => $prefix . "allowSyncMySettings",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowWiFi", "checkbox", array(
                "label" => $prefixGeneral . "allowWiFi",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowAutoConnectToWiFiSenseHotspots", "checkbox", array(
                "label" => $prefix . "allowAutoConnect",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowInternetSharing", "checkbox", array(
                "label" => $prefix . "allowInternetSharing",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowManualWiFiConfiguration", "checkbox", array(
                "label" => $prefix . "allowWiFiConfiguration",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowWiFiHotspotReporting", "checkbox", array(
                "label" => $prefix . "allowWiFiHotspotReporting",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowNFC", "checkbox", array(
                "label" => $prefixGeneral . "allowNFC",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowBluetooth", "checkbox", array(
                "label" => $prefixGeneral . "allowBluetooth",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowCellularDataRoaming", "checkbox", array(
                "label" => $prefix . "allowCellularDataRoaming",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowVPNOverCellular", "checkbox", array(
                "label" => $prefix . "allowVPNOverCellular",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowVPNRoamingOverCellular", "checkbox", array(
                "label" => $prefix . "allowVPNRoamingOverCellular",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowBrowser", "checkbox", array(
                "label" => $prefix . "allowBrowser",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowUSBConnection", "checkbox", array(
                "label" => $prefix . "allowUSBConnection",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowStorageCard", "checkbox", array(
                "label" => $prefixGeneral . "allowSdCard",
                "required" => false,
            ))
            ->add("allowTelemetry", "choice", array(
                "label" => $prefix . "allowTelemetry",
                "choices" => array(
                    2 => $prefix . "allowTelemetryChoice.allowed",
                    1 => $prefix . "allowTelemetryChoice.noSecondaryDataRequests",
                    0 => $prefix . "allowTelemetryChoice.notAllowed",
                ),
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowLocation", "checkbox", array(
                "label" => $prefix . "allowLocation",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowSearchToUseLocation", "checkbox", array(
                "label" => $prefix . "allowSearchToUseLocation",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("safeSearchPermissions", "choice", array(
                "label" => $prefix . "adultContentSearchFilter",
                "description" => $prefix . "adultContentSearchFilterDescr",
                "choices" => array(
                    1 => $prefix . "adultContentSearchFilterChoice.moderate",
                    0 => $prefix . "adultContentSearchFilterChoice.strict"
                ),
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowStoringImagesFromVisionSearch", "checkbox", array(
                "label" => $prefix . "allowStoringImagesFromVisionSearch",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowManualRootCertificateInstallation", "checkbox", array(
                "label" => $prefix . "allowRootCertificateInstallation",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowDeveloperUnlock", "checkbox", array(
                "label" => $prefix . "allowDeveloperUnlock",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowMicrosoftAccountConnection", "checkbox", array(
                "label" => $prefix . "allowMicrosoftAccountConnection",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->add("allowAddingNonMicrosoftAccountsManually", "checkbox", array(
                "label" => $prefix . "allowAddingNonMicrosoftAccounts",
                "required" => false,
                "os" => array("WinPhone" => ">=8.1"),
            ))
            ->addViewTransformer(new WinPhoneRestrictionsTransformer())
        ;
    }

    public function getName()
    {
        return "restrictions";
    }
}
