<?php
namespace Topalis\Configuration\Command;

use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\PropertyAccess\PropertyAccess;

/**
 * This command gets or sets values in the apache config. Returns 65 if a
 * property doesn't exist.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class AccessAuralisConfigCommand extends ContainerAwareCommand
{
    const EX_NO_SUCH_PROPERTY = 65;

    /**
     * @return \Topalis\Configuration\AuralisConfig
     */
    private function getConfig()
    {
        return $this->getContainer()->get("config.auralis");
    }

    protected function configure()
    {
        $this
        ->setName("auralis:config")
        ->setDescription("Get or set values in the auralis config.")
        ->setHelp(
            "Get or set values in the auralis config. If no value is defined the current value is returned.")
        ->addArgument("property", InputArgument::REQUIRED, "The property to access")
        ->addArgument("value", InputArgument::OPTIONAL, "The value to set")
        ;
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $property = $input->getArgument("property");
        $value = $input->getArgument("value");

        $config = $this->getConfig();
        $accessor = PropertyAccess::createPropertyAccessor();

        try {
            if (strlen($value) > 0) {
                $accessor->setValue($config, $property, $value);
            } else {
                $value = $accessor->getValue($config, $property);
                $output->writeln($value);
            }
        } catch (NoSuchPropertyException $e) {
            $output->writeln("No such property exists.");
            return self::EX_NO_SUCH_PROPERTY;
        }
    }
}
