<?php
namespace Topalis\Configuration\Command;

use Topalis\Form\Validator\Constraint\IPList;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand;

class AdminNetworkCommand extends ContainerAwareCommand
{
    /**
     * @return \Topalis\Configuration\AuralisConfig
     */
    private function getConfig()
    {
        return $this->getContainer()->get("config.auralis");
    }

    /**
     * @return \Symfony\Component\Validator\ValidatorInterface
     */
    private function getValidator()
    {
        return $this->getContainer()->get("validator");
    }

    protected function configure()
    {
        $this
        ->setName("config:admin_network")
        ->setDescription("Gets or sets the administration network.")
        ->setHelp("Gets or sets the administration network.")
        ->addArgument("admin-network", InputArgument::OPTIONAL, "The administration network in CIDR notation.");
    }

    protected function execute(\Symfony\Component\Console\Input\InputInterface $input,
        \Symfony\Component\Console\Output\OutputInterface $output)
    {
        $adminNetwork = $input->getArgument("admin-network");
        if ($adminNetwork !== null) {
            $errors = $this->getValidator()->validateValue($adminNetwork, new IPList());
            if (count($errors)) {
                throw new \InvalidArgumentException((string) $errors);
            }
            $this->getConfig()->setAllowFrom($adminNetwork);
        } else {
            $output->writeln($this->getConfig()->getAllowFrom());
        }
    }
}
