<?php
namespace Topalis\Configuration\Controller\Section;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\HttpFoundation\Response;
use Topalis\Configuration\Form\LdapConfigurationForm;
use Topalis\Configuration\LdapConfig;
use Topalis\User\Ldap\LdapManager;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @Route("/admin/config/ldap")
 */
class LdapConfigController extends Controller
{
    /**
     * @Route("", name="admin_config_ldap")
     * @Template()
     * @param Request $request
     *
     * @return array
     */
    public function indexAction(Request $request)
    {
        $config = $this->get("config.auralis");
        $form = $this->createForm(new LdapConfigurationForm(), $config->getLdapConfig());
        $form->handleRequest($request);

        if ($form->isValid()) {
            $config->setLdapConfig($form->getData());

            $this->get("session")->getFlashBag()->add("success",
                $this->get("translator")->trans("admin.global.saveSuccess")
            );

            return $this->redirect($this->generateUrl("admin_config_ldap"));
        }

        return array(
            "form"           => $form->createView(),
            "sections"       => $this->container->getParameter("config.sections"),
            "active_section" => "ldap",
        );
    }

    /**
     * @Route("/test", name="admin_config_ldap_test")
     *
     * @return string
     */
    public function testLdapAction()
    {
        try {
            $data = $this->getRequest()->request->all();
            $config = new LdapConfig();
            $config->setBaseDn($data['baseDn']);
            $config->bindName = $data['bindName'];
            $config->bindPassword = $data['bindPassword'];
            if (strlen($config->bindPassword) == 0 && strlen($config->bindName) > 0) {
                $config->bindPassword = $this->get("config.auralis")->getLdapConfig()->bindPassword;
            }
            $config->hostname = $data['hostname'];
            $config->port = $data['port'];
            $config->security = $data['security'];
            $manager = new LdapManager();
            $manager->setLdapConfig($config);
            $manager->bind();
            $manager->hasUsers(); // verify that base DN has valid syntax
        } catch (\Exception $e) {
            return new Response($e->getMessage());
        }

        return new Response("OK");
    }
}
