<?php
namespace Topalis\Configuration\Controller\Section;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Topalis\Configuration\Form\MailConfigurationForm;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @Route("/admin/config/mail")
 */
class MailConfigController extends Controller
{
    /**
     * @param Request $request
     *
     * @Route("", name="admin_config_mail")
     * @Template()
     */
    public function indexAction(Request $request)
    {
        $config = $this->get("config.auralis");
        $form = $this->createForm(new MailConfigurationForm(), $config);

        $form->handleRequest($request);
        if ($form->isValid()) {
            $mtaConfig = $this->get("system.mtaconfig");
            if ($mtaConfig->isSupportedSystem()) {
                $mtaConfig->setAlias("root", $config->getMailContact());
                $mtaConfig->setGenericMapping("root", $config->getMailSender());
                $mtaConfig->setRelayHost($config->getMailServer());
                $mtaConfig->setRelayPort($config->getMailPort());
                $mtaConfig->setClientTLSEnabled(false);
                $mtaConfig->store();
            }

            $this->get("session")->getFlashBag()->add("success",
                $this->get("translator")->trans("admin.global.saveSuccess")
            );

            return $this->redirect($this->generateUrl("admin_config_mail"));
        }

        return array(
            "form"           => $form->createView(),
            "sections"       => $this->container->getParameter("config.sections"),
            "active_section" => "mail",
        );
    }

    /**
     * @Route("/test", name="admin_config_mail_test")
     */
    public function testAction()
    {
        try {
            $settings = $this->getRequest()->request->all();
            $mailer = $this->get("mailer");
            $mailer->setMailSettings($settings);
            $mailer->sendAdminMessage(
                $this->get("translator")->trans("admin.mailer.test.subject"),
                $this->get("translator")->trans("admin.mailer.test.message")
            );
        } catch (\Exception $e) {
            return new Response($e->getMessage());
        }

        return new Response("OK");
    }
}
