<?php
namespace Topalis\Configuration\Controller;

use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Response;
use Topalis\Configuration\Form\RestoreForm;
use Topalis\Kernel\Controller;
use Topalis\Kernel\Http\RedirectDelayResponse;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;

/**
 * Setup auralis
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 *
 * @Route("/admin/setup", service="config.setup.controller")
 */
class SetupController extends Controller
{
    private function setStep($step)
    {
        $this->getTwig()->addGlobal("wizard_step", $step);
    }

    /**
     * @Route("/network", name="admin_setup_network")
     * @return RedirectResponse|Response
     */
    public function networkAction()
    {
        $this->setStep(1);
        $response = $this->forward("TopalisConfigurationBundle:Section/NetworkConfig:index", array(
            "embed" => true
        ));
        if ($response instanceof RedirectResponse) {
            return $this->redirect($this->generateUrl("admin_setup_ca"));
        }

        return $response;
    }
    /**
     * @Route("", name="admin_setup_restore")
     * @Template()
     *
     * @return Response|RedirectDelayResponse
     */
    public function restoreAction()
    {
        $this->setStep(0);
        $restoreForm = $this->createForm(new RestoreForm())->createView();

        return array("restore" => $restoreForm);
    }

    /**
     * @Route("/ca", name="admin_setup_ca")
     * @Template("TopalisCertificateBundle:Cert:ca_cert.html.twig")
     * @return Response|RedirectDelayResponse
     */
    public function caAction()
    {
        $this->setStep(2);
        $response = $this->forward("cacert.controller:editAction", array(
            "embed" => true,
        ));
        if ($response instanceof RedirectResponse) {
            return new RedirectDelayResponse($this->generateUrl("admin_setup_server_cert"));
        }

        return $response;
    }

    /**
     * @Route("/server_cert", name="admin_setup_server_cert")
     * @Template("TopalisCertificateBundle:Cert:server_cert.html.twig")
     * @return Response|RedirectDelayResponse
     */
    public function serverAction()
    {
        $this->setStep(3);
        $response = $this->forward("servercert.controller:editAction", array(
            "embed" => true
        ));
        if ($response instanceof RedirectResponse) {
            return new RedirectDelayResponse($this->generateUrl("admin_dashboard"));
        }

        return $response;
    }
}
