<?php
namespace Topalis\Configuration\DependencyInjection;

use Symfony\Component\Config\FileLocator;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Exception\InvalidArgumentException;
use Symfony\Component\DependencyInjection\Extension\Extension;
use Symfony\Component\DependencyInjection\Loader\YamlFileLoader;

/**
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class TopalisConfigurationExtension extends Extension
{
    public function load(array $configs, ContainerBuilder $container)
    {
        $configuration = $this->getConfiguration($configs, $container);
        $config = $this->processConfiguration($configuration, $configs);
        if (!$container->hasParameter("config.sysconfig_filename")) {
            $container->setParameter("config.sysconfig_filename", $config['sysconfig']);
        }

        $loader = new YamlFileLoader($container, new FileLocator(__DIR__ . "/../Resources/config"));
        $loader->load("services.yml");

        if (!$container->hasParameter("database_configured") || !$container->getParameter("database_configured")) {
            $sysConfig = $container->get("config.auralis.system");
            $dbConfig = $sysConfig->getDbConfig();
            $container->setParameter("database_driver", "pdo_mysql");
            $container->setParameter("database_host", $dbConfig['host']);
            $container->setParameter("database_port", $dbConfig['port']);
            $container->setParameter("database_name", $dbConfig['database']);
            $container->setParameter("database_user", $dbConfig['user']);
            $container->setParameter("database_password", $dbConfig['password']);
        }

        $container->setParameter("config.sections", array(
            "network"     => array("title" => "admin.global.network.title", "route" => "admin_config_network"),
            "exchange"    => array("title" => "admin.global.exchange.title", "route" => "admin_config_exchange"),
            "mail"        => array("title" => "admin.global.mail.title", "route" => "admin_config_mail"),
            "snmp"        => array("title" => "admin.global.snmp.title", "route" => "admin_config_snmp"),
            "ldap"        => array("title" => "admin.global.ldap.title", "route" => "admin_config_ldap"),
            "certificate" => array("title" => "admin.cert.title", "route" => "admin_cacert"),
            "push"        => array("title" => "admin.global.push.title", "route" => "admin_config_push"),
            "app"         => array("title" => "admin.global.app.title", "route" => "admin_config_app"),
            "advanced"    => array("title" => "admin.global.advanced.title", "route" => "admin_config_advanced"),
        ));
    }
}
