<?php
namespace Topalis\Configuration\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Validator\Constraints as Assert;
use Topalis\Configuration\Form\Type\WinPhoneStoreLocaleType;

/**
 * AppConfigurationForm
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class AppConfigurationForm extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused

        $builder
            ->add("itunesStore", "country", array(
                "label"             => "admin.app.store",
                "preferred_choices" => array(\Locale::getRegion(\Locale::getDefault()))
            ))
            ->add("googlePlayStoreLang", "language", array(
                "label"             => "admin.app.android.storeLang",
                "description"       => "admin.app.android.storeLangDescr",
                "descriptionBlock"  => true,
                "preferred_choices" => array(\Locale::getPrimaryLanguage(\Locale::getDefault()))
            ))
            ->add("winPhoneStoreLocale", new WinPhoneStoreLocaleType(), array(
                "label" => "admin.app.winphone.store.locale",
                "preferred_choices" => array(str_replace("_", "-", strtolower(\Locale::getDefault())))
            ))
            ->add("appInstallAttempts", "integer", array(
                "label"            => "admin.app.installAttempts",
                "required"         => false,
                "description"      => "admin.app.installAttemptsDescription",
                "descriptionBlock" => true,
                "constraints"      => new Assert\Range(array("min" => 1))
            ))
            ->add("vppToken", "file", array(
                "label"       => "admin.global.app.vppToken.label",
                "constraints" => array(new Assert\File()),
                "required"    => false,
            ))
        ;
    }

    public function getName()
    {
        return "config_app";
    }
}
