<?php
namespace Topalis\Configuration\Form\Handler;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Form\FormInterface;

/**
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class ExchangeConfigurationFormHandler
{
    /**
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    private $container;

    /**
     * @var \Symfony\Component\HttpFoundation\Request
     */
    private $request;

    public function __construct(Request $request, ContainerInterface $container)
    {
        $this->request = $request;
        $this->container = $container;
    }

    /**
     * @param \Symfony\Component\Form\FormInterface $form
     * @return boolean
     */
    public function process(FormInterface $form)
    {
        $form->handleRequest($this->request);
        if (!$form->isSubmitted() || !$form->isValid()) {
            return false;
        }

        $config = $this->container->get("config.auralis");
        $data = $form->getData();
        $updateMailProfiles = $config->getExchangeDomain() != $data['exchangeDomain']
            || $config->isExchangeAltLoginType() != $data['exchangeAltLogin'];

        $config->setExchangeHost($data['exchangeHost']);
        $config->setExchangeSsl($data['exchangeSSL']);
        $config->setExchangeDomain($data['exchangeDomain']);
        $config->setExchangeAltLoginType($data['exchangeAltLogin']);

        if ($updateMailProfiles) {
            $this->updateMailProfiles();
        }

        return true;
    }

    private function updateMailProfiles()
    {
        $em = $this->container->get("device.entity.manager.device");
        $mdmFacade = $this->container->get("device.mdm.facade");
        foreach ($em->findAll() as $device) {
            if ($device->isActive() && $device->isManaged() && !$device->isActiveSyncDisabled()) {
                foreach ($device->getMailAccounts() as $mailAccount) {
                    $mdmFacade->installMailAccount($mailAccount);
                }
            }
        }
    }
}
