<?php
namespace Topalis\Configuration\Validator;

use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;
use Topalis\Gcm\Gcm;
use Topalis\Gcm\Exception\GcmClientException;

/**
 * Validates the GCM API Key.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class GcmApiKeyValidator extends ConstraintValidator
{
    /**
     *
     * @var \Topalis\Gcm\Gcm
     */
    private $gcm;

    public function validate($value, Constraint $constraint)
    {
        if (strlen($value) == 0) {
            return;
        }

        try {
            $status = $this->gcm->getStatus($value);
            if ($status >= 500 && $status <= 599) {
                // Internal GCM server error
                $this->context->addViolation($constraint->messageServerError);
            } else if ($status == 401) {
                $this->context->addViolation($constraint->message);
            }
        } catch (GcmClientException $e) {
            // timeout, status 5xx, ...
            $this->context->addViolation($constraint->messageError, array("%errmsg%" => $e->getMessage()));
        }
    }

    public function setGcm(Gcm $gcm)
    {
        $this->gcm = $gcm;
    }
}
