<?php
namespace Topalis\Dashboard\System;

/**
 * Get CPU information
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class CPU extends SystemInformation
{
    protected $load = 0;
    protected $user = 0;
    protected $nice = 0;
    protected $system = 0;
    protected $ioWait = 0;

    public function __construct($sleep = false)
    {
        $load1 = $this->readLoad();
        if ($sleep) {
            sleep(2);
        }
        $load2 = $this->readLoad();

        $this->load = $this->calcPercentage($load1, $load2, "load");
        $this->user = $this->calcPercentage($load1, $load2, "user");
        $this->nice = $this->calcPercentage($load1, $load2, "nice");
        $this->system = $this->calcPercentage($load1, $load2, "system");
        $this->ioWait = $this->calcPercentage($load1, $load2, "ioWait");
    }

    protected function calcPercentage($data1, $data2, $key)
    {
        $total1 = $data1['total'];
        $total2 = $data2['total'];
        $load1 = $data1[$key];
        $load2 = $data2[$key];

        if ($total1 > 0 && $total2 > 0 && $load1 > 0 && $load2 > 0 && $total2 != $total1 && $load2 != $load1) {
            return abs(100 * ($load2 - $load1) / ($total2 - $total1));
        }

        return 0;
    }

    protected function readLoad()
    {
        $stat = $this->readFile("/proc/stat", 0);
        $data = array(
            "user" => 0,
            "nice" => 0,
            "system" => 0,
            "idle" => 0,
            "ioWait" => 0
        );

        sscanf(
            $stat,
            "%*s %Ld %Ld %Ld %Ld %Ld",
            $data['user'],
            $data['nice'],
            $data['system'],
            $data['idle'],
            $data['ioWait']
        );
        $data['load'] = $data['user'] + $data['nice'] + $data['system'] + $data['ioWait'];
        $data['total'] = $data['load'] + $data['idle'];

        return $data;
    }

    public function getLoad()
    {
        return $this->load;
    }

    public function getPercentage()
    {
        return number_format((float) $this->getLoad(), 0, ".", "");
    }

    public function getIoWait()
    {
        return $this->ioWait;
    }

    public function getNice()
    {
        return $this->nice;
    }

    public function getSystem()
    {
        return $this->system;
    }

    public function getUser()
    {
        return $this->user;
    }
}
