<?php
namespace Topalis\Dashboard\System;

use Topalis\Dashboard\System\Device\DiskDevice;

/**
 * fetch data about disks
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class Filesystem extends SystemInformation
{
    /**
     * @var DiskDevice[]
     */
    protected $disks;

    public function __construct()
    {
        $this->loadDisks();
    }

    protected function loadDisks()
    {
        $output = $this->execute("df");
        $output = preg_split("/\n/", $output, -1, PREG_SPLIT_NO_EMPTY);
        unset($output[0]);
        $merge = array();
        foreach ($output as $line) {
            $parts = preg_split("/(\s+)/", $line, 6);
            if (count($parts) != 6) {
                $merge = $parts;
                continue;
            }
            if (!empty($merge)) {
                foreach ($merge as $key => $value) {
                    $parts[$key] = $value;
                }
                $merge = array();
            }
            if ("/dev/shm" == $parts[5]) {
                continue;
            }

            $disk = new DiskDevice();
            $disk
                ->setName($parts[0])
                ->setSize($parts[1] * 1024)
                ->setUsed($parts[2] * 1024)
                ->setAvailable($parts[3] * 1024)
                ->setUse(intval(rtrim($parts[4], "%")))
                ->setMountPoint($parts[5]);
            $this->disks[] = $disk;
        }
    }

    /**
     * @return DiskDevice[]
     */
    public function getDisks()
    {
        return $this->disks;
    }
}
