<?php
namespace Topalis\Dashboard\System;

use DirectoryIterator;
use Topalis\Dashboard\System\Device\NetworkInterface;

/**
 * Get network information
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class Network extends SystemInformation
{
    protected $interfaces;

    public function __construct($sleep = false)
    {
        $interfaces = new DirectoryIterator("/sys/class/net");
        foreach ($interfaces as $interface) {
            if ($interface->isDot()) {
                continue;
            }
            if ("lo" == $interface->getBasename()) {
                continue;
            }
            $device = new NetworkInterface();
            $device
                ->setName($interface->getBasename());

            $this->interfaces[] = $device;
        }

        $bytes = array();
        foreach ($this->interfaces as $interface) {
            $bytes[$interface->getName()] = $this->getBytes($interface);
        }
        if ($sleep) {
            sleep(1);
        }
        foreach ($this->interfaces as $interface) {
            list($transmitted, $received) = $this->getBytes($interface);
            $transmittedPerSecond = $transmitted - $bytes[$interface->getName()][0];
            $receivedPerSecond = $received - $bytes[$interface->getName()][1];
            $interface->setSendSpeed($transmittedPerSecond);
            $interface->setReceivedSpeed($receivedPerSecond);
        }

    }

    protected function getBytes(NetworkInterface $interface)
    {
        $transmitted = $this->readFile(sprintf("/sys/class/net/%s/statistics/tx_bytes", $interface->getName()));
        settype($transmitted, "integer");

        $received = $this->readFile(sprintf("/sys/class/net/%s/statistics/rx_bytes", $interface->getName()));
        settype($received, "integer");

        return array($transmitted, $received);
    }

    public function getInterfaces()
    {
        return $this->interfaces;
    }
}
