<?php
namespace Topalis\Database\Types;

use Doctrine\DBAL\Types\Type;
use Doctrine\DBAL\Platforms\AbstractPlatform;

class BinaryType extends Type
{
    public function getSQLDeclaration(array $fieldDeclaration, AbstractPlatform $platform)
    {
        if ($platform->getName() != "mysql") {
            return $platform->getBlobTypeDeclarationSQL($fieldDeclaration);
        }

        if (!isset($fieldDeclaration['length'])) {
            $fieldDeclaration['length'] = $platform->getVarcharDefaultLength();
        }

        if ($fieldDeclaration['length'] > $platform->getVarcharMaxLength()) {
            return $platform->getBlobTypeDeclarationSQL($fieldDeclaration);
        }

        $fixed = (isset($fieldDeclaration['fixed'])) ? $fieldDeclaration['fixed'] : false;

        return $fixed ? 'BINARY(' . $fieldDeclaration['length'] . ')'
            : 'VARBINARY(' . $fieldDeclaration['length'] . ')';
    }

    public function getName()
    {
        return "binary";
    }

    public function requiresSQLCommentHint(AbstractPlatform $platform)
    {
        return true;
    }
}
