<?php
namespace Topalis\Database\Types;

use Doctrine\DBAL\Platforms\AbstractPlatform;
use Doctrine\DBAL\Types\Type;

/**
 * Maps a simple PHP array to a VARCHAR field using JSON.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class JsonArrayStringType extends Type
{
    public function getSQLDeclaration(array $fieldDeclaration, AbstractPlatform $platform)
    {
        return $platform->getVarcharTypeDeclarationSQL($fieldDeclaration);
    }

    public function convertToDatabaseValue($value, AbstractPlatform $platform)
    {
        $platform; // unused
        if (null === $value) {
            return null;
        }

        return json_encode($value);
    }

    public function convertToPHPValue($value, AbstractPlatform $platform)
    {
        $platform; // unused
        if ($value === null) {
            return null;
        }

        $value = (is_resource($value)) ? stream_get_contents($value) : $value;

        return json_decode($value, true);
    }

    public function getName()
    {
        return "json_array_string";
    }

    public function requiresSQLCommentHint(AbstractPlatform $platform)
    {
        $platform; // unused
        return true;
    }
}
