<?php
namespace Topalis\Database\Util;

use Doctrine\DBAL\Driver\Connection;
use Doctrine\DBAL\DBALException;
use Doctrine\DBAL\Driver\PDOException;

/**
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class DatabaseUtils
{
    /**
     * Ensure that there is a connection to the database. If a connection wasn't
     * possible in the first try, the method sleeps for 15 seconds and tries
     * again in case the DBMS is restarted.
     *
     * @param Connection $connection
     *
     * @throws \Doctrine\DBAL\DBALException If connection fails.
     * @throws \PDOException If connection fails.
     */
    public static function ensureConnected(Connection $connection)
    {
        try {
            // check if we have a connection. if the connection is closed a new
            // one will be established.
            $connection->query('select 1;')->fetch();
        } catch (\Exception $e) {
            // db server might be restarted so wait some time and try to reconnect
            sleep(15);
            $connection->close();
            $connection->connect();
            $connection->query('select 1;')->fetch();
        }
    }
}
