<?php
namespace Topalis\Device\Command;

use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand;

/**
 * This command removes entries in the device accesslog that are older than 60
 * days.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class CleanDeviceAccessLogCommand extends ContainerAwareCommand
{
    /**
     * @return \Topalis\Device\Entity\AccessLogEntityManager
     */
    private function getAccessLogEntityManager()
    {
        return $this->getContainer()->get("device.entity.manager.access_log");
    }

    /**
     * @return \Doctrine\ORM\EntityManager
     */
    private function getEntityManager()
    {
        return $this->getContainer()->get("doctrine.orm.entity_manager");
    }

    /**
     * @return \Topalis\Kernel\TimeProviderInterface
     */
    private function getTimeProvider()
    {
        return $this->getContainer()->get("kernel.time_provider");
    }

    protected function configure()
    {
        $this
        ->setName("device:clean_accesslog")
        ->setDescription("Removes entries in the device accesslog that are older than 60 days.")
        ->setHelp("Removes entries in the device accesslog that are older than 60 days.");
    }

    protected function execute(\Symfony\Component\Console\Input\InputInterface $input,
        \Symfony\Component\Console\Output\OutputInterface $output)
    {
        $input; // unused
        $output; // unused

        $exists = $this->getEntityManager()->createQuery("SELECT 1 FROM TopalisDeviceBundle:AccessStatYearMonth")
            ->setMaxResults(1)->getOneOrNullResult();
        if ($exists === null) {
            // don't clean accesslog if the aggregation of AccessStatYearMonth
            // did not happen, yet, after the update from auralis 2.1
            return;
        }

        $date = $this->getTimeProvider()->getDateTime();
        $date->sub(new \DateInterval("P60D"));
        $qb = $this->getAccessLogEntityManager()->createQueryBuilder("a");
        $qb->delete("TopalisDeviceBundle:AccessLog", "a")
            ->where("a.tstamp < :cleanDate")
            ->setParameter("cleanDate", $date->format("Y-m-d 00:00:00"))
            ->getQuery()->execute();
    }
}
