<?php
namespace Topalis\Device\DependencyInjection\Compiler;

use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Definition;
use Symfony\Component\DependencyInjection\Reference;

/**
 * Adds the device info sections to the section container.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class SectionPass implements CompilerPassInterface
{
    public function process(ContainerBuilder $container)
    {
        $sectionQueue = new \SplPriorityQueue();
        foreach ($container->findTaggedServiceIds("device.info.section") as $serviceId => $tag) {
            $order = isset($tag[0]['order']) ? $tag[0]['order'] : 0;
            $sectionQueue->insert(new Reference($serviceId), $order);
        }

        $sections = array();
        foreach ($sectionQueue as $section) {
            $sections[] = $section;
        }

        $definition = $container->getDefinition("device.info.section_container");
        $definition->addArgument(array_reverse($sections));
    }
}
