<?php

namespace Topalis\Device\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * AccessLog
 *
 * @ORM\Table(name="accesslog", indexes={@ORM\Index(name="idx_accesslog_tstamp", columns={"tstamp"})})
 * @ORM\Entity
 */
class AccessLog
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="bigint", nullable=false, options={"unsigned"=true})
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    protected $id;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="tstamp", type="datetime", nullable=false,
     *     options={"version"=true, "comment"="Timestamp of access"})
     */
    protected $tstamp;

    /**
     * @var string
     *
     * @ORM\Column(name="ip", type="string", length=50, nullable=true,
     *     options={"comment"="Remote IP of access"})
     */
    protected $ip;

    /**
     * @var integer
     *
     * @ORM\Column(name="status", type="integer", nullable=false,
     *     options={"comment"="The HTTP status code of access"})
     */
    protected $status;

    /**
     * @var integer
     *
     * @ORM\Column(name="traffic", type="integer", nullable=false,
     *     options={"unsigned"=true, "comment"="Traffic of access in bytes"})
     */
    protected $traffic;

    /**
     * @var \Topalis\Certificate\Entity\ClientCertificate
     *
     * @ORM\ManyToOne(targetEntity="Topalis\Certificate\Entity\ClientCertificate")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="cert_id", referencedColumnName="id", nullable=false)
     * })
     */
    protected $cert;

    /**
     * @var \Topalis\Device\Entity\Device
     *
     * @ORM\ManyToOne(targetEntity="Topalis\Device\Entity\Device")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="device_id", referencedColumnName="id", nullable=false)
     * })
     */
    protected $device;

    /**
     * Get id
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set tstamp
     *
     * @param \DateTime $tstamp
     * @return AccessLog
     */
    public function setTstamp(\DateTime $tstamp)
    {
        $this->tstamp = $tstamp;

        return $this;
    }

    /**
     * Get tstamp
     *
     * @return \DateTime
     */
    public function getTstamp()
    {
        return $this->tstamp;
    }

    /**
     * Set ip
     *
     * @param string $ip
     * @return AccessLog
     */
    public function setIp($ip)
    {
        $this->ip = $ip;

        return $this;
    }

    /**
     * Get ip
     *
     * @return string
     */
    public function getIp()
    {
        return $this->ip;
    }

    /**
     * Set status
     *
     * @param integer $status
     * @return AccessLog
     */
    public function setStatus($status)
    {
        $this->status = $status;

        return $this;
    }

    /**
     * Get status
     *
     * @return integer
     */
    public function getStatus()
    {
        return $this->status;
    }

    /**
     * Set traffic
     *
     * @param integer $traffic
     * @return AccessLog
     */
    public function setTraffic($traffic)
    {
        $this->traffic = $traffic;

        return $this;
    }

    /**
     * Get traffic
     *
     * @return integer
     */
    public function getTraffic()
    {
        return $this->traffic;
    }

    /**
     * Set cert
     *
     * @param \Topalis\Certificate\Entity\ClientCertificate $cert
     * @return AccessLog
     */
    public function setCert(\Topalis\Certificate\Entity\ClientCertificate $cert = null)
    {
        $this->cert = $cert;

        return $this;
    }

    /**
     * Get cert
     *
     * @return \Topalis\Certificate\Entity\ClientCertificate
     */
    public function getCert()
    {
        return $this->cert;
    }

    /**
     * Set device
     *
     * @param \Topalis\Device\Entity\Device $device
     * @return AccessLog
     */
    public function setDevice(\Topalis\Device\Entity\Device $device = null)
    {
        $this->device = $device;

        return $this;
    }

    /**
     * Get device
     *
     * @return \Topalis\Device\Entity\Device
     */
    public function getDevice()
    {
        return $this->device;
    }
}
