<?php
namespace Topalis\Device\Entity;

use Doctrine\Common\Persistence\ObjectManager;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Topalis\Certificate\CertificateManager;
use Topalis\Database\EntityManager;

/**
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class DeviceEntityManager extends EntityManager
{
    /**
     * @var \Topalis\Certificate\CertificateManager
     */
    private $certificateManager;
    /**
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    private $container;

    public function __construct(ObjectManager $em, $class, CertificateManager $certificateManager,
        ContainerInterface $container)
    {
        parent::__construct($em, $class);
        $this->certificateManager = $certificateManager;
        $this->container = $container;
    }

    /**
     * @return \Topalis\Device\MDM\MdmFacadeInterface
     */
    private function getMdmFacade()
    {
        return $this->container->get("device.mdm.facade");
    }

    public function enableDeleteFilter()
    {
        $this->em->getFilters()->enable("device_deleted");

        return $this;
    }

    public function disableDeleteFilter()
    {
        $filterCollection = $this->em->getFilters();
        // we have to check if the filter is enabled first to avaid an exception.
        $enabledFilters = $filterCollection->getEnabledFilters();
        if (isset($enabledFilters['device_deleted'])) {
            $filterCollection->disable("device_deleted");
        }

        return $this;
    }

    public function delete($device, $flush = true)
    {
        /** @var $device Device */
        if ($device->isManaged()) {
            if ($device->getWipeStatus() != Device::WIPE_PENDING
                && $device->getWipeStatus() != Device::WIPE_EXECUTED
                && $device->getWipeStatus() != Device::WIPE_ERROR) {
                $this->getMdmFacade()->wipeDevice($device);
            }
        }

        if ($device->isDeleted() && $device->getWipestatus() == Device::WIPE_PENDING) {
            $device->setWipestatus(Device::WIPE_UNKNOWN);
        }

        $device->setDisabled(true);
        $device->setDeleted(true);
        $device->setPassword(null);

        foreach ($device->getMailAccounts() as $mailAccount) {
            $this->em->remove($mailAccount);
            // if we remove the mail account from the device we will get an
            // exception from doctrine; don't know why.
            $this->flush();
        }

        $this->save($device, $flush);
    }

}
