<?php
namespace Topalis\Device\EventListener;

use Doctrine\ORM\Event\LifecycleEventArgs;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Topalis\Device\Entity\Device;

/**
 * This listener ensures that a new CRL is created if required.
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class DeviceCertificateListener
{
    /**
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    private $container;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    /**
     * @return \Topalis\Certificate\CertificateManager
     */
    private function getCertificateManager()
    {
        return $this->container->get("certificate.manager");
    }

    public function postUpdate(LifecycleEventArgs $eventArgs)
    {
        $device = $eventArgs->getEntity();
        if (!$device instanceof Device) {
            return;
        }

        $uow = $eventArgs->getEntityManager()->getUnitOfWork();
        $changeSet = $uow->getEntityChangeSet($device);

        $createCrl = false;
        if (!$device->isManaged()) {
            if (isset($changeSet['disabled']) || isset($changeSet['activeSyncDisabled'])) {
                $createCrl = true;
            }
        } else if (isset($changeSet['wipestatus'])) {
            switch ($changeSet['wipestatus'][1]) {
                case Device::WIPE_EXECUTED:
                    /* fall through */
                case Device::WIPE_ERROR:
                    /* fall through */
                case Device::WIPE_UNKNOWN:
                    $createCrl = true;
            }
        }

        if ($createCrl) {
            $this->getCertificateManager()->enableCreateRevocationList();
        }
    }
}
