<?php
namespace Topalis\Device\EventListener;

use Doctrine\ORM\Event\LifecycleEventArgs;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Topalis\Device\Entity\Device;
use Topalis\Device\Entity\MailAccount;

/**
 *
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class DeviceMdmEventListener
{
    /**
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    private $container;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    /**
     * @return \Topalis\Device\MDM\MdmFacadeInterface
     */
    private function getMdmFacade()
    {
        return $this->container->get("device.mdm.facade");
    }

    public function prePersist(LifecycleEventArgs $eventArgs)
    {
        $device = $eventArgs->getEntity();
        if (!$device instanceof Device) {
            return;
        }

        if ($device->getConfigGroup()->isNoExchange()) {
            return;
        }

        $user = $device->getUser();
        $email = $user->getEmail();
        foreach ($device->getMailAccounts() as $mailAccount) {
            if ($mailAccount->getEmail() == $email) {
                // default mail account exists
                return;
            }
        }

        // add default mail account
        $defaultMailAccount = new MailAccount();
        $defaultMailAccount->setEmail($email);
        $defaultMailAccount->setUser($user->getLogin());
        $device->addMailAccount($defaultMailAccount);
    }

    public function postUpdate(LifecycleEventArgs $eventArgs)
    {
        $device = $eventArgs->getEntity();
        if (!$device instanceof Device) {
            return;
        }
        if (!$device->isManaged() || !$device->isActive()) {
            return;
        }

        $uow = $eventArgs->getEntityManager()->getUnitOfWork();
        $this->getMdmFacade()->updateDevice($device, $uow);
    }
}
