<?php
namespace Topalis\Device\Form\Extension;

use Symfony\Component\Form\AbstractTypeExtension;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\Form\FormView;
use Symfony\Component\OptionsResolver\Options;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;

/**
 * extend forms with os field
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class SupportedOSExtension extends AbstractTypeExtension
{
    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        $versionsList = array(
            "iOS" => array("5", "5.1", "6", "7", "8", "9"),
            "Android" => array("4.2", "4.3", "4.4", "5.0", "5.1"),
            "KNOX" => array("4", "4.1", "5", "5.1", "5.2", "5.3", "5.4", "5.5"),
            "WinPhone" => array("8.0", "8.1"),
        );
        $osNormalizer = function (Options $options, $operationsSystems) use ($versionsList) {
            $options; // unused
            if (null === $operationsSystems) {
                return;
            }

            foreach ($operationsSystems as $os => $versions) {
                if (is_int($os)) {
                    // no versions specified
                    $os = $versions;
                    $versions = "*";
                }

                if (empty($versions) || $versions == "*") {
                    $operationsSystems[$os] = array();
                } else {
                    if (preg_match("/(<=|>=|<|>|=|!=)?([\d\.]+)/si", $versions, $matches)) {
                        $operator = $matches[1] ?: "=";
                        $version = $matches[2];
                        $versionDots = substr_count($version, ".");
                        $versions = array();
                        foreach ($versionsList[$os] as $version2) {
                            $tmpVersion2 = $version2;
                            $version2Dots = substr_count($version2, ".");
                            if ($version2Dots > $versionDots) {
                                // if $version2 has more dots than $version we
                                // have to cut it for the comparation
                                $tmpVersion2 = strtok($version2, ".");
                                for ($i = $version2Dots - $versionDots; $i > 1; $i--) {
                                    $version2 .= "." . strtok(".");
                                }
                                if (in_array($tmpVersion2, $versions)) {
                                    continue;
                                }
                            } else if ($version2Dots < $versionDots) {
                                // if $version2 has less dots than $version we
                                // have to extend it for the comparation
                                for ($i = $versionDots - $version2Dots; $i > 0; $i--) {
                                    $tmpVersion2 .= ".0";
                                }
                            }
                            if (version_compare($tmpVersion2, $version, $operator)) {
                                $versions[] = $version2;
                            }
                        }
                        $operationsSystems[$os] = $versions;
                        if (count($versions) == count($versionsList[$os])) {
                            $operationsSystems[$os] = array();
                        }
                    }
                }
            }

            return $operationsSystems;
        };

        $resolver->setDefaults(array(
            "os" => null
        ));
        $resolver->setNormalizers(array(
            "os" => $osNormalizer
        ));
    }

    public function buildView(FormView $view, FormInterface $form, array $options)
    {
        $form; // unused
        $view->vars = array_replace($view->vars, array(
            "os" => $options['os']
        ));
    }

    public function getExtendedType()
    {
        return "form";
    }
}
