<?php
namespace Topalis\Device\Info;

use Topalis\Device\Exception\NoSuchSectionException;
use Topalis\Device\Exception\DuplicateSectionKeyException;

/**
 * DeviceInfoSectionContainer
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class DeviceInfoSectionContainer implements DeviceInfoSectionContainerInterface
{
    private $sections = array();

    /**
     * @param DeviceInfoSectionInterface[] $sections Initial sections.
     */
    public function __construct(array $sections = array())
    {
        foreach ($sections as $section) {
            $this->add($section);
        }
    }

    public function add(DeviceInfoSectionInterface $section)
    {
        $key = $section->getKey();
        if ($this->has($key)) {
            throw new DuplicateSectionKeyException("A section with key \"" . $key . "\" is already registered");
        }

        $this->sections[$key] = $section;
    }

    public function get($key)
    {
        if (!$this->has($key)) {
            throw new NoSuchSectionException("No section with key \"". $key . "\" found");
        }

        return $this->sections[$key];
    }

    public function getAll()
    {
        return $this->sections;
    }

    public function has($key)
    {
        return isset($this->sections[$key]);
    }
}
