<?php
namespace Topalis\Device\Info;

/**
 * Container for device info sections.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
interface DeviceInfoSectionContainerInterface
{
    /**
     * @param DeviceInfoSectionInterface $section The section to add.
     *
     * @return DeviceInfoSectionContainerInterface
     *
     * @throws \Topalis\Device\Exception\DuplicateSectionKeyException If a
     *     section with the same key of the section to add is already
     *     registered.
     */
    public function add(DeviceInfoSectionInterface $section);

    /**
     * @param string $key The key of the section to get.
     *
     * @return DeviceInfoSectionInterface The section with the specified key.
     *
     * @throws \Topalis\Device\Exception\NoSuchSectionException If a section
     *     with the specified key does not exist.
     */
    public function get($key);

    /**
     * @return DeviceInfoSectionInterface[] All sections in the container.
     */
    public function getAll();

    /**
     * @param string $key The key to check.
     *
     * @return boolean true if a section with the specified key exists, false
     *     otherwise.
     */
    public function has($key);
}
