<?php
namespace Topalis\Device\Info;

use Symfony\Component\Templating\EngineInterface;
use Topalis\Configuration\AuralisConfig;
use Topalis\Device\DeviceManager;
use Topalis\Device\Entity\Device;

/**
 * MainDeviceInfoSection
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class MainDeviceInfoSection implements DeviceInfoSectionInterface
{
    /**
     * @var \Topalis\Configuration\AuralisConfig
     */
    private $config;

    /**
     * @var \Topalis\Device\DeviceManager
     */
    private $deviceManager;

    /**
     * @var \Symfony\Bundle\FrameworkBundle\Templating\EngineInterface
     */
    private $templating;

    public function __construct(DeviceManager $deviceManager, AuralisConfig $config, EngineInterface $templating)
    {
        $this->deviceManager = $deviceManager;
        $this->config = $config;
        $this->templating = $templating;
    }

    public function getKey()
    {
        return "main";
    }

    public function getTabAttributes()
    {
        return array();
    }

    public function getTitle()
    {
        return "admin.devices.info.infoTab";
    }

    public function isVisible(Device $device)
    {
        return true;
    }

    public function renderContent(Device $device)
    {
        return $this->templating->render("TopalisDeviceBundle:Device/Info:main.html.twig", array(
            "device" => $device,
            "maxPasswordValidity" => $this->config->getPasswordValidity(),
            "data" => $device->getType()->getDeviceInfo($device),
            "traffic" => $this->deviceManager->getDeviceTraffic($device),
        ));
    }
}
