<?php
namespace Topalis\Device\Twig\Extension;

use Topalis\MDM\Entity\MdmCommand;
use Topalis\WinPhone\Entity\SyncMLCommand;
use Topalis\Device\MDM\MdmCommandInterface;

/**
 * Twig extension to format the status of an MDM command.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class MdmCommandStatusExtension extends \Twig_Extension
{
    /**
     * @see Twig_Extension::getFunctions()
     */
    public function getFunctions()
    {
        return array(
            new \Twig_SimpleFunction("formatMdmCommandStatus", array($this, "formatStatus")),
        );
    }

    /**
     * @see Twig_Extension::getFilters()
     */
    public function getFilters()
    {
        return array(
            new \Twig_SimpleFilter("formatMdmCommandStatus", array($this, "formatStatus")),
        );
    }

    public function formatStatus($object, array $labels)
    {
        if (!$object instanceof MdmCommandInterface) {
            return null;
        }

        $cssClass = "label";
        if (isset($labels[$object->getStatus()])) {
            $cssClass .= " label-" . $labels[$object->getStatus()];
        }
        $rv = '<span class="' . $cssClass . '">' . $object->getStatus() . '</span>';

        if ($object instanceof MdmCommand) {
            if ($object->getStatus() == MdmCommand::STATUS_ERROR) {
                $response = $object->getResponse();
                if (isset($response['ErrorChain'])) {
                    $rv .= '<ul>';
                    foreach ($response['ErrorChain'] as $error) {
                        if (isset($error['USEnglishDescription'])) {
                            $rv .= '<li>' . $error['USEnglishDescription'] . '</li>';
                        }
                    }
                    $rv .= '</ul>';
                }
            }
        } else if ($object instanceof SyncMLCommand) {
            if ($object->getStatus() == SyncMLCommand::STATUS_ERROR) {
                $rv .= ' Code: ' . $object->getStatusCode();
            }
        }

        return $rv;
    }

    /**
     * @see Twig_ExtensionInterface::getName()
     */
    public function getName()
    {
        return "formatMdmCommandStatus";
    }
}
