<?php
namespace Topalis\Device\Type;

use Topalis\Configuration\AuralisConfig;
use Topalis\Device\Type\Info\AndroidDeviceInfo;
use Topalis\Device\Entity\Device;
use Topalis\Profile\AndroidConfigurationProfile;
use Topalis\Profile\Payload\Android\SamsungPayload;

/**
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class AndroidDeviceType extends AbstractDeviceType
{
    /**
     * @var \Topalis\Configuration\AuralisConfig
     */
    protected $config;

    /**
     * Array with config group id as key and the correspondig profile as value.
     * @var array
     */
    private $deviceProfiles = array();

    public function __construct(AuralisConfig $config)
    {
        $this->config = $config;
    }

    public function getName()
    {
        return "android";
    }

    public function getId()
    {
        return 2;
    }

    public function getTranslation()
    {
        return "admin.devices.os.android";
    }

    public function hasDeviceInfo(Device $device)
    {
        return null !== $device->getMdmCert();
    }

    /**
     *
     * @param string $name
     * @param Device $device
     * @return boolean true if the device supports the specified operation,
     *     false otherwise.
     */
    public function hasSupport($name, Device $device = null)
    {
        $device; // unused
        switch ($name) {
            case "clearPasscode":
                return false;
            case "setPasscode":
                return true;
            case "apps":
                return true;
            case "deviceLock":
                return true;
            case "deviceLockMessage":
                return true;
            case "mdm":
                return true;
            case "push":
                return true;
        }

        return false;
    }

    public function getDeviceInfo(Device $device)
    {
        return new AndroidDeviceInfo($device->getDeviceinformation() ?: array());
    }

    /**
     * @param \Topalis\Device\Entity\Device $device
     *
     * @return boolean true if the device is manged with MDM.
     */
    public function isManaged(Device $device)
    {
        return null !== $device->getMdmCert();
    }

    public function isRolloutFailed(Device $device)
    {
        return $device->isDisabled() && null === $device->getMdmCert();
    }

    public function getPushTopic()
    {
        return $this->config->getGcmConfig()->getProjectId();
    }

    public function getDeviceProfile(Device $device)
    {
        $group = $device->getConfigGroup();
        if (!isset($this->deviceProfiles[$group->getId()])) {
            $this->deviceProfiles[$group->getId()] = new AndroidConfigurationProfile($group->getAndroidProfile());
        }

        return $this->deviceProfiles[$group->getId()];
    }

    public function getAppStateEntityManagerId()
    {
        return "app.entity.manager.android_app_state";
    }

    public function getSamsungPayload()
    {
        $samsung = new SamsungPayload();
        $samsung->setLicense($this->config->getSamsungLicense());
        return $samsung;
    }
}
