<?php
namespace Topalis\Device\Type;

use Topalis\Device\Entity\Device;
use Topalis\Device\Type\Info\DeviceInfo;
use Topalis\Profile\AbstractProfile;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
interface DeviceTypeInterface
{
    /**
     * Should be the same as the service alias
     * @return string
     */
    public function getName();

    /**
     * OS Id
     * @return integer
     */
    public function getId();

    /**
     * Translation of this type
     * @return string
     */
    public function getTranslation();

    /**
     * Return whether this device is able to show device info
     * @param Device $device
     *
     * @return boolean
     */
    public function hasDeviceInfo(Device $device);

    /**
     *
     * @param string $name
     * @param Device $device
     * @return boolean true if the device supports the specified operation,
     *     false otherwise.
     */
    public function hasSupport($name, Device $device = null);

    /**
     * @param Device $device
     *
     * @return DeviceInfo
     */
    public function getDeviceInfo(Device $device);

    /**
     * @param \Topalis\Device\Entity\Device $device
     *
     * @return boolean true if the device is manged with MDM.
     */
    public function isManaged(Device $device);

    /**
     * @param Device $device
     *
     * @return boolean true if the rollout of the device failed, false otherwise.
     */
    public function isRolloutFailed(Device $device);

    /**
     * @param Device $device
     *
     * @return true if the rollout of the device is finished, false otherwise.
     */
    public function isRolloutFinished(Device $device);

    public function getPushTopic();

    /**
     * Parse mdm token before storing in db
     * @param Device $device
     * @param string $token
     *
     * @return string
     */
    public function parseMdmToken(Device $device, $token);

    /**
     * @param Device $device
     *
     * @return AbstractProfile
     */
    public function getDeviceProfile(Device $device);

    /**
     * Container id of entity manager for app states if available
     *
     * @return string|null
     */
    public function getAppStateEntityManagerId();
}
