<?php
namespace Topalis\Device\Type;

use Topalis\Certificate\CertificateManager;
use Topalis\Device\Type\Info\DeviceInfo;
use Topalis\Device\Entity\Device;
use Topalis\Device\Type\Info\IosDeviceInfo;
use Topalis\Profile\ConfigurationProfile;

/**
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class IosDeviceType extends AbstractDeviceType
{
    /**
     * @var \Topalis\Certificate\CertificateManager
     */
    private $certificateManager;

    /**
     * Array with config group id as key and the correspondig profile as value.
     * @var array
     */
    private $deviceProfiles = array();

    public function __construct(CertificateManager $certificateManager)
    {
        $this->certificateManager = $certificateManager;
    }

    public function getName()
    {
        return "ios";
    }

    public function getId()
    {
        return 0;
    }

    public function getTranslation()
    {
        return "admin.devices.os.iOS";
    }

    /**
     * @param Device $device
     *
     * @return DeviceInfo
     */
    public function getDeviceInfo(Device $device)
    {
        return new IosDeviceInfo($device->getDeviceInformation() ?: array());
    }

    /**
     * Return whether this device is able to show device info
     *
     * @param Device $device
     *
     * @return boolean
     */
    public function hasDeviceInfo(Device $device)
    {
        return null !== $device->getMdmCert();
    }

    /**
     *
     * @param string $name
     * @param Device $device
     * @return boolean true if the device supports the specified operation,
     *     false otherwise.
     */
    public function hasSupport($name, Device $device = null)
    {
        $device; // unused
        switch ($name) {
            case "clearPasscode":
                return true;
            case "apps":
                return true;
            case "deviceLock":
                return true;
            case "deviceLockMessage":
                return true;
            case "mdm":
                return true;
            case "push":
                return true;
        }

        return false;
    }

    /**
     * @param \Topalis\Device\Entity\Device $device
     *
     * @return boolean true if the device is manged with MDM.
     */
    public function isManaged(Device $device)
    {
        return null !== $device->getMdmCert();
    }

    public function isRolloutFailed(Device $device)
    {
        return $device->isDisabled() && null === $device->getMdmCert();
    }

    public function getPushTopic()
    {
        return $this->certificateManager->getMdmTopic();
    }

    public function parseMdmToken(Device $device, $token)
    {
        $device; // unused
        return $token === null ? null : bin2hex($token);
    }

    public function getDeviceProfile(Device $device)
    {
        $group = $device->getConfigGroup();
        if (!isset($this->deviceProfiles[$group->getId()])) {
            $this->deviceProfiles[$group->getId()] = new ConfigurationProfile($group->getProfile());
        }

        return $this->deviceProfiles[$group->getId()];
    }

    public function getAppStateEntityManagerId()
    {
        return "app.entity.manager.ios_app_state";
    }

}
