<?php
namespace Topalis\Device\Type;

use Topalis\Device\Entity\Device;
use Topalis\Device\Type\Info\WinPhoneDeviceInfo;

/**
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class WinPhoneDeviceType extends AbstractDeviceType
{
    public function getName()
    {
        return "winphone";
    }

    public function getId()
    {
        return 3;
    }

    public function getTranslation()
    {
        return "admin.devices.os.winphone";
    }

    /**
     * @param Device $device
     *
     * @return DeviceInfo
     */
    public function getDeviceInfo(Device $device)
    {
        return new WinPhoneDeviceInfo($device->getDeviceinformation());
    }

    /**
     * Return whether this device is able to show device info
     *
     * @param Device $device
     *
     * @return boolean
     */
    public function hasDeviceInfo(Device $device)
    {
        return null !== $device->getOmaAuthNonce();
    }

    /**
     *
     * @param string $name
     * @param Device $device
     * @return boolean true if the device supports the specified operation,
     *     false otherwise.
     */
    public function hasSupport($name, Device $device = null)
    {
        switch ($name) {
            case "deviceLock":
                if (null !== $device && version_compare($device->getVersion(), "8.1", ">=")) {
                    return true;
                }
                break;
            case "mdm":
                return true;
        }

        return false;
    }

    /**
     * @param \Topalis\Device\Entity\Device $device
     *
     * @return boolean true if the device is manged with MDM.
     */
    public function isManaged(Device $device)
    {
        return null !== $device->getMdmCert();
    }
}
