<?php
namespace Topalis\Form\Extension\EventListener;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Topalis\Form\Validator\Constraint\AndroidPasscode;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class DefaultPasscodeListener implements EventSubscriberInterface
{
    /**
     * @var array
     */
    private $passcodeConfig;

    public function __construct(array $passcodeConfig)
    {
        $this->passcodeConfig = $passcodeConfig;
    }

    public static function getSubscribedEvents()
    {
        return array(
            FormEvents::PRE_SET_DATA => "preSetData"
        );
    }

    public function preSetData(FormEvent $event)
    {
        $data = $event->getData();

        if (null !== $data) {
            // only change empty data
            return;
        }

        $event->setData($this->generatePassword());
    }

    private function generatePassword()
    {
        if ($this->passcodeConfig['quality'] <= AndroidPasscode::PASSWORD_QUALITY_NUMERIC) {
            return str_repeat("1", max(4, $this->passcodeConfig['minLength']));
        }

        if ($this->passcodeConfig['quality'] <= AndroidPasscode::PASSWORD_QUALITY_ALPHANUMERIC) {
            return "auralis1" . str_repeat("1", max($this->passcodeConfig['minLength'] - 8, 0));
        }

        // complex
        $code = "";
        $code .= str_repeat("A", max(1, $this->passcodeConfig['minLetters'] + $this->passcodeConfig['minUppercase']));
        $code .= str_repeat("b", max(1, $this->passcodeConfig['minLowercase']));
        $code .= str_repeat("1", max(1, $this->passcodeConfig['minNonLetter'] + $this->passcodeConfig['minNumeric']));
        $code .= str_repeat("-", max(1, $this->passcodeConfig['minSymbols']));

        while (strlen($code) < $this->passcodeConfig['minLength']) {
            $code .= $code;
        }

        return $code;
    }
}
