<?php
namespace Topalis\Form\Extension\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;

/**
 * The PasswordSubscriber remembers a saved password and sets it again if an
 * empty password was submitted.
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class PasswordSubscriber implements EventSubscriberInterface
{
    protected $password;

    public static function getSubscribedEvents()
    {
        return array(
            FormEvents::PRE_SET_DATA => "preSetData",
            FormEvents::PRE_SUBMIT   => "preSubmit",
        );
    }

    public function preSetData(FormEvent $event)
    {
        $data = $event->getData();
        if (!empty($data)) {
            $this->password = $data;
            $event->getForm()->usePreviousValue = true;
        } else {
            $event->getForm()->usePreviousValue = false;
        }
    }

    public function preSubmit(FormEvent $event)
    {
        $data = $event->getData();
        if (empty($data)) {
            $event->setData($this->password);
        } else {
            // password is set so we won't use the stored password again if the
            // form is loaded again (e.g. because of failed validation)
            $event->getForm()->usePreviousValue = false;
        }
    }

}
