<?php
namespace Topalis\Form\Upload;

use Oneup\UploaderBundle\Uploader\File\FileInterface;
use Oneup\UploaderBundle\Uploader\Storage\StorageInterface;
use Symfony\Component\HttpFoundation\File\File;
use Symfony\Component\HttpFoundation\File\UploadedFile;

/**
 * Replace uploaded files with instances of DecoratedFiles to preseve original filename
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class StorageDecorator implements StorageInterface
{

    /**
     * @var StorageInterface
     */
    private $storage;

    /**
     * @param StorageInterface $storage
     */
    public function __construct(StorageInterface $storage)
    {
        $this->storage = $storage;
    }

    public function upload(FileInterface $file, $name, $path = null)
    {
        if (!$file instanceof UploadedFile) {
            return $this->storage->upload($file, $name, $path);
        }
        $originalName = $file->getClientOriginalName();

        return new DecoratedFile(
            $this->storage->upload($file, $name, $path),
            $originalName
        );
    }
}
