<?php
namespace Topalis\Form\Validator\Constraint;

use Symfony\Component\Validator\Constraint;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class AndroidPasscode extends Constraint
{
    /**
     * the policy has no requirements
     * for the password.  Note that quality constants are ordered so that higher
     * values are more restrictive.
     * @var int
     */
    const PASSWORD_QUALITY_UNSPECIFIED = 0;

    /**
     * the policy allows for low-security biometric
     * recognition technology.  This implies technologies that can recognize the identity of
     * an individual to about a 3 digit PIN (false detection is less than 1 in 1,000).
     * Note that quality constants are ordered so that higher values are more restrictive.
     * @var int
     */
    const PASSWORD_QUALITY_BIOMETRIC_WEAK = 0x8000;

    /**
     * the policy requires some kind
     * of password, but doesn't care what it is.  Note that quality constants
     * are ordered so that higher values are more restrictive.
     * @var int
     */
    const PASSWORD_QUALITY_SOMETHING = 0x10000;

    /**
     * the user must have entered a
     * password containing at least numeric characters.  Note that quality
     * constants are ordered so that higher values are more restrictive.
     * @var int
     */
    const PASSWORD_QUALITY_NUMERIC = 0x20000;

    /**
     * the user must have entered a
     * password containing at least alphabetic (or other symbol) characters.
     * Note that quality constants are ordered so that higher values are more
     * restrictive.
     * @var int
     */
    const PASSWORD_QUALITY_ALPHABETIC = 0x40000;

    /**
     * the user must have entered a
     * password containing at least <em>both></em> numeric <em>and</em>
     * alphabetic (or other symbol) characters.  Note that quality constants are
     * ordered so that higher values are more restrictive.
     * @var int
     */
    const PASSWORD_QUALITY_ALPHANUMERIC = 0x50000;

    /**
     * the user must have entered a
     * password containing at least a letter, a numerical digit and a special
     * symbol, by default. With this password quality, passwords can be
     * restricted to contain various sets of characters, like at least an
     * uppercase letter, etc. These are specified using various methods,
     * like {@link #setPasswordMinimumLowerCase(ComponentName, int)}. Note
     * that quality constants are ordered so that higher values are more
     * restrictive.
     * @var int
     */
    const PASSWORD_QUALITY_COMPLEX = 0x60000;

    public $lenghtMessage = "passcode.minLength";
    public $letterMessage = "passcode.minLetters";
    public $lowercaseMessage = "passcode.minLowercase";
    public $uppercaseMessage = "passcode.minUppercase";
    public $numericMessage = "passcode.minNumeric";
    public $nonLetterMessage = "passcode.minNonLetter";
    public $symbolsMessage = "passcode.minSymbols";

    public $quality;
    public $minLength = 0;
    public $minLetters = 0;
    public $minLowercase = 0;
    public $minUppercase = 0;
    public $minNonLetter = 0;
    public $minNumeric = 0;
    public $minSymbols = 0;
}
