<?php
namespace Topalis\Form\Validator\Constraint;

use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;
use Symfony\Component\Validator\Exception\UnexpectedTypeException;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class AndroidPasscodeValidator extends ConstraintValidator
{
    public function validate($value, Constraint $constraint)
    {
        /** @var $constraint AndroidPasscode */
        if (null === $value || '' === $value) {
            return;
        }

        if (!is_scalar($value) && !(is_object($value) && method_exists($value, '__toString'))) {
            throw new UnexpectedTypeException($value, 'string');
        }

        if ($constraint->quality <= AndroidPasscode::PASSWORD_QUALITY_NUMERIC) {
            return;
        }

        if ($constraint->minLength > 0 && strlen($value) < $constraint->minLength) {
            $this->context->addViolation($constraint->lenghtMessage,
                array("%length%" => $constraint->minLength), $value);
        }

        if ($constraint->quality < AndroidPasscode::PASSWORD_QUALITY_COMPLEX) {
            return;
        }

        if ($constraint->minLetters > 0
            && $this->countOccurences("=[[:alpha:]]=i", $value) < $constraint->minLetters) {
            $this->context->addViolation($constraint->letterMessage,
                array("%count%" => $constraint->minLetters), $value);
        }

        if ($constraint->minLowercase > 0
            && $this->countOccurences("=[[:lower:]]=", $value) < $constraint->minLowercase) {
            $this->context->addViolation($constraint->lowercaseMessage,
                array("%count%" => $constraint->minLowercase), $value);
        }

        if ($constraint->minUppercase > 0
            && $this->countOccurences("=[[:upper:]]=", $value) < $constraint->minUppercase) {
            $this->context->addViolation($constraint->uppercaseMessage,
                array("%count%" => $constraint->minUppercase), $value);
        }

        if ($constraint->minNumeric > 0
            && $this->countOccurences("=[[:digit:]]=", $value) < $constraint->minNumeric) {
            $this->context->addViolation($constraint->numericMessage,
                array("%count%" => $constraint->minNumeric), $value);
        }

        if ($constraint->minNonLetter > 0
            && $this->countOccurences("=[[:^alpha:]]=i", $value) < $constraint->minNonLetter) {
            $this->context->addViolation($constraint->nonLetterMessage,
                array("%count%" => $constraint->minNonLetter), $value);
        }

        if ($constraint->minSymbols > 0
            && $this->countOccurences("=[[:^alnum:]]=i", $value) < $constraint->minSymbols) {
            $this->context->addViolation($constraint->symbolsMessage,
                array("%count%" => $constraint->minSymbols), $value);
        }
    }

    private function countOccurences($regex, $string)
    {
        if (preg_match_all($regex, $string, $results)) {
            return count($results[0]);
        }

        return 0;
    }
}
