<?php
namespace Topalis\Generator\Command;

use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Topalis\Profile\Annotation\Payload\Key;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class GeneratePayloadFormCommand extends ContainerAwareCommand
{
    protected function configure()
    {
        $this
            ->setName("generate:payload:form")
            ->setDescription("Adds payload methods from payload")
            ->addArgument("class", InputArgument::REQUIRED, "class name for form type")
        ;
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $class = $input->getArgument("class");
        $reflection = new \ReflectionClass($class);
        $instance = new $class();
        $optionResolver = new OptionsResolver();
        $reflection->getMethod("setDefaultOptions")->invoke($instance, $optionResolver);
        $options = $optionResolver->resolve(array());
        $dataClass = new \ReflectionClass($options['data_class']);

        $reader = $this->getContainer()->get("annotation_reader");
        $annotations = $reader->getClassAnnotations($dataClass);

        $keys = array();
        foreach ($annotations as $annotation) {
            if (!$annotation instanceof Key) {
                continue;
            }
            $name = $annotation->getName();
            $type = $annotation->getType();
            $formType = "text";
            switch ($type) {
                case "boolean":
                    $formType = "checkbox";
                    break;
            }

            $keys[] = lcfirst($name);
            $code = array(
                "->add(\"".lcfirst($name)."\", \"".$formType."\", array(",
                "   \"label\" => \$prefix . \"".lcfirst($name)."\",",
                "))",
            );
            echo implode("\n", $code)."\n";
        }

        $output->writeln("<info>translations</info>");
        foreach ($keys as $key) {
            echo $key.":\n";
        }
    }
}
