<?php
namespace Topalis\Kernel;

use Symfony\Component\DependencyInjection\ContainerAware;

abstract class AbstractAuralisService extends ContainerAware implements AuralisServiceInterface
{
    /**
     * @return string
     */
    public function getAuralisVersion()
    {
        return VERSION;
    }

    /**
     * @return \Topalis\Configuration\AuralisConfig
     */
    public function getConfig()
    {
        return $this->container->get("config.auralis");
    }

    /**
     * @return \Topalis\Database\MySqlDb
     */
    public function getDB()
    {
        return $this->container->get("db");
    }

    /**
     * @return \Symfony\Bridge\Doctrine\RegistryInterface
     */
    public function getDoctrine()
    {
        return $this->container->get("doctrine");
    }

    /**
     * @return \Topalis\License\License
     */
    public function &getLicense()
    {
        return $this->getLicenseManager()->getLicense();
    }

    /**
     * @return \Topalis\License\LicenseManager
     */
    public function getLicenseManager()
    {
        return $this->container->get("license.manager");
    }

    /**
     * @return \Psr\Log\LoggerInterface
     */
    public function getLogger()
    {
        return $this->container->get("logger");
    }

    /**
     * @return \Topalis\Kernel\TimeProviderInterface
     */
    public function getTimeProvider()
    {
        return $this->container->get("kernel.time_provider");
    }

    /**
     * @return \Symfony\Component\Translation\TranslatorInterface
     */
    public function getTranslator()
    {
        return $this->container->get("translator");
    }

    /**
     * Convenience function to call getTranslator()->trans().
     *
     * @param string $id The message id.
     * @param array $parameters An array of parameters for the message.
     * @param string $domain The domain for the message.
     * @param string $locale The locale.
     * @return string The translated string.
     */
    protected function tr($id, array $parameters = array(), $domain = 'messages', $locale = null)
    {
        return $this->getTranslator()->trans($id, $parameters, $domain, $locale);
    }
}
