<?php
namespace Topalis\Kernel\Command;

use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Topalis\Kernel\Exception\UnexpectedTypeException;
use Topalis\Kernel\Job\JobRunnerInterface;

/**
 * Command to run a JobRunner.
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 *
 * @see \Topalis\Kernel\Job\JobRunnerInterface
 */
class WorkerCommand extends LogrotateAwareCommand
{
    protected function configure()
    {
        parent::configure();
        $this
            ->setName("worker:run")
            ->setDescription("Run a pheanstalk worker")
            ->addArgument("runner", InputArgument::REQUIRED, "service id of the runner")
        ;
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $output; // unused

        $runner = $this->getContainer()->get($input->getArgument("runner"));
        if (!$runner instanceof JobRunnerInterface) {
            throw new UnexpectedTypeException($runner, "Topalis\Kernel\Job\JobRunnerInterface");
        }

        $config = $this->getContainer()->get("config.auralis");
        $config->setCacheEnabled(false);

        $mailer = $this->getContainer()->get("mailer");
        $mailer->setAlwaysLoadSettings(true);

        $runner->run();
    }
}
