<?php
namespace Topalis\Kernel\Controller;

use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Security\Core\SecurityContext;
use Topalis\Kernel\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;

/**
 *
 *
 * @author Florian Pfitzer <florian.pfitzer@to.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 *
 * @Route("/admin", service="kernel.controller")
 */
class KernelController extends Controller
{
    /**
     * @Route("/about", name="admin_about", methods="GET")
     * @Template()
     *
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function aboutAction()
    {
        return array();
    }

    /**
     * @Route("/status", name="admin_status", options={"expose" = true})
     *
     * @return \Symfony\Component\HttpFoundation\Response Always returns "1".
     */
    public function statusAction()
    {
        return new Response("1");
    }

    /**
     * @Template()
     * @Route("/login", name="admin_login")
     *
     * @return array
     */
    public function loginAction()
    {
        $lastUsername = $this->getRequest()->getSession()->get(SecurityContext::LAST_USERNAME);
        if ($this->getRequest()->attributes->has(SecurityContext::AUTHENTICATION_ERROR)) {
            $error = $this->getRequest()->attributes->get(SecurityContext::AUTHENTICATION_ERROR);
        } else {
            $error = $this->getRequest()->getSession()->get(SecurityContext::AUTHENTICATION_ERROR);
        }

        if ($error) {
            $error = "Bad credentials";
            $this->getRequest()->getSession()->clear();
        }
        $csrfToken = $this->container->get("form.csrf_provider")->generateCsrfToken('authenticate');

        return array(
            'lastUsername' => $lastUsername,
            'error'         => $error,
            'csrf_token'    => $csrfToken,
        );
    }

    /**
     * @Route("/login_check", name="admin_security_check")
     */
    public function securityCheckAction()
    {
        // The security layer will intercept this request
    }

    /**
     * @Route("/logout", name="admin_logout")
     */
    public function logoutAction()
    {
        // The security layer will intercept this request
    }

    /**
     * @Route("/reload_status", name="admin_reload_status")
     *
     * This action is used to detect if an Apache HTTPD reload has been timed
     * out.
     *
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function reloadStatusAction()
    {
        $content = $this->getRequest()->server->get("RELOAD_COOKIE");
        $headers = array("Content-Type: text/plain");
        return new Response($content, 200, $headers);
    }

    /**
     * @Route("/switch_language/{language}?from={from}", name="admin_switch_language")
     *
     * @param string $language
     * @param string $from
     */
    public function switchLanguage($language, $from)
    {
        $this->container->get("kernel.listener.locale")->updateLocaleFromRequest($this->getRequest(), $language);

        $from = urldecode($from);
        return $this->redirect($from);
    }
}
