<?php
namespace Topalis\Kernel\DependencyInjection\Compiler;

use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\DefinitionDecorator;
use Symfony\Component\DependencyInjection\Reference;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class WorkerPass implements CompilerPassInterface
{
    public function process(ContainerBuilder $container)
    {
        foreach ($container->findTaggedServiceIds("worker") as $serviceId => $tags) {
            $tag = $tags[0];
            if (!isset($tag['queue'])) {
                throw new \RuntimeException("no queue defiend on worker tag at service " . $serviceId);
            }
            $runnerId = isset($tag['runner']) ? $tag['runner'] : $serviceId . ".runner";
            if (!$container->hasDefinition($runnerId)) {
                $runner = new DefinitionDecorator("kernel.job.runner");
                $runner
                    ->replaceArgument(2, new Reference($tag['queue']))
                    ->replaceArgument(3, new Reference($serviceId))
                ;
                $container->setDefinition($runnerId, $runner);
            }
        }
    }
}
