<?php
namespace Topalis\Kernel\EventListener;

use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Symfony\Component\HttpKernel\HttpKernel;
use Symfony\Component\Routing\Exception\MethodNotAllowedException;
use Symfony\Component\Routing\Exception\ResourceNotFoundException;
use Topalis\Util\StringUtil;

/**
 * Set route data in session for redirects to previous page.
 * Ensure that _route is set in the request to ensure we can determine the
 * active MenuItem.
 *
 * @see http://www.fractalizer.ru/frpost_658/symfony2-how-redirect-user-to-a-previous-page-correctly/
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class RouteListener
{
    /**
     * @var \Symfony\Component\Routing\RouterInterface
     */
    private $router;

    public function __construct(\Symfony\Component\Routing\RouterInterface $router)
    {
        $this->router = $router;
    }

    public function onKernelRequest(GetResponseEvent $event)
    {
        $request = $event->getRequest();
        $routeName = $request->get("_route");

        if (!$routeName) {
            try {
                $routeParams = $this->router->match($request->getPathInfo());
            } catch (MethodNotAllowedException $e) {
                return;
            } catch (ResourceNotFoundException $e) {
                return;
            }
            $routeName = $routeParams['_route'];
            // required to determine the active MenuItem on sub requests
            $request->attributes->set("_route", $routeName);
        }

        if ($event->getRequestType() !== HttpKernel::MASTER_REQUEST) {
            return;
        }

        $format = $request->getRequestFormat();
        if ($routeName[0] == '_' || StringUtil::startsWith($routeName, "fos_") || $routeName == "admin_login"
            || $format == "json") {
            return;
        }

        try {
            $routeParams = $this->router->match($request->getPathInfo());
        } catch (MethodNotAllowedException $e) {
            return;
        } catch (ResourceNotFoundException $e) {
            return;
        }
        unset($routeParams['_route']);
        $routeData = array(
            "name" => $routeName,
            "params" => $routeParams
        );

        // Skipping duplicates
        $session = $request->getSession();
        $thisRoute = $session->get("thisRoute");
        if ($thisRoute == $routeData && $session->has("lastRoute")) {
            return;
        }

        if ($thisRoute !== null) {
            $session->set("lastRoute", $thisRoute);
        }
        $session->set("thisRoute", $routeData);
    }
}
