<?php
namespace Topalis\Kernel\Http;

use Buzz\Browser as BaseBrowser;
use Buzz\Message\MessageInterface;
use Buzz\Message\RequestInterface;
use Topalis\Configuration\AuralisConfig;
use Topalis\Configuration\Client\AuralisCurl;
use Topalis\Kernel\Exception\Http\RequestFailedException;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class Browser extends BaseBrowser
{
    public function __construct(AuralisConfig $config)
    {
        parent::__construct(new AuralisCurl($config), null);
    }

    /**
     * @param RequestInterface $request
     * @param MessageInterface $response
     *
     * @return MessageInterface
     * @throws \Buzz\Exception\InvalidArgumentException If the URL is invalid.
     * @throws \Buzz\Exception\ClientException If something goes wrong.
     * @throws \Topalis\Kernel\Exception\Http\RequestFailedException If the status code is not between 200 and 299.
     */
    public function send(RequestInterface $request, MessageInterface $response = null)
    {
        if (null === $response) {
            $response = new Response();
            $response->setRequest($request);
        }

        parent::send($request, $response);

        $status = $response->getStatusCode();
        if ($status < 200 || $status > 299) {
            throw new RequestFailedException($response);
        }

        return $response;
    }
}
