<?php
namespace Topalis\Kernel\Job;

use Doctrine\ORM\EntityManagerInterface;
use Psr\Log\LoggerAwareInterface;
use Psr\Log\LoggerInterface;
use Topalis\Database\Util\DatabaseUtils;

/**
 * JobRunner
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class JobRunner extends AbstractJobRunner
{
    /**
     * @var EntityManagerInterface
     */
    protected $entityManager;

    /**
     * @var WorkerInterface
     */
    protected $worker;

    public function __construct(
        EntityManagerInterface $entityManager,
        LoggerInterface $logger,
        QueueInterface $queue,
        WorkerInterface $worker
    )
    {
        parent::__construct($entityManager->getConnection(), $logger, $queue);

        $this->entityManager = $entityManager;
        $this->worker = $worker;
        if ($worker instanceof LoggerAwareInterface) {
            $worker->setLogger($logger);
        }
    }

    protected function handle(\Pheanstalk_Job $job)
    {
        $data = json_decode($job->getData(), true);
        $this->worker->handle($data);
    }

    protected function cleanup()
    {
        $this->worker->cleanup();
        $this->entityManager->flush();
        $this->entityManager->clear();
    }
}
