<?php
namespace Topalis\Kernel\Job;

/**
 * Interface for a Pheanstalk queue.
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
interface QueueInterface
{
    /**
     * @param \Pheanstalk_Job $job The job to delete from the queue.
     *
     * @return boolean true if the job has been deleted, or false if the job
     *     does not exist in the queue.
     *
     * @throws \Topalis\Compliance\Job\Exception\JobReservedException If the job
     *     could not be deleted because it is reserved by another client.
     *
     * @see \Pheanstalk_PheanstalkInterface::delete
     */
    public function delete(\Pheanstalk_Job $job);

    /**
     * @param int $jobId The id of the job to get.
     *
     * @return \Pheanstalk_Job|null The job with the specified id, or null if no
     *     such job exists.
     *
     * @see \Pheanstalk_PheanstalkInterface::peek
     */
    public function peek($jobId);

    /**
     * @param \Pheanstalk_Job $job The job to release.
     * @param int $priority From 0 (most urgent) to 0xFFFFFFFF (least urgent)
     * @param int $delay Seconds to wait before job becomes ready.
     *
     * @see \Pheanstalk_PheanstalkInterface::release
     */
    public function release(\Pheanstalk_Job $job,
        $priority = \Pheanstalk_PheanstalkInterface::DEFAULT_PRIORITY, $delay = 0);

    /**
     * Reserves/locks a ready job and returns it.
     *
     * @param int|NULL $timeout The number of seconds to block on the reserve
     *     request until a job becomes available. If null the reserve request
     *     will be blocked until a job is reserved.
     *
     * @return \Pheanstalk_Job The reserved job.
     *
     * @see \Pheanstalk_PheanstalkInterface::reserve
     */
    public function reserve($timeout = null);

    /**
     * Allows a worker to request more time to work on a job. Postpones the auto
     * release of a reserved job until TTR seconds from when the command is
     * issued.
     *
     * @param \Pheanstalk_Job $job The job to touch.
     *
     * @see \Pheanstalk_PheanstalkInterface::touch
     */
    public function touch(\Pheanstalk_Job $job);
}
