<?php
namespace Topalis\Kernel\Security;

use Symfony\Bundle\SecurityBundle\DependencyInjection\Security\Factory\SecurityFactoryInterface;
use Symfony\Component\Config\Definition\Builder\NodeBuilder;
use Symfony\Component\Config\Definition\Builder\NodeDefinition;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\DefinitionDecorator;

/**
 * Enabled the initial admin event listener, for setup login
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class AdminSecurityFactory implements SecurityFactoryInterface
{
    public function create(ContainerBuilder $container, $id, $config, $userProvider, $defaultEntryPoint)
    {
        $userProvider; // unused

        $key = $config['key'];

        $provider = "security.authentication.provider.anonymous." . $id;
        $container
            ->setDefinition($provider, new DefinitionDecorator("security.authentication.provider.anonymous"))
            ->replaceArgument(0, $key);

        $listenerId = "security.authentication.listener.anonymous." . $id;
        $container
            ->setDefinition($listenerId, new DefinitionDecorator("kernel.security.listener.initial_admin"))
            ->replaceArgument(2, $key);

        return array($provider, $listenerId, $defaultEntryPoint);
    }

    public function getPosition()
    {
        return "http";
    }

    public function getKey()
    {
        return "initial_admin";
    }

    public function addConfiguration(NodeDefinition $node)
    {
        /** @var NodeBuilder $builder */
        $builder = $node->children();

        $builder
            ->scalarNode('key')->defaultValue(uniqid())->end()
        ;
    }
}
