<?php
namespace Topalis\Kernel\Security;

use Psr\Log\LoggerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Symfony\Component\Security\Core\Authentication\Token\AnonymousToken;
use Symfony\Component\Security\Core\SecurityContextInterface;
use Symfony\Component\Security\Http\Firewall\ListenerInterface;
use Topalis\Admin\Entity\Admin;

/**
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class InitialAdminListener implements ListenerInterface
{

    private $context;

    private $key;

    private $logger;

    /**
     * @var \Symfony\Component\Routing\RouterInterface
     */
    private $router;

    /**
     * @var \Topalis\Database\MySqlDb
     */
    private $db;

    public function __construct(
        \Topalis\Database\MySqlDb $db,
        SecurityContextInterface $context,
        $key,
        LoggerInterface $logger = null)
    {
        $this->db = $db;
        $this->context = $context;
        $this->key = $key;
        $this->logger = $logger;
    }

    /**
     * @return \Symfony\Component\Routing\RouterInterface
     */
    public function getRouter()
    {
        return $this->router;
    }

    /**
     * @param \Symfony\Component\Routing\RouterInterface $router
     */
    public function setRouter(\Symfony\Component\Routing\RouterInterface $router)
    {
        $this->router = $router;
    }

    /**
     * This interface must be implemented by firewall listeners.
     *
     * @param GetResponseEvent $event
     */
    public function handle(GetResponseEvent $event)
    {
        if (null !== $this->context->getToken()) {
            return;
        }

        if ($this->db->exists("admins", array("level" => Admin::LEVEL_ADMIN, "id" => array("!=", 0)))) {
            return;
        }

        $this->context->setToken(new AnonymousToken($this->key, "anon.", array("ROLE_ADMIN")));

        if (null !== $this->logger) {
            $this->logger->info("Populated SecurityContext with an anonymous Token");
        }

        $whitelistedRoutes = array(
            "admin_setup_network",
            "admin_setup_restore",
            "admin_switch_language",
        );

        $route = $event->getRequest()->attributes->get("_route");
        if (!in_array($route, $whitelistedRoutes)) {
            $event->setResponse(new RedirectResponse($this->getRouter()->generate("admin_setup_restore")));
        }
    }
}
