<?php
namespace Topalis\Kernel;

use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\HttpKernel\Bundle\Bundle;
use Topalis\Kernel\DependencyInjection\Compiler\WorkerPass;
use Topalis\Kernel\Security\AdminSecurityFactory;
use Topalis\Kernel\Security\DeviceSecurityFactory;

/**
 *
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class TopalisKernelBundle extends Bundle
{
    public function boot()
    {
        $logger = $this->container->get("logger");
        ErrorHandler::setLogger($logger);
        if (!$this->container->getParameter("kernel.debug")
            || "prod" == $this->container->getParameter("kernel.environment")) {
            // don't log deprecation warnings when not in debug mode or in production
            ErrorHandler::setLogger(null, "deprecation");
        }
    }

    public function build(ContainerBuilder $container)
    {
        parent::build($container);

        $container->addCompilerPass(new WorkerPass());

        $extension = $container->getExtension('security');
        $extension->addSecurityListenerFactory(new DeviceSecurityFactory());
        $extension->addSecurityListenerFactory(new AdminSecurityFactory());
    }

}
