<?php
namespace Topalis\Kernel\Twig\Extension;

use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * @author Florian Pfitzer <florian.pfitzer@to.com>
 */
class AuralisExtension extends \Twig_Extension
{
    /**
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    private $container;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    public function getFilters()
    {
        return array(
            "floor"   => new \Twig_SimpleFilter("floor", "floor"),
            "string"  => new \Twig_SimpleFilter("string", "Topalis\Util\StringUtil::toString"),
            "ucfirst" => new \Twig_SimpleFilter("ucfirst", "ucfirst"),
        );
    }

    public function getGlobals()
    {
        $mailFooter = array(
            "organization: " . $this->getCertificateManager()->getCAOrg(),
            "auralis version: " . $this->getAuralisVersion(),
            "auralis ID: ". $this->getLicense()->getAuralisId(),
            "auralis fully qualified domain name: ". $this->getConfig()->getHostname()
        );

        return array(
            "version" => $this->getAuralisVersion(),
            "buildDate" => BUILDDATE,
            "mailFooter" => implode("\n", $mailFooter),
        );
    }

    /**
     * Returns the name of the extension.
     *
     * @return string The extension name
     */
    public function getName()
    {
        return "auralis";
    }

    /**
     * @return string
     */
    private function getAuralisVersion()
    {
        return VERSION;
    }

    /**
     * @return \Topalis\Certificate\CertificateManager
     */
    private function getCertificateManager()
    {
        return $this->container->get("certificate.manager");
    }

    /**
     * @return \Topalis\Configuration\AuralisConfig
     */
    private function getConfig()
    {
        return $this->container->get("config.auralis");
    }

    /**
     * @return \Topalis\License\License
     */
    private function &getLicense()
    {
        return $this->getLicenseManager()->getLicense();
    }

    /**
     * @return \Topalis\License\LicenseManager
     */
    private function getLicenseManager()
    {
        return $this->container->get("license.manager");
    }
}
