<?php
namespace Topalis\License\Command;

use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand;
use Symfony\Component\Console\Input\InputArgument;

class LicenseStatusCommand extends ContainerAwareCommand
{
    /**
     * @return \Topalis\License\License
     */
    private function &getLicense()
    {
        return $this->getLicenseManager()->getLicense();
    }

    /**
     * @return \Topalis\License\LicenseManager
     */
    private function getLicenseManager()
    {
        return $this->getContainer()->get("license.manager");
    }

    /**
     * @return \Topalis\User\Entity\UserEntityManager
     */
    private function getUserEntityManager()
    {
        return $this->getContainer()->get("user.entity.manager.user");
    }

    protected function configure()
    {
        $argDesc = "What do you want to now? ";
        $argDesc .= "[allowed (number of allowed users), used (number of used users), ";
        $argDesc .= "validto (expiration date as UNIX timestamp)]";
        $this
        ->setName("license:status")
        ->setDescription("Prints license status information.")
        ->setHelp("Prints license status information.")
        ->addArgument("type", InputArgument::REQUIRED, $argDesc)
        ;
    }

    protected function execute(\Symfony\Component\Console\Input\InputInterface $input,
        \Symfony\Component\Console\Output\OutputInterface $output)
    {
        $type = $input->getArgument("type");

        switch ($type) {
            case "allowed":
                $output->writeln($this->getLicense()->getAllowedUsers());
                break;
            case "used":
                $output->writeln($this->getUserEntityManager()->count());
                break;
            case "validto":
                $output->writeln($this->getLicense()->getValidTo());
                break;
            default:
                $output->writeln("Unknown type '" . $type . "'");
                break;
        }
    }
}
