<?php
namespace Topalis\Log;

use Topalis\Util\File;
use Topalis\Util\Process;

/**
 * A log file
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class Log extends File implements LogInterface
{
    protected $name;
    protected $content;
    protected $autoRefresh = true;

    /**
     * @param string $fileName Absolute path to the log
     * @param string $name Nicer name of the log
     * @param boolean $autoRefresh Whether to update the log automactically
     */
    public function __construct($fileName, $name, $autoRefresh = true)
    {
        parent::__construct($fileName);

        $this->name = $name;
        $this->autoRefresh = $autoRefresh;
    }

    public function getName()
    {
        return $this->name;
    }

    public function setName($name)
    {
        $this->name = $name;

        return $this;
    }

    public function getId()
    {
        return md5($this->getRealPath());
    }

    public function getContent()
    {
        if (null !== $this->content) {
            return $this->content;
        }

        return $this->content = file_get_contents($this->getRealPath());
    }

    public function getContentFromLine($line)
    {
        $output = "";
        $cmd = sprintf("tail -n +%s '%s'", $line, $this->getRealPath());
        Process::exec($cmd, $output);

        return $output;
    }

    public function getLines()
    {
        $cmd = sprintf("wc '%s'", $this->getRealPath());

        $output = "";
        Process::exec($cmd, $output);
        $output = explode(" ", trim($output));

        return $output[0];
    }

    public function isAutoRefresh()
    {
        return $this->autoRefresh;
    }
}
