<?php
namespace Topalis\MDM\Device\Info;

use Topalis\Device\Info\DeviceInfoSectionInterface;
use Topalis\Device\Entity\Device;
use Symfony\Component\Templating\EngineInterface;
use Topalis\Device\MDM\MdmFacadeInterface;

/**
 * MdmDeviceInfoSection
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class MdmDeviceInfoSection implements DeviceInfoSectionInterface
{
    /**
     * @var \Topalis\Device\MDM\MdmFacadeInterface
     */
    private $mdmFacade;

    /**
     * @var \Symfony\Bundle\FrameworkBundle\Templating\EngineInterface
     */
    private $templating;

    public function __construct(MdmFacadeInterface $mdmFacade, EngineInterface $templating)
    {
        $this->mdmFacade = $mdmFacade;
        $this->templating = $templating;
    }

    public function getTabAttributes()
    {
        return array();
    }

    public function getKey()
    {
        return "mdm";
    }

    public function getTitle()
    {
        return "admin.mdm.titleShort";
    }

    public function isVisible(Device $device)
    {
        return $device->getType()->hasSupport("mdm", $device);
    }

    public function renderContent(Device $device)
    {
        /** @var MdmCommand[] $mdmCommands */
        $mdmCommands = $this->mdmFacade->getCommands($device, 0, array("id" => "DESC"));

        return $this->templating->render("TopalisMdmBundle:Device:info.html.twig", array(
            "device" => $device,
            "mdmCommands" => $mdmCommands,
        ));
    }
}
