<?php
namespace Topalis\MDM;

use CFPropertyList\CFPropertyList;

/**
 * Class representing an MDM request from the client.
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class MdmRequest
{
    private $payload;

    public static function getErrorDescription(array $error)
    {
        if (isset($error['USEnglishDescription'])) {
            return $error['USEnglishDescription'];
        }

        if (isset($error['LocalizedDescription'])) {
            return $error['LocalizedDescription'];
        }

        return "unknown";
    }

    /**
     * Constructor.
     *
     * @param string|CFPropertyList|array $content
     */
    public function __construct($content)
    {
        if (is_array($content)) {
            $this->payload = $content;
        } else {
            if (is_string($content)) {
                $plist = new CFPropertyList();
                if (strlen($content) > 0) {
                    $plist->parse($content);
                }
            } else {
                $plist = $content;
            }
            $this->payload = $plist->toArray();
        }
    }

    /**
     * @return array The payload.
     */
    public function getPayload()
    {
        return $this->payload;
    }

    /**
     * @param string $key
     * @return array|string|NULL The payload value with the specified key, or
     *     null if no such value is defined.
     */
    public function get($key)
    {
        return isset($this->payload[$key]) ? $this->payload[$key] : null;
    }

    /**
     * @return string The UDID.
     */
    public function getUdid()
    {
        return $this->get("UDID");
    }

    /**
     * @return string The command UUID.
     */
    public function getCommandUuid()
    {
        return (string) $this->get("CommandUUID");
    }

    /**
     * @return string The status.
     */
    public function getStatus()
    {
        return (string) $this->get("Status");
    }

    /**
     * @return array|null The error chain.
     */
    public function getErrorChain()
    {
         return $this->get("ErrorChain");
    }

    /**
     * @return string|null The message type if defined, null otherwise.
     */
    public function getMessageType()
    {
        return $this->get("MessageType");
    }

    /**
     * @return boolean true if key 'MessageType' is defined, false otherwise.
     */
    public function isMessage()
    {
        return $this->getMessageType() !== null;
    }

    /**
     * @return boolean true if the request is empty, false otherwise.
     */
    public function isEmpty()
    {
        return empty($this->payload);
    }
}
