<?php
namespace Topalis\Mail;

/**
 * A mailer creates and sends emails.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
interface MailerInterface
{
    /**
     * Like createMessage, but sets recipient to configured admins
     * @param string $subject
     *
     * @return \Swift_Message
     */
    public function createAdminMessage($subject);

    /**
     * @param string $subject Subject of the message
     *
     * @return \Swift_Message
     */
    public function createMessage($subject);

    /**
     * @return boolen true if the mailer is configured such that mails can be
     *     send.
     */
    public function isConfigured();

    /**
     * @param string $text
     *
     * @return string The specified text with a salutation and a footer.
     */
    public function prepareAdminText($text);

    /**
     * Sends message to configured admins with specified subject and text.
     *
     * @param string $subject The mail subject.
     * @param string $text The mail text.
     *
     * @return int The number of recipients who were accepted for delivery.
     */
    public function sendAdminMessage($subject, $text);

    /**
     * sends a message
     * @param \Swift_Message $message
     *
     * @return int The number of recipients who were accepted for delivery.
     */
    public function sendMessage(\Swift_Message $message);
}
