<?php
namespace Topalis\Profile;

use Topalis\Profile\Payload\AirPlayPayload;
use Topalis\Profile\Payload\AirPrintPayload;
use Topalis\Profile\Payload\ApnPayload;
use Topalis\Profile\Payload\PasscodePayload;
use Topalis\Profile\Payload\RestrictionsPayload;
use Topalis\Profile\Payload\WebContentFilterPayload;
use Topalis\Profile\Payload\WifiPayload;

// @codingStandardsIgnoreStart
/**
 * Class that represents a client profile of type "Configuration".
 * @see    https://developer.apple.com/library/ios/#featuredarticles/iPhoneConfigurationProfileRef/Introduction/Introduction.html
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
// @codingStandardsIgnoreEnd
class ConfigurationProfile extends AbstractProfile
{
    const TYPE = "Configuration";

    public function getPassCode()
    {
        return $this->getPayloads(PasscodePayload::TYPE);
    }

    public function setPassCode(array $payloads)
    {
        $this->clearAndSetPayloads(PasscodePayload::TYPE, $payloads);
    }

    public function getRestrictions()
    {
        return $this->getPayloads(RestrictionsPayload::TYPE);
    }

    public function setRestrictions(array $payloads)
    {
        $this->clearAndSetPayloads(RestrictionsPayload::TYPE, $payloads);
    }

    public function getWifi()
    {
        return $this->getPayloads(WifiPayload::TYPE);
    }

    public function setWifi(array $payloads)
    {
        $this->clearPayloadWithType(WifiPayload::TYPE);
        foreach ($payloads as $payload) {
            $this->addPayload($payload);
        }
    }

    public function getApn()
    {
        return $this->getPayloads(ApnPayload::TYPE);
    }

    public function setApn(array $payloads)
    {
        $this->clearAndSetPayloads(ApnPayload::TYPE, $payloads);
    }

    public function getWebContentFilter()
    {
        return $this->getPayloads(WebContentFilterPayload::TYPE);
    }

    public function setWebContentFilter(array $payloads)
    {
        $this->clearAndSetPayloads(WebContentFilterPayload::TYPE, $payloads);
    }

    public function getAirPlay()
    {
        return $this->getPayloads(AirPlayPayload::TYPE);
    }

    public function setAirPlay(array $payloads)
    {
        $this->clearAndSetPayloads(AirPlayPayload::TYPE, $payloads);
    }

    public function getAirPrint()
    {
        return $this->getPayloads(AirPrintPayload::TYPE);
    }

    public function setAirPrint(array $payloads)
    {
        $this->clearAndSetPayloads(AirPrintPayload::TYPE, $payloads);
    }

}
