<?php
namespace Topalis\ReverseProxy\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Topalis\ConfigGroup\Entity\ConfigGroup;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Topalis\ReverseProxy\Entity\ReverseProxyUrl;

/**
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @Route("/admin/group/{group}/section/secure-intranet")
 */
class ConfigGroupController extends Controller
{
    /**
     * @Route("", name="admin_group_reverse_proxy")
     * @param ConfigGroup                   $group
     * @Template()
     *
     * @return array
     */
    public function indexAction(ConfigGroup $group)
    {
        $urls = $this->get("reverse_proxy.entity.manager.url")->findAll();

        return array(
            "urls"             => $urls,
            "group"            => $group,
        );
    }

    /**
     * @Route("/{id}/enable", name="admin_reverse_proxy_group_enable")
     *
     * @param ConfigGroup     $group
     * @param ReverseProxyUrl $url
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function enable(ConfigGroup $group, ReverseProxyUrl $url)
    {
        $group->addReverseProxyUrl($url);
        $this->get("config_group.entity.manager.config_group")->save($group);

        return $this->redirect(
            $this->generateUrl("admin_group_reverse_proxy", array("group" => $group->getId()))
        );
    }

    /**
     * @Route("/{id}/disable", name="admin_reverse_proxy_group_disable")
     *
     * @param ConfigGroup     $group
     * @param ReverseProxyUrl $url
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function disable(ConfigGroup $group, ReverseProxyUrl $url)
    {
        $group->removeReverseProxyUrl($url);
        $this->get("config_group.entity.manager.config_group")->save($group);

        return $this->redirect(
            $this->generateUrl("admin_group_reverse_proxy", array("group" => $group->getId()))
        );
    }
}
