<?php

namespace Topalis\ReverseProxy\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Topalis\ConfigGroup\Entity\ConfigGroup;
use Topalis\WebClip\Entity\AbstractWebClip;

/**
 * ReverseProxyUrl
 *
 * @ORM\Table(name="reverseproxy_urls")
 * @ORM\Entity
 * @UniqueEntity(fields={"externalPath"}, message="reverse_proxy.pathTaken")
 */
class ReverseProxyUrl extends AbstractWebClip
{

    /**
     * @var string
     *
     * @ORM\Column(name="external_path", type="string", length=4095, nullable=false)
     */
    private $externalPath;

    /**
     * @var string
     *
     * @ORM\Column(name="internal_path", type="string", length=4095, nullable=false)
     */
    private $internalPath;

    /**
     * @var string
     *
     * @ORM\Column(name="external_path_hash", type="binary", length=20, nullable=false, unique=true,
     *     options={"fixed"=true})
     */
    private $externalPathHash;

    /**
     * @var bool
     *
     * @ORM\Column(type="boolean")
     */
    private $useRemoteProxy = false;

    /**
     * @var ArrayCollection
     *
     * @ORM\ManyToMany(
     *  targetEntity="Topalis\ConfigGroup\Entity\ConfigGroup",
     *  inversedBy="reverseProxyUrls",
     *  cascade={"persist"}
     * )
     * @ORM\JoinTable(name="configgroups_reverseproxyurls",
     *   joinColumns={@ORM\JoinColumn(name="reverseproxyurl_id", referencedColumnName="id")},
     *   inverseJoinColumns={@ORM\JoinColumn(name="configgroup_id", referencedColumnName="id")})
     */
    protected $configGroups;

    /**
     * Set externalPath
     *
     * @param string $externalPath
     *
     * @return ReverseProxyUrl
     */
    public function setExternalPath($externalPath)
    {
        $this->externalPath = $externalPath;

        if ($externalPath === null) {
            $this->externalPathHash = null;
        } else {
            $this->externalPathHash = sha1($externalPath, true);
        }

        return $this;
    }

    /**
     * Get externalPath
     *
     * @return string
     */
    public function getExternalPath()
    {
        return $this->externalPath;
    }

    /**
     * Set internalPath
     *
     * @param string $internalPath
     *
     * @return ReverseProxyUrl
     */
    public function setInternalPath($internalPath)
    {
        $this->internalPath = $internalPath;

        return $this;
    }

    /**
     * Get internalPath
     *
     * @return string
     */
    public function getInternalPath()
    {
        return $this->internalPath;
    }

    /**
     * Get externalPathHash
     *
     * @return string
     */
    public function getExternalPathHash()
    {
        return $this->externalPathHash;
    }

    /**
     * Set useRemoteProxy
     *
     * @param bool $useRemoteProxy
     */
    public function setUseRemoteProxy($useRemoteProxy)
    {
        $this->useRemoteProxy = $useRemoteProxy;

        return $this;
    }

    /**
     * Get useRemoteProxy
     *
     * @return bool
     */
    public function isUseRemoteProxy()
    {
        return $this->useRemoteProxy;
    }

    public function addConfigGroup(ConfigGroup $group)
    {
        if ($this->configGroups->contains($group)) {
            return $this;
        }

        $this->configGroups->add($group);
        $group->addReverseProxyUrl($this);

        return $this;
    }

    public function removeConfigGroup(ConfigGroup $group)
    {
        if (!$this->configGroups->contains($group)) {
            return $this;
        }
        $this->configGroups->removeElement($group);
        $group->removeReverseProxyUrl($this);

        return $this;
    }

    public function getUploadDir()
    {
        return "reverse_proxy";
    }
}
