<?php
namespace Topalis\ReverseProxy\EventListener;

use Doctrine\ORM\Event\LifecycleEventArgs;
use Doctrine\ORM\PersistentCollection;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Topalis\ReverseProxy\Entity\ReverseProxyUrl;

/**
 * Replace icon file with path to file and store file in filesystem
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class ReverseProxyUrlEventListener
{
    /**
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    private $container;

    /**
     * @param ContainerInterface $container
     */
    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    /**
     * @return \Topalis\Apache\Apache
     */
    private function getApache()
    {
        return $this->container->get("apache");
    }

    /**
     * @return \Topalis\Device\MDM\MdmFacadeInterface
     */
    private function getMdmFacade()
    {
        return $this->container->get("device.mdm.facade");
    }

    public function preRemove(LifecycleEventArgs $eventArgs)
    {
        $entity = $eventArgs->getEntity();
        if (!$entity instanceof ReverseProxyUrl) {
            return;
        }

        foreach ($entity->getConfigGroups() as $configGroup) {
            $configGroup->removeReverseProxyUrl($entity);
            $eventArgs->getEntityManager()->persist($configGroup);
        }
        $eventArgs->getEntityManager()->flush();

        $this->getApache()->removeReverseProxy($entity->getId());
        $this->getMdmFacade()->removeWebClip($entity);
    }

    public function postPersist(LifecycleEventArgs $eventArgs)
    {
        $entity = $eventArgs->getEntity();
        if (!$entity instanceof ReverseProxyUrl) {
            return;
        }

        $this->getApache()->writeReverseProxy($entity);
        $this->getMdmFacade()->addWebClip($entity);
    }

    public function postUpdate(LifecycleEventArgs $eventArgs)
    {
        $entity = $eventArgs->getEntity();
        if (!$entity instanceof ReverseProxyUrl) {
            return;
        }

        $this->getApache()->writeReverseProxy($entity);
        /** @var PersistentCollection $configGroups */
        $configGroups = $entity->getConfigGroups();
        $uow = $eventArgs->getEntityManager()->getUnitOfWork();
        $this->getMdmFacade()->updateWebClip(
            $entity,
            $configGroups->getDeleteDiff(),
            $configGroups->getInsertDiff(),
            $uow
        );
    }
}
