<?php
namespace Topalis\ReverseProxy\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Symfony\Component\Validator\Constraints as Assert;
use Topalis\ReverseProxy\Validator\InternalHost;
use Topalis\ReverseProxy\Validator\SimpleUrl;

/**
 * Url for reverse Proxy form
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 */
class ReverseProxyUrlForm extends AbstractType
{
    /**
     * @var string
     */
    protected $hostname;

    public function __construct($hostname)
    {
        $this->hostname = $hostname;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused
        $fileConstraints = array();

        $fileConstraints[] = new Assert\Image(array(
            "mimeTypes" => "image/png"
        ));

        $builder
            ->add("name", "text", array(
                "label" => "admin.reverseProxy.name",
                "constraints" => new Assert\NotBlank()
            ))
            ->add("externalPath", "text", array(
                "label" => "admin.reverseProxy.externalPath",
                "descriptionBlock" => true,
                "description" => "admin.reverseProxy.externalPathDescription",
                "descriptionParams" => array("%url%" => $this->hostname),
                "constraints" => new Assert\NotBlank()
            ))
            ->add("internalPath", "url", array(
                "label" => "admin.reverseProxy.internalURL",
                "descriptionBlock" => true,
                "description" => "admin.reverseProxy.internalURLDescription",
                "constraints" => array(new Assert\NotBlank(), new SimpleUrl())
            ))
            ->add("useRemoteProxy", "checkbox", array(
                "label" => "admin.reverseProxy.useRemoteProxy",
                "description" => "admin.reverseProxy.useRemoteProxyDescription",
                "required" => false,
            ))
            ->add("configGroups", "genemu_jqueryselect2_entity", array(
                "label" => "admin.reverseProxy.groups",
                "descriptionBlock" => true,
                "description" => "admin.reverseProxy.groupsDescription",
                "class" => 'Topalis\ConfigGroup\Entity\ConfigGroup',
                "property" => "name",
                "multiple" => "true",
                "by_reference" => false,
                "required" => false,
                "placeholder" => "admin.reverseProxy.selectGroup",
            ))
            ->add("visible", "checkbox", array(
                "label" => "admin.reverseProxy.visible",
                "description" => "admin.reverseProxy.visibleDescription",
                "os"       => array("iOS"),
                "required" => false
            ))
            ->add("icon", "file", array(
                "label" => "admin.reverseProxy.icon",
                "descriptionBlock" => true,
                "description" => "admin.reverseProxy.iconDescription",
                "constraints" => $fileConstraints,
                "required" => false,
                "data_class" => null
            ))
            // disable possibility to enable fullscreen because on remove the
            // icon will disappear on the device, but the box that contained the
            // icon remains. (propably an iOS bug)
            // @codingStandardsIgnoreStart
            // avoid warning for commented code
            /*
               ->add("fullscreen", "checkbox", array(
                "label" => "admin.reverseProxy.fullscreen",
                "required" => false,
            ))
            */
            // @codingStandardsIgnoreEnd

            // disable possibility to allow removal of WebClips because they
            // are reinstalled on change of any assigned WebClip. This
            // behaviour would lead to confusions.
            // @codingStandardsIgnoreStart
            // avoid warning for commented code
            /*->add("removable", "checkbox", array(
                "label" => "admin.reverseProxy.removable",
                "descriptionBlock" => true,
                "description" => "admin.reverseProxy.removableDescription",
                "required" => false
            ))*/
            // @codingStandardsIgnoreEnd
            ->add("preComposed", "checkbox", array(
                "label" => "admin.reverseProxy.precomposed",
                "description" => "admin.reverseProxy.precomposedDescription",
                "required" => false
            ))
        ;
    }

    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        $resolver
            ->setDefaults(array(
                "data_class" => "Topalis\ReverseProxy\Entity\ReverseProxyUrl",
                "constraints" => new InternalHost(),
            ))
        ;
    }

    /**
     * Returns the name of this type.
     * @return string The name of this type
     */
    public function getName()
    {
        return "reverse_proxy_url";
    }
}
