<?php
namespace Topalis\System\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Symfony\Component\Validator\Constraints as Assert;
use Topalis\System\Validator\DynamicIP;
use Topalis\System\Validator\Netmask;

/**
 * InterfaceConfigForm
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class InterfaceConfigForm extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused
        $builder
            ->add("bootProto", "choice", array(
                "label" => "admin.global.network.bootProto",
                "choices" => array(
                    "dhcp" => "admin.global.network.dhcp",
                    "static" => "admin.global.network.static"
                ),
                "required" => true,
            ))
            ->add("ipAddress", "text", array(
                "label" => "admin.global.network.ipAddress",
                "constraints" => new Assert\Ip(array("version" => Assert\Ip::ALL)),
                "required" => false,
            ))
            ->add("netmask", "text", array(
                "label" => "admin.global.network.netmask",
                "constraints" => new Netmask(),
                "required" => false,
            ))
            ->add("gateway", "text", array(
                "label" => "admin.global.network.gateway",
                "constraints" => new Assert\Ip(array("version" => Assert\Ip::ALL)),
                "required" => false,
            ))
            ->add("dns1", "text", array(
                "label" => "admin.global.network.dns1",
                "constraints" => new Assert\Ip(array("version" => Assert\Ip::ALL)),
                "required" => false,
            ))
            ->add("dns2", "text", array(
                "label" => "admin.global.network.dns2",
                "constraints" => new Assert\Ip(array("version" => Assert\Ip::ALL)),
                "required" => false,
            ))
        ;
    }

    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        $resolver->setDefaults(array(
            "constraints" => array(new DynamicIP()),
        ));
    }

    /**
     * Returns the name of this type.
     *
     * @return string The name of this type
     */
    public function getName()
    {
        return "interface";
    }
}
