<?php
namespace Topalis\Test;

use Topalis\Database\MySqlDb;
use Topalis\Certificate\Entity\ClientCertificate;
use Topalis\Device\Entity\MailAccount;
use Topalis\Device\Entity\Device;
use Topalis\User\Entity\User;
use Topalis\Profile\ConfigurationProfile;
use Topalis\ConfigGroup\Entity\ConfigGroup;
use Topalis\ReverseProxy\Entity\ReverseProxyUrl;
use Topalis\Profile\Payload\GeneralPayload;
use Topalis\Admin\Entity\Admin;

class MockObjectFactory
{
    private $db;

    private $admins = array();
    private $devices = array();
    private $configGroups = array();
    private $users = array();
    private $mailAccounts = array();
    private $reverseProxyUrls = array();

    public function __construct(\Topalis\Database\MySqlDb $db)
    {
        $this->db = $db;
    }

    /**
     * @return MySqlDb
     */
    protected function getDB()
    {
        return $this->db;
    }

    /**
     *
     * @return \Doctrine\ORM\EntityManager
     */
    protected function getEntityManager()
    {
        return $this->db->getDoctrine()->getManager();
    }

    public function unmock()
    {
        $this->users = array();
    }

    public function getAdmin(array $options = array())
    {
        $admin = new Admin();
        $admin->setLogin($this->getOption($options, "login", "TestLogin"));
        $admin->setLevel($this->getOption($options, "level", Admin::LEVEL_ADMIN));
        $admin->setRealname($this->getOption($options, "realname"));

        $key = md5(serialize($admin));
        if (!isset($this->admins[$key])) {
            $this->getEntityManager()->persist($admin);
            $this->getEntityManager()->flush();
            $this->admins[$key] = $admin;
        }

        return $this->admins[$key];
    }

    /**
     *
     * @param array $options
     * @return Device
     */
    public function getDevice(array $options = array())
    {
        $device = new Device();
        $deviceid = $this->getOption($options, "deviceid") ?: $this->getOption($options, "deviceId");
        $device->setDeviceid($deviceid);
        $device->setPlainChallenge($this->getOption($options, "challenge"));
        $device->setOs($this->getOption($options, "os", 0));
        $device->setVersion($this->getOption($options, "version", null));
        $device->setOwner(Device::OWNER_COMPANY);

        $key = $device->getDeviceid();
        if (!isset($this->devices[$key])) {
            $device->setUser($this->getOption($options, "user", $this->getUser()));
            $device->setConfigGroup($this->getOption($options, "configGroup", $this->getConfigGroup()));
            $this->getEntityManager()->persist($device);
            $this->getEntityManager()->flush();
            $this->devices[$key] = $device;
        }

        return $this->devices[$key];
    }

    /**
     *
     * @param array $options
     * @return MailAccount
     */
    public function getMailAccount(array $options = array())
    {
        if (isset($options['deviceId'])) {
            $device = $this->getEntityManager()->getRepository("TopalisDeviceBundle:Device")
                ->find($options['deviceId']);
        } else {
            $device = $this->getDevice();
        }

        if (isset($options['certId'])) {
            $options['cert'] = $this->getEntityManager()
                ->getRepository("TopalisCertificateBundle:ClientCertificate")->find($options['certId']);
        }

        $email = $this->getOption($options, "email", $device->getUser()->getEmail());
        $mailAccount = $this->getEntityManager()
                ->getRepository("TopalisDeviceBundle:MailAccount")->findOneBy(array("email" => $email));
        if ($mailAccount !== null) {
            return $mailAccount;
        }

        $mailAccount = new MailAccount();
        $mailAccount->setEmail($email);
        $mailAccount->setUser($this->getOption($options, "user", $device->getUser()->getLogin()));

        $key = md5(serialize($mailAccount));
        if (!isset($this->mailAccounts[$key])) {
            $mailAccount->setCert($this->getOption($options, "cert"));
            $mailAccount->setDevice($this->getOption($options, "device", $device));
            $this->getEntityManager()->persist($mailAccount);
            $this->getEntityManager()->flush();
            $this->mailAccounts[$key] = $mailAccount;
        }

        return $this->mailAccounts[$key];
    }

    /**
     * @param array $options
     * @return ConfigGroup
     */
    public function getConfigGroup(array $options = array())
    {
        $profile = $this->getOption($options, "profile");
        $configGroup = new ConfigGroup();
        $configGroup->setName($this->getOption($options, "name", "TestConfigGroup"));
        $configGroup->setComment($this->getOption($options, "comment", "Comment for TestConfigGroup"));
        $configGroup->setProfile($profile);

        $key = md5(serialize($configGroup));
        if (!isset($this->configGroups[$key])) {
            if ($profile === null) {
                $configProfile = new ConfigurationProfile();
                $configProfile->setDisplayName("TestProfile");
                $configProfile->setIdentifier("TestIdentifier");
                $configProfile->setOrganization("TestOrganization");
                $payload = new GeneralPayload();
                $payload->setType("TestType");
                $configProfile->addPayload($payload);
                $profile = $configProfile->toXML();
                $configGroup->setProfile($profile);
            }
            $this->getEntityManager()->persist($configGroup);
            $this->getEntityManager()->flush();
            $this->configGroups[$key] = $configGroup;
        }

        return $this->configGroups[$key];
    }

    public function getReverseProxyUrl(array $options = array())
    {
        $reverseProxyUrl = new ReverseProxyUrl();
        $reverseProxyUrl->setName($this->getOption($options, "name", "ReverseProxyUrlTest"));
        $reverseProxyUrl->setExternalPath($this->getOption($options, "externalPath", "external"));
        $reverseProxyUrl->setInternalPath($this->getOption($options, "internalPath", "internal"));
        $reverseProxyUrl->setIcon($this->getOption($options, "icon", "icon"));

        $key = md5(serialize($reverseProxyUrl));
        if (!isset($this->reverseProxyUrls[$key])) {
            $this->getEntityManager()->persist($reverseProxyUrl);
            $this->getEntityManager()->flush();
            $this->reverseProxyUrls[$key] = $reverseProxyUrl;
        }

        return $this->reverseProxyUrls[$key];
    }

    /**
     *
     * @param array $options
     * @return User
     */
    public function getUser(array $options = array())
    {
        $user = new User();
        $user->setComment($this->getOption($options, "comment", "TestComment"));
        $user->setEmail($this->getOption($options, "email", "test@test.test"));
        $user->setLogin($this->getOption($options, "login", "TestLogin"));
        $user->setRealname($this->getOption($options, "realname", "TestRealname"));

        $key = md5(serialize($user));
        if (!isset($this->users[$key])) {
            $user->setConfigGroup($this->getOption($options, "configGroup", $this->getConfigGroup()));
            $this->getEntityManager()->persist($user);
            $this->getEntityManager()->flush();
            $this->users[$key] = $user;
        }

        return $this->users[$key];
    }

    protected function getOption(array $options, $name, $default = null)
    {
        return isset($options[$name]) ? $options[$name] : $default;
    }
}
