<?php
namespace Topalis\Test;

/**
 * This class can be used to override the time() function in specific
 * namespaces for tests to get a specified time.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class TestTime
{
    /**
     * @var integer The time to return.
     */
    public static $now;

    /**
     * Override time() in namespace  of the specified class for testing. If
     * the namespace contains "\Tests\" the method will also be overridden in
     * the namespace without "\Tests\". The overriden method will return
     * self::$now or \time() if null.
     *
     * @param string $className
     *
     * @see self::time
     */
    public static function registerClass($className)
    {
        self::registerNamespace(self::getNamespace($className));
    }

    /**
     * Override time() in the specified namespace for testing. If the namespace
     * contains "\Tests(\|$)" the method will also be overridden in the
     * namespace without "\Tests(\|$)". The overriden method will return
     * self::$now or \time() if null.
     *
     * @param string $namespace
     *
     * @see self::time
     */
    public static function registerNamespace($namespace)
    {
        self::registerFunction($namespace);

        $count = 0;
        $namespace = preg_replace('/\\\\Tests(\\\\|$)/', '$1', $namespace, 1, $count);
        if ($count === 1) {
            self::registerFunction($namespace);
        }
    }

    /**
     * @return int self::$now or \time() if null.
     */
    public static function time()
    {
        return null === self::$now ? \time() : self::$now;
    }

    private static function getNamespace($className)
    {
        $pos = strrpos($className, "\\");
        return substr($className, 0, $pos);
    }

    private static function registerFunction($namespace)
    {
        if (!preg_match("/^[A-Za-z0-9_\\\\]+$/", $namespace)) {
            throw new \InvalidArgumentException($namespace . " is not a valid namespace");
        }

        if (!function_exists("\\" . $namespace . "\\time")) {
            $string = "namespace " . $namespace . "; function time() { return \Topalis\Test\TestTime::time(); }";
            eval($string);
        }
    }
}
