<?php
namespace Topalis\Update\Command;

use Topalis\WinPhone\OMA\SyncML\Entity\Add;
use Topalis\WinPhone\OMA\SyncML\Entity\Item;
use Topalis\WinPhone\OMA\SyncML\Entity\Target;
use Topalis\WinPhone\OMA\SyncML\Entity\Meta;
use Topalis\WinPhone\OMA\SyncML\Entity\ConfigurationServiceProvider\PollCSP;
use Topalis\WinPhone\WinPhoneConstants;
use Topalis\WinPhone\OMA\SyncML\Entity\Sequence;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * This class contains methods to perform the update to version 2.3.5
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class UpdateHelper020305
{
    /**
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    private $container;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    /**
     * Fix the polling of Windows Phones #AUR-639
     */
    public function fixWindowsPhonePolling()
    {
        $sequence = new Sequence();

        $locURI = "./Vendor/MSFT/DMClient/Provider/" . WinPhoneConstants::PROVIDER_ID . "/Poll";
        $item = $this->createCommandItem($locURI, "", array("Format" => "node"));
        $add = new Add();
        $add->addItem($item);

        $sequence->addAdd($add);

        $pollCSP = new PollCSP();
        $pollCSP->setProviderId(WinPhoneConstants::PROVIDER_ID);
        $pollCSP->setIntervalForFirstSetOfRetries(
            $this->container->getParameter("winphone.interval_for_first_set_of_retries"));
        $pollCSP->setNumberOfFirstRetries(
            $this->container->getParameter("winphone.number_of_first_retries"));
        $pollCSP->setIntervalForSecondSetOfRetries(
            $this->container->getParameter("winphone.interval_for_second_set_of_retries"));
        $pollCSP->setNumberOfSecondRetries(
            $this->container->getParameter("winphone.number_of_second_retries"));
        $pollCSP->setIntervalForRemainingScheduledRetries(
            $this->container->getParameter("winphone.interval_for_remaining_scheduled_retries"));
        $pollCSP->setNumberOfRemainingScheduledRetries(
            $this->container->getParameter("winphone.number_of_remaining_scheduled_retries"));

        foreach ($pollCSP->getCommands() as $command) {
            $sequence->addCommand($command);
        }

        $pollDevices = array();
        $syncMLMdmFacade = $this->container->get("winphone.oma.syncml.mdmfacade");
        $syncMLAdmin = $this->container->get("winphone.oma.syncml.admin");
        foreach ($syncMLMdmFacade->getActiveManagedDevices() as $device) {
            if (version_compare($device->getVersion(), "8.1", "<")) {
                continue;
            }

            $syncMLAdmin->addCommand($device, $sequence, "Poll configuration");
            $pollDevices[] = $device;
        }

        if ($pollDevices) {
            $mailer = $this->container->get("mailer");
            if (!$mailer->isConfigured()) {
                return;
            }

            $deviceList = "";
            foreach ($pollDevices as $device) {
                $deviceList .= "- " . $device->getName() . " of user " . $device->getUser()->getLogin() . "\n";
            }
            $translator = $this->container->get("translator");
            $subject = $translator->trans("admin.update.inform.winphone_poll.subject");
            $text = $translator->trans("admin.update.inform.winphone_poll.text", array(
                "%devices%" => $deviceList
            ));

            $mailer->sendAdminMessage($subject, $text);
        }
    }

    private function createCommandItem($locURI, $data = null, array $meta = null)
    {
        $item = new Item();
        $target = new Target();
        $target->setLocURI($locURI);
        $item->setTarget($target);
        $item->setData($data);
        if ($meta !== null) {
            $item->setMeta(new Meta($meta));
        }

        return $item;
    }
}
