<?php
namespace Topalis\Update\Command;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\File\File;
use Topalis\App\Entity\App;
use Topalis\Util\FileSystemUtil;

/**
 * This class contains methods to perform the update to version 2.5.3
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class UpdateHelper020503
{
    /**
     * @var ContainerInterface
     */
    private $container;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    /**
     * Icons of newly uploaded iOS apps where stored in "ios_app_icons/" instead
     * of "ios_app_icons/<id>/". This method fixes this.
     */
    public function fixUploadedIosAppIcons()
    {
        $appEm = $this->getIosAppEntityManager();
        $apps = $appEm->createQueryBuilder("a")
            ->where("a.type = :typeUploaded")
            ->andWhere("a.icon = :icon OR a.iconLarge = :iconLarge")
            ->setParameter("typeUploaded", App::TYPE_UPLOADED)
            ->setParameter("icon", "/uploads/ios_app_icons//icon.png")
            ->setParameter("iconLarge", "/uploads/ios_app_icons//icon-large.png")
            ->getQuery()->getResult();
        ;
        foreach ($apps as $app) {
            try {
                $ipa = new File($app->getIpaPath());
                // make IosUploadEventListener update the icons
                $app->setIpaPath($ipa);
                $app->setIcon(null);
                $app->setIconLarge(null);
                $appEm->save($app);
            } catch (\Exception $e) {
                $this->container->get("logger")->error("Failed to fix icon of app '" . $app->getIdentifier() . "'", array(
                    "app" => $app->getId(),
                    "exception" => $e,
                ));
            }
        }

        $iconsDir = $this->container->getParameter("kernel.upload_dir") . "/ios_app_icons/";
        FileSystemUtil::tryUnlinkFile($iconsDir . "icon.png");
        FileSystemUtil::tryUnlinkFile($iconsDir . "icon-large.png");
    }

    /**
     * @return \Topalis\App\Entity\AppEntityManager
     */
    private function getIosAppEntityManager()
    {
        return $this->container->get("app.entity.manager.ios_app");
    }
}
