<?php
namespace Topalis\Update\Command;

use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * This class contains methods to perform the update to version 2.5.4
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class UpdateHelper020504
{
    /**
     * @var ContainerInterface
     */
    private $container;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    /**
     * Creates a new reverse proxy CA cert if it has the same serial as the
     * CA cert and installs new SecureIntranet profiles in that case.
     */
    public function fixReverseProxyCACert()
    {
        $certManager = $this->container->get("certificate.manager");
        $caCert = $certManager->getCACert();

        if (null === $caCert) {
            // installation wizard wasn't performed
            return;
        }

        $revProxyCaCert = $certManager->getReverseProxyCACert();
        if ($caCert->getSerial() != $revProxyCaCert->getSerial()) {
            // nothing to do
            return;
        }

        // generate a new rev proxy CA cert with different serial
        $config = $this->container->get("config.auralis");
        $config->setReverseProxyCACert(null);
        $config->setReverseProxyCAPrivateKey(null);
        $certManager->exportCACert();

        // install new SecureIntranet profiles
        $mdmAdmin = $this->container->get("mdm.admin");
        foreach ($mdmAdmin->getActiveManagedDevices() as $device) {
            $mdmAdmin->installSecureIntranetProfile($device);
        }
    }
}
