<?php
namespace Topalis\User\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Toyota\Component\Ldap\Exception\LdapException;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Topalis\User\Form\LdapAddForm;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 * @Route("/admin/user/ldap")
 */
class LdapController extends Controller
{
    /**
     * @return \Psr\Log\LoggerInterface
     */
    private function getLogger()
    {
        return $this->container->get("logger");
    }

    /**
     * @Route("", name="admin_user_ldap")
     * @Template()
     */
    public function indexAction()
    {
        $ldapManager = $this->get("user.ldap.manager");
        if (!$ldapManager->isConfigured()) {
            return array("configured" => false, "tree" => null);
        }

        $tree = null;
        try {
            $ldapManager->bind();
            $tree = $ldapManager->getOuTree();
            $tree['state'] = "open";
        } catch (LdapException $e) {
            $this->getLogger()->error("Error accessing LDAP", array("exception" => $e));
            $this->get("session")->getFlashBag()->add("error", $this->get("translator")
                ->trans("admin.users.ldap.error.access", array("%errmsg%" => $e->getMessage())));
        }

        return array(
            "configured" => true,
            "tree" => $tree,
        );
    }

    /**
     * @Route("/import", name="admin_user_ldap_import")
     * @Template()
     */
    public function importAction()
    {
        $dn = $this->getRequest()->request->get("dn");
        if (null === $dn) {
            return $this->redirect($this->generateUrl("admin_user_ldap"));
        }

        try {
            $form = $this->createForm(new LdapAddForm());
            $imported = $this->get("user.ldap.add.form.handler")->process($form, $this->getRequest());
            if ($imported !== false) {
                if ($imported > 0) {
                    $this->get("session")->getFlashBag()->add("success",
                        $this->get("translator")->trans("admin.users.ldap.importSuccess"));
                }
                return $this->redirect($this->generateUrl("admin_user"));
            }
        } catch (LdapException $e) {
            $this->getLogger()->error("Error accessing LDAP", array("exception" => $e));
            $this->get("session")->getFlashBag()->add("error", $this->get("translator")
                ->trans("admin.users.ldap.error.access", array("%errmsg%" => $e->getMessage())));
        }

        return array(
            "form" => $form->createView(),
            "dn"   => $dn,
            "limit" => $this->container->getParameter("user.ldap_import_limit"),
        );
    }
}
