<?php
namespace Topalis\User\Form\Handler;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Form\FormInterface;
use Toyota\Component\Ldap\Core\Manager;
use Toyota\Component\Ldap\Core\Node;
use Toyota\Component\Ldap\Platform\Native\Driver;
use Toyota\Component\Ldap\Platform\Native\Search;

class LdapFormHandler
{
    /**
     * @var \Topalis\User\Entity\UserEntityManager
     */
    private $userEntityManager;

    /**
     * @return \Topalis\User\Entity\UserEntityManager
     */
    protected function getUserEntityManager()
    {
        return $this->userEntityManager;
    }

    /**
     * @param \Topalis\User\Entity\UserEntityManager $userEntityManager
     */
    public function setUserEntityManager(\Topalis\User\Entity\UserEntityManager $userEntityManager)
    {
        $this->userEntityManager = $userEntityManager;
    }

    /**
     * @param FormInterface $form
     * @param Request $request
     * @return array|boolean The users fetched from LDAP, or false if the form
     *     has not been filled completely.
     */
    public function process(FormInterface $form, Request $request)
    {
        $form->handleRequest($request);
        if (!$form->isValid()) {
            return false;
        }

        $data = $form->getData();
        $params = array(
                "hostname" => $data['hostname'],
                "port" => $data['port'],
                "base_dn"  => $data['base_dn'],
                "options"  => array(
                    LDAP_OPT_PROTOCOL_VERSION => $data['version']
                )
        );
        if ($data['security'] != "None") {
            $params['security'] = $data['security'];
        }

        $manager = new Manager($params, new Driver());
        $manager->connect();
        if (!empty($data['bind_name'])) {
            $manager->bind($data['bind_name'], $data['bind_password']);
        } else {
            $manager->bind();
        }

        $userEntityManager = $this->getUserEntityManager();
        $results = $manager->search(null, $data['filter'], true, array("uid", "cn", "mail"));
        $users = array();
        foreach ($results as $node) {
            /** @var $node Node */
            if (!$node->has("mail")) {
                continue;
            }

            $login = $node->get("uid")->current();
            if ($userEntityManager->exists("entity.login = :login", array("login" => $login))) {
                continue;
            }

            $dn = $this->parseDn($node->getDn());
            $ou = isset($dn['ou']) ? $dn['ou'][0] : "";
            $data = array(
                "enabled" => true,
                "login" => $login,
                "name" => $node->get("cn")->current(),
                "email" => $node->get("mail")->current(),
                "ou" => $ou
            );
            $users[] = $data;
        }

        return $users;
    }

    protected function parseDn($dn)
    {
        $parsed = array();
        $attributes = explode(",", $dn);
        foreach ($attributes as $attribute) {
            $attributeSplit = explode("=", $attribute);
            $parsed[$attributeSplit[0]][] = $attributeSplit[1];
        }

        return $parsed;
    }
}
