<?php
namespace Topalis\User\Form;

use Topalis\User\Validator\LdapImport;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Doctrine\ORM\EntityRepository;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Validator\Constraints as Assert;
use Topalis\Device\Entity\Device;

/**
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class LdapAddForm extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused

        $builder
            ->add("configGroup", "entity", array(
                "label" => "admin.users.group.default.label",
                "description" => "admin.users.group.default.description",
                "class" => "TopalisConfigGroupBundle:ConfigGroup",
                "query_builder" => function (EntityRepository $repository) {
                    return $repository->createQueryBuilder("cg")->orderBy("cg.name", "ASC");
                },
                "property" => "name",
                "empty_value" => "admin.users.ldap.groupFromOu",
                "required" => false
                ))
            ->add("createDevices", "checkbox", array(
                "label" => "admin.users.ldap.createDevices.label",
                "description" => "admin.users.ldap.createDevices.description",
                "required" => false
            ))
            ->add("sendUserMail", "checkbox", array(
                "label" => "admin.devices.sendUserMail",
                "required" => false,
            ))
            ->add("deviceOs", "device_type", array(
                "label" => "admin.devices.os.title",
                "constraints" => new Assert\NotBlank(),
            ))
            ->add("owner", "choice", array(
                "label" => "admin.devices.owner",
                "choices" => array(
                    Device::OWNER_COMPANY => "admin.device.owner.company",
                    Device::OWNER_USER => "admin.device.owner.user",
                )
            ))
            ->add("rolloutPassword", "password", array(
                "label" => "admin.devices.rolloutPassword",
            ))
            ->add("users", "collection", array(
                "type" => new UserImportType(),
                "allow_add" => true,
            ))
            ->add("limitExceeded", "hidden")
        ;
    }

    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        $resolver->setDefaults(array(
                "constraints" => new LdapImport()
        ))
        ;
    }

    public function getName()
    {
        return "ldap_add";
    }
}
