<?php
namespace Topalis\User\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;
use Symfony\Component\Validator\Constraints\Email;
use Symfony\Component\Validator\Constraints\NotBlank;

/**
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class UserForm extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $options; // unused
        $builder
            ->add("login", "text", array(
                "label" => "admin.users.login",
                "constraints" => new NotBlank()
            ))
            ->add("real_name", "text", array(
                "label" => "admin.users.real",
                "constraints" => new NotBlank()
            ))
            ->add("email", "text", array(
                "label" => "email",
                "constraints" => new Email()
            ))
            ->add("config_group", "entity", array(
                "label" => "admin.users.group.default.label",
                "description" => "admin.users.group.default.description",
                "class" => "TopalisConfigGroupBundle:ConfigGroup",
                "query_builder" => function ($repository) {
                    return $repository->createQueryBuilder("cg")->orderBy("cg.name", "ASC");
                },
                "property" => "name",
                "constraints" => new NotBlank(),
            ))
            ->add("comment", "text", array(
                "label" => "Comment",
                "required" => false
            ))
        ;
    }

    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        $resolver
            ->setDefaults(array(
                "data_class" => "Topalis\User\Entity\User"
            ));
    }

    /**
     * Returns the name of this type.
     * @return string The name of this type
     */
    public function getName()
    {
        return "user";
    }
}
