<?php
namespace Topalis\User\Validator;

use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;
use Symfony\Component\Validator\Exception\UnexpectedTypeException;

/**
 * Validates rollout password.
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
class LdapImportValidator extends ConstraintValidator
{
    public function validate($value, Constraint $constraint)
    {
        /** @var $constraint LdapImport */
        if (null === $value || '' === $value) {
            return;
        }

        if (!is_array($value)) {
            throw new UnexpectedTypeException($value, 'array');
        }

        if (isset($value['createDevices']) && $value['createDevices'] == true) {
            if (strlen($value['deviceOs']) == 0) {
                $this->context->addViolationAt("[deviceOs]", $constraint->message);
            }
            if (empty($value['rolloutPassword'])) {
                $this->context->addViolationAt("[rolloutPassword]", $constraint->message);
            }
        }
    }

}
