<?php
namespace Topalis\Util;

class DateUtil
{
    /**
     * @var Symfony\Component\Translation\TranslatorInterface
     */
    private $translator;

    /**
     * @param \Symfony\Component\Translation\TranslatorInterface $translator
     */
    public function __construct(\Symfony\Component\Translation\TranslatorInterface $translator)
    {
        $this->translator = $translator;
    }

    /**
     * Returns a string in the form YYYY-MM-01 for the specified variable.
     *
     * @param array|string|int $time Might be an array with the entries 'year'
     *     and 'month', a date string, that can be parsed by strtotime(), or a
     *     UNIX timestamp.
     * @param int $now The timestamp which is used as a base for the
     *     calculation of relative dates. (Default: current time)
     * @return string A string in the form YYYY-MM-01.
     */
    public static function getFirstOfMonth($time, $now = null)
    {
        if (is_array($time)) {
            if (strlen($time['month']) == 1) {
                return $time['year']."-0".$time['month']."-01";
            }
            return $time['year']."-".$time['month']."-01";
        }
        if (is_string($time)) {
            $time = strtotime($time, $now);
        }
        return date("Y-m-01", $time);
    }

    /**
     * @see \Topalis\Util\Date::getTranslator()
     */
    protected function getTranslator()
    {
        return $this->translator;
    }

    /**
     * Convert time difference from seconds to human readable time
     * @param integer $seconds
     * @param boolean $showOne
     * @param string $type
     * @return string
     */
    public function diff($seconds, $showOne = false, $type = 'diff')
    {
        $rest = floor($seconds);
        $outSec = $rest % 60;
        $rest = floor($rest / 60);
        $outMin = $rest % 60;
        $rest = floor($rest / 60);
        $outHours = $rest % 24;
        $rest = floor($rest / 24);
        $outDays = $rest % 30;
        $rest = floor($rest / 30);
        $outMonths = $rest % 12;
        $outYear = floor($rest / 12);

        $output = "";
        if (!empty($outYear) && (!$showOne || empty($output))) {
            $output .= $this->getTranslator()->transChoice(
                "date.".$type.".year",
                $outYear,
                array("%years%" => $outYear)
            ) . " ";
        }
        if (!empty($outMonths) && (!$showOne || empty($output))) {
            $output .= $this->getTranslator()->transChoice(
                "date.".$type.".month",
                $outMonths,
                array("%months%" => $outMonths)
            ). " ";
        }
        if (!empty($outDays) && (!$showOne || empty($output))) {
            $output .= $this->getTranslator()->transChoice(
                "date.".$type.".day",
                $outDays,
                array("%days%" => $outDays)
            ). " ";
        }
        if (!empty($outHours) && (!$showOne || empty($output))) {
            $output .= $this->getTranslator()->transChoice(
                "date.".$type.".hour",
                $outHours,
                array("%hours%" => $outHours)). " ";
        }
        if (!empty($outMin) && (!$showOne || empty($output))) {
            $output .= $this->getTranslator()->transChoice(
                "date.".$type.".minute",
                $outMin,
                array("%minutes%" => $outMin)
            ). " ";
        }
        if (!empty($outSec) && (!$showOne || empty($output))) {
            $output .= $this->getTranslator()->transChoice(
                "date.".$type.".second",
                $outSec,
                array("%seconds%" => $outSec)
            ). " ";
        }
        return substr($output, 0, -1);

    }

    /**
     * Get the ellapsed time in days, hours, minutes, seconds...
     *
     * @param integer $seconds
     * @param bool    $showOne output only the biggest unit, which isn't zero
     *
     * @return string
     */
    public function since($seconds, $showOne = false)
    {
        $output = $this->getTranslator()
            ->trans("date.ago.ago", array("%time%" => $this->diff($seconds, $showOne, 'ago')));

        return $output;
    }

    public function until($seconds, $showOne = false)
    {
        $output = $this->getTranslator()->trans("date.until", array("%time%" => $this->diff($seconds, $showOne)));

        return $output;
    }

}
