<?php
namespace Topalis\Util;

class DebugUtil
{
    /**
     * Converts a backtrace to a string array with one entry for every entry in
     * the specified backtrace.
     *
     * @param array $backtrace The backtrace to convert.
     * @param int $startAt The index of the first converted entry.
     * @param boolean $hideStrings If true strings are removed from the trace.
     *     This can be used to hide sensible data such as passwords.
     * @return array The resulting string array.
     * @see debug_backtrace()
     */
    public static function backtraceToString(array $backtrace, $startAt = 0, $hideStrings = false)
    {
        $tracemsgs = array();
        $i = 0;
        foreach ($backtrace as $t) {
            if ($i >= $startAt) {
                $tracemsg = '#' .$i . ' ';
                if (array_key_exists("file", $t)) {
                    $tracemsg .= $t["file"].'('.$t["line"].'): ';
                }
                if (array_key_exists("class", $t)) {
                    $tracemsg .= $t["class"] . $t["type"];
                }
                $a = array();
                $args = isset($t["args"]) ? $t["args"] : array();
                $argc = count($args);
                for ($j = 0; $j < $argc; $j++) {
                    $ta = $args[$j];
                    $ta = self::replaceObjectWithTypeName($ta, $hideStrings);
                    // @codingStandardsIgnoreStart
                    array_push($a, preg_replace('/\n\s*/', " ", print_r($ta, true)));
                    // @codingStandardsIgnoreEnd
                }
                $tracemsg .= $t["function"].'('.implode(", ", $a).') ';

                $tracemsgs[] = $tracemsg;
            }
            $i++;
        }

        return $tracemsgs;
    }

    private static function replaceObjectWithTypeName($value, $hideStrings = false)
    {
        if (is_string($value)) {
            if ($hideStrings || !mb_check_encoding($value, "UTF-8")) {
                // exclude string if requested or the string contains non UTF-8 characters
                $rv = "'...'";
            } else {
                $rv = "'" . $value . "'";
            }
        } else if (is_array($value)) {
            // we MUST use a new array, otherwise we would replace arguments
            // passed by reference
            $rv = array();
            foreach ($value as $key => $val) {
                if (!mb_check_encoding($key, "UTF-8")) {
                    // ignore keys containing non UTF-8 characters
                    continue;
                }
                if (is_array($val)) {
                    // required, we could have an infinite recursion otherwise
                    $rv[$key] = "array";
                } else {
                    $rv[$key] = self::replaceObjectWithTypeName($val, $hideStrings);
                }
            }
        } else if (!is_scalar($value)) {
            $type = gettype($value);
            if ($type == "object") {
                $type = get_class($value);
            }
            $rv = $type;
        } else {
            $rv = $value;
        }

        return $rv;
    }
}
