<?php
namespace Topalis\Util;

class PasswordUtil
{

    /**
     * Compare salted passwords.
     * @param string $salted A string containing salt:pwhash
     *     pwhash is the SHA1 hash of the salt concatenated with the initial password
     * @param string $password A string containing the plaintext password.
     * @return int 0 if password matches.
     */
    public static function comparePasswords($salted, $password)
    {
        if ($salted === null || $password === null) {
            return -1;
        }

        $a = explode(':', $salted);
        if (count($a) != 2) {
            return -1;
        }

        return strcmp(sha1($a[0].$password), $a[1]);
    }

    /**
     * Creates a salted password hash using SHA1.
     *
     * @param string $password The password to salt.
     * @return string salt:pwhash
     */
    public static function createSaltedPassword($password)
    {
        $salt = Random::getString(16);
        return $salt.':'.sha1($salt.$password);
    }

}
