<?php
namespace Topalis\WebClip\Controller;

use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\HttpFoundation\Request;
use Topalis\Kernel\Controller;
use Topalis\WebClip\Entity\WebClip;
use Topalis\WebClip\Form\WebClipForm;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 *
 * @Route("/admin/web-clips", service="web_clip.controller.web_clip")
 */
class WebClipController extends Controller
{
    /**
     * @Route("", name="admin_web_clip")
     * @Template()
     */
    public function indexAction()
    {
        $webClips = $this->getWebClipEntityManager()->findAll();

        return array(
            "webClips" => $webClips,
        );
    }

    /**
     * @Route("/add", name="admin_web_clip_add")
     * @Template()
     */
    public function addAction()
    {
        $webClip = new WebClip();

        return $this->forward("web_clip.controller.web_clip:editAction", array("webClip" => $webClip));
    }

    /**
     * @Route("/{webClip}/edit", name="admin_web_clip_edit")
     * @Template()
     *
     * @param Request $request
     * @param WebClip $webClip
     *
     * @return array
     */
    public function editAction(Request $request, WebClip $webClip)
    {
        $form = $this->createForm(new WebClipForm(), $webClip);
        try {
            $form->handleRequest($request);
            if ($form->isValid()) {
                $this->getWebClipEntityManager()->save($webClip);
                $this->addSuccess($this->getTranslator()->trans("admin.webClip.saveSuccess"));

                return $this->redirect($this->generateUrl("admin_web_clip"));
            }
        } catch (\Exception $e) {
            $this->getLogger()->error("Error saving WebClip " . $webClip->getId(), array("exception" => $e));
            $this->addError(
                $this->getTranslator()->trans(
                    "admin.webClip.error.save",
                    array(
                        "%errmsg%" => $e->getMessage()
                    )
                )
            );
        }

        return array(
            "form"    => $form->createView(),
            "webClip" => $webClip,
        );
    }

    /**
     * @Route("/{webClip}/delete", name="admin_web_clip_delete")
     *
     * @param WebClip $webClip
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function deleteAction(WebClip $webClip)
    {
        try {
            $this->getWebClipEntityManager()->delete($webClip);
            $this->addSuccess($this->tr("admin.webClip.deleteSuccess"));
        } catch (\Exception $e) {
            $this->getLogger()->error(
                "Error deleting WebClip with id " . $webClip->getId(),
                array("exception" => $e)
            );
            $this->addError(
                $this->tr(
                    "admin.webClip.error.delete",
                    array(
                        "%name%"   => $webClip->getName(),
                        "%errmsg%" => $e->getMessage()
                    )
                )
            );
        }

        return $this->redirect($this->generateUrl("admin_web_clip"));
    }

    /**
     * @return \Topalis\WebClip\Entity\WebClipEntityManager
     */
    protected function getWebClipEntityManager()
    {
        return $this->container->get("web_clip.entity.manager.web_clip");
    }
}
