<?php
namespace Topalis\WebClip\Entity;

use Topalis\ConfigGroup\Entity\ConfigGroup;
use Topalis\ReverseProxy\Entity\ReverseProxyUrl;

/**
 * Interface for WebClips
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
interface WebClipInterface
{
    /**
     * Set id
     *
     * @param integer $id
     *
     * @return ReverseProxyUrl
     */
    public function setId($id);

    /**
     * Get id
     *
     * @return integer
     */
    public function getId();

    /**
     * Set icon
     *
     * @param string $icon
     *
     * @return ReverseProxyUrl
     */
    public function setIcon($icon);

    /**
     * Get icon
     *
     * @return string
     */
    public function getIcon();

    /**
     * Set name
     *
     * @param string $name
     *
     * @return ReverseProxyUrl
     */
    public function setName($name);

    /**
     * Get name
     *
     * @return string
     */
    public function getName();

    /**
     * Set removable
     *
     * @param boolean $removable
     *
     * @return ReverseProxyUrl
     */
    public function setRemovable($removable);

    /**
     * Get removable
     *
     * @return boolean
     */
    public function isRemovable();

    /**
     * Set precomposed
     *
     * @param boolean $precomposed
     *
     * @return ReverseProxyUrl
     */
    public function setPrecomposed($precomposed);

    /**
     * Get precomposed
     *
     * @return boolean
     */
    public function isPrecomposed();

    /**
     * Set fullscreen
     *
     * @param boolean $fullscreen
     *
     * @return ReverseProxyUrl
     */
    public function setFullscreen($fullscreen);

    /**
     * Get fullscreen
     *
     * @return boolean
     */
    public function isFullscreen();

    /**
     * Enables or disables an icon on the home screen.
     *
     * @param boolean $visible true to add an icon to the home screen, false otherwise.
     *
     * @return \Topalis\ReverseProxy\Entity\ReverseProxyUrl $this
     */
    public function setVisible($visible);

    /**
     * @return boolean true if an icon is added to the home screen, false otherwise.
     */
    public function isVisible();

    /**
     * @param ConfigGroup[] $configGroups
     *
     * @return ReverseProxyUrl
     */
    public function setConfigGroups(array $configGroups);

    public function addConfigGroup(ConfigGroup $group);

    public function removeConfigGroup(ConfigGroup $group);

    /**
     * @return ConfigGroup[]
     */
    public function getConfigGroups();

    /**
     * @return string Subdirectory in web/uploads for icons
     */
    public function getUploadDir();
}
