<?php
namespace Topalis\WebClip\EventListener;

use Doctrine\ORM\Event\LifecycleEventArgs;
use Doctrine\ORM\PersistentCollection;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Topalis\WebClip\Entity\WebClip;

/**
 * Handle MDM Web Clip profile changes
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class WebClipMdmListener
{
    /**
     * @var \Symfony\Component\DependencyInjection\ContainerInterface
     */
    private $container;

    /**
     * @param ContainerInterface $container
     */
    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    /**
     * @return \Topalis\Device\MDM\MdmFacadeInterface
     */
    private function getMdmFacade()
    {
        return $this->container->get("device.mdm.facade");
    }

    public function preRemove(LifecycleEventArgs $eventArgs)
    {
        $entity = $eventArgs->getEntity();
        if (!$entity instanceof WebClip) {
            return;
        }

        foreach ($entity->getConfigGroups() as $configGroup) {
            $configGroup->removeWebClip($entity);
            $eventArgs->getEntityManager()->persist($configGroup);
        }
        $eventArgs->getEntityManager()->flush();

        $this->getMdmFacade()->removeWebClip($entity);
    }

    public function postPersist(LifecycleEventArgs $eventArgs)
    {
        $entity = $eventArgs->getEntity();
        if (!$entity instanceof WebClip) {
            return;
        }

        $this->getMdmFacade()->addWebClip($entity);
    }

    public function postUpdate(LifecycleEventArgs $eventArgs)
    {
        $entity = $eventArgs->getEntity();
        if (!$entity instanceof WebClip) {
            return;
        }

        /** @var PersistentCollection $configGroups */
        $configGroups = $entity->getConfigGroups();
        $uow = $eventArgs->getEntityManager()->getUnitOfWork();
        $this->getMdmFacade()->updateWebClip(
            $entity,
            $configGroups->getDeleteDiff(),
            $configGroups->getInsertDiff(),
            $uow
        );
    }
}
