<?php
namespace Topalis\Wifi\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Topalis\ConfigGroup\Entity\ConfigGroup;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Topalis\Wifi\Entity\WifiConfig;

/**
 * @author Dominic Tubach <dominic.tubach@to.com>
 * @Route("/admin/group/{group}/section/wifi")
 */
class ConfigGroupController extends Controller
{
    /**
     * @Route("", name="admin_group_section_wifi")
     * @param ConfigGroup                   $group
     * @Template()
     *
     * @return array
     */
    public function indexAction(ConfigGroup $group)
    {
        $wifiConfigs = $this->get("wifi_config.entity.manager.wifi_config")->findAll();

        return array(
            "wifiConfigs"      => $wifiConfigs,
            "group"            => $group,
        );
    }

    /**
     * @Route("/{wifiConfig}/enable", name="admin_wifi_config_group_enable")
     *
     * @param ConfigGroup $group
     * @param WifiConfig $wifiConfig
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function enable(ConfigGroup $group, WifiConfig $wifiConfig)
    {
        $group->addWifiConfig($wifiConfig);
        $this->get("config_group.entity.manager.config_group")->save($group);

        return $this->redirect(
            $this->generateUrl("admin_group_section_wifi", array("group" => $group->getId()))
        );
    }

    /**
     * @Route("/{wifiConfig}/disable", name="admin_wifi_config_group_disable")
     *
     * @param ConfigGroup $group
     * @param WifiConfig $wifiConfig
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function disable(ConfigGroup $group, WifiConfig $wifiConfig)
    {
        $group->removeWifiConfig($wifiConfig);
        $this->get("config_group.entity.manager.config_group")->save($group);

        return $this->redirect(
            $this->generateUrl("admin_group_section_wifi", array("group" => $group->getId()))
        );
    }
}
