<?php
namespace Topalis\Wifi\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Bridge\Doctrine\Validator\Constraints as ORMAssert;

/**
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 *
 * @ORM\Table(name="wificonfigs")
 * @ORM\Entity
 * @ORMAssert\UniqueEntity(fields="name")
 * @ORMAssert\UniqueEntity(fields="ssid")
 */
class WifiConfig implements \Serializable
{
    const ENCRYPTION_TYPE_NONE = "None";
    const ENCRYPTION_TYPE_WPAPSK = "WPAPSK";
    const ENCRYPTION_TYPE_WPA2PSK = "WPA2PSK";

    const PROXY_TYPE_NONE = "None";
    const PROXY_TYPE_MANUAL = "Manual";
    const PROXY_TYPE_AUTO = "Auto";

    /**
     * @var integer
     * @ORM\Column(type="integer", options={"unsigned"=true})
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    protected $id;

    /**
     * @var string
     * @ORM\Column(type="string", unique=true)
     */
    protected $name;

    /**
     * @var string
     * @ORM\Column(type="string", unique=true)
     */
    protected $ssid;

    /**
     * @var string
     * @ORM\Column(type="string")
     */
    protected $encryptionType;

    /**
     * @var string
     * @ORM\Column(type="string", nullable=true)
     */
    protected $encryptionKey;

    /**
     * @var boolean
     * @ORM\Column(type="boolean")
     */
    protected $hidden = false;

    /**
     * @var boolean
     * @ORM\Column(type="boolean")
     */
    protected $autoJoin = true;

    /**
     * @var string
     * @ORM\Column(type="string")
     */
    protected $proxyType;

    /**
     * @var string
     * @ORM\Column(type="string", nullable=true)
     */
    protected $proxyHost;

    /**
     * @var integer
     * @ORM\Column(type="integer", nullable=true)
     */
    protected $proxyPort;

    /**
     * @var string
     * @ORM\Column(type="string", nullable=true)
     */
    protected $proxyUsername;

    /**
     * @var string
     * @ORM\Column(type="string", nullable=true)
     */
    protected $proxyPassword;

    /**
     * @var string
     * @ORM\Column(type="string", nullable=true)
     */
    protected $proxyPacUrl;

    /**
     * @var boolean
     * @ORM\Column(type="boolean", nullable=true)
     */
    protected $proxyPacFallbackAllowed;

    /**
     * @var boolean
     * @ORM\Column(type="boolean")
     */
    protected $hotspot = false;

    /**
     * @var \Doctrine\Common\Collections\ArrayCollection
     * @ORM\ManyToMany(targetEntity="Topalis\ConfigGroup\Entity\ConfigGroup", inversedBy="wifiConfigs")
     */
    protected $configGroups;

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->configGroups = new \Doctrine\Common\Collections\ArrayCollection();
    }

    /**
     * Get id
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return WifiConfig
     */
    public function setName($name)
    {
        $this->name = $name;

        return $this;
    }

    /**
     * Get name
     *
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set ssid
     *
     * @param string $ssid
     * @return WifiConfig
     */
    public function setSsid($ssid)
    {
        $this->ssid = $ssid;

        return $this;
    }

    /**
     * Get ssid
     *
     * @return string
     */
    public function getSsid()
    {
        return $this->ssid;
    }

    /**
     * Set encryptionType
     *
     * @param string $encryptionType
     * @return WifiConfig
     */
    public function setEncryptionType($encryptionType)
    {
        $this->encryptionType = $encryptionType;

        return $this;
    }

    /**
     * Get encryptionType
     *
     * @return string
     */
    public function getEncryptionType()
    {
        return $this->encryptionType;
    }

    /**
     * Set encryptionKey
     *
     * @param string $encryptionKey
     * @return WifiConfig
     */
    public function setEncryptionKey($encryptionKey)
    {
        $this->encryptionKey = $encryptionKey;

        return $this;
    }

    /**
     * Get encryptionKey
     *
     * @return string
     */
    public function getEncryptionKey()
    {
        return $this->encryptionKey;
    }

    /**
     * Set hidden
     *
     * @param boolean $hidden
     * @return WifiConfig
     */
    public function setHidden($hidden)
    {
        $this->hidden = $hidden;

        return $this;
    }

    /**
     * Get hidden
     *
     * @return boolean
     */
    public function isHidden()
    {
        return $this->hidden;
    }

    /**
     * Set autoJoin
     *
     * @param boolean $autoJoin
     * @return WifiConfig
     */
    public function setAutoJoin($autoJoin)
    {
        $this->autoJoin = $autoJoin;

        return $this;
    }

    /**
     * Get autoJoin
     *
     * @return boolean
     */
    public function isAutoJoin()
    {
        return $this->autoJoin;
    }

    /**
     * Set proxyType
     *
     * @param string $proxyType
     * @return WifiConfig
     */
    public function setProxyType($proxyType)
    {
        $this->proxyType = $proxyType;

        return $this;
    }

    /**
     * Get proxyType
     *
     * @return string
     */
    public function getProxyType()
    {
        return $this->proxyType;
    }

    /**
     * Set proxyHost
     *
     * @param string $proxyHost
     * @return WifiConfig
     */
    public function setProxyHost($proxyHost)
    {
        $this->proxyHost = $proxyHost;

        return $this;
    }

    /**
     * Get proxyHost
     *
     * @return string
     */
    public function getProxyHost()
    {
        return $this->proxyHost;
    }

    /**
     * Set proxyPort
     *
     * @param integer $proxyPort
     * @return WifiConfig
     */
    public function setProxyPort($proxyPort)
    {
        $this->proxyPort = $proxyPort;

        return $this;
    }

    /**
     * Get proxyPort
     *
     * @return integer
     */
    public function getProxyPort()
    {
        return $this->proxyPort;
    }

    /**
     * Set proxyUsername
     *
     * @param string $proxyUsername
     * @return WifiConfig
     */
    public function setProxyUsername($proxyUsername)
    {
        $this->proxyUsername = $proxyUsername;

        return $this;
    }

    /**
     * Get proxyUsername
     *
     * @return string
     */
    public function getProxyUsername()
    {
        return $this->proxyUsername;
    }

    /**
     * Set proxyPassword
     *
     * @param string $proxyPassword
     * @return WifiConfig
     */
    public function setProxyPassword($proxyPassword)
    {
        $this->proxyPassword = $proxyPassword;

        return $this;
    }

    /**
     * Get proxyPassword
     *
     * @return string
     */
    public function getProxyPassword()
    {
        return $this->proxyPassword;
    }

    /**
     * Set proxyPacUrl
     *
     * @param string $proxyPacUrl
     * @return WifiConfig
     */
    public function setProxyPacUrl($proxyPacUrl)
    {
        $this->proxyPacUrl = $proxyPacUrl;

        return $this;
    }

    /**
     * Get proxyPacUrl
     *
     * @return string
     */
    public function getProxyPacUrl()
    {
        return $this->proxyPacUrl;
    }

    /**
     * Set proxyPacFallbackAllowed
     *
     * @param boolean $proxyPacFallbackAllowed
     * @return WifiConfig
     */
    public function setProxyPacFallbackAllowed($proxyPacFallbackAllowed)
    {
        $this->proxyPacFallbackAllowed = $proxyPacFallbackAllowed;

        return $this;
    }

    /**
     * Get proxyPacFallbackAllowed
     *
     * @return boolean
     */
    public function isProxyPacFallbackAllowed()
    {
        return $this->proxyPacFallbackAllowed;
    }

    /**
     * Set hotspot
     *
     * @param boolean $hotspot
     * @return WifiConfig
     */
    public function setHotspot($hotspot)
    {
        $this->hotspot = $hotspot;

        return $this;
    }

    /**
     * Get hotspot
     *
     * @return boolean
     */
    public function isHotspot()
    {
        return $this->hotspot;
    }

    /**
     * Add configGroups
     *
     * @param \Topalis\ConfigGroup\Entity\ConfigGroup $configGroup
     * @return WifiConfig
     */
    public function addConfigGroup(\Topalis\ConfigGroup\Entity\ConfigGroup $configGroup)
    {
        if (!$this->configGroups->contains($configGroup)) {
            $this->configGroups[] = $configGroup;
            $configGroup->addWifiConfig($this);
        }

        return $this;
    }

    /**
     * Remove configGroup
     *
     * @param \Topalis\ConfigGroup\Entity\ConfigGroup $configGroup
     */
    public function removeConfigGroup(\Topalis\ConfigGroup\Entity\ConfigGroup $configGroup)
    {
        if ($this->configGroups->removeElement($configGroup)) {
            $configGroup->removeWifiConfig($this);
        }
    }

    /**
     * Get configGroups
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getConfigGroups()
    {
        return $this->configGroups;
    }

    /**
     * @see \Serializable::serialize()
     */
    public function serialize()
    {
        return serialize(array(
            $this->id,
        ));
    }

    /**
     * @param string $serialized The value returned by serialize().
     * @see \Serializable::unserialize()
     */
    public function unserialize($serialized)
    {
        list ($this->id) = unserialize($serialized);
    }
}
