<?php
namespace Topalis\WinPhone\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * Contains a SyncML command for a device and related information.
 *
 * @ORM\Table(name="mswlanconfigs",
 *     uniqueConstraints={@ORM\UniqueConstraint(columns={"ssid", "configgroup_id"})})
 * @ORM\Entity
 */
class MSWlanConfig
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="bigint", nullable=false, options={"unsigned"=true})
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    protected $id;

    /**
     *
     * @var string
     *
     * @ORM\Column(name="ssid", type="string", length=32, nullable=false)
     */
    protected $ssid;

    /**
     * The config group the WLAN config belongs to.
     *
     * @var \Topalis\ConfigGroup\Entity\ConfigGroup
     *
     * @ORM\ManyToOne(targetEntity="Topalis\ConfigGroup\Entity\ConfigGroup", inversedBy="msWlanConfigs",
     *     cascade={"persist"})
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="configgroup_id", referencedColumnName="id", nullable=false)
     * })
     */
    protected $configGroup;

    /**
     *
     * @var string
     *
     * @ORM\Column(name="profile", type="text", length=65532, nullable=true)
     */
    protected $profile;

    /**
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     *
     * @param integer $id
     */
    public function setId($id)
    {
        $this->id = $id;
    }

    /**
     * @return string
     */
    public function getSsid()
    {
        return $this->ssid;
    }

    /**
     *
     * @param string $ssid
     */
    public function setSsid($ssid)
    {
        $this->ssid = $ssid;
    }

    /**
     *
     * @return \Topalis\ConfigGroup\Entity\ConfigGroup
     */
    public function getConfigGroup()
    {
        return $this->configGroup;
    }

    /**
     *
     * @param \Topalis\ConfigGroup\Entity\ConfigGroup $configGroup
     */
    public function setConfigGroup(\Topalis\ConfigGroup\Entity\ConfigGroup $configGroup)
    {
        if ($this->configGroup == $configGroup) {
            return;
        }

        $this->configGroup = $configGroup;
        $configGroup->addMSWlanConfig($this);
    }

    /**
     *
     * @return string
     */
    public function getProfile()
    {
        return $this->profile;
    }

    /**
     *
     * @param string $profile
     */
    public function setProfile($profile)
    {
        $this->profile = $profile;
    }
}
