<?php
namespace Topalis\WinPhone\Entity;

use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;

/**
 * Provides status information about a configuration service provider on a
 * device.
 * @ORM\Table(name="syncml_cspstatus",
 *   uniqueConstraints={@ORM\UniqueConstraint(columns={"device_id", "locuriprefix"})})
 * @ORM\Entity
 */
class SyncMLCSPStatus
{

    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="bigint", nullable=false, options={"unsigned"=true})
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    protected $id;

    /**
     * @var \Topalis\Device\Entity\Device
     *
     * @ORM\ManyToOne(targetEntity="Topalis\Device\Entity\Device")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="device_id", referencedColumnName="id", nullable=false, onDelete="CASCADE")
     * })
     */
    protected $device;

    /**
     * @var string
     *
     * @ORM\Column(name="locuriprefix", type="string", length=255, nullable=true)
     */
    protected $locURIPrefix;

    /**
     * @var boolean
     *
     * @ORM\Column(name="installed", type="boolean", nullable=false)
     */
    protected $installed = false;

    /**
     * @var string
     *
     * @ORM\Column(name="pendingoperation", type="string", length=64, nullable=true)
     */
    protected $pendingOperation;

    /**
     * @var \Doctrine\Common\Collections\ArrayCollection
     *
     * @ORM\OneToMany(targetEntity="Topalis\WinPhone\Entity\SyncMLCommand", mappedBy="cspStatus", cascade={"all"})
     * @ORM\OrderBy({"id" = "ASC"})
     */
    protected $commands;

    public function __construct()
    {
        $this->commands = new ArrayCollection();
    }

    /**
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     *
     * @param integer $id
     */
    public function setId($id)
    {
        $this->id = $id;
        return $this;
    }

    /**
     *
     * @return \Topalis\Device\Entity\Device
     */
    public function getDevice()
    {
        return $this->device;
    }

    /**
     *
     * @param \Topalis\Device\Entity\Device $device
     */
    public function setDevice(\Topalis\Device\Entity\Device $device)
    {
        $this->device = $device;
        return $this;
    }

    /**
     *
     * @return string
     */
    public function getLocURIPrefix()
    {
        return $this->locURIPrefix;
    }

    /**
     *
     * @param string $locURIPrefix
     */
    public function setLocURIPrefix($locURIPrefix)
    {
        $this->locURIPrefix = $locURIPrefix;
        return $this;
    }

    /**
     * The installation status is required to now if we have to add or replace
     * a CSP.
     *
     * @return boolean
     */
    public function isInstalled()
    {
        return $this->installed;
    }

    /**
     *
     * @param boolean $installed
     */
    public function setInstalled($installed)
    {
        $this->installed = $installed;
        return $this;
    }

    /**
     *
     * @return string Pending operation such as "Add", "Replace", or "Delete"
     */
    public function getPendingOperation()
    {
        return $this->pendingOperation;
    }

    /**
     *
     * @param string $pendingOperation Pending operation such as "Add",
     *     "Replace", or "Delete"
     */
    public function setPendingOperation($pendingOperation)
    {
        $this->pendingOperation = $pendingOperation;
        return $this;
    }

    /**
     *
     * @return \Doctrine\Common\Collections\ArrayCollection
     */
    public function getCommands()
    {
        return $this->commands;
    }

    /**
     *
     * @param \Topalis\WinPhone\Entity\SyncMLCommand $command
     */
    public function addCommand(\Topalis\WinPhone\Entity\SyncMLCommand $command)
    {
        if ($this->commands->contains($command)) {
            return;
        }

        $this->commands->add($command);
        $command->setCSPStatus($this);

        return $this;
    }
}
