<?php
namespace Topalis\WinPhone\Entity;

use Topalis\Database\EntityManager;
use Doctrine\Common\Persistence\ObjectManager;

/**
 * Entity manager for SyncMLCSPStatus.
 *
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class SyncMLCSPStatusEntityManager extends EntityManager
{
    public function __construct(ObjectManager $em)
    {
        parent::__construct($em, 'Topalis\WinPhone\Entity\SyncMLCSPStatus');
    }

    /**
     *
     * @param \Topalis\Device\Entity\Device $device
     * @param string $locURIPrefixStart
     * @param boolean $installedOnly Flag to specifiy if only SyncMLCSPStatus
     *     are returned that are marked as installed. (Default: true)
     * @return array Array with all SyncMLCSPStatus for the specified device
     *     that have a locURIPrefix that start with $locURIPrefixStart
     */
    public function getForDevice(\Topalis\Device\Entity\Device $device, $locURIPrefixStart, $installedOnly = true)
    {
        $qb = $this->createQueryBuilder("c")
            ->where("c.device = :device")
            ->andWhere("c.locURIPrefix LIKE :locURIPrefixStart")
            ->setParameter("device", $device)
            ->setParameter("locURIPrefixStart", $locURIPrefixStart . "%");
        if ($installedOnly) {
            $qb->andWhere("c.installed = 1");
        }
        return $qb->getQuery()->getResult();
    }

    /**
     *
     * @param \Topalis\Device\Entity\Device $device
     * @param string $locURIPrefix
     * @return \Topalis\WinPhone\Entity\SyncMLCSPStatus|NULL The entity for the
     *     specified device with the specified locURIPrefix, or null if no such
     *     entity exists.
     */
    public function getOneOrNullForDevice(\Topalis\Device\Entity\Device $device, $locURIPrefix)
    {
        return $this->createQueryBuilder("c")
            ->where("c.device = :device")
            ->andWhere("c.locURIPrefix = :locURIPrefix")
            ->setParameter("device", $device)
            ->setParameter("locURIPrefix", $locURIPrefix)
            ->getQuery()->getOneOrNullResult();
    }

    /**
     * Refreshes the mapped entities with the specified device.
     *
     * @param \Topalis\Device\Entity\Device $device
     */
    public function refreshForDevice(\Topalis\Device\Entity\Device $device)
    {
        $identityMap = $this->em->getUnitOfWork()->getIdentityMap();
        if (!isset($identityMap[$this->class])) {
            // nothing to refresh
            return;
        }

        foreach ($identityMap[$this->class] as $cspStatus) {
            if ($cspStatus->getDevice() == $device) {
                $this->refresh($cspStatus);
            }
        }
    }
}
