<?php
namespace Topalis\WinPhone\Entity;

use Doctrine\ORM\Mapping as ORM;
use Topalis\Device\MDM\MdmCommandInterface;

/**
 * Contains a SyncML command for a device and related information.
 *
 * @ORM\Table(name="syncml_commands")
 * @ORM\Entity
 */
class SyncMLCommand implements MdmCommandInterface
{
    const STATUS_NEW = "New";
    const STATUS_WAITING = "Waiting";
    const STATUS_CANCELED = "Canceled";
    const STATUS_OK = "OK";
    const STATUS_ERROR = "Error";

    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="bigint", nullable=false, options={"unsigned"=true})
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    protected $id;

    /**
     * The administrator that generated the MDM command.
     * @var \Topalis\Admin\Entity\Admin
     *
     * @ORM\ManyToOne(targetEntity="Topalis\Admin\Entity\Admin")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="admin_id", referencedColumnName="id", onDelete="SET NULL")
     * })
     */
    protected $admin;

    /**
     * The device the MDM command is bound for.
     * @var \Topalis\Device\Entity\Device
     *
     * @ORM\ManyToOne(targetEntity="Topalis\Device\Entity\Device", inversedBy="syncMLCommands")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="device_id", referencedColumnName="id", nullable=false, onDelete="CASCADE")
     * })
     */
    protected $device;

    /**
     * @var integer
     *
     * @ORM\Column(name="createtime", type="integer", nullable=false,
     *     options={"unsigned"=true, "comment"="The creation time of the command"})
     */
    protected $createTime;

    /**
     *
     * @var string
     *
     * @ORM\Column(name="command", type="text", length=16777215, nullable=true,
     *     options={"comment"="The SyncML command"})
     */
    protected $command;

    /**
     * @var string
     *
     * @ORM\Column(name="comandtype", type="string", length=64, nullable=false,
     *     options={"comment"="The type of the SyncML command"})
     */
    protected $commandType;

    /**
     * @var string
     *
     * @ORM\Column(name="defaultcomandtype", type="string", length=64, nullable=true,
     *     options={"comment"="The default command type of command groups"})
     */
    protected $defaultCommandType;

    /**
     * @var string
     *
     * @ORM\Column(name="status", type="string", length=64, nullable=false,
     *     options={"default"=SyncMLCommand::STATUS_NEW, "comment"="The current status of the command"})
     */
    protected $status = self::STATUS_NEW;

    /**
     * @var integer
     *
     * @ORM\Column(name="sentcount", type="integer", nullable=false,
     *     options={"unsigned"=true, "comment"="The number of times the command has been sent"})
     */
    protected $sentCount = 0;

    /**
     * @var integer
     *
     * @ORM\Column(name="copy_count", type="smallint", nullable=false, options={"unsigned"=true})
     */
    protected $copyCount = 0;

    /**
     * @var integer
     *
     * @ORM\Column(name="responsetime", type="integer", nullable=true,
     *     options={"unsigned"=true, "comment"="The time of the response"})
     */
    protected $responseTime;

    /**
     * @var string
     *
     * @ORM\Column(name="statuscode", type="string", length=10, nullable=true,
     *     options={"comment"="The status code returned by the client"})
     */
    protected $statusCode;

    /**
     *
     * @var array
     *
     * @ORM\Column(name="statuscodes", type="json_array_string", length=1000, nullable=true,
     *     options={"comment"="The status codes for commands in a command group returned by the client"})
     */
    protected $statusCodes;

    /**
     * @var \Topalis\WinPhone\Entity\SyncMLCSPStatus
     *
     * @ORM\ManyToOne(targetEntity="Topalis\WinPhone\Entity\SyncMLCSPStatus", inversedBy="commands", cascade={"all"})
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="cspstatus_id", referencedColumnName="id")
     * })
     */
    protected $cspStatus;

    /**
     * @var string
     *
     * @ORM\Column(name="info", type="string", length=255, nullable=true)
     */
    protected $info;

    /**
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     *
     * @param integer $id
     */
    public function setId($id)
    {
        $this->id = $id;
        return $this;
    }

    /**
     *
     * @return \Topalis\Admin\Entity\Admin
     */
    public function getAdmin()
    {
        return $this->admin;
    }

    /**
     *
     * @param \Topalis\Admin\Entity\Admin $admin
     */
    public function setAdmin(\Topalis\Admin\Entity\Admin $admin)
    {
        $this->admin = $admin;
        return $this;
    }

    /**
     *
     * @return \Topalis\Device\Entity\Device
     */
    public function getDevice()
    {
        return $this->device;
    }

    /**
     *
     * @param \Topalis\Device\Entity\Device $device
     */
    public function setDevice(\Topalis\Device\Entity\Device $device)
    {
        $this->device = $device;

        return $this;
    }

    /**
     *
     * @return integer
     */
    public function getCreateTime()
    {
        return $this->createTime;
    }

    /**
     *
     * @param integer $createTime
     */
    public function setCreateTime($createTime)
    {
        $this->createTime = $createTime;
        return $this;
    }

    /**
     *
     * @return string
     */
    public function getCommand()
    {
        return $this->command;
    }

    /**
     *
     * @param string $command
     */
    public function setCommand($command)
    {
        $this->command = $command;
        return $this;
    }

    /**
     *
     * @return string
     */
    public function getCommandType()
    {
        return $this->commandType;
    }

    /**
     *
     * @param string $commandType
     */
    public function setCommandType($commandType)
    {
        $this->commandType = $commandType;
        return $this;
    }

    public function getType()
    {
        return $this->getCommandType();
    }

    /**
     *
     * @return string
     */
    public function getDefaultCommandType()
    {
        return $this->defaultCommandType;
    }

    /**
     *
     * @param string $defaultDommandType
     */
    public function setDefaultCommandType($defaultDommandType)
    {
        $this->defaultCommandType = $defaultDommandType;
        return $this;
    }

    /**
     *
     * @return string
     */
    public function getStatus()
    {
        return $this->status;
    }

    /**
     *
     * @param string $status
     */
    public function setStatus($status)
    {
        $this->status = $status;
        return $this;
    }

    /**
     *
     * @return integer
     */
    public function getSentCount()
    {
        return $this->sentCount;
    }

    /**
     *
     * @param integer $sentCount
     */
    public function setSentCount($sentCount)
    {
        $this->sentCount = $sentCount;
    }

    public function getCopyCount()
    {
        return $this->copyCount;
    }

    public function incCopyCount()
    {
        $this->copyCount++;
        return $this;
    }

    public function setCopyCount($copyCount)
    {
        $this->copyCount = $copyCount;
        return $this;
    }

    /**
     *
     * @return integer
     */
    public function getResponseTime()
    {
        return $this->responseTime;
    }

    /**
     *
     * @param integer $responseTime
     */
    public function setResponseTime($responseTime)
    {
        $this->responseTime = $responseTime;
        return $this;
    }

    /**
     *
     * @return string
     */
    public function getStatusCode()
    {
        return $this->statusCode;
    }

    /**
     *
     * @param string $statusCode
     */
    public function setStatusCode($statusCode)
    {
        $this->statusCode = $statusCode;
        return $this;
    }

    /**
     *
     * @return array Associative array with pairs of CmdID and status code for
     *     sub-commands of a command group.
     */
    public function getStatusCodes()
    {
        return $this->statusCodes;
    }

    /**
     *
     * @param array $statusCodes Associative array with pairs of CmdID and
     *     status code for sub-commands of a command group.
     */
    public function setStatusCodes(array $statusCodes)
    {
        $this->statusCodes = $statusCodes;
        return $this;
    }

    /**
     *
     * @return \Topalis\WinPhone\Entity\SyncMLCSPStatus
     */
    public function getCSPStatus()
    {
        return $this->cspStatus;
    }

    public function setCSPStatus(\Topalis\WinPhone\Entity\SyncMLCSPStatus $cspStatus)
    {
        if ($this->cspStatus === $cspStatus) {
            return;
        }

        $this->cspStatus = $cspStatus;
        $cspStatus->addCommand($this);

        return $this;
    }

    /**
     * @return string Information about the command.
     */
    public function getInfo()
    {
        return $this->info;
    }

    /**
     * Sets the information about the command.
     *
     * @param string $info The command information to set
     *
     * @return SyncMLCommand $this
     */
    public function setInfo($info)
    {
        $this->info = $info;

        return $this;
    }
}
