<?php
namespace Topalis\WinPhone\Event\OMA\SyncML;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Topalis\Kernel\AbstractAuralisService;
use Topalis\Device\Entity\Device;

class UserUnenrollSubscriber extends AbstractAuralisService implements EventSubscriberInterface
{
    /**
     * @return \Topalis\Certificate\CertificateManager
     */
    private function getCertificateManager()
    {
        return $this->container->get("certificate.manager");
    }

    /**
     * @return \Topalis\Device\Entity\DeviceEntityManager
     */
    private function getDeviceEntityManager()
    {
        return $this->container->get("device.entity.manager.device");
    }

    /**
     * @return \Topalis\Mail\Mailer
     */
    private function getMailer()
    {
        return $this->container->get("mailer");
    }

    /**
     * @return \Topalis\WinPhone\OMA\SyncML\SyncMLAdmin
     */
    private function getSyncMLAdmin()
    {
        return $this->container->get("winphone.oma.syncml.admin");
    }

    public static function getSubscribedEvents()
    {
        return array(
            SyncMLEvents::USER_UNENROLL => "onUserUnenroll"
        );
    }

    public function onUserUnenroll(SyncMLEvent $event)
    {
        $device = $event->getDevice();
        $this->getLogger()->info("Device with id " . $device->getCombinedId() . " unenrolls");
        try {
            $mailer = $this->getMailer();
            if ($mailer->isConfigured()) {
                $subject = $this->tr("admin.winphone.syncml.userUnenrollSubject");
                // user might be deleted
                $user = $device->getUser() ? $device->getUser()->getLogin() : null;
                $deviceName = $device->getName();
                if (strlen($device->getComment() > 0)) {
                    $deviceName .= " (" . $device->getComment() . ")";
                }
                if ($user) {
                    $text = $this->tr("admin.winphone.syncml.userUnenrollText.user", array(
                        "%user%" => $user,
                        "%device%" => $deviceName
                    ));
                } else {
                    $text = $this->tr("admin.winphone.syncml.userUnenrollText.woUser", array(
                        "%device%" => $deviceName
                    ));
                }
                $mailer->sendAdminMessage($subject, $text);
            }
        } catch (\Exception $e) {
            $this->getLogger()->error("Sending unenrollment message failed", array("exception" => $e));
        }
        try {
            $device->setWipeStatus(Device::WIPE_EXECUTED);
            $this->removeDeviceFromMdm($device);
        } catch (\Exception $e) {
            $msg = "Error finishing unenrollment of device with id " . $device->getCombinedId();
            $this->getLogger()->error($msg, array("exception" => $e));
        }
    }

    protected function removeDeviceFromMdm(Device $device)
    {
        $device->setDisabled(true);
        $device->setOmaAuthAppSrv(null);
        $device->setOmaAuthClient(null);
        $device->setOmaAuthNonce(null);
        $this->getDeviceEntityManager()->save($device);
        $this->getSyncMLAdmin()->cancelRemainingCommands($device);
        $this->getCertificateManager()->setDeviceCertsUnused($device);
    }
}
