<?php
namespace Topalis\WinPhone\OMA\Provisioning;

class ApplicationProvider extends ConfigurationServiceProvider
{
    public function __construct()
    {
        parent::__construct("APPLICATION");
    }

    /**
     * @return AppAddrCharacteristic|NULL
     */
    public function getAppAddr()
    {
        return $this->getFirstCharacteristic("APPADDR");
    }

    public function setAppAddr(AppAddrCharacteristic $appAddr = null)
    {
        $this->setCharacteristic("APPADDR", $appAddr);
    }

    public function getAppId()
    {
        return $this->getParmValue("APPID");
    }

    public function getAppAuth($authLevel)
    {
        $characteristics = $this->getCharacteristics("APPAUTH");
        foreach ($characteristics as $characteristic) {
            if ($characteristic->getAAuthLevel() == $authLevel) {
                return $characteristic;
            }
        }

        return null;
    }

    public function removeAppAuth($authLevel)
    {
        $appAuth = $this->getAppAuth($authLevel);
        if ($appAuth) {
            $this->removeCharacteristic($appAuth);
        }
    }

    public function setAppAuth(AppAuthCharacteristic $appAuth)
    {
        $existingAppAuth = $this->getAppAuth($appAuth->getAAuthLevel());
        if ($existingAppAuth) {
            $this->removeCharacteristic($existingAppAuth);
        }
        $this->addCharacteristic($appAuth);
    }

    public function setAppId($appId)
    {
        $this->setParmValue("APPID", $appId);
    }

    public function isBackCompatRetryDisabled()
    {
        return $this->getParm("BACKCOMPATRETRYDISABLED") !== null;
    }

    public function setBackCompatRetryDisabled($backCompatRetryDisabled)
    {
        if ($backCompatRetryDisabled) {
            $this->addParm(new Parm("BACKCOMPATRETRYDISABLED"));
        } else {
            $this->removeParm("BACKCOMPATRETRYDISABLED");
        }
    }

    public function getConnRetryFreq()
    {
        return $this->getParmValue("CONNRETRYFREQ");
    }

    public function setConnRetryFreq($connRetryFreq)
    {
        $this->setParmValue("CONNRETRYFREQ", $connRetryFreq);
    }

    public function getDefaultEncoding()
    {
        return $this->getParmValue("DEFAULTENCODING");
    }

    public function setDefaultEncoding($defaultEncoding)
    {
        $this->setParmValue("DEFAULTENCODING", $defaultEncoding);
    }

    /**
     * The INIT parameter is used to indicate that the management server wants
     * the client to initiate a management session immediately after settings
     * approval.
     *
     * @return boolean
     */
    public function isInit()
    {
        return $this->getParmValue("INIT") !== null;
    }

    /**
     * The INIT parameter is used to indicate that the management server wants
     * the client to initiate a management session immediately after settings
     * approval.
     *
     * @param boolean $init
     */
    public function setInit($init)
    {
        if ($init) {
            $this->addParm(new Parm("INIT"));
        } else {
            $this->removeParm("INIT");
        }
    }

    public function getInitialBackOffTime()
    {
        return $this->getParmValue("INITIALBACKOFFTIME");
    }

    public function setInitialBackOffTime($initialBackOffTime)
    {
        $this->setParmValue("INITIALBACKOFFTIME", $initialBackOffTime);
    }

    public function getMaxBackOffTime()
    {
        return $this->getParmValue("MAXBACKOFFTIME");
    }

    public function setMaxBackOffTime($maxBackOffTime)
    {
        $this->setParmValue("MAXBACKOFFTIME", $maxBackOffTime);
    }

    public function getName()
    {
        return $this->getParmValue("NAME");
    }

    public function setName($name)
    {
        $this->setParmValue("NAME", $name);
    }

    public function getProtoVer()
    {
        return $this->getParmValue("PROTOVER");
    }

    public function setProtoVer($protoVer)
    {
        $this->setParmValue("PROTOVER", $protoVer);
    }

    public function getProviderId()
    {
        return $this->getParmValue("PROVIDER-ID");
    }

    public function setProviderId($providerId)
    {
        $this->setParmValue("PROVIDER-ID", $providerId);
    }

    public function getRole()
    {
        return $this->getParmValue("ROLE");
    }

    public function setRole($role)
    {
        $this->setParmValue("ROLE", $role);
    }

    public function getSslClientCertSearchCriteria()
    {
        return $this->getParmValue("SSLCLIENTCERTSEARCHCRITERIA");
    }

    public function setSslClientCertSearchCriteria($sslClientCertSearchCriteria)
    {
        $this->setParmValue("SSLCLIENTCERTSEARCHCRITERIA", $sslClientCertSearchCriteria);
    }

    public function getToNapId()
    {
        return $this->getParmValue("TO-NAPID");
    }

    public function setToNapId($toNapId)
    {
        $this->setParmValue("TO-NAPID", $toNapId);
    }

    public function getUseHwDevId()
    {
        return $this->getParmValue("USEHWDEVID");
    }

    public function setUseHwDevId($useHwDevId)
    {
        $this->setParmValue("USEHWDEVID", $useHwDevId);
    }
}
