<?php
namespace Topalis\WinPhone\OMA\Provisioning;

use Topalis\Util\StringUtil;

class Parm
{

    /**
     *
     * @var string
     */
    private $name;

    /**
     *
     * @var string
     */
    private $value;

    /**
     * Possible values: integer|string|float|boolean|binary|multiplestring
     *
     * @var string
     */
    private $datatype;

    /**
     *
     * @var string
     */
    private $semanticType;

    /**
     *
     * @var string
     */
    private $maxvalue;

    /**
     *
     * @var string
     */
    private $minvalue;

    /**
     *
     * @var string
     */
    private $maxlength;

    /**
     *
     * @var string
     */
    private $options;

    /**
     *
     * @var boolean
     */
    private $multiple;

    /**
     * Possible values: 1|2|3
     *
     * @var integer
     */
    private $rwAccess;

    /**
     *
     * @var string
     */
    private $label;

    /**
     *
     * @var boolean
     */
    private $nooverwrite;

    /**
     *
     * @var string
     */
    private $accessRole;

    /**
     *
     * @var string
     */
    private $translation;

    public static function fromDOMElement(\DOMElement $elem)
    {
        if ($elem->tagName != "parm") {
            throw new \InvalidArgumentException("The tag name is not 'parm'");
        }

        $name = $elem->getAttribute("name");
        if (!$name) {
            throw new \InvalidArgumentException("Attribute 'name' is missing");
        }

        $parm = new Parm($name);

        foreach ($elem->attributes as $attr) {
            switch ($attr->nodeName) {
                case "value":
                    $parm->setValue($attr->nodeValue);
                    break;
                case "datatype":
                    $parm->setDatatype($attr->nodeValue);
                    break;
                case "semantic-type":
                    $parm->setSemanticType($attr->nodeValue);
                    break;
                case "maxvalue":
                    $parm->setMaxvalue($attr->nodeValue);
                    break;
                case "minvalue":
                    $parm->setMinvalue($attr->nodeValue);
                    break;
                case "options":
                    $parm->setOptions($attr->nodeValue);
                    break;
                case "multiple":
                    $parm->setMultiple($attr->nodeValue);
                    break;
                case "rw-access":
                    $parm->setRwAccess($attr->nodeValue);
                    break;
                case "label":
                    $parm->setLabel($attr->nodeValue);
                    break;
                case "nooverwrite":
                    $parm->setNooverwrite($attr->nodeValue);
                    break;
                case "access-role":
                    $parm->setAccessRole($attr->nodeValue);
                    break;
                case "translation":
                    $parm->setTranslation($attr->nodeValue);
                    break;
            }
        }

        return $parm;
    }

    /**
     * @param string $name
     * @param string $value
     * @param string $datatype
     */
    public function __construct($name, $value = null, $datatype = null)
    {
        $this->setName($name);
        $this->setValue($value);
        $this->setDatatype($datatype);
    }

    /**
     *
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     *
     * @param string $name
     */
    public function setName($name)
    {
        $this->name = $name;
    }

    /**
     *
     * @return string
     */
    public function getValue()
    {
        return $this->value;
    }

    /**
     *
     * @param string $value
     */
    public function setValue($value)
    {
        $this->value = $value;
    }

    /**
     *
     * @return string
     */
    public function getDatatype()
    {
        return $this->datatype;
    }

    /**
     *
     * @param string|NULL $datatype integer, string, float, boolean, binary, or
     *     multiplestring
     */
    public function setDatatype($datatype)
    {
        $this->datatype = $datatype;
    }

    /**
     *
     * @return string
     */
    public function getSemanticType()
    {
        return $this->semanticType;
    }

    /**
     *
     * @param string $semanticType
     */
    public function setSemanticType($semanticType)
    {
        $this->semanticType = $semanticType;
    }

    /**
     *
     * @return string
     */
    public function getMaxvalue()
    {
        return $this->maxvalue;
    }

    /**
     *
     * @param string $maxvalue
     */
    public function setMaxvalue($maxvalue)
    {
        $this->maxvalue = $maxvalue;
    }

    /**
     *
     * @return string
     */
    public function getMinvalue()
    {
        return $this->minvalue;
    }

    /**
     *
     * @param string $minvalue
     */
    public function setMinvalue($minvalue)
    {
        $this->minvalue = $minvalue;
    }

    /**
     *
     * @return string
     */
    public function getMaxlength()
    {
        return $this->maxlength;
    }

    /**
     *
     * @param string $maxlength
     */
    public function setMaxlength($maxlength)
    {
        $this->maxlength = $maxlength;
    }

    /**
     *
     * @return string
     */
    public function getOptions()
    {
        return $this->options;
    }

    /**
     *
     * @param string $options
     */
    public function setOptions($options)
    {
        $this->options = $options;
    }

    /**
     *
     * @return boolean
     */
    public function isMultiple()
    {
        return $this->multiple;
    }

    /**
     *
     * @param boolean $multiple
     */
    public function setMultiple($multiple)
    {
        if (is_string($multiple)) {
            $multiple = StringUtil::strtobool($multiple);
        }
        $this->multiple = $multiple;
    }

    /**
     *
     * @return integer
     */
    public function getRwAccess()
    {
        return $this->rwAccess;
    }

    /**
     *
     * @param integer|NULL $rwAccess 1, 2, or 3
     */
    public function setRwAccess($rwAccess)
    {
        $this->rwAccess = $rwAccess;
    }

    /**
     *
     * @return string
     */
    public function getLabel()
    {
        return $this->label;
    }

    /**
     *
     * @param string $label
     */
    public function setLabel($label)
    {
        $this->label = $label;
    }

    /**
     *
     * @return boolean
     */
    public function isNooverwrite()
    {
        return $this->nooverwrite;
    }

    /**
     *
     * @param boolean $nooverwrite
     */
    public function setNooverwrite($nooverwrite)
    {
        if (is_string($nooverwrite)) {
            $nooverwrite = StringUtil::strtobool($nooverwrite);
        }
        $this->nooverwrite = $nooverwrite;
    }

    /**
     *
     * @return string
     */
    public function getAccessRole()
    {
        return $this->accessRole;
    }

    /**
     *
     * @param string $accessRole
     */
    public function setAccessRole($accessRole)
    {
        $this->accessRole = $accessRole;
    }

    /**
     *
     * @return string
     */
    public function getTranslation()
    {
        return $this->translation;
    }

    /**
     *
     * @param string $translation
     */
    public function setTranslation($translation)
    {
        $this->translation = $translation;
    }

    /**
     * Creates a DOM element for the object and appends it to the specified
     * node.
     *
     * @param \DOMNode $node The node to append the element to.
     * @return \DOMElement The appended element.
     */
    public function appendToDOM(\DOMNode $node)
    {
        $doc = $node->ownerDocument;
        $elem = $doc->createElement("parm");
        $node->appendChild($elem);

        $elem->setAttribute("name", $this->getName());

        if ($this->getValue() !== null) {
            $elem->setAttribute("value", $this->getValue());
        }

        if ($this->getDatatype() !== null) {
            $elem->setAttribute("datatype", $this->getDatatype());
        }

        if ($this->getSemanticType() !== null) {
            $elem->setAttribute("semantic-type", $this->getSemanticType());
        }

        if ($this->getMaxvalue() !== null) {
            $elem->setAttribute("maxvalue", $this->getMaxvalue());
        }

        if ($this->getMinvalue() !== null) {
            $elem->setAttribute("minvalue", $this->getMinvalue());
        }

        if ($this->getOptions() !== null) {
            $elem->setAttribute("options", $this->getOptions());
        }

        if ($this->isMultiple() !== null) {
            $elem->setAttribute("multiple", $this->isMultiple() ? "1" : "0");
        }

        if ($this->getRwAccess() !== null) {
            $elem->setAttribute("rw-access", $this->getRwAccess());
        }

        if ($this->getLabel() !== null) {
            $elem->setAttribute("label", $this->getLabel());
        }

        if ($this->isNooverwrite() !== null) {
            $elem->setAttribute("nooverwrite", $this->isNooverwrite() ? "1" : "0");
        }

        if ($this->getAccessRole() !== null) {
            $elem->setAttribute("access-role", $this->getAccessRole());
        }

        if ($this->getTranslation() !== null) {
            $elem->setAttribute("translation", $this->getTranslation());
        }

        return $elem;
    }
}
