<?php
namespace Topalis\WinPhone\OMA\SyncML\Entity;

abstract class AbstractCommandGroup extends AbstractCommand
{
    /**
     *
     * @var array
     */
    protected $commands = array();

    /**
     * Sets the CmdId of the command group and its child commands. Each child
     * command will get a CmdID in this form: CmdID_i with i as an ascending
     * integer starting with 0.
     *
     * @param string $cmdID The CmdID to set.
     *
     * @return $this
     */
    public function setCmdIDRecursive($cmdID)
    {
        $this->setCmdID($cmdID);
        $i = 0;
        foreach ($this->getCommands() as $command) {
            $command->setCmdID($cmdID . "_" . ($i++));
        }

        return $this;
    }

    /**
     *
     * @param AbstractCommand $command
     */
    public function addCommand(AbstractCommand $command)
    {
        $this->commands[] = $command;
        return $this;
    }

    /**
     *
     * @return array
     */
    public function getCommands()
    {
        return $this->commands;
    }

    /**
     *
     * @param array $commands
     */
    public function setCommands(array $commands)
    {
        $this->commands = $commands;
        return $this;
    }

    public function addAlert(Alert $alert)
    {
        $this->addCommand($alert);
    }

    public function addAtomic(Atomic $atomic)
    {
        $this->addCommand($atomic);
    }

    public function addExec(Exec $exec)
    {
        $this->addCommand($exec);
    }

    public function addGet(Get $get)
    {
        $this->addCommand($get);
    }

    public function addPut(Put $put)
    {
        $this->addCommand($put);
    }

    public function addSearch(Search $search)
    {
        $this->addCommand($search);
    }

    public function addSequence(Sequence $sequence)
    {
        $this->addCommand($sequence);
    }

    public function addStatus(Status $status)
    {
        $this->addCommand($status);
    }

    public function addSync(Sync $sync)
    {
        $this->addCommand($sync);
    }

    public function addAdd(Add $add)
    {
        $this->addCommand($add);
    }

    public function addMove(Move $move)
    {
        $this->addCommand($move);
    }

    public function addReplace(Replace $replace)
    {
        $this->addCommand($replace);
    }

    // @codingStandardsIgnoreStart
    // ignore rule Generic.PHP.ForbiddenFunctions.FoundWithAlternative
    public function addDelete(Delete $delete)
    {
        $this->addCommand($delete);
    }
    // @codingStandardsIgnoreEnd

    /**
     * Counts the different types of commands.
     *
     * @return array Array with pairs of command type and count.
     */
    public function countCommandTypes()
    {
        $count = array();
        foreach ($this->getCommands() as $command) {
            $type = $command->getElementName();
            if (isset($count[$type])) {
                $count[$type]++;
            } else {
                $count[$type] = 0;
            }
        }

        return $count;
    }
}
