<?php
namespace Topalis\WinPhone\OMA\SyncML\Entity\ConfigurationServiceProvider;

/**
 * Poll configuration service provider.
 *
 * @see Windows Phone 8 Enterprise Device Management Protocol
 * @author Dominic Tubach <dominic.tubach@to.com>
 */
class PollCSP extends AbstractConfigurationServiceProvider
{
    /**
     *
     * @var string
     */
    private $providerId;

    /**
     *
     * @param string $cmdID
     * @param string $providerId
     */
    public function __construct($cmdID = null, $providerId = null)
    {
        parent::__construct($cmdID);
        $this->setDefaultCommand("Replace");
        if ($providerId !== null) {
            $this->setProviderId($providerId);
        }
        foreach ($this->getDefaults() as $locURI => $data) {
            $this->setData($locURI, array("data" => $data, "format" => "int"), "Replace");
        }
    }

    /**
     * @return string
     */
    public function getProviderId()
    {
        return $this->providerId;
    }

    /**
     *
     * @param string $providerId
     */
    public function setProviderId($providerId)
    {
        $this->providerId = $providerId;
        $this->setLocURIPrefix("./Vendor/MSFT/DMClient/Provider/" . $providerId . "/Poll/");
    }

    /**
     * @return int The waiting time (in minutes) for the initial set of retries
     *     as specified by the number of retries in NumberOfFirstRetries. The
     *     default value is 15. If the value is set to 0, this schedule is
     *     disabled.
     */
    public function getIntervalForFirstSetOfRetries()
    {
        return $this->getData("IntervalForFirstSetOfRetries");
    }

    /**
     * Sets the waiting time (in minutes) for the initial set of retries as
     * specified by the number of retries in NumberOfFirstRetries. The default
     * value is 15. If the value is set to 0, this schedule is disabled.
     *
     * @param int $intervalForFirstSetOfRetries The interval in minutes to set.
     */
    public function setIntervalForFirstSetOfRetries($intervalForFirstSetOfRetries)
    {
        $this->setData("IntervalForFirstSetOfRetries",
            array("data" => $intervalForFirstSetOfRetries, "format" => "int"), "Replace");
    }

    /**
     *
     * @return int The number of times the DM client should retry connecting to
     *     the server when the client is initially configured/enrolled to
     *     communicate with the server. If the value is set to 0 and
     *     IntervalForFirstSetOfRetries value isn’t 0, then schedule will be set
     *     to repeat an infinite number of times and second set and this set of
     *     schedule will not set in this case. The default value is 10.
     */
    public function getNumberOfFirstRetries()
    {
        return $this->getData("NumberOfFirstRetries");
    }

    /**
     * Sets the number of times the DM client should retry connecting to the
     * server when the client is initially configured/enrolled to communicate
     * with the server. If the value is set to 0 and
     * IntervalForFirstSetOfRetries value isn’t 0, then schedule will be set to
     * repeat an infinite number of times and second set and this set of
     * schedule will not set in this case. The default value is 10.
     *
     * @param int $numberOfFirstRetries The number of retries to set.
     */
    public function setNumberOfFirstRetries($numberOfFirstRetries)
    {
        $this->setData("NumberOfFirstRetries",
            array("data" => $numberOfFirstRetries, "format" => "int"), "Replace");
    }

    /**
     * @return int The waiting time (in minutes) for the second set of retries
     *     as specified by the number of retries in NumberOfSecondRetries.
     *     Default value is 0. If this value is set to zero, then this schedule
     *     is disabled.
     */
    public function getIntervalForSecondSetOfRetries()
    {
        return $this->getData("IntervalForSecondSetOfRetries");
    }

    /**
     * Sets the waiting time (in minutes) for the second set of retries as specified
     * by the number of retries in NumberOfSecondRetries. Default value is 0.
     * If this value is set to zero, then this schedule is disabled.
     *
     * @param int $intervalForSecondSetOfRetries The interval in minutes to set.
     */
    public function setIntervalForSecondSetOfRetries($intervalForSecondSetOfRetries)
    {
        $this->setData("IntervalForSecondSetOfRetries",
            array("data" => $intervalForSecondSetOfRetries, "format" => "int"), "Replace");
    }

    /**
     *
     * @return int The number of times the DM client should retry second round
     *     connecting to the server when the client is initially
     *     configured/enrolled to communicate with the server. Default value is
     *     0. If the value is set to 0 and IntervalForSecondSetOfRetries isn’t
     *     set to 0 AND first set of retries isn’t set as infinite retries, then
     *     schedule will be set to repeat an infinite number of times. However,
     *     if first set of retries is set at infinite, then this schedule will
     *     be disabled.
     */
    public function getNumberOfSecondRetries()
    {
        return $this->getData("NumberOfSecondRetries");
    }

    /**
     * Sets the number of times the DM client should retry second round
     * connecting to the server when the client is initially configured/enrolled
     * to communicate with the server. Default value is 0. If the value is set
     * to 0 and IntervalForSecondSetOfRetries isn’t set to 0 AND first set of
     * retries isn’t set as infinite retries, then schedule will be set to
     * repeat an infinite number of times. However, if first set of retries is
     * set at infinite, then this schedule will be disabled.
     *
     * @param int $numberOfSecondRetries The number of retries to set.
     */
    public function setNumberOfSecondRetries($numberOfSecondRetries)
    {
        $this->setData("NumberOfSecondRetries",
            array("data" => $numberOfSecondRetries, "format" => "int"), "Replace");
    }

    /**
     * @return int The waiting time (in minutes) for the initial set of retries
     *     as specified by the number of retries in
     *     NumberOfRemainingScheduledRetries. Default value is 0. If
     *     IntervalForRemainingScheduledRetries is set to 0, then this schedule
     *     is disabled.
     */
    public function getIntervalForRemainingScheduledRetries()
    {
        return $this->getData("IntervalForRemainingScheduledRetries");
    }

    /**
     * Sets the waiting time (in minutes) for the initial set of retries as
     * specified by the number of retries in NumberOfRemainingScheduledRetries.
     * Default value is 0. If IntervalForRemainingScheduledRetries is set to 0,
     * then this schedule is disabled.
     *
     * @param int $intervalForRemainingScheduledRetries The interval in minutes
     *     to set.
     */
    public function setIntervalForRemainingScheduledRetries($intervalForRemainingScheduledRetries)
    {
        $this->setData("IntervalForRemainingScheduledRetries",
            array("data" => $intervalForRemainingScheduledRetries, "format" => "int"), "Replace");
    }

    /**
     *
     * @return int The number of times the DM client should retry connecting to
     *     the server when the client is initially configured/enrolled to
     *     communicate with the server. Default value is 0. If the value is set
     *     to 0 and IntervalForRemainingScheduledRetries AND first and second
     *     set of retries aren’t set as infinite retries, then schedule will be
     *     set to repeat an infinite number of times. However, if either or both
     *     of first and second set of retries are set as infinite, then this
     *     schedule will be disabled.
     */
    public function getNumberOfRemainingScheduledRetries()
    {
        return $this->getData("NumberOfRemainingScheduledRetries");
    }

    /**
     * Sets the number of times the DM client should retry connecting to the
     * server when the client is initially configured/enrolled to communicate
     * with the server. Default value is 0. If the value is set to 0 and
     * IntervalForRemainingScheduledRetries AND first and second set of retries
     * aren’t set as infinite retries, then schedule will be set to repeat an
     * infinite number of times. However, if either or both of first and second
     * set of retries are set as infinite, then this schedule will be disabled.
     *
     * @param int $numberOfRemainingScheduledRetries The number of retries to
     *     set.
     */
    public function setNumberOfRemainingScheduledRetries($numberOfRemainingScheduledRetries)
    {
        $this->setData("NumberOfRemainingScheduledRetries",
            array("data" => $numberOfRemainingScheduledRetries, "format" => "int"), "Replace");
    }

    protected function getDefaults()
    {
        return array(
            "IntervalForFirstSetOfRetries" => 15,
            "NumberOfFirstRetries" => 10,
            "IntervalForSecondSetOfRetries" => 0,
            "NumberOfSecondRetries" => 0,
            "IntervalForRemainingScheduledRetries" => 0,
            "NumberOfRemainingScheduledRetries" => 0,
        );
    }
}
