<?php
namespace Topalis\WinPhone\OMA\SyncML\Entity\ConfigurationServiceProvider;

use Topalis\Profile\UUIDGenerator;

/**
 * Partial CertificateStore configuration service provider to install a
 * certificate through SCEP.
 *
 * @see Windows Phone 8.1 Enterprise Device Management Protocol
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 *
 */
class ScepInstallCSP extends AbstractConfigurationServiceProvider
{

    private $uniqueID;

    /**
     *
     * @param string $cmdID
     * @param string $uniqueID
     */
    public function __construct($cmdID = null, $uniqueID = null)
    {
        parent::__construct($cmdID);
        if ($uniqueID === null) {
            $uuidGenerator = new UUIDGenerator();
            $uniqueID = $uuidGenerator->generateUUID();
        }

        $this->setUniqueID($uniqueID);

        foreach ($this->getDefaults() as $locURI => $data) {
            $this->setData($locURI, $data);
        }
    }

    public function getChildren()
    {
        $this->removeData("Enroll");
        $this->setData("Enroll", null, "Exec");
        return parent::getChildren();
    }

    public function getUniqueID()
    {
        return $this->uniqueID;
    }

    public function setUniqueID($uniqueID)
    {
        $this->uniqueID = $uniqueID;
        $this->setLocURIPrefix("./Vendor/MSFT/CertificateStore/My/SCEP/" . $uniqueID . "/Install/");
    }

    public function getServerURL()
    {
        return $this->getData("ServerURL");
    }

    public function setServerURL($serverURL)
    {
        $this->setData("ServerURL", array("data" => $serverURL, "format" => "chr"));
    }

    public function getChallenge()
    {
        return $this->getData("Challenge");
    }

    public function setChallenge($challenge)
    {
        $this->setData("Challenge", array("data" => $challenge, "format" => "chr"));
    }

    public function getRetryCount()
    {
        return $this->getData("RetryCount");
    }

    public function setRetryCount($retryCount)
    {
        $this->setData("RetryCount", array("data" => $retryCount, "format" => "int"));
    }

    public function getRetryDelay()
    {
        return $this->getData("RetryDelay");
    }

    public function setRetryDeleay($retryDelay)
    {
        $this->setData("RetryDelay", array("data" => $retryDelay, "format" => "int"));
    }

    public function getTemplateName()
    {
        return $this->getData("TemplateName");
    }

    public function setTemplateName($templateName)
    {
        $this->setData("TemplateName", array("data" => $templateName, "format" => "chr"));
    }

    public function getKeyUsage()
    {
        return $this->getData("KeyUsage");
    }

    public function setKeyUsage($keyUsage)
    {
        $this->setData("KeyUsage", array("data" => $keyUsage, "format" => "int"));
    }

    public function getKeyLength()
    {
        return $this->getData("KeyLength");
    }

    public function setKeyLength($keyLength)
    {
        $this->setData("KeyLength", array("data" => $keyLength, "format" => "int"));
    }

    public function getHashAlgorithm()
    {
        return $this->getData("HashAlgorithm");
    }

    public function setHashAlgorithm($hashAlgorithm)
    {
        $this->setData("HashAlgorithm", array("data" => $hashAlgorithm, "format" => "chr"));
    }

    public function getCAThumbprint()
    {
        return $this->getData("CAThumbprint");
    }

    public function setCAThumbprint($cAThumbprint)
    {
        $this->setData("CAThumbprint", array("data" => $cAThumbprint, "format" => "chr"));
    }

    public function getSubjectName()
    {
        return $this->getData("SubjectName");
    }

    public function setSubjectName($subjectName)
    {
        $this->setData("SubjectName", array("data" => $subjectName, "format" => "chr"));
    }

    public function getSubjectAlternativeNames()
    {
        return $this->getData("SubjectAlternativeNames");
    }

    public function setSubjectAlternativeNames($subjectAlternativeNames)
    {
        $this->setData("SubjectAlternativeNames", array("data" => $subjectAlternativeNames, "format" => "chr"));
    }

    public function getValidPeriod()
    {
        return $this->getData("ValidPeriod");
    }

    public function setValidPeriod($validPeriod)
    {
        $this->setData("ValidPeriod", array("data" => $validPeriod, "format" => "chr"));
    }

    public function getValidPeriodUnits()
    {
        return $this->getData("ValidPeriodUnits");
    }

    public function setValidPeriodUnits($validPeriodUnits)
    {
        $this->setData("ValidPeriodUnits", array("data" => $validPeriodUnits, "format" => "int"));
    }

    public function getEKUMapping()
    {
        return $this->getData("EKUMapping");
    }

    public function setEKUMapping($eKUMapping)
    {
        $this->setData("EKUMapping", array("data" => $eKUMapping, "format" => "chr"));
    }

    public function getKeyProtection()
    {
        return $this->getData("KeyProtection");
    }

    public function setKeyProtection($keyProtection)
    {
        $this->setData("KeyProtection", array("data" => $keyProtection, "format" => "int"));
    }

    protected function getDefaults()
    {
        return array(
            "KeyProtection" => array("data" => 2, "format" => "int"), // protect key by phone TPM if supported
        );
    }
}
