<?php
namespace Topalis\WinPhone\OMA\SyncML\Entity\ConfigurationServiceProvider;

/**
 * WiFi configuration service provider.
 *
 * @see Windows Phone 8 Enterprise Device Management Protocol
 * @see http://msdn.microsoft.com/en-us/library/windows/desktop/ms706965%28v=vs.85%29.aspx
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 *
 */
class WiFiCSP extends AbstractConfigurationServiceProvider
{
    /**
     *
     * @var string
     */
    private $ssid;

    /**
     *
     * @param string $cmdID
     * @param string $ssid
     */
    public function __construct($cmdID = null, $ssid = null)
    {
        parent::__construct($cmdID);
        if ($ssid !== null) {
            $this->setSsid($ssid);
        }

        $this->setProxy(null);
    }

    /**
     * @return string
     */
    public function getSsid()
    {
        return $this->ssid;
    }

    /**
     *
     * @param string $ssid
     */
    public function setSsid($ssid)
    {
        $this->ssid = $ssid;
        $this->setLocURIPrefix("./Vendor/MSFT/WiFi/Profile/" . $ssid . "/");
    }

    /**
     * @return string|NULL The proxy in the form host:port
     */
    public function getProxy()
    {
        return $this->getData("Proxy");
    }

    /**
     * Sets the proxy.
     *
     * @param string $proxy The proxy to set in the form host:port
     */
    public function setProxy($proxy)
    {
        $this->setData("Proxy", $proxy, "Replace");
    }

    /**
     *
     * @return string|NULL
     */
    public function getWlanXml()
    {
        return $this->getData("WlanXml");
    }

    /**
     *
     * @param string $wlanXml
     */
    public function setWlanXml($wlanXml)
    {
        $this->setData("WlanXml", array("data" => $wlanXml, "format" => "chr"));
    }
}
