<?php
namespace Topalis\WinPhone\OMA\SyncML\Entity;

class XmlConverter
{
    public static function fromDOMElement(\DOMElement $element)
    {
        $newClassName = self::getNamespace() . "\\" . $element->tagName;
        if (!class_exists($newClassName)) {
            return $element->nodeValue;
        }

        if (method_exists($newClassName, "fromDOMElement")) {
            return call_user_func(array($newClassName, "fromDOMElement"), $element);
        }

        $rv = new $newClassName;
        if (method_exists($rv, "fromDOMElement")) {
            call_user_func(array($rv, "fromDOMElement"), $element);
            return $rv;
        }

        foreach ($element->childNodes as $child) {
            $attribute = $child->tagName;
            $methodName = self::getSetOrAddMethod($rv, $attribute);
            if (!$methodName) {
                throw new \InvalidArgumentException("Unknwown element " . $child->tagName
                    . " in element " . $rv->getElementName());
            }

            if ($child->nodeType == XML_ELEMENT_NODE) {
                $value = static::fromDOMElement($child);
            } else if ($child->nodeType == XML_ATTRIBUTE_NODE) {
                continue;
            } else {
                throw new \InvalidArgumentException("Unexpected node type " . $child->nodeType);
            }

            if ($methodName == "__set") {
                $rv->$attribute = $value;
            } else {
                call_user_func(array($rv, $methodName), $value);
            }
        }

        return $rv;
    }

    public static function fromXml($xml)
    {
        $doc = new \DOMDocument();
        $doc->loadXML($xml);
        return static::fromDOMElement($doc->documentElement);
    }

    public static function getNamespace()
    {
        static $namespace = null;

        if ($namespace === null) {
            $className = get_class();
            $pos = strrpos($className, "\\");
            $namespace = substr($className, 0, $pos);
        }
        return $namespace;
    }

    private static function getSetOrAddMethod($object, $attribute)
    {
        static $prefixes = array("set", "add");

        foreach ($prefixes as $prefix) {
            $methodName = $prefix . $attribute;
            if (method_exists($object, $methodName)) {
                return $methodName;
            }
        }

        if (method_exists($object, "__set")) {
            return "__set";
        }

        return null;
    }
}
