<?php
namespace Topalis\WinPhone\Wstep\Entity;

/**
 * This class stands for Authenticator originally named AuthenticatorType
 * Meta informations extracted from the WSDL
 * - from schema : ws-trust-1.3.xsd
 * @date 2013-12-03
 */
class Authenticator
{
    /**
     * The CombinedHash
     * @var base64Binary
     */
    public $CombinedHash;
    /**
     * The any
     * @var DOMDocument
     */
    public $any;
    /**
     * Constructor method for AuthenticatorType
     * @uses Authenticator::setCombinedHash()
     * @uses Authenticator::setAny()
     * @param  base64Binary  $_combinedHash
     * @param  DOMDocument   $_any
     * @return Authenticator
     */
    public function __construct($_combinedHash = null, $_any = null)
    {
        $this->setCombinedHash($_combinedHash);
        $this->setAny($_any);
    }
    /**
     * Get CombinedHash value
     * @return base64Binary|null
     */
    public function getCombinedHash()
    {
        return $this->CombinedHash;
    }
    /**
     * Set CombinedHash value
     * @param  base64Binary $_combinedHash the CombinedHash
     * @return base64Binary
     */
    public function setCombinedHash($_combinedHash)
    {
        return ($this->CombinedHash = $_combinedHash);
    }
    /**
     * Get any value
     * @uses DOMDocument::loadXML()
     * @uses DOMDocument::hasChildNodes()
     * @uses DOMDocument::saveXML()
     * @uses DOMNode::item()
     * @uses Authenticator::setAny()
     * @param bool true or false whether to return XML value as string or as DOMDocument
     * @return DOMDocument|null
     */
    public function getAny($_asString = true)
    {
        if (!empty($this->any) && !($this->any instanceof DOMDocument)) {
            $dom = new \DOMDocument('1.0', 'UTF-8');
            $dom->formatOutput = true;
            if ($dom->loadXML($this->any)) {
                $this->setAny($dom);
            }
            unset($dom);
        }

        return ($_asString && ($this->any instanceof DOMDocument)
            && $this->any->hasChildNodes()) ? $this->any->saveXML($this->any->childNodes->item(0)) : $this->any;
    }
    /**
     * Set any value
     * @param  DOMDocument $_any the any
     * @return DOMDocument
     */
    public function setAny($_any)
    {
        return ($this->any = $_any);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
