<?php
namespace Topalis\WinPhone\Wstep\Entity;

/**
 * This class stands for KeyValue originally named KeyValueType
 * Meta informations extracted from the WSDL
 * - from schema : xmldsig-core-schema.xsd
 * @date 2013-12-03
 */
class KeyValue
{
    /**
     * The DSAKeyValue
     * @var DSAKeyValue
     */
    public $DSAKeyValue;
    /**
     * The RSAKeyValue
     * @var RSAKeyValue
     */
    public $RSAKeyValue;
    /**
     * The any
     * @var DOMDocument
     */
    public $any;
    /**
     * Constructor method for KeyValueType
     * @uses KeyValue::setDSAKeyValue()
     * @uses KeyValue::setRSAKeyValue()
     * @uses KeyValue::setAny()
     * @param  DSAKeyValue $_dSAKeyValue
     * @param  RSAKeyValue $_rSAKeyValue
     * @param  DOMDocument $_any
     * @return KeyValue
     */
    public function __construct($_dSAKeyValue = null, $_rSAKeyValue = null, $_any = null)
    {
        $this->setDSAKeyValue($_dSAKeyValue);
        $this->setRSAKeyValue($_rSAKeyValue);
        $this->setAny($_any);
    }
    /**
     * Get DSAKeyValue value
     * @return DSAKeyValue|null
     */
    public function getDSAKeyValue()
    {
        return $this->DSAKeyValue;
    }
    /**
     * Set DSAKeyValue value
     * @param  DSAKeyValue $_dSAKeyValue the DSAKeyValue
     * @return DSAKeyValue
     */
    public function setDSAKeyValue($_dSAKeyValue)
    {
        return ($this->DSAKeyValue = $_dSAKeyValue);
    }
    /**
     * Get RSAKeyValue value
     * @return RSAKeyValue|null
     */
    public function getRSAKeyValue()
    {
        return $this->RSAKeyValue;
    }
    /**
     * Set RSAKeyValue value
     * @param  RSAKeyValue $_rSAKeyValue the RSAKeyValue
     * @return RSAKeyValue
     */
    public function setRSAKeyValue($_rSAKeyValue)
    {
        return ($this->RSAKeyValue = $_rSAKeyValue);
    }
    /**
     * Get any value
     * @uses DOMDocument::loadXML()
     * @uses DOMDocument::hasChildNodes()
     * @uses DOMDocument::saveXML()
     * @uses DOMNode::item()
     * @uses KeyValue::setAny()
     * @param bool true or false whether to return XML value as string or as DOMDocument
     * @return DOMDocument|null
     */
    public function getAny($_asString = true)
    {
        if (!empty($this->any) && !($this->any instanceof DOMDocument)) {
            $dom = new \DOMDocument('1.0', 'UTF-8');
            $dom->formatOutput = true;
            if ($dom->loadXML($this->any)) {
                $this->setAny($dom);
            }
            unset($dom);
        }

        return ($_asString && ($this->any instanceof DOMDocument)
            && $this->any->hasChildNodes()) ? $this->any->saveXML($this->any->childNodes->item(0)) : $this->any;
    }
    /**
     * Set any value
     * @param  DOMDocument $_any the any
     * @return DOMDocument
     */
    public function setAny($_any)
    {
        return ($this->any = $_any);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
