<?php
namespace Topalis\WinPhone\Wstep\Entity;

/**
 * This class stands for PGPData originally named PGPDataType
 * Meta informations extracted from the WSDL
 * - from schema : xmldsig-core-schema.xsd
 * @date 2013-12-03
 */
class PGPData
{
    /**
     * The PGPKeyID
     * @var base64Binary
     */
    public $PGPKeyID;
    /**
     * The PGPKeyPacket
     * Meta informations extracted from the WSDL
     * - minOccurs : 0
     * @var base64Binary
     */
    public $PGPKeyPacket;
    /**
     * The any
     * @var DOMDocument
     */
    public $any;
    /**
     * Constructor method for PGPDataType
     * @uses PGPData::setPGPKeyID()
     * @uses PGPData::setPGPKeyPacket()
     * @uses PGPData::setAny()
     * @param  base64Binary $_pGPKeyID
     * @param  base64Binary $_pGPKeyPacket
     * @param  DOMDocument  $_any
     * @return PGPData
     */
    public function __construct($_pGPKeyID = null, $_pGPKeyPacket = null, $_any = null)
    {
        $this->setPGPKeyID($_pGPKeyID);
        $this->setPGPKeyPacket($_pGPKeyPacket);
        $this->setAny($_any);
    }
    /**
     * Get PGPKeyID value
     * @return base64Binary|null
     */
    public function getPGPKeyID()
    {
        return $this->PGPKeyID;
    }
    /**
     * Set PGPKeyID value
     * @param  base64Binary $_pGPKeyID the PGPKeyID
     * @return base64Binary
     */
    public function setPGPKeyID($_pGPKeyID)
    {
        return ($this->PGPKeyID = $_pGPKeyID);
    }
    /**
     * Get PGPKeyPacket value
     * @return base64Binary|null
     */
    public function getPGPKeyPacket()
    {
        return $this->PGPKeyPacket;
    }
    /**
     * Set PGPKeyPacket value
     * @param  base64Binary $_pGPKeyPacket the PGPKeyPacket
     * @return base64Binary
     */
    public function setPGPKeyPacket($_pGPKeyPacket)
    {
        return ($this->PGPKeyPacket = $_pGPKeyPacket);
    }
    /**
     * Get any value
     * @uses DOMDocument::loadXML()
     * @uses DOMDocument::hasChildNodes()
     * @uses DOMDocument::saveXML()
     * @uses DOMNode::item()
     * @uses PGPData::setAny()
     * @param bool true or false whether to return XML value as string or as DOMDocument
     * @return DOMDocument|null
     */
    public function getAny($_asString = true)
    {
        if (!empty($this->any) && !($this->any instanceof DOMDocument)) {
            $dom = new \DOMDocument('1.0', 'UTF-8');
            $dom->formatOutput = true;
            if ($dom->loadXML($this->any)) {
                $this->setAny($dom);
            }
            unset($dom);
        }

        return ($_asString && ($this->any instanceof DOMDocument)
            && $this->any->hasChildNodes()) ? $this->any->saveXML($this->any->childNodes->item(0)) : $this->any;
    }
    /**
     * Set any value
     * @param  DOMDocument $_any the any
     * @return DOMDocument
     */
    public function setAny($_any)
    {
        return ($this->any = $_any);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
