<?php
namespace Topalis\WinPhone\Wstep\Entity;

/**
 * This class stands for X509Data originally named X509DataType
 * Meta informations extracted from the WSDL
 * - from schema : xmldsig-core-schema.xsd
 * @date 2013-12-03
 */
class X509Data
{
    /**
     * The X509IssuerSerial
     * @var X509IssuerSerial
     */
    public $X509IssuerSerial;
    /**
     * The X509SKI
     * @var base64Binary
     */
    public $X509SKI;
    /**
     * The X509SubjectName
     * @var string
     */
    public $X509SubjectName;
    /**
     * The X509Certificate
     * @var base64Binary
     */
    public $X509Certificate;
    /**
     * The X509CRL
     * @var base64Binary
     */
    public $X509CRL;
    /**
     * The any
     * @var DOMDocument
     */
    public $any;
    /**
     * Constructor method for X509DataType
     * @uses X509Data::setX509IssuerSerial()
     * @uses X509Data::setX509SKI()
     * @uses X509Data::setX509SubjectName()
     * @uses X509Data::setX509Certificate()
     * @uses X509Data::setX509CRL()
     * @uses X509Data::setAny()
     * @param  X509IssuerSerial $_x509IssuerSerial
     * @param  base64Binary     $_x509SKI
     * @param  string           $_x509SubjectName
     * @param  base64Binary     $_x509Certificate
     * @param  base64Binary     $_x509CRL
     * @param  DOMDocument      $_any
     * @return X509Data
     */
    public function __construct($_x509IssuerSerial = null, $_x509SKI = null,
        $_x509SubjectName = null, $_x509Certificate = null, $_x509CRL = null, $_any = null)
    {
        $this->setX509IssuerSerial($_x509IssuerSerial);
        $this->setX509SKI($_x509SKI);
        $this->setX509SubjectName($_x509SubjectName);
        $this->setX509Certificate($_x509Certificate);
        $this->setX509CRL($_x509CRL);
        $this->setAny($_any);
    }
    /**
     * Get X509IssuerSerial value
     * @return X509IssuerSerial|null
     */
    public function getX509IssuerSerial()
    {
        return $this->X509IssuerSerial;
    }
    /**
     * Set X509IssuerSerial value
     * @param  X509IssuerSerial $_x509IssuerSerial the X509IssuerSerial
     * @return X509IssuerSerial
     */
    public function setX509IssuerSerial($_x509IssuerSerial)
    {
        return ($this->X509IssuerSerial = $_x509IssuerSerial);
    }
    /**
     * Get X509SKI value
     * @return base64Binary|null
     */
    public function getX509SKI()
    {
        return $this->X509SKI;
    }
    /**
     * Set X509SKI value
     * @param  base64Binary $_x509SKI the X509SKI
     * @return base64Binary
     */
    public function setX509SKI($_x509SKI)
    {
        return ($this->X509SKI = $_x509SKI);
    }
    /**
     * Get X509SubjectName value
     * @return string|null
     */
    public function getX509SubjectName()
    {
        return $this->X509SubjectName;
    }
    /**
     * Set X509SubjectName value
     * @param  string $_x509SubjectName the X509SubjectName
     * @return string
     */
    public function setX509SubjectName($_x509SubjectName)
    {
        return ($this->X509SubjectName = $_x509SubjectName);
    }
    /**
     * Get X509Certificate value
     * @return base64Binary|null
     */
    public function getX509Certificate()
    {
        return $this->X509Certificate;
    }
    /**
     * Set X509Certificate value
     * @param  base64Binary $_x509Certificate the X509Certificate
     * @return base64Binary
     */
    public function setX509Certificate($_x509Certificate)
    {
        return ($this->X509Certificate = $_x509Certificate);
    }
    /**
     * Get X509CRL value
     * @return base64Binary|null
     */
    public function getX509CRL()
    {
        return $this->X509CRL;
    }
    /**
     * Set X509CRL value
     * @param  base64Binary $_x509CRL the X509CRL
     * @return base64Binary
     */
    public function setX509CRL($_x509CRL)
    {
        return ($this->X509CRL = $_x509CRL);
    }
    /**
     * Get any value
     * @uses DOMDocument::loadXML()
     * @uses DOMDocument::hasChildNodes()
     * @uses DOMDocument::saveXML()
     * @uses DOMNode::item()
     * @uses X509Data::setAny()
     * @param bool true or false whether to return XML value as string or as DOMDocument
     * @return DOMDocument|null
     */
    public function getAny($_asString = true)
    {
        if (!empty($this->any) && !($this->any instanceof DOMDocument)) {
            $dom = new \DOMDocument('1.0', 'UTF-8');
            $dom->formatOutput = true;
            if ($dom->loadXML($this->any)) {
                $this->setAny($dom);
            }
            unset($dom);
        }

        return ($_asString && ($this->any instanceof DOMDocument)
            && $this->any->hasChildNodes()) ? $this->any->saveXML($this->any->childNodes->item(0)) : $this->any;
    }
    /**
     * Set any value
     * @param  DOMDocument $_any the any
     * @return DOMDocument
     */
    public function setAny($_any)
    {
        return ($this->any = $_any);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
