<?php
namespace Topalis\WinPhone\Xcep\Entity;

/**
 * This class stands for Client originally named Client
 * Meta informations extracted from the WSDL
 * - from schema : xcep.xsd
 * @date 2013-12-10
 */
class Client
{
    /**
     * The lastUpdate
     * Meta informations extracted from the WSDL
     * - nillable : true
     * @var dateTime
     */
    public $lastUpdate;

    /**
     * The preferredLanguage
     * Meta informations extracted from the WSDL
     * - nillable : true
     * @var language
     */
    public $preferredLanguage;

    /**
     * The any
     * @var DOMDocument
     */
    public $any;

    /**
     * Constructor method for Client
     * @uses Client::setLastUpdate()
     * @uses Client::setPreferredLanguage()
     * @uses Client::setAny()
     * @param dateTime $_lastUpdate
     * @param language $_preferredLanguage
     * @param DOMDocument $_any
     * @return Client
     */
    public function __construct($_lastUpdate = null, $_preferredLanguage = null, $_any = null)
    {
        $this->setLastUpdate($_lastUpdate);
        $this->setPreferredLanguage($_preferredLanguage);
        $this->setAny($_any);
    }

    /**
     * Get lastUpdate value
     * @return dateTime|null
     */
    public function getLastUpdate()
    {
        return $this->lastUpdate;
    }

    /**
     * Set lastUpdate value
     * @param dateTime $_lastUpdate the lastUpdate
     * @return dateTime
     */
    public function setLastUpdate($_lastUpdate)
    {
        return ($this->lastUpdate = $_lastUpdate);
    }

    /**
     * Get preferredLanguage value
     * @return language|null
     */
    public function getPreferredLanguage()
    {
        return $this->preferredLanguage;
    }

    /**
     * Set preferredLanguage value
     * @param language $_preferredLanguage the preferredLanguage
     * @return language
     */
    public function setPreferredLanguage($_preferredLanguage)
    {
        return ($this->preferredLanguage = $_preferredLanguage);
    }

    /**
     * Get any value
     * @uses DOMDocument::loadXML()
     * @uses DOMDocument::hasChildNodes()
     * @uses DOMDocument::saveXML()
     * @uses DOMNode::item()
     * @uses Client::setAny()
     * @param bool true or false whether to return XML value as string or as DOMDocument
     * @return DOMDocument|null
     */
    public function getAny($_asString = true)
    {
        if (!empty($this->any) && !($this->any instanceof DOMDocument)) {
            $dom = new \DOMDocument('1.0', 'UTF-8');
            $dom->formatOutput = true;
            if ($dom->loadXML($this->any)) {
                $this->setAny($dom);
            }

            unset($dom);
        }

        return ($_asString && ($this->any instanceof DOMDocument)
            && $this->any->hasChildNodes()) ? $this->any->saveXML($this->any->childNodes->item(0)) : $this->any;
    }

    /**
     * Set any value
     * @param DOMDocument $_any the any
     * @return DOMDocument
     */
    public function setAny($_any)
    {
        return ($this->any = $_any);
    }

    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }

}
