var UsageGraph = {
    args:       {},
    graph:      null,
    yAxis:      null,
    firstUsage: true,

    create: function (args) {
        var graph = Object.create(this);
        graph.init(args);

        return graph;
    },

    init: function (args) {
        var self = this;
        var now = (new Date()).getTime() / 1000;
        var start = args.start ? args.start : now - 60;
        var seconds = args.seconds ? args.seconds : 60;
        var end = start + seconds;

        args = $.extend({
            renderer: "line",
            yAxis:      false,
            yAxisWidth: 60,
            xAxis:      false,
            legend:     false,
            centered:   false,
            unstack:    false
        }, args);
        this.args = args;

        var $element = args.element;

        var series = args.series;
        for (var i = 0; i < series.length; i++) {
            var tmpSeries = series[i];
            if (!tmpSeries.data || tmpSeries.data.length == 0) {
                tmpSeries.data.push({x: end, y: 0});
            }

            while (tmpSeries.data[0].x > start) {
                tmpSeries.data.unshift({x: tmpSeries.data[0].x - 1, y: 0});
            }
        }

        var $graphElemenet = $('<div></div>').addClass('chart').css({marginLeft: args.yAxisWidth});
        $element.append($graphElemenet);
        this.graph = new Rickshaw.Graph({
            element:       $graphElemenet.get(0),
            width:         args.width ? args.width : $('.main-center').innerWidth() - args.yAxisWidth - 10,
            height:        args.height ? args.height : 150,
            min:           args.min,
            max:           args.max,
            renderer:      args.renderer,
            interpolation: "linear",
            series:        series
        });
        if (args.unstack) {
            this.graph.renderer.unstack = true;
        }

        if (args.yAxis) {
            var $yAxisElement = $('<div></div>').addClass('y-axis').width(args.yAxisWidth);
            $element.append($yAxisElement);
            this.yAxis = new Rickshaw.Graph.Axis.Y({
                graph:       self.graph,
                orientation: "left",
                tickFormat:  args.tickFormat,
                element:     $yAxisElement.get(0)
            });
        }
        if (args.yAxis) {
            var $xAxisElement = $('<div></div>').addClass('x-axis').css({left: args.yAxisWidth});
            $element.append($xAxisElement);
            new Rickshaw.Graph.Axis.X({
                graph:      self.graph,
                element:    $xAxisElement.get(0),
                tickFormat: function (x) {
                    var date = new Date(x * 1000);
                    return date.getHours() + ":" + date.getMinutes() + ":" + date.getSeconds();
                }
            });
        }

        var trafficHoverDetail = new Rickshaw.Graph.HoverDetail({
            graph:      self.graph,
            xFormatter: function (x) {
                return new Date(x * 1000).toLocaleString();
            },
            yFormatter: args.yFormatter ? args.yFormatter : function (y) {
                return y;
            }
        });


        if (args.legend) {
            var $legendContainer = $('<div></div>').addClass('legend-container').css({left: args.yAxisWidth + 10});
            $element.append($legendContainer);
            var $legendElement = $('<div></div>').addClass('legend');
            $legendContainer.append($legendElement);
            var trafficLegend = new Rickshaw.Graph.Legend({
                element: $legendElement.get(0),
                graph:   self.graph
            });

            var trafficShelving = new Rickshaw.Graph.Behavior.Series.Toggle({
                graph:  self.graph,
                legend: trafficLegend
            });

            var trafficHighlighter = new Rickshaw.Graph.Behavior.Series.Highlight({
                graph:  self.graph,
                legend: trafficLegend
            });
        }

        this.graph.render();
    },

    addUsage: function (usage) {
        var now = (new Date()).getTime() / 1000;
        this.graph.window.xMin = now - 60;
        this.graph.window.xMax = now;

        //usage['total'] = (usage.user - 0) + (usage.system - 0) + (usage.ioWait - 0);
        for (var i = 0; i < this.graph.series.length; i++) {
            var series = this.graph.series[i];
            if (this.firstUsage) {
                series.data.push({x: now - 1, y: 0});
            }
            series.data.push({x: now, y: usage[series.key]});

            while (series.data.length > 1 && series.data[1].x < this.graph.window.xMin) {
                series.data.shift();
            }
        }
        if (this.args.centered) {
            var yValues = this.graph.series.map(function(s) {
                return s.data.map(function(d) {
                    return d.y;
                });
            });
            var flatYValues = d3.merge(yValues);
            var maxValue = Math.max.apply(Math, flatYValues);
            var minValue = Math.min.apply(Math, flatYValues);
            this.graph.max = Math.max(Math.abs(minValue), maxValue);
            this.graph.min = this.graph.max * -1;
            this.graph.update();
        }
        this.firstUsage = false;
        this.graph.render();
    }
};

var FilesystemChart =  {
    args: {},
    element: null,
    mountPoint: null,
    disks: {},
    create: function (args) {
        var graph = Object.create(this);
        graph.init(args);

        return graph;
    },
    init: function(args) {
        args = $.extend({
            disks: {},
            labels: {
                used: 'used',
                available: 'available'
            }
        }, args);
        this.args = args;
        this.element = args.element;
        this.mountPoint = args.mountPoint;
        this.disks = args.disks;

        this.chart = nv.models.pieChart()
            .x(function(d) { return d.label; })
            .y(function(d) { return d.value; })
            .valueFormat(formatBytes)
            .showLabels(true)     //Display pie labels
            .labelThreshold(.05)  //Configure the minimum slice size for labels to show up
            .labelType("percent") //Configure what type of data to show in the label. Can be "key", "value" or "percent"
            .donut(true)          //Turn on Donut mode. Makes pie chart look tasty!
            .donutRatio(0.35)     //Configure how big you want the donut hole size to be.
        ;
        nv.addGraph(this.chart);

        this.render();
    },

    setDisks: function(disks) {
        this.disks = disks;
        this.render();
    },

    setMountPoint: function(mountPoint) {
        this.mountPoint = mountPoint;
        this.render();
    },

    render: function() {
        var data = [];
        for (var i = 0; i < this.disks.length; i++) {
            var disk = this.disks[i];
            if (disk.mountPoint == this.mountPoint) {
                data = [
                    { label: this.args.labels.used, value: disk.used - 0 },
                    { label: this.args.labels.available, value: (disk.size - 0) - (disk.used - 0) }
                ];
                break;
            }
        }
        d3.select(this.element)
            .datum(data)
            .transition().duration(350)
            .call(this.chart)
        ;
    }
};

