<?php
namespace Topalis\Profile\Payload;

use Topalis\Profile\Payload\Data\AirPlayPassword;

// @codingStandardsIgnoreStart
/**
 * Represents an AirPlay payload.
 * This payload configures connections to AirPlay destinations on the device.
 * @see    https://developer.apple.com/library/ios/featuredarticles/iPhoneConfigurationProfileRef/iPhoneConfigurationProfileRef.pdf#//apple_ref/doc/uid/TP40010206-CH1-SW38
 * @since  iOS 7.0
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
// @codingStandardsIgnoreEnd
class AirPlayPayload extends AbstractPayload
{
    const TYPE = "com.apple.airplay";

    /**
     * Supervised only.
     * @return array|null
     */
    public function getWhiteList()
    {
        return $this->getValue("WhiteList");
    }

    /**
     * Supervised only.
     *
     * @param AirPlayPassword[] $whiteList
     */
    public function setWhiteList(array $whiteList = null)
    {
        $this->setValue("WhiteList", $whiteList, self::TYPE_ARRAY);
    }

    public function getPasswords()
    {
        return $this->getSubTypeArray("Passwords", 'Topalis\Profile\Payload\Data\AirPlayPassword');
    }

    /**
     * @param AirPlayPassword[] $passwords
     */
    public function setPasswords(array $passwords = null)
    {
        $this->setSubTypeArray("Passwords", $passwords);
    }
}
