<?php
namespace Topalis\Profile\Payload\Android;

use Topalis\Profile\Payload\AbstractPayload;
use Topalis\Profile\Annotation\Payload\Key;

/**
 * @Key(name="Quality", type="string", default="false")
 * @Key(name="History", type="integer")
 * @Key(name="MaxFailedAttempts", type="integer")
 * @Key(name="MinLength", type="integer")
 * @Key(name="MinLetters", type="integer")
 * @Key(name="MinLowercase", type="integer")
 * @Key(name="MinNonLetter", type="integer")
 * @Key(name="MinNumeric", type="integer")
 * @Key(name="MinSymbols", type="integer")
 * @Key(name="MinUppercase", type="integer")
 * @Key(name="Timeout", type="integer")
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 *
 * @see https://developer.android.com/reference/android/app/admin/DevicePolicyManager.html
 */
class PasscodePayload extends AbstractPayload
{
    const TYPE = "de.auralis.android.passcode";

    public function setQuality($quality)
    {
        $this->setValue("Quality", $quality, self::TYPE_STRING);
    }

    public function getQuality()
    {
        return $this->getValue("Quality", false);
    }

    public function setHistory($history)
    {
        $this->setValue("History", $history, self::TYPE_INTEGER);
    }

    public function getHistory()
    {
        return $this->getValue("History");
    }

    public function setMaxFailedAttempts($maxFailedAttempts)
    {
        $this->setValue("MaxFailedAttempts", $maxFailedAttempts, self::TYPE_INTEGER);
    }

    public function getMaxFailedAttempts()
    {
        return $this->getValue("MaxFailedAttempts");
    }

    public function setMinLength($minLength)
    {
        $this->setValue("MinLength", $minLength, self::TYPE_INTEGER);
    }

    public function getMinLength()
    {
        return $this->getValue("MinLength");
    }

    public function setMinLetters($minLetters)
    {
        $this->setValue("MinLetters", $minLetters, self::TYPE_INTEGER);
    }

    public function getMinLetters()
    {
        return $this->getValue("MinLetters");
    }

    public function setMinLowercase($minLowercase)
    {
        $this->setValue("MinLowercase", $minLowercase, self::TYPE_INTEGER);
    }

    public function getMinLowercase()
    {
        return $this->getValue("MinLowercase");
    }

    public function setMinNonLetter($minNonLetter)
    {
        $this->setValue("MinNonLetter", $minNonLetter, self::TYPE_INTEGER);
    }

    public function getMinNonLetter()
    {
        return $this->getValue("MinNonLetter");
    }

    public function setMinNumeric($minNumeric)
    {
        $this->setValue("MinNumeric", $minNumeric, self::TYPE_INTEGER);
    }

    public function getMinNumeric()
    {
        return $this->getValue("MinNumeric");
    }

    public function setMinSymbols($minSymbols)
    {
        $this->setValue("MinSymbols", $minSymbols, self::TYPE_INTEGER);
    }

    public function getMinSymbols()
    {
        return $this->getValue("MinSymbols");
    }

    public function setMinUppercase($minUppercase)
    {
        $this->setValue("MinUppercase", $minUppercase, self::TYPE_INTEGER);
    }

    public function getMinUppercase()
    {
        return $this->getValue("MinUppercase");
    }

    public function setExpirationTimeout($timeout)
    {
        $this->setValue("Timeout", $timeout, self::TYPE_INTEGER);
    }

    public function getExpirationTimeout()
    {
        return $this->getValue("Timeout");
    }
}
