<?php
namespace Topalis\Profile\Payload;

// @codingStandardsIgnoreStart
/**
 * Represents a CalDAV payload.
 * This payload configures a CalDAV connection on the device.
 * @see https://developer.apple.com/library/ios/featuredarticles/iPhoneConfigurationProfileRef/iPhoneConfigurationProfileRef.pdf#//apple_ref/doc/uid/TP40010206-CH1-SW16
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
// @codingStandardsIgnoreEnd
class CalDavPayload extends AbstractPayload
{
    const TYPE = "com.apple.caldav.account";

    public function getAccountDescription()
    {
        return $this->getValue("CalDAVAccountDescription");
    }

    public function setAccountDescription($accountDescription)
    {
        $this->setValue("CalDAVAccountDescription", $accountDescription, self::TYPE_STRING);
    }

    public function getHostName()
    {
        return $this->getValue("CalDAVHostName");
    }

    public function setHostName($hostName)
    {
        $this->setValue("CalDAVHostName", $hostName, self::TYPE_STRING);
    }

    public function getUsername()
    {
        return $this->getValue("CalDAVUsername");
    }

    public function setUsername($username)
    {
        $this->setValue("CalDAVUsername", $username, self::TYPE_STRING);
    }

    public function getPassword()
    {
        return $this->getValue("CalDAVPassword");
    }

    public function setPassword($password)
    {
        $this->setValue("CalDAVPassword", $password, self::TYPE_STRING);
    }

    public function isUseSsl()
    {
        return $this->getValue("CalDAVUseSSL");
    }

    public function setUseSsl($useSsl)
    {
        $this->setValue("CalDAVUseSSL", $useSsl, self::TYPE_BOOLEAN);
    }

    public function getPort()
    {
        return $this->getValue("CalDAVPort");
    }

    public function setPort($port)
    {
        $this->setValue("CalDAVPort", $port, self::TYPE_NUMBER);
    }

    public function getPrincipalUrl()
    {
        return $this->getValue("CalDAVPrincipalURL");
    }

    public function setPrincipalUrl($principalUrl)
    {
        $this->setValue("CalDAVPrincipalURL", $principalUrl, self::TYPE_STRING);
    }
}
