<?php
namespace Topalis\Profile\Payload;

// @codingStandardsIgnoreStart
/**
 * Represents an Calendar Subscription payload.
 * This payload adds a subscribed calendar to the user's calendars list.
 * @see https://developer.apple.com/library/ios/featuredarticles/iPhoneConfigurationProfileRef/iPhoneConfigurationProfileRef.pdf#//apple_ref/doc/uid/TP40010206-CH1-SW17
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
// @codingStandardsIgnoreEnd
class CalendarSubscriptionPayload extends AbstractPayload
{
    const TYPE = "com.apple.subscribedcalendar.account";

    public function getAccountDescription()
    {
        return $this->getValue("SubCalAccountDescription");
    }

    public function setAccountDescription($accountDescription)
    {
        $this->setValue("SubCalAccountDescription", $accountDescription, self::TYPE_STRING);
    }

    public function getHostName()
    {
        return $this->getValue("SubCalAccountHostName");
    }

    public function setHostName($hostName)
    {
        $this->setValue("SubCalAccountHostName", $hostName, self::TYPE_STRING);
    }

    public function getUsername()
    {
        return $this->getValue("SubCalAccountUsername");
    }

    public function setUsername($username)
    {
        $this->setValue("SubCalAccountUsername", $username, self::TYPE_STRING);
    }

    public function getPassword()
    {
        return $this->getValue("SubCalAccountPassword");
    }

    public function setPassword($password)
    {
        $this->setValue("SubCalAccountPassword", $password, self::TYPE_STRING);
    }

    public function isUseSsl()
    {
        return $this->getValue("SubCalAccountUseSSL");
    }

    public function setUseSsl($useSsl)
    {
        $this->setValue("SubCalAccountUseSSL", $useSsl, self::TYPE_BOOLEAN);
    }
}
