<?php
namespace Topalis\Profile\Payload;

// @codingStandardsIgnoreStart
/**
 * Represents a CalDAV payload.
 * This payload configures a CardDAV connection on the device.
 * @see https://developer.apple.com/library/ios/featuredarticles/iPhoneConfigurationProfileRef/iPhoneConfigurationProfileRef.pdf#//apple_ref/doc/uid/TP40010206-CH1-SW15
 * @since MacOS X 10.8
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
// @codingStandardsIgnoreEnd
class CardDavPayload extends AbstractPayload
{
    const TYPE = "com.apple.carddav.account";

    public function getAccountDescription()
    {
        return $this->getValue("CardDAVAccountDescription");
    }

    public function setAccountDescription($accountDescription)
    {
        $this->setValue("CardDAVAccountDescription", $accountDescription, self::TYPE_STRING);
    }

    public function getHostName()
    {
        return $this->getValue("CardDAVHostName");
    }

    public function setHostName($hostName)
    {
        $this->setValue("CardDAVHostName", $hostName, self::TYPE_STRING);
    }

    public function getUsername()
    {
        return $this->getValue("CrdDAVUsername");
    }

    public function setUsername($username)
    {
        $this->setValue("CardDAVUsername", $username, self::TYPE_STRING);
    }

    public function getPassword()
    {
        return $this->getValue("CardDAVPassword");
    }

    public function setPassword($password)
    {
        $this->setValue("CardDAVPassword", $password, self::TYPE_STRING);
    }

    public function isUseSsl()
    {
        return $this->getValue("CardDAVUseSSL");
    }

    public function setUseSsl($useSsl)
    {
        $this->setValue("CardDAVUseSSL", $useSsl, self::TYPE_BOOLEAN);
    }

    public function getPort()
    {
        return $this->getValue("CardDAVPort");
    }

    public function setPort($port)
    {
        $this->setValue("CardDAVPort", $port, self::TYPE_NUMBER);
    }

    public function getPrincipalUrl()
    {
        return $this->getValue("CardDAVPrincipalURL");
    }

    public function setPrincipalUrl($principalUrl)
    {
        $this->setValue("CardDAVPrincipalURL", $principalUrl, self::TYPE_STRING);
    }
}
