<?php
namespace Topalis\Profile\Payload;

// @codingStandardsIgnoreStart
use CFPropertyList\CFBoolean;

    /**
 * Represents an Email payload.
 * This payload configures an Email account on the device.
 * @see https://developer.apple.com/library/ios/featuredarticles/iPhoneConfigurationProfileRef/iPhoneConfigurationProfileRef.pdf#//apple_ref/doc/uid/TP40010206-CH1-SW11
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
// @codingStandardsIgnoreEnd
class EmailPayload extends AbstractPayload
{
    const TYPE = "com.apple.mail.managed";

    public function getAccountDescription()
    {
        return $this->getValue("EmailAccountDescription");
    }

    public function setAccountDescription($accountDescription)
    {
        $this->setValue("EmailAccountDescription", $accountDescription, self::TYPE_STRING);
    }

    public function getAccountName()
    {
        return $this->getValue("EmailAccountName");
    }

    public function setAccountName($accountName)
    {
        $this->setValue("EmailAccountName", $accountName, self::TYPE_STRING);
    }

    public function getAddress()
    {
        return $this->getValue("EmailAddress");
    }

    public function setAddress($address)
    {
        $this->setValue("EmailAddress", $address, self::TYPE_STRING);
    }

    public function getIncomingAuthentication()
    {
        return $this->getValue("IncomingMailServerAuthentication");
    }

    public function setIncomingAuthentication($authentication)
    {
        $this->setValue("IncomingMailServerAuthentication", $authentication, self::TYPE_STRING);
    }

    public function getIncomingHostName()
    {
        return $this->getValue("IncomingMailServerHostName");
    }

    public function setIncomingHostName($hostName)
    {
        $this->setValue("IncomingMailServerHostName", $hostName, self::TYPE_STRING);
    }

    public function getIncomingPort()
    {
        return $this->getValue("IncomingMailServerPortNumber");
    }

    public function setIncomingPort($port)
    {
        $this->setValue("IncomingMailServerPortNumber", $port, self::TYPE_NUMBER);
    }

    public function isIncomingUseSsl()
    {
        return $this->getValue("IncomingMailServerUseSSL", true);
    }

    public function setIncomingUseSsl($useSsl)
    {
        $this->setValue("IncomingMailServerUseSSL", $useSsl, self::TYPE_BOOLEAN);
    }

    public function getIncomingUsername()
    {
        return $this->getValue("IncomingMailServerUsername");
    }

    public function setIncomingUsername($username)
    {
        $this->setValue("IncomingMailServerUsername", $username, self::TYPE_STRING);
    }

    public function getIncomingPassword()
    {
        return $this->getValue("IncomingPassword");
    }

    public function setIncomingPassword($password)
    {
        $this->setValue("IncomingPassword", $password, self::TYPE_STRING);
    }

    public function isOutgoingPasswordSameAsIncomingPassword()
    {
        return $this->getValue("OutgoingPasswordSameAsIncomingPassword");
    }

    public function setOutgoingPasswordSameAsIncomingPassword($same)
    {
        $this->setValue("OutgoingPasswordSameAsIncomingPassword", $same, self::TYPE_BOOLEAN);
    }

    public function getOutgoingAuthentication()
    {
        return $this->getValue("OutgoingMailServerAuthentication");
    }

    public function setOutgoingAuthentication($authentication)
    {
        $this->setValue("OutgoingMailServerAuthentication", $authentication, self::TYPE_STRING);
    }

    public function getOutgoingHostName()
    {
        return $this->getValue("OutgoingMailServerHostName");
    }

    public function setOutgoingHostName($hostName)
    {
        $this->setValue("OutgoingMailServerHostName", $hostName, self::TYPE_STRING);
    }

    public function getOutgoingPort()
    {
        return $this->getValue("OutgoingMailServerPortNumber");
    }

    public function setOutgoingPort($port)
    {
        $this->setValue("OutgoingMailServerPortNumber", $port, self::TYPE_NUMBER);
    }

    public function isOutgoingUseSsl()
    {
        return $this->getValue("OutgoingMailServerUseSSL", true);
    }

    public function setOutgoingUseSsl($useSsl)
    {
        $this->setValue("OutgoingMailServerUseSSL", $useSsl, self::TYPE_BOOLEAN);
    }

    public function getOutgoingUsername()
    {
        return $this->getValue("OutgoingMailServerUsername");
    }

    public function setOutgoingUsername($username)
    {
        $this->setValue("OutgoingMailServerUsername", $username, self::TYPE_STRING);
    }

    public function getOutgoingPassword()
    {
        return $this->getValue("OutgoingPassword");
    }

    public function setOutgoingPassword($password)
    {
        $this->setValue("OutgoingPassword", $password, self::TYPE_STRING);
    }

    public function isPreventMove()
    {
        return $this->getValue("PreventMove", false);
    }

    public function setPreventMove($preventMove)
    {
        if ($preventMove === null) {
            $this->del("PreventMove");
        } else {
            $this->set("PreventMove", new CFBoolean($preventMove));
        }
        return $this;
    }

    public function isPreventAppSheet()
    {
        return $this->getValue("PreventAppSheet", false);
    }

    public function setPreventAppSheet($preventAppSheet)
    {
        if ($preventAppSheet === null) {
            $this->del("PreventAppSheet");
        } else {
            $this->set("PreventAppSheet", new CFBoolean($preventAppSheet));
        }
        return $this;
    }

    public function isSMimeEnabled()
    {
        return $this->getValue("SMIMEEnabled", false);
    }

    public function setSMimeEnabled($smimeEnabled)
    {
        $this->setValue("SMIMEEnabled", $smimeEnabled, self::TYPE_BOOLEAN);
    }

    public function getSMimeSigningCertificateUUID()
    {
        return $this->getValue("SMIMESigningCertificateUUID");
    }

    public function setSMimeSigningCertificateUUID($smimeSigningCertificateUUID)
    {
        $this->setValue("SMIMESigningCertificateUUID", $smimeSigningCertificateUUID, self::TYPE_STRING);
    }

    public function getSMimeEncryptionCertificateUUID()
    {
        return $this->getValue("SMIMEEncryptionCertificateUUID");
    }

    public function setSMimeEncryptionCertificateUUID($smimeEncryptionCertificateUUID)
    {
        $this->setValue("SMIMEEncryptionCertificateUUID", $smimeEncryptionCertificateUUID, self::TYPE_STRING);
    }

    public function isDisableMailRecentsSyncing()
    {
        return $this->getValue("disableMailRecentsSyncing", false);
    }

    public function setDisableMailRecentsSyncing($disableMailRecentsSyncing)
    {
        $this->setValue("disableMailRecentsSyncing", $disableMailRecentsSyncing, self::TYPE_BOOLEAN);
    }
}
