<?php
namespace Topalis\Profile\Payload;

// @codingStandardsIgnoreStart
/**
 * Represents a LDAP payload.
 * This payload installs information about on LDAP server to use on the device.
 * @see https://developer.apple.com/library/ios/featuredarticles/iPhoneConfigurationProfileRef/iPhoneConfigurationProfileRef.pdf#//apple_ref/doc/uid/TP40010206-CH1-SW43
 * @since iOS 7.0
 *
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
// @codingStandardsIgnoreEnd
class LdapPayload extends AbstractPayload
{
    const TYPE = "com.apple.ldap.account";

    public function getAccountDescription()
    {
        return $this->getValue("LDAPAccountDescription");
    }

    public function setAccountDescription($accountDescription)
    {
        $this->setValue("LDAPAccountDescription", $accountDescription, self::TYPE_STRING);
    }

    public function getHostName()
    {
        return $this->getValue("LDAPAccountHostName");
    }

    public function setHostName($hostName)
    {
        $this->setValue("LDAPAccountHostName", $hostName, self::TYPE_STRING);
    }

    public function isUseSsl()
    {
        return $this->getValue("LDAPAccountUseSSL");
    }

    public function setUseSsl($useSsl)
    {
        $this->setValue("LDAPAccountUseSSL", $useSsl, self::TYPE_BOOLEAN);
    }

    public function getUsername()
    {
        return $this->getValue("LDAPAccountUserName");
    }

    public function setUsername($username)
    {
        $this->setValue("LDAPAccountUserName", $username, self::TYPE_STRING);
    }

    public function getPassword()
    {
        return $this->getValue("LDAPAccountPassword");
    }

    public function setPassword($password)
    {
        $this->setValue("LDAPAccountPassword", $password, self::TYPE_STRING);
    }

    public function getSearchSettings()
    {
        return $this->getValue("LDAPSearchSettings");
    }

    public function setSearchSettings(array $searchSettings = null)
    {
        $this->setValue("LDAPSearchSettings", $searchSettings, self::TYPE_DICTIONARY);
    }

    public function getSearchSettingDescription()
    {
        return $this->getValue("LDAPSearchSettingDescription");
    }

    public function setSearchSettingsDescription($searchSettingDescription)
    {
        $this->setValue("LDAPSearchSettingDescription", $searchSettingDescription, self::TYPE_STRING);
    }

    public function getSearchSettingSearchBase()
    {
        return $this->getValue("LDAPSearchSettingSearchBase");
    }

    public function setSearchSettingSearchBase($searchSettingSearchBase)
    {
        $this->setValue("LDAPSearchSettingSearchBase", $searchSettingSearchBase, self::TYPE_STRING);
    }

    public function getSearchSettingScope()
    {
        return $this->getValue("LDAPSearchSettingScope");
    }

    public function setSearchSettingScop($searchSettingScope)
    {
        $this->setValue("LDAPSearchSettingScope", $searchSettingScope, self::TYPE_STRING);
    }
}
