<?php
namespace Topalis\Profile\Payload;

// @codingStandardsIgnoreStart
/**
 * This class represents a Profile Removal Password payload.
 * If it is part of a profile the device asks for the password if the user wants
 * to remove the profile.
 * @see https://developer.apple.com/library/ios/featuredarticles/iPhoneConfigurationProfileRef/iPhoneConfigurationProfileRef.pdf#//apple_ref/doc/uid/TP40010206-CH1-SW13
 *
 * @author Florian Pfitzer <florian.pfitzer@topalis.com>
 * @author Dominic Tubach <dominic.tubach@topalis.com>
 */
// @codingStandardsIgnoreEnd
class RestrictionsPayload extends AbstractPayload
{
    const TYPE = "com.apple.applicationaccess";

    public function setAllowAppInstallation($allowAppInstallation)
    {
        $this->setValue("allowAppInstallation", $allowAppInstallation, self::TYPE_BOOLEAN);
    }

    public function isAllowAppInstallation()
    {
        return $this->getValue("allowAppInstallation", true);
    }

    public function setAllowCamera($allowCamera)
    {
        $this->setValue("allowCamera", $allowCamera, self::TYPE_BOOLEAN);
    }

    public function isAllowCamera()
    {
        return $this->getValue("allowCamera", true);
    }

    public function setAllowScreenShot($allowScreenShot)
    {
        $this->setValue("allowScreenShot", $allowScreenShot, self::TYPE_BOOLEAN);
    }

    public function isAllowScreenShot()
    {
        return $this->getValue("allowScreenShot", true);
    }

    public function setAllowPhotoStream($allowPhotoStream)
    {
        $this->setValue("allowPhotoStream", $allowPhotoStream, self::TYPE_BOOLEAN);
    }

    public function isAllowPhotoStream()
    {
        return $this->getValue("allowPhotoStream", true);
    }

    public function setAllowPassbookWhileLocked($allowPassbookWhileLocked)
    {
        $this->setValue("allowPassbookWhileLocked", $allowPassbookWhileLocked, self::TYPE_BOOLEAN);
    }

    public function isAllowPassbookWhileLocked()
    {
        return $this->getValue("allowPassbookWhileLocked", true);
    }

    public function setAllowSharedStream($allowSharedStream)
    {
        $this->setValue("allowSharedStream", $allowSharedStream, self::TYPE_BOOLEAN);
    }

    public function isAllowSharedStream()
    {
        return $this->getValue("allowSharedStream", true);
    }

    public function setAllowAssistant($allowAssistant)
    {
        $this->setValue("allowAssistant", $allowAssistant, self::TYPE_BOOLEAN);
    }

    public function isAllowAssistant()
    {
        return $this->getValue("allowAssistant", true);
    }

    public function setAllowAssistantWhileLocked($allowAssistantWhileLocked)
    {
        $this->setValue("allowAssistantWhileLocked", $allowAssistantWhileLocked, self::TYPE_BOOLEAN);
    }

    public function isAllowAssistantWhileLocked()
    {
        return $this->getValue("allowAssistantWhileLocked", true);
    }

    public function setAllowCloudBackup($allowCloudBackup)
    {
        $this->setValue("allowCloudBackup", $allowCloudBackup, self::TYPE_BOOLEAN);
    }

    public function isAllowCloudBackup()
    {
        return $this->getValue("allowCloudBackup", true);
    }

    public function setAllowCloudDocumentSync($allowCloudDocumentSync)
    {
        $this->setValue("allowCloudDocumentSync", $allowCloudDocumentSync, self::TYPE_BOOLEAN);
    }

    public function isAllowCloudDocumentSync()
    {
        return $this->getValue("allowCloudDocumentSync", true);
    }

    public function setAllowDiagnosticSubmission($allowDiagnosticSubmission)
    {
        $this->setValue("allowDiagnosticSubmission", $allowDiagnosticSubmission, self::TYPE_BOOLEAN);
    }

    public function isAllowDiagnosticSubmission()
    {
        return $this->getValue("allowDiagnosticSubmission", true);
    }

    public function setAllowGlobalBackgroundFetchWhenRoaming($allowGlobalBackgroundFetchWhenRoaming)
    {
        $this->setValue("allowGlobalBackgroundFetchWhenRoaming",
            $allowGlobalBackgroundFetchWhenRoaming, self::TYPE_BOOLEAN);
    }

    public function isAllowGlobalBackgroundFetchWhenRoaming()
    {
        return $this->getValue("allowGlobalBackgroundFetchWhenRoaming", true);
    }

    public function setAllowInAppPurchases($allowInAppPurchases)
    {
        $this->setValue("allowInAppPurchases", $allowInAppPurchases, self::TYPE_BOOLEAN);
    }

    public function isAllowInAppPurchases()
    {
        return $this->getValue("allowInAppPurchases", true);
    }

    public function setAllowLockScreenControlCenter($allowLockScreenControlCenter)
    {
        $this->setValue("allowLockScreenControlCenter", $allowLockScreenControlCenter, self::TYPE_BOOLEAN);
    }

    public function isAllowLockScreenControlCenter()
    {
        return $this->getValue("allowLockScreenControlCenter", true);
    }

    public function setAllowLockScreenNotificationsView($allowLockScreenNotificationsView)
    {
        $this->setValue("allowLockScreenNotificationsView", $allowLockScreenNotificationsView, self::TYPE_BOOLEAN);
    }

    public function isAllowLockScreenNotificationsView()
    {
        return $this->getValue("allowLockScreenNotificationsView", true);
    }

    public function setAllowLockScreenTodayView($allowLockScreenTodayView)
    {
        $this->setValue("allowLockScreenTodayView", $allowLockScreenTodayView, self::TYPE_BOOLEAN);
    }

    public function isAllowLockScreenTodayView()
    {
        return $this->getValue("allowLockScreenTodayView", true);
    }

    public function setAllowOTAPKIUpdates($allowOTAPKIUpdates)
    {
        $this->setValue("allowOTAPKIUpdates", $allowOTAPKIUpdates, self::TYPE_BOOLEAN);
    }

    public function isAllowOTAPKIUpdates()
    {
        return $this->getValue("allowOTAPKIUpdates", true);
    }

    public function setAllowOpenFromManagedToUnmanaged($allowOpenFromManagedToUnmanaged)
    {
        $this->setValue("allowOpenFromManagedToUnmanaged", $allowOpenFromManagedToUnmanaged, self::TYPE_BOOLEAN);
    }

    public function isAllowOpenFromManagedToUnmanaged()
    {
        return $this->getValue("allowOpenFromManagedToUnmanaged", true);
    }

    public function setAllowOpenFromUnmanagedToManaged($allowOpenFromUnmanagedToManaged)
    {
        $this->setValue("allowOpenFromUnmanagedToManaged", $allowOpenFromUnmanagedToManaged, self::TYPE_BOOLEAN);
    }

    public function isAllowOpenFromUnmanagedToManaged()
    {
        return $this->getValue("allowOpenFromUnmanagedToManaged", true);
    }

    public function setAllowSafari($allowSafari)
    {
        $this->setValue("allowSafari", $allowSafari, self::TYPE_BOOLEAN);
    }

    public function isAllowSafari()
    {
        return $this->getValue("allowSafari", true);
    }

    public function setAllowUntrustedTLSPrompt($allowUntrustedTLSPrompt)
    {
        $this->setValue("allowUntrustedTLSPrompt", $allowUntrustedTLSPrompt, self::TYPE_BOOLEAN);
    }

    public function isAllowUntrustedTLSPrompt()
    {
        return $this->getValue("allowUntrustedTLSPrompt", true);
    }

    public function setAllowVoiceDialing($allowVoiceDialing)
    {
        $this->setValue("allowVoiceDialing", $allowVoiceDialing, self::TYPE_BOOLEAN);
    }

    public function isAllowVoiceDialing()
    {
        return $this->getValue("allowVoiceDialing", true);
    }

    public function setAllowYouTube($allowYouTube)
    {
        $this->setValue("allowYouTube", $allowYouTube, self::TYPE_BOOLEAN);
    }

    public function isAllowYouTube()
    {
        return $this->getValue("allowYouTube", true);
    }

    public function setAllowiTunes($allowiTunes)
    {
        $this->setValue("allowiTunes", $allowiTunes, self::TYPE_BOOLEAN);
    }

    public function isAllowiTunes()
    {
        return $this->getValue("allowiTunes", true);
    }

    public function setForceEncryptedBackup($forceEncryptedBackup)
    {
        $this->setValue("forceEncryptedBackup", $forceEncryptedBackup, self::TYPE_BOOLEAN);
    }

    public function isForceEncryptedBackup()
    {
        return $this->getValue("forceEncryptedBackup", false);
    }

    public function setForceITunesStorePasswordEntry($forceITunesStorePasswordEntry)
    {
        $this->setValue("forceITunesStorePasswordEntry", $forceITunesStorePasswordEntry, self::TYPE_BOOLEAN);
    }

    public function isForceITunesStorePasswordEntry()
    {
        return $this->getValue("forceITunesStorePasswordEntry", false);
    }

    public function setForceLimitAdTracking($forceLimitAdTracking)
    {
        $this->setValue("forceLimitAdTracking", $forceLimitAdTracking, self::TYPE_BOOLEAN);
    }

    public function isForceLimitAdTracking()
    {
        return $this->getValue("forceLimitAdTracking", true);
    }
}
